<?php
/**
 * Smart by NiceThemes.
 *
 * This file includes hooks to manage color settings in the admin-facing side
 * of the theme.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://www.nicethemes.com/theme-page
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_admin_color_dropdown_styles' ) ) :
add_filter( 'nice_admin_inline_styles', 'nice_admin_color_dropdown_styles' );
/**
 * Add Styles for the colors dropdown within the admin section.
 *
 * @since 1.0.0
 *
 * @param string $admin_inline_styles
 *
 * @return string
 */
function nice_admin_color_dropdown_styles( $admin_inline_styles ) {
	$nice_colors = nice_theme_colors();

	if ( ! empty( $nice_colors ) ) {
		$output = '';

		foreach ( $nice_colors as $color ) {
			$background_color = $color['value'];
			$text_color       = nice_contrast_color( $background_color );

			$output .= '.nice-select-color .' . $color['id'] . ' { background-color: ' . $background_color . '; color: ' . $text_color . '; }' . "\n";
		}

		$admin_inline_styles .= $output;
	}

	return $admin_inline_styles;
}
endif;

if ( ! function_exists( 'nice_admin_color_list_item_styles' ) ) :
add_filter( 'nice_admin_inline_styles', 'nice_admin_color_list_item_styles' );
/**
 * Add Styles for the list item colors within the admin section.
 *
 * @since 1.0.0
 *
 * @param string $admin_inline_styles
 *
 * @return string
 */
function nice_admin_color_list_item_styles( $admin_inline_styles ) {
	$nice_colors = nice_theme_colors();

	if ( ! empty( $nice_colors ) ) {
		$output = '';

		foreach ( $nice_colors as $color ) {
			$background_color = $color['value'];
			$text_color       = nice_contrast_color( $background_color );

			$output .= '.nice-framework-admin-ui-list-item .' . $color['id'] . ' { background-color: ' . $background_color . '; color: ' . $text_color . '; }' . "\n";
		}

		$admin_inline_styles .= $output;
	}

	return $admin_inline_styles;
}
endif;
