<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles the theme demo packs.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_theme_demo_packs_remote_data_url' ) ) :
add_filter( 'nice_demo_packs_remote_data_url', 'nice_theme_demo_packs_remote_data_url', 10, 2 );
/**
 * Make sure the demo packs are obtained from the correct URL.
 *
 * @since  1.0.1
 *
 * @param  string                   $url
 * @param  Nice_Admin_System_Status $system_status
 *
 * @return string
 */
function nice_theme_demo_packs_remote_data_url( $url, $system_status ) {
	if ( version_compare( NICE_FRAMEWORK_VERSION, '2.0.4', '<' ) ) {
		$url = $system_status->get_demo_packs_remote_url() . '/smart/demo-packs.json';
	}

	return $url;
}
endif;

if ( ! function_exists( 'nice_theme_register_demo_packs' ) ) :
add_filter( 'nice_theme_demo_packs', 'nice_theme_register_demo_packs' );
/**
 * Obtain a list of demo packs from remote and local sources.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_theme_register_demo_packs() {
	static $demo_packs = null;

	if ( is_null( $demo_packs ) ) {
		$system_status = nice_admin_system_status();

		$demo_packs = $system_status->get_nice_theme_demo_packs();
	}

	return $demo_packs;
}
endif;


if ( ! function_exists( 'nice_theme_demo_pack_random_importing_messages' ) ) :
add_filter( 'nice_theme_demo_pack_random_importing_messages', 'nice_theme_demo_pack_random_importing_messages' );
/**
 * Add random importing messages to the demo pack installer.
 *
 * @since 1.0.0
 *
 * @param array $random_importing_messages
 *
 * @return array
 */
function nice_theme_demo_pack_random_importing_messages( $random_importing_messages ) {
	$system_status = nice_admin_system_status();

	$added_messages = array(
		esc_attr__( 'Thank you for choosing NiceThemes.', 'smart' ),
		sprintf( esc_attr__( 'Enjoying %s? Let us know what you think!', 'smart' ), $system_status->get_nice_theme_name() ),
		esc_attr__( 'We want you to have the best experience. Please let us help you if something behaves unexpectedly.', 'smart' ),
		esc_attr__( 'What great things are you doing today?', 'smart' ),
		esc_html__( 'It\'s a beautiful day to create, isn\'t it?', 'smart' ),
	);

	// Make sure HTML entities are correctly decoded.
	foreach ( $added_messages as $k => $v ) {
		$val = html_entity_decode( $v, ENT_QUOTES | ENT_XML1, 'UTF-8' );
		$added_messages[ $k ] = $val;
	}

	$random_importing_messages = array_merge( $random_importing_messages, $added_messages );

	return $random_importing_messages;
}
endif;
