<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage custom styles for admin post editor.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_add_editor_styles' ) ) :
add_action( 'after_setup_theme', 'nice_add_editor_styles' );
/**
 * Add editor styles for this theme.
 *
 * {@link http://codex.wordpress.org/Function_Reference/add_editor_style}
 *
 * @since 1.0.0
 */
function nice_add_editor_styles() {
	$web_fonts_uri = nice_get_web_fonts_uri();

	if ( ! $web_fonts_uri  ) {
		return;
	}

	// Add basic styles.
	add_editor_style( 'editor-style.css' );
	add_editor_style( str_replace( ',', '%2C', $web_fonts_uri ) );
}
endif;

if ( ! function_exists( 'nice_add_editor_custom_styles' ) ) :
add_action( 'after_wp_tiny_mce', 'nice_add_editor_custom_styles' );
/**
 * Make sure custom styles are correctly applied to TinyMCE editor.
 *
 * We use jQuery to wait for the document to be ready, and then we rely on a
 * little timeout to ensure TinyMCE is completely loaded before applying styles
 * to the content iframe. We do it via jQuery since iframes can't be efficiently
 * modified via linked or inline CSS.
 *
 * This function is pretty hacky, since neither WordPress nor TinyMCE offer
 * a simple way to apply styles dynamically to a TinyMCE box at the time.
 * Maybe in the future we could come up with a more elegant way to achieve this.
 *
 * {@link http://codex.wordpress.org/TinyMCE}
 *
 * @since 1.0.0
 */
function nice_add_editor_custom_styles() {
	$use_custom_typography = nice_bool( nice_get_option( 'nice_custom_typography' ) );
	$font_body = nice_get_option( 'nice_font_body' );

	if ( $use_custom_typography && ! empty( $font_body ) ) : ?>
		<script>
			function nice_apply_editor_custom_styles( $ ) {
				setTimeout( function () {
					var tinymce = $( 'iframe#content_ifr' ).contents().find( '#tinymce' );
					<?php if ( isset( $font_body['color'] ) && ! empty( $font_body['color'] ) ) : ?>
					tinymce.css( 'color', '<?php echo esc_js( $font_body['color'] ); ?>' );
					<?php endif;?>
					<?php if ( isset( $font_body['family'] ) && ! empty( $font_body['family'] ) ) : ?>
					tinymce.css( 'font-family', '<?php echo esc_js( $font_body['family'] ); ?>' );
					<?php endif;?>
					<?php if ( isset( $font_body['style'] ) && ! empty( $font_body['style'] ) ) : ?>
					tinymce.css( 'font-style', '<?php echo esc_js( $font_body['style'] ); ?>' );
					<?php endif;?>
					<?php if ( isset( $font_body['size'] ) && ! empty( $font_body['size'] ) ) : ?>
					tinymce.css( 'font-size', '<?php echo esc_js( $font_body['size'] ); ?>' );
					<?php endif;?>
				}, 1 )
			}
			jQuery( document ).ready( function() {
				nice_apply_editor_custom_styles( jQuery );
			} );
			jQuery( '#content-tmce' ).click( function() {
				nice_apply_editor_custom_styles( jQuery );
			} );
		</script>
	<?php endif;
}
endif;
