<?php
/**
 * Smart by NiceThemes.
 *
 * This file includes functions to interact with the TGMPA class
 * https://github.com/TGMPA/TGM-Plugin-Activation
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_theme_register_plugins' ) ) :
add_filter( 'nice_theme_plugins', 'nice_theme_register_plugins' );
/**
 * Define the required and recommended plugins for the theme.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_theme_register_plugins() {
	$system_status = nice_admin_system_status();

	$plugins = array(
		array(
			'name'         => esc_html__( 'Nice Portfolio', 'smart' ),
			'slug'         => 'nice-portfolio',
			'description'  => esc_html__( 'A great portfolio plugin to show your work to the world in a clean, responsive and beautiful way. You can show your projects in a specific page, using a shortcode, widgets or template tags.', 'smart' ),
			'external_url' => 'http://nicethemes.com/product/nice-portfolio/',
			'author_name'  => 'NiceThemes',
			'author_url'   => 'http://nicethemes.com/',
			'required'     => false,
			'menu_order'   => 10,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/nice-portfolio/screenshot.jpg',
		),
		array(
			'name'         => esc_html__( 'WooCommerce', 'smart' ),
			'slug'         => 'woocommerce',
			'description'  => esc_html__( 'An e-commerce toolkit that helps you sell anything. Beautifully.', 'smart' ),
			'external_url' => 'https://woothemes.com/woocommerce/',
			'author_name'  => 'WooThemes',
			'author_url'   => 'http://woothemes.com/',
			'required'     => false,
			'menu_order'   => 20,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/woocommerce/screenshot.jpg',
		),
		array(
			'name'         => esc_html__( 'WPBakery Visual Composer', 'smart' ),
			'slug'         => 'js_composer',
			'description'  => esc_html__( 'Drag and drop page builder for WordPress. Take full control over your WordPress site, build any layout you can imagine - no programming knowledge required.', 'smart' ),
			'external_url' => 'https://vc.wpbakery.com/',
			'author_name'  => 'Michael M - WPBakery.com',
			'author_url'   => 'http://wpbakery.com/',
			'required'     => false,
			'menu_order'   => 30,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/visual-composer/screenshot.jpg',
			'source'       => 'https://' . $system_status->get_aws_s3_bucket_updates() . '.' . $system_status->get_aws_s3_endpoint() . '/js_composer.zip',
		),
		array(
			'name'         => esc_html__( 'Slider Revolution', 'smart' ),
			'slug'         => 'revslider',
			'description'  => esc_html__( 'Slider Revolution - Premium responsive slider', 'smart' ),
			'external_url' => 'http://revolution.themepunch.com/',
			'author_name'  => 'ThemePunch',
			'author_url'   => 'http://themepunch.com/',
			'required'     => false,
			'menu_order'   => 35,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/slider-revolution/screenshot.jpg',
			'source'       => 'https://' . $system_status->get_aws_s3_bucket_updates() . '.' . $system_status->get_aws_s3_endpoint() . '/revslider.zip',
		),
		array(
			'name'         => esc_html__( 'Nice Likes', 'smart' ),
			'slug'         => 'nice-likes',
			'description'  => esc_html__( 'Add "liking" functionality to your posts, pages and custom post types on your WordPress site.', 'smart' ),
			'external_url' => 'http://nicethemes.com/product/nice-likes/',
			'author_name'  => 'NiceThemes',
			'author_url'   => 'http://nicethemes.com/',
			'required'     => false,
			'menu_order'   => 40,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/nice-likes/screenshot.jpg',
		),
		array(
			'name'         => esc_html__( 'Nice Testimonials', 'smart' ),
			'slug'         => 'nice-testimonials',
			'description'  => esc_html__( 'Show testimonials from your customers in your WordPress site in a beautiful and organized way.', 'smart' ),
			'external_url' => 'http://nicethemes.com/product/nice-testimonials/',
			'author_name'  => 'NiceThemes',
			'author_url'   => 'http://nicethemes.com/',
			'required'     => false,
			'menu_order'   => 50,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/nice-testimonials/screenshot.jpg',
		),
		array(
			'name'         => esc_html__( 'Nice Team', 'smart' ),
			'slug'         => 'nice-team',
			'description'  => esc_html__( 'A great plugin to display team member profiles on your WordPress site.', 'smart' ),
			'external_url' => 'http://nicethemes.com/product/nice-team/',
			'author_name'  => 'NiceThemes',
			'author_url'   => 'http://nicethemes.com/',
			'required'     => false,
			'menu_order'   => 60,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/nice-team/screenshot.jpg',
		),
		array(
			'name'         => esc_html__( 'Nice Infoboxes', 'smart' ),
			'slug'         => 'nice-infoboxes',
			'description'  => esc_html__( 'Show any kind of information in a beautiful and organized way.', 'smart' ),
			'external_url' => 'http://nicethemes.com/product/nice-infoboxes/',
			'author_name'  => 'NiceThemes',
			'author_url'   => 'http://nicethemes.com/',
			'required'     => false,
			'menu_order'   => 70,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/nice-infoboxes/screenshot.jpg',
		),
		array(
			'name'         => esc_html__( 'Contact Form 7', 'smart' ),
			'slug'         => 'contact-form-7',
			'description'  => esc_html__( 'Just another contact form plugin. Simple but flexible.', 'smart' ),
			'external_url' => 'https://wordpress.org/plugins/contact-form-7/',
			'author_name'  => 'Takayuki Miyoshi',
			'author_url'   => 'http://ideasilo.wordpress.com/',
			'required'     => false,
			'menu_order'   => 80,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/contact-form-7/screenshot.jpg',
		),
		array(
			'name'         => esc_html__( 'YITH WooCommerce Order Tracking', 'smart' ),
			'slug'         => 'yith-woocommerce-order-tracking',
			'description'  => esc_html__( 'Add an easy tool to manage order shipping information of your shop and to notify your customers about the shipping.', 'smart' ),
			'external_url' => 'https://wordpress.org/plugins/yith-woocommerce-order-tracking/',
			'author_name'  => 'YITHEMES',
			'author_url'   => 'https://yithemes.com/',
			'required'     => false,
			'menu_order'   => 90,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/woocommerce/ywot-screenshot.jpg',
		),
		array(
			'name'         => esc_html__( 'YITH WooCommerce Wishlist', 'smart' ),
			'slug'         => 'yith-woocommerce-wishlist',
			'description'  => esc_html__( 'Add all Wishlist features to your website.', 'smart' ),
			'external_url' => 'https://wordpress.org/plugins/yith-woocommerce-wishlist/',
			'author_name'  => 'YITHEMES',
			'author_url'   => 'https://yithemes.com/',
			'required'     => false,
			'menu_order'   => 90,
			'image_url'    => NICE_TPL_DIR . '/includes/plugin-integrations/woocommerce/yww-screenshot.jpg',
		),
	);

	return $plugins;
}
endif;


if ( ! function_exists( 'nice_theme_plugin_activated_visual_composer' ) ) :
add_action( 'nice_tgmpa_plugin_activated_js_composer', 'nice_theme_plugin_activated_visual_composer' );
/**
 * Special actions to be executed when Visual Composer is activated.
 *
 * @since 1.0.0
 */
function nice_theme_plugin_activated_visual_composer() {
	// Disable welcome redirect.
	delete_transient( '_vc_page_welcome_redirect' );
}
endif;
