<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to handle AJAX requests.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

// Return early if not in AJAX context.
if ( ! nice_doing_ajax() ) {
	return;
}

if ( ! function_exists( 'nice_masonry_blog_ajax' ) ) :
add_action( 'wp_ajax_nopriv_nice_more_posts_loader', 'nice_masonry_blog_ajax' );
add_action( 'wp_ajax_nice_more_posts_loader', 'nice_masonry_blog_ajax' );
/**
 * AJAX function for the masonry blog.
 *
 * @since 1.0.0
 */
function nice_masonry_blog_ajax() {
	// Return early if we're not in an AJAX context.
	if ( ! nice_doing_ajax() ) {
		return;
	}

	check_ajax_referer( 'play-nice', 'nonce' );

	if ( ! empty( $_POST ) ) {
		$page = ( isset( $_POST['pageNumber'] ) ) ? intval( $_POST['pageNumber'] ) : 0;

		$query_args = array(
			'post_status'    => 'publish',
			'posts_per_page' => get_option( 'posts_per_page' ),
			'paged'          => $page,
		);

		// The Query.
		$query = new WP_Query( $query_args );

		// The Loop.
		if ( $query->have_posts() ) :
			/**
			 * Initialize Masonry Loop.
			 */
			nice_masonry_loop_init();

			while ( $query->have_posts() ) :
				/**
				 * Iterate Masonry Loop.
				 */
				nice_masonry_loop_add();

				$query->the_post();

				/**
				 * Load template for Masonry blog posts.
				 */
				get_template_part( 'template-parts/archive/content-masonry', get_post_format() );

			endwhile;
		else : ?>
			<div class="no-more-posts">
				<span><?php esc_html_e( 'No More Posts Found.', 'smart' ); ?></span>
			</div>
		<?php endif;

		// Restore original Post Data.
		wp_reset_postdata();
	}

	die(); // Needed to return a proper result.
}
endif;
