var NiceContactMap = ( function( $ ) {
	'use strict';

	/**
	 * Check if the module has already been initialized.
	 *
	 * @type {boolean}
	 */
	var fired = false,

	/**
	 * Window width breakpoint for mobile viewports.
	 *
	 * @type {number}
	 */
	breakpoint = 1024,

	/**
     * Prevent scrolling on Google map unless focus is set by clicking it.
     *
     * @since 1.0.0
     */
	handleContactMap = function() {
		var $container = $( '.nice-contact-map-container' ),
		    $map       = $( '#nice-contact-map' );

	    /**
	     * Set height of map for desktop viewports.
	     *
	     * @param event
	     * @param headerHeight
	     * @private
	     */
	    var _setDesktopHeight = function( event, headerHeight ) {
		    var mapHeight = $map.height();

		    var _setMapHeight = function() {
			    if ( $( window ).width() >= breakpoint ) {
				    $map.css( { 'height': headerHeight + mapHeight } );
			    }
		    };

		    $( window ).resize( _setMapHeight );

		    _setMapHeight();
	    };

	    /**
	     * Set height of map for mobile viewports.
	     *
	     * @private
	     */
	    var _setMobileHeight = function() {
		    var mapHeight = $map.height();

		    var _setMapHeight = function() {
			    if ( $( window ).width() < breakpoint ) {
				    $map.css( { 'height': mapHeight } );
			    }
		    };

		    $( window ).resize( _setMapHeight );

		    _setMapHeight();
	    };

	    /**
	     * Disallow scrolling over map.
	     *
	     * @private
	     */
	    var _disallowScroll = function() {
		    $map.addClass ( 'scrolloff' );
	    };

	    /**
	     * Allow scrolling over map.
	     *
	     * @private
	     */
	    var _allowScroll = function() {
		    $map.removeClass( 'scrolloff' );
	    };

	    // Schedule map resizing when header heights are set.
		$( '#header' )
			.bind( 'setDesktopHeight', _setDesktopHeight )
			.bind( 'setMobileHeight', _setMobileHeight );

	    // Schedule actions on mouse events.
		$container
			.on( 'mouseup', _disallowScroll )
			.on( 'mousedown', _allowScroll );

		$map.on( 'mouseleave', _disallowScroll );

	    // Disallow scroll on page load.
	    $( document ).ready( _disallowScroll );
	},

	/**
	 * Initialize contact map functionality.
	 */
	init = function() {
		if ( fired ) {
			return;
		}

		$( handleContactMap );

		fired = true;
	};

	return {
		init: init
	};

} )( jQuery );

NiceContactMap.init();
