/**
 * NiceDev.
 *
 * Development and debug helper.
 *
 * @since   1.0.0
 * @package Smart
 */
var NiceDev = ( function( $ ) {
	// Tell browsers we're not doing anything silly.
	'use strict';

	/**
	 * Check if the module has been initialized.
	 *
	 * @type {boolean}
	 */
	var fired = false,

	/**
	 * Monitor all events on an given element.
	 *
	 * @since 1.0.3
	 *
	 * @param element
	 */
	monitor = function( element ) {
		var events = [];

		for ( var i in element ) {
			i.startsWith( 'on' ) && events.push( i.substr( 2 ) );
		}

		events.forEach( function( eventName ) {
			element.addEventListener( eventName, logEvent );
		} );
	},

	/**
	 * Stop monitoring events on an given element.
	 *
	 * @since 1.0.3
	 *
	 * @param element
	 */
	unmonitor = function( element ) {
		var events = [];

		for ( var i in element ) {
			i.startsWith( 'on' ) && events.push( i.substr( 2 ) );
		}

		events.forEach( function( eventName ) {
			element.removeEventListener( eventName, logEvent );
		} );
	},

	/**
	 * Log events to the console.
	 *
	 * @since 1.0.3
	 *
	 * @param event
	 */
	logEvent = function( event ) {
		window.console.log( event );
	},

	/**
	 * Log a message to the console.
	 *
	 * @param message
	 */
	logMessage = function( message ) {
		window.generalData.devMode && window.console.log( '[NiceDevLog]', message );
		return true;
	},

	/**
	 * Extend jQuery functionality.
	 *
	 * @since 1.0.0
	 */
	extendLib = function() {
		/**
		 * NiceDev
		 *
		 * Development and debugging helper.
		 *
		 * @since 1.0.0
		 */
		// Setup development tool.
		$.NiceDev = {
			log: logMessage,
			monitor: monitor,
			unmonitor: unmonitor,
		};
	},

	/**
	 * Initialize helpers
	 *
	 * @since 1.0.0
	 */
	init = function() {
		if ( fired ) {
			return;
		}

		// Make jQuery available using "$".
		if ( window.generalData.devMode && 'undefined' === typeof window.$ ) {
			window.$ = jQuery;
		}

		extendLib();

		fired = true;
	};

	// Expose the ready function to the world.
	return {
		init: init
	};

} )( jQuery );

NiceDev.init();
