/**
 * Smart by NiceThemes.
 *
 * Manage tabs widget.
 *
 * @since   1.0.0
 * @package Smart
 */
var NiceTabsWidget = ( function( $ ) {
	// Tell browsers we're not doing anything silly.
	'use strict';

	/**
	 * Manage class assignations.
	 *
	 * @since 1.0.0
	 */
	var addClass = function() {
		$( 'ul.nice-tabs' ).each( function() {
			$( this ).children( 'li' ).children( 'a:first' ).addClass( 'active' );
		} );
	},

	/**
	 * Dynamically show and hide elements.
	 *
	 * @since 1.0.0
	 */
	toggle = function() {
		$( '.inside > *' ).hide();
		$( '.inside > *:first-child' ).show();
	},

	/**
	 * Mark tab as active when clicked.
	 *
	 * @since 1.0.0
	 */
	activateTab = function() {
		$( 'ul.nice-tabs li a' ).click( function( event ) {
			event.preventDefault();
			$( this ).parent().siblings().children( 'a' ).removeClass( 'active' );
			$( this ).addClass( 'active' );
			$( this ).parent().parent().parent().children( '.inside' ).children( '*' ).hide();
			$( '.inside ' + $( this ).attr( 'href' ) ).fadeIn( 800 );

			$( document ).trigger( 'NiceDOMChanged' );
		} );
	},

	/**
	 * Add an extra class to the tabs container for responsiveness.
	 *
	 * @since 1.0.0
	 */
	toggleResponsiveClass = function() {
		toggleResponsiveClassFunctionality();

		$( window ).resize( function() {
			toggleResponsiveClassFunctionality();
		} );
	},

	/**
	 * Process responsive class management depending on available and used size.
	 *
	 * @since 1.0.0
	 */
	toggleResponsiveClassFunctionality = function() {
		// Capture all tab containers.
		var tabs = $( 'ul.nice-tabs' );

		// Iterate over tab container.
		tabs.each( function() {
			var available = $( this ).width(),          // Available space.
			    used      = 0,                          // Used space (initial).
			    items     = $( this ).children( 'li' ); // Tabs inside container.

			// Calculate actual space used by tabs.
			items.each( function() {
				used = used + $( this ).width();
			} );

			// Set a breakpoint where to add and remove responsive class.
			var breakpoint = $( this ).data( 'limit' ) ? $( this ).data( 'limit' ) : used;

			// Add or remove responsive class.
			if ( ( ( used + 1 ) >= available ) && ( ( $( this ).width() - 1 ) <= breakpoint ) ) {
				$( this ).parent().addClass( 'responsive' );

				// Set limit as object data, so we can obtain it in a different iteration.
				if ( ! $( this ).data( 'limit' ) ) {
					$( this ).data( 'limit', breakpoint );
				}
			} else {
				$( this ).parent().removeClass( 'responsive' );
			}
		} );
	},

	/**
	 * Fire events on document ready, and bind other events.
	 *
	 * @since 1.0.0
	 */
	ready = function() {
		$( document ).ready( function() {
			addClass();
			toggle();
			activateTab();
			toggleResponsiveClass();
		} );
	};

	// Expose the ready function to the world.
	return {
		ready: ready
	};

} )( jQuery );

NiceTabsWidget.ready();
