<?php
/**
 * Smart by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://www.nicethemes.com/theme-page
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_theme_colors_option' ) ) :
/**
 * Obtain theme colors option.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_theme_colors_option() {
	$prefix = NICE_PREFIX;

	return $prefix . '_colors';
}
endif;

if ( ! function_exists( 'nice_theme_default_colors' ) ) :
/**
 * Build the default array of colors.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_theme_default_colors() {
	$nice_default_colors = array(
		array(
			'name' => esc_html__( 'Accent Color', 'smart' ),
			'id'   => 'nice_accent_color',
			'std'  => array(
				'default' => '#5b799c',
			),
		),
		array(
			'name' => esc_html__( 'Complementary Color', 'smart' ),
			'id'   => 'nice_complementary_color',
			'std'  => array(
				'default' => '#50dfc2',
			),
		),
		array(
			'name' => esc_html__( 'Black', 'smart' ),
			'id'   => 'nice_black_color',
			'std'  => array(
				'default' => '#222',
			),
		),
		array(
			'name' => esc_html__( 'Dark 1', 'smart' ),
			'id'   => 'nice_dark_color_1',
			'std'  => array(
				'default' => '#333',
			),
		),
		array(
			'name' => esc_html__( 'Dark 2', 'smart' ),
			'id'   => 'nice_dark_color_2',
			'std'  => array(
				'default' => '#454545',
			),
		),
		array(
			'name' => esc_html__( 'Dark 3', 'smart' ),
			'id'   => 'nice_dark_color_3',
			'std'  => array(
				'default' => '#686868',
			),
		),
		array(
			'name' => esc_html__( 'White', 'smart' ),
			'id'   => 'nice_white_color',
			'std'  => array(
				'default' => '#fff',
			),
		),
		array(
			'name' => esc_html__( 'Light 1', 'smart' ),
			'id'   => 'nice_light_color_1',
			'std'  => array(
				'default' => '#eee',
			),
		),
		array(
			'name' => esc_html__( 'Light 2', 'smart' ),
			'id'   => 'nice_light_color_2',
			'std'  => array(
				'default' => '#ddd',
			),
		),
		array(
			'name' => esc_html__( 'Light 3', 'smart' ),
			'id'   => 'nice_light_color_3',
			'std'  => array(
				'default' => '#bbb',
			),
		),
		array(
			'name' => esc_html__( 'Red', 'smart' ),
			'id'   => 'nice_red_color',
			'std'  => array(
				'default' => '#fe595e',
			),
		),
		array(
			'name' => esc_html__( 'Orange', 'smart' ),
			'id'   => 'nice_orange_color',
			'std'  => array(
				'default' => '#ff7b00',
			),
		),
		array(
			'name' => esc_html__( 'Yellow', 'smart' ),
			'id'   => 'nice_yellow_color',
			'std'  => array(
				'default' => '#ecdf54',
			),
		),
		array(
			'name' => esc_html__( 'Green', 'smart' ),
			'id'   => 'nice_green_color',
			'std'  => array(
				'default' => '#2ebd59',
			),
		),
		array(
			'name' => esc_html__( 'Blue', 'smart' ),
			'id'   => 'nice_blue_color',
			'std'  => array(
				'default' => '#4978b3',
			),
		),
		array(
			'name' => esc_html__( 'Indigo', 'smart' ),
			'id'   => 'nice_indigo_color',
			'std'  => array(
				'default' => '#4B0082',
			),
		),
		array(
			'name' => esc_html__( 'Purple', 'smart' ),
			'id'   => 'nice_purple_color',
			'std'  => array(
				'default' => '#b9a6e4',
			),
		),
		array(
			'name' => esc_html__( 'Cyan', 'smart' ),
			'id'   => 'nice_cyan_color',
			'std'  => array(
				'default' => '#008B8B',
			),
		),
		array(
			'name' => esc_html__( 'Magenta', 'smart' ),
			'id'   => 'nice_magenta_color',
			'std'  => array(
				'default' => '#FF00FF',
			),
		),
		array(
			'name' => esc_html__( 'Pink', 'smart' ),
			'id'   => 'nice_pink_color',
			'std'  => array(
				'default' => '#fcbbb6',
			),
		),
		array(
			'name' => esc_html__( 'Brown', 'smart' ),
			'id'   => 'nice_brown_color',
			'std'  => array(
				'default' => '#b39964',
			),
		),
	);

	/**
	 * @hook nice_theme_default_colors
	 *
	 * Hook here to change the default colors.
	 *
	 * @since 1.0.0
	 */
	return apply_filters( 'nice_theme_default_colors', $nice_default_colors );
}
endif;

if ( ! function_exists( 'nice_theme_colors' ) ) :
/**
 * Obtain theme colors.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_theme_colors() {
	static $colors = null;

	if ( is_null( $colors ) ) {
		$colors = array();

		$prefix        = NICE_PREFIX;
		$colors_option = $prefix . '_colors';

		$nice_colors = nice_get_option( $colors_option );

		// Double check for colors.
		if ( empty( $nice_colors ) ) {
			$default_colors = nice_theme_default_colors();

			if ( ! empty( $default_colors ) ) {
				foreach ( $default_colors as $default_color ) {
					$nice_colors[ $default_color['id'] ] = $default_color['name'];
				}
			}
		}

		if ( ! empty( $nice_colors ) ) {
			foreach ( $nice_colors as $color_id => $color_name ) {
				$colors[ $color_id ] = array(
					'name'   => $color_name,
					'id'     => $color_id,
					'css_id' => str_replace( '_', '-', str_replace( 'nice_', '', $color_id ) ),
					'option' => $color_id,
					'value'  => nice_get_option( $color_id ),
				);
			}
		}

		/**
		 * @hook nice_theme_colors
		 *
		 * Hook here to change the colors.
		 *
		 * @since 1.0.0
		 */
		$colors = apply_filters( 'nice_theme_colors', $colors );
	}

	return $colors;
}
endif;

if ( ! function_exists( 'nice_theme_color_name' ) ) :
/**
 * Obtain the name of a color. Returns false if the color does not exist.
 *
 * @since  1.0.0
 *
 * @param string $color_id
 *
 * @return bool|string
 */
function nice_theme_color_name( $color_id ) {
	$nice_colors = nice_theme_colors();

	if ( ! empty( $nice_colors[ $color_id ]['name'] ) ) {
		return $nice_colors[ $color_id ]['name'];
	}

	return false;
}
endif;

if ( ! function_exists( 'nice_theme_color_css_id' ) ) :
/**
 * Obtain the CSS ID of a color. Returns false if the color does not exist.
 *
 * @since  1.0.0
 *
 * @param string $color_id
 *
 * @return bool|string
 */
function nice_theme_color_css_id( $color_id ) {
	$nice_colors = nice_theme_colors();

	if ( ! empty( $nice_colors[ $color_id ]['css_id'] ) ) {
		return $nice_colors[ $color_id ]['css_id'];
	}

	return false;
}
endif;

if ( ! function_exists( 'nice_theme_color_option' ) ) :
/**
 * Obtain the option of a color. Returns false if the color does not exist.
 *
 * @since  1.0.0
 *
 * @param string $color_id
 *
 * @return bool|string
 */
function nice_theme_color_option( $color_id ) {
	$nice_colors = nice_theme_colors();

	if ( ! empty( $nice_colors[ $color_id ]['option'] ) ) {
		return $nice_colors[ $color_id ]['option'];
	}

	return false;
}
endif;

if ( ! function_exists( 'nice_theme_color_value' ) ) :
/**
 * Obtain the value of a color. Returns false if the color does not exist.
 *
 * @since  1.0.0
 *
 * @param string $color_id
 *
 * @return bool|string
 */
function nice_theme_color_value( $color_id ) {
	$nice_colors = nice_theme_colors();

	if ( ! empty( $nice_colors[ $color_id ]['value'] ) ) {
		return $nice_colors[ $color_id ]['value'];
	}

	return false;
}
endif;

if ( ! function_exists( 'nice_theme_colors_dropdown_values' ) ) :
/**
 * Return an array of the theme colors to use in the dropdown values.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_theme_colors_dropdown_values() {
	$nice_colors = nice_theme_colors();

	$colors = array();
	$colors[''] = array(
		'name'  => esc_html__( 'Default', 'smart' ),
		'value' => '',
	);

	if ( ! empty( $nice_colors ) ) {
		foreach ( $nice_colors as $color ) {
			$colors[ $color['id'] ] = array(
				'name'  => $color['name'],
				'value' => $color['value'],
			);
		}
	}

	return $colors;
}
endif;

if ( ! function_exists( 'nice_customizer_selectable_colors_styles' ) ) :
add_filter( 'nice_customizer_styles', 'nice_customizer_selectable_colors_styles' );
/**
 * Add styles for selectable colors in Customizer view.
 *
 * @since 1.1
 *
 * @param  string $styles
 *
 * @return string
 */
function nice_customizer_selectable_colors_styles( $styles = '' ) {
	$nice_colors = nice_theme_colors();

	foreach ( $nice_colors as $color ) {
		$styles .= '[data-value="' . esc_attr( $color['id'] ) . '"]:before { background-color: ' . esc_attr( $color['value'] ) . '; }' . "\n";
	}

	return $styles;
}
endif;
