<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the default theme settings.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.1
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_theme_default_settings' ) ) :
add_filter( 'nice_default_settings', 'nice_theme_default_settings' );
/**
 * Define and return default values for theme settings.
 *
 * @param  array $settings
 *
 * @return array
 */
function nice_theme_default_settings( $settings = array() ) {
	$theme_settings = array(
		// Design & Styles
		'favicon'                     => '',
		'content_skin'                => 'light',
		'layout_type'                 => 'full',
		'background_color'            => '',
		'background_image'            => '',
		'background_image_repeat'     => 'repeat',
		'background_image_position'   => 'left top',
		'background_image_attachment' => 'scroll',
		'site_content_width'          => '',
		'site_content_width_value'    => '',
		'sidebar_position'            => is_rtl() ? 'left' : 'right',

		// Design & Styles > Colors
		'colors' => nice_theme_default_colors(),

		// Design & Styles > Blog & Posts
		'masonry_posts_load_method' => 'on_scroll',
		'masonry_posts_loader_icon' => 'beat',

		// Design & Styles > Buttons
		'btn_shape' => '',
		'btn_color' => '',

		// Design & Styles > Images
		'image_not_available' => '',

		// Design & Styles > Page Loader
		'page_loader'                            => 'top_bar',
		'page_loader_color'                      => '',
		'page_loader_full_page_background_color' => '',
		'page_loader_full_page_loader_icon'      => 'spin',
		'page_loader_full_page_loader_color'     => '',
		'google_map'                             => '',

		// Header > Layout
		'header_navigation'                    => 'default',
		'header_top_navigation_alignment'      => 'navigation-right',
		'header_full_width'                    => false,
		'header_vertical_width'                => array(
			'range' => 'min',
			'value' => '225',
			'min'   => '200',
			'max'   => '400',
			'unit'  => 'px',
		),
		'header_vertical_hidden'               => false,
		'header_vertical_align'                => 'top',
		'header_vertical_logo_top'             => false,
		'header_vertical_justify'              => is_rtl() ? 'right' : 'left',
		'header_vertical_content_width'        => 'full-width',
		'header_vertical_content_custom_width' => array(
			'range' => 'min',
			'value' => '1440',
			'min'   => '400',
			'max'   => '1680',
			'unit'  => 'px',
		),

		// Header > Design
		'header_skin'                             => 'light',
		'header_background_color'                 => '',
		'header_background_color_dark'            => '',
		'header_background_image'                 => '',
		'header_background_image_repeat'          => 'repeat',
		'header_background_image_position'        => 'left top',
		'header_background_transparent'           => false,
		'header_background_transparent_mobile'    => false,
		'header_background_transparent_skin'      => 'dark',
		'header_overlay_skin'                     => 'dark',
		'header_overlay_background_color'         => '',
		'header_border'                           => false,
		'header_shadow'                           => false,
		'header_overlay_background_color_opacity' => array(
			'range' => 'min',
			'value' => '0.8',
			'min'   => '0',
			'max'   => '1',
			'step'  => '0.01',
		),
		'header_overlay_accent_color'             => '#ffffff',

		// Header > Logo
		'text_title'                     => false,
		'font_site_title'                => array(
			'font-size'   => '30',
			'unit'        => 'px',
			'font-family' => 'Poppins',
			'font-style'  => '',
		),
		'text_tagline'                   => false,
		'font_tagline'                   => array(
			'font-size'   => '18',
			'unit'        => 'px',
			'font-family' => 'Open Sans',
			'font-style'  => '',
		),
		'logo'                           => '',
		'logo_retina'                    => '',
		'logo_dark'                      => '',
		'logo_dark_retina'               => '',
		'hide_logo'                      => '',
		'hide_logo_mobile'               => '',
		'logo_height'                    => array(
			'range' => 'min',
			'value' => '28',
			'min'   => '10',
			'max'   => '400',
			'unit'  => 'px',
		),
		'logo_padding'                   => array(
			'range' => 'min',
			'value' => '40',
			'min'   => '0',
			'max'   => '90',
			'unit'  => 'px',
		),
		'logo_padding_top'               => array(
			'range' => 'min',
			'value' => '40',
			'min'   => '0',
			'max'   => '90',
			'unit'  => 'px',
		),
		'logo_padding_bottom'            => array(
			'range' => 'min',
			'value' => '10',
			'min'   => '0',
			'max'   => '90',
			'unit'  => 'px',
		),
		'logo_padding_remove_horizontal' => false,
		'logo_mobile'                    => '',
		'logo_mobile_retina'             => '',
		'logo_mobile_dark'               => '',
		'logo_mobile_dark_retina'        => '',
		'logo_mobile_custom_settings'    => false,
		'logo_mobile_height'             => array(
			'range' => 'min',
			'value' => '28',
			'min'   => '10',
			'max'   => '400',
			'unit'  => 'px',
		),
		'logo_mobile_padding'            => array(
			'range' => 'min',
			'value' => '40',
			'min'   => '0',
			'max'   => '90',
			'unit'  => 'px',
		),

		// Header > Animation
		'header_fixed'                        => true,
		'header_fixed_mobile'                 => false,
		'header_fixed_hide_logo'              => false,
		'header_shrink'                       => true,
		'header_transition_duration'          => array(
			'range' => 'min',
			'value' => '250',
			'min'   => '0',
			'max'   => '1000',
		),
		'header_hide_until_scroll'            => false,
		'header_hide_until_scroll_breakpoint' => array(
			'range' => 'min',
			'value' => '85',
			'min'   => '1',
			'max'   => '900',
			'unit'  => 'px',
		),
		'header_autohide'                     => true,

		// Header > Navigation Menu
		'header_submenu_skin'         => 'dark',
		'header_menu_uppercase'       => false,
		'header_submenu_uppercase'    => false,
		'header_menu_hide_arrows'     => false,
		'header_menu_remove_border'   => false,
		'header_menu_hide_separators' => false,
		'top_bar'                     => false,
		'top_bar_padding'             => array(
			'range' => 'min',
			'value' => '10',
			'min'   => '0',
			'max'   => '90',
			'unit'  => 'px',
		),
		'top_bar_fixed'               => false,
		'top_bar_background_color'    => '',
		'top_bar_skin'                => 'dark',
		'top_bar_content_left'        => '',
		'top_bar_content_right'       => '',

		// Header > Extras
		'header_display_search' => '0',
		'header_display_social' => '0',

		// Title Bar > Layout
		'heading_height'      => '',
		'heading_height_min'  => '',
		'heading_alignment'   => is_rtl() ? 'right' : 'left',
		'heading_alignment_v' => 'middle',


		// Page Title > Design
		'heading_background_color'          => '',
		'heading_skin'                      => 'dark',
		'heading_text_transform'            => 'default',
		'heading_font_weight'               => 'default',
		'heading_font_size'                 => 'h1',
		'heading_background_image'          => '',
		'heading_background_image_parallax' => false,
		'heading_background_repeat'         => 'no-repeat',
		'heading_background_position'       => 'center top',
		'heading_background_size'           => 'auto',
		'heading_background_attachment'     => 'scroll',

		// Footer > Layout
		'footer_full_width'  => false,
		'footer_skin'        => 'dark',
		'footer_transparent' => false,

		// Footer > Widgets
		'footer_columns' => array(
			'range' => 'min',
			'value' => '3',
			'min'   => '2',
			'max'   => '4',
		),

		// Footer > Extended
		'custom_copyright_enable' => false,
		'custom_copyright_text'   => '',
		'footer_display_social'   => '0',

		// Footer > Back To Top
		'back_to_top'                  => '1',
		'back_to_top_style'            => '',
		'back_to_top_shape'            => '',
		'back_to_top_background_color' => '',

		// Layout > Posts > Header
		'post_header'                               => true,
		'post_navigation_menu'                      => '',
		'post_navigation_style'                     => '',
		'post_header_background_transparent'        => '',
		'post_header_background_transparent_mobile' => '',
		'post_header_skin'                          => '',
		'post_header_background_color'              => '',
		'post_navigation_submenu_skin'              => '',
		'post_header_width'                         => '',
		'post_header_width_value'                   => '',
		'post_header_display_search'                => '',
		'post_header_display_social'                => '',

		// Layout > Posts > Title Bar
		'post_heading'                     => true,
		'post_title_heading'               => true,
		'post_categories_heading'          => false,
		'post_categories_heading_color'    => '',
		'post_categories_heading_shape'    => '',
		'post_categories_heading_style'    => '',
		'post_title_alignment'             => '',
		'post_title_alignment_v'           => '',
		'post_title_width'                 => '',
		'post_title_width_value'           => '',
		'post_title_height'                => '',
		'post_title_height_min'            => '',
		'post_title_text_transform'        => '',
		'post_title_font_weight'           => '',
		'post_title_font_size'             => '',
		'post_heading_skin'                => '',
		'post_background_image'            => '',
		'post_background_image_parallax'   => '',
		'post_background_repeat'           => '',
		'post_background_position'         => '',
		'post_background_size'             => '',
		'post_background_attachment'       => '',
		'post_background_color'            => '',
		'post_scroll_down_arrow'           => false,
		'post_title_content'               => false,
		'post_thumbnail_content'           => false,
		'post_content_skin'                => '',
		'post_content_width'               => '',
		'post_content_width_value'         => '',
		'post_author'                      => true,
		'post_navigation_skin'             => 'light',
		'post_navigation_background_color' => '',

		// Layout > Posts > Sidebar
		'post_sidebar'          => false,
		'post_sidebar_id'       => '',
		'post_sidebar_position' => '',

		// Layout > Posts > Footer
		'post_footer'                => true,
		'post_footer_skin'           => '',
		'post_footer_widgets'        => true,
		'post_footer_extended'       => true,
		'post_footer_display_social' => '',
		'post_footer_width'          => '',
		'post_footer_width_value'    => '',

		// Layout > Pages > Header
		'page_header'                               => true,
		'page_navigation_menu'                      => '',
		'page_navigation_style'                     => '',
		'page_header_background_transparent'        => '',
		'page_header_background_transparent_mobile' => '',
		'page_header_skin'                          => '',
		'page_header_background_color'              => '',
		'page_navigation_submenu_skin'              => '',
		'page_header_width'                         => '',
		'page_header_width_value'                   => '',
		'page_header_display_search'                => '',
		'page_header_display_social'                => '',

		// Layout > Pages > Title Bar
		'page_heading'                   => true,
		'page_title_heading'             => true,
		'page_subtitle'                  => '',
		'page_title_alignment'           => '',
		'page_title_alignment_v'         => '',
		'page_title_width'               => '',
		'page_title_width_value'         => '',
		'page_title_height'              => '',
		'page_title_height_min'          => '',
		'page_title_text_transform'      => '',
		'page_title_font_weight'         => '',
		'page_title_font_size'           => '',
		'page_heading_skin'              => '',
		'page_background_image'          => '',
		'page_background_image_parallax' => '',
		'page_background_repeat'         => '',
		'page_background_position'       => '',
		'page_background_size'           => '',
		'page_background_attachment'     => '',
		'page_background_color'          => '',
		'page_scroll_down_arrow'         => false,

		// Layout > Pages > Content
		'page_content_skin'        => '',
		'page_title_content'       => false,
		'page_content_width'       => '',
		'page_content_width_value' => '',

		// Layout > Pages > Sidebar
		'page_sidebar'          => false,
		'page_sidebar_position' => '',

		// Layout > Pages > Footer
		'page_footer'                => true,
		'page_footer_skin'           => '',
		'page_footer_widgets'        => true,
		'page_footer_extended'       => true,
		'page_footer_display_social' => '',
		'page_footer_width'          => '',
		'page_footer_width_value'    => '',

		// Customize > General
		'html_background_color' => '',

		// Customize > Light Skin
		'light_skin_background_color'                 => '',
		'light_skin_text_color'                       => '',
		'light_skin_link_color'                       => '',
		'light_skin_heading_color'                    => '',
		'light_skin_nav_text_color'                   => '',
		'light_skin_subnav_text_color'                => '',
		'light_skin_subnav_background_color'          => '',
		'light_skin_footer_background_color'          => '',
		'light_skin_footer_extended_background_color' => '',

		// Customize > Dark Skin
		'dark_skin_background_color'                 => '',
		'dark_skin_text_color'                       => '',
		'dark_skin_link_color'                       => '',
		'dark_skin_heading_color'                    => '',
		'dark_skin_nav_text_color'                   => '',
		'dark_skin_subnav_text_color'                => '',
		'dark_skin_subnav_background_color'          => '',
		'dark_skin_footer_background_color'          => '',
		'dark_skin_footer_extended_background_color' => '',

		// Customize > Navigation
		'menu_hover_effect'    => '',
		'menu_highlight_color' => '',

		// Customize > Custom Code & Scripts
		'custom_css'    => '',
		'custom_js'     => '',
		'tracking_code' => '',

		// Customize > Admin
		'admin_bar_menu' => '1',

		// Typography > Custom Fonts
		'custom_typography' => false,
		'font_body'         => array(
			'font-size'   => '14',
			'unit'        => 'px',
			'font-family' => 'Open Sans',
			'font-style'  => '',
		),
		'font_menu'         => array(
			'font-size'   => '13',
			'unit'        => 'px',
			'font-family' => 'Poppins',
			'font-style'  => '',
		),
		'font_submenu'      => array(
			'font-size'   => '13',
			'unit'        => 'px',
			'font-family' => 'Open Sans',
			'font-style'  => '',
		),
		'font_top_bar'      => array(
			'font-size'   => '13',
			'unit'        => 'px',
			'font-family' => 'Open Sans',
			'font-style'  => '',
		),
		'font_overlay_menu' => array( 'font-family' => 'Open Sans' ),
		'font_headings'     => array(
			'font-family'         => 'Poppins',
			'font-style'          => 'normal',
			'letter-spacing'      => '0',
			'letter-spacing-unit' => 'px',
		),
		'font_buttons'      => array(
			'font-family'         => 'Poppins',
			'font-style'          => 'normal',
			'letter-spacing'      => '',
			'letter-spacing-unit' => 'px',
		),
		'font_secondary'    => array(
			'font-family' => 'Poppins',
			'font-style'  => 'normal',
		),

		// Typography > Font Sizes
		'heading_h1' => '',
		'heading_h2' => '',
		'heading_h3' => '',
		'heading_h4' => '',
		'heading_h5' => '',
		'heading_h6' => '',


		// Social Media.
		'social_links_new_tab' => true,
		'social_links'         => nice_theme_default_social_links(),

		// Home
		'homepage_elements'                         => nice_options_homepage_default_elements(),
		'homepage_content'                          => false,
		'homepage_content_title'                    => '',
		'homepage_content_description'              => '',
		'homepage_content_background_image'         => '',
		'homepage_content_background_color'         => '',
		'homepage_content_background_color_opacity' => array(
			'range' => 'min',
			'value' => '1',
			'min'   => '0',
			'max'   => '1',
			'step'  => '0.01',
		),
		 'homepage_content_text_skin'               => '',

		 // Performance > Images
		'jpeg_quality'         => array(
			'range' => 'min',
			'value' => '90',
			'min'   => '40',
			'max'   => '100',
			'unit'  => '%',
		),
		'lazyload_images'      => true,
		'lazyload_images_logo' => false,

		 // Performance > CSS
		'async_styles' => false,
		'async_google_fonts' => false,

		// Performance > JavaScript
		'load_js_on_demand' => true,
		'load_minified_js'  => true,

		// Performance > Advanced
		'development_mode' => false,
	);

	return array_merge( $settings, $theme_settings );
}
endif;
