<?php
/**
 * Smart by NiceThemes.
 *
 * Load plugin-integrations and dependencies.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_load_navigation' ) ) :
add_action( 'nice_load', 'nice_load_navigation' );
/**
 * Load navigation-related classes.
 *
 * @since 1.0.0.
 */
function nice_load_navigation() {
	nice_loader( 'includes/nav-menus/' );
}
endif;

if ( ! function_exists( 'nice_load_public_functions' ) ) :
add_action( 'nice_load', 'nice_load_public_functions' );
/**
 * Load public functions in `includes/public/` folder.
 *
 * @since 1.0.3
 */
function nice_load_public_functions() {
	if ( is_admin() && ! nice_doing_ajax() && ! nice_is_mixed_content() ) {
		return;
	}

	nice_loader( 'includes/public/' );
}
endif;

if ( ! function_exists( 'nice_load_theming' ) ) :
add_action( 'nice_load', 'nice_load_theming' );
/**
 * Load theming functions.
 *
 * @since 1.0.0.
 */
function nice_load_theming() {
	if ( is_admin() && ! nice_doing_ajax() && ! nice_is_mixed_content() ) {
		return;
	}

	nice_loader( 'includes/public/theming/' );
}
endif;

if ( ! function_exists( 'nice_load_shortcodes' ) ) :
add_action( 'nice_load', 'nice_load_shortcodes' );
/**
 * Load shortcode-related functions.
 *
 * @since 1.0.0.
 */
function nice_load_shortcodes() {
	if ( is_admin() && ! nice_is_mixed_content() ) {
		return;
	}

	nice_loader( 'includes/public/shortcodes/' );
}
endif;

if ( ! function_exists( 'nice_load_woocommerce' ) ) :
add_action( 'nice_load', 'nice_load_woocommerce' );
/**
 * Load WooCommerce Compatibility.
 *
 * @since 1.0.0
 */
function nice_load_woocommerce() {
	// Check if WooCommerce is active and load integration.
	if ( ! class_exists( 'WooCommerce' ) ) {
		return;
	}

	$context = is_admin() ? 'admin' : 'public';

	// Load main files.
	nice_loader( 'includes/plugin-integrations/woocommerce/' );

	// Load context files.
	nice_loader( 'includes/plugin-integrations/woocommerce/' . $context . '/' );

	if ( nice_doing_ajax() ) {
		nice_loader( 'includes/plugin-integrations/woocommerce/public/' );
	}

	// Load integrations with other plugins.
	nice_loader( 'includes/plugin-integrations/woocommerce/integrations/' );
}
endif;

if ( ! function_exists( 'nice_load_visual_composer' ) ) :
add_action( 'nice_load', 'nice_load_visual_composer' );
/**
 * Load Visual Composer integration.
 *
 * @since 1.0.0
 */
function nice_load_visual_composer() {
	// Return early if Visual Composer is not active.
	if ( ! class_exists( 'Vc_Manager' ) ) {
		return;
	}

	$context = is_admin() ? 'admin' : 'public';

	// Load configuration files.
	nice_loader( 'includes/plugin-integrations/visual-composer/' );

	// Load classes.
	nice_loader( 'includes/plugin-integrations/visual-composer/classes/' );

	// Load components.
	nice_loader( 'includes/plugin-integrations/visual-composer/components/' );

	// Load helper hooks and functions.
	nice_loader( 'includes/plugin-integrations/visual-composer/includes/' );
	nice_loader( 'includes/plugin-integrations/visual-composer/includes/' . $context . '/' );

	if ( 'admin' === $context && nice_is_mixed_content() ) {
		nice_loader( 'includes/plugin-integrations/visual-composer/includes/public/' );
	}

	// Load integrations with other plugins.
	nice_loader( 'includes/plugin-integrations/visual-composer/integrations/' );

	/**
	 * @hook nice_vc_integration_loaded
	 *
	 * Do something after Visual Composer integration files have been loaded.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_vc_integration_loaded' );
}
endif;

if ( ! function_exists( 'nice_load_slider_revolution' ) ) :
add_action( 'nice_load', 'nice_load_slider_revolution' );
/**
 * Load Slider Revolution integration.
 *
 * @since 1.0.0
 */
function nice_load_slider_revolution() {
	// Check if Slider Revolution is active and load integration.
	if ( class_exists( 'RevSliderBase' ) ) {
		// Load configuration files.
		nice_loader( 'includes/plugin-integrations/slider-revolution/' );

		/**
		 * @hook nice_sr_integration_loaded
		 *
		 * Do something after Slider Revolution integration files have been loaded.
		 *
		 * @since 1.0.0
		 */
		do_action( 'nice_sr_integration_loaded' );
	}
}
endif;

if ( ! function_exists( 'nice_load_likes' ) ) :
add_action( 'nice_load', 'nice_load_likes' );
/**
 * Load Likes integration.
 *
 * @since 1.0.0
 */
function nice_load_likes() {
	// Check if Likes is active and load integration.
	if ( ! class_exists( 'Nice_Likes_Plugin' ) ) {
		return;
	}

	$settings = nice_likes_settings();

	// Don't load integration if Likes are not enabled.
	if ( empty( $settings['enable'] ) ) {
		return;
	}

	$context = is_admin() ? 'admin' : 'public';

	nice_loader( 'includes/plugin-integrations/nice-likes/' . $context . '/' );

	if ( 'admin' === $context && nice_doing_ajax() ) {
		nice_loader( 'includes/plugin-integrations/nice-likes/public/' );
	}
}
endif;

if ( ! function_exists( 'nice_load_testimonials' ) ) :
add_action( 'nice_load', 'nice_load_testimonials' );
/**
 * Load Testimonials integration.
 *
 * @since 1.0.0
 */
function nice_load_testimonials() {
	// Check if Testimonials is active and load integration.
	if ( ! class_exists( 'Nice_Testimonials_Plugin' ) ) {
		return;
	}

	$context = is_admin() ? 'admin' : 'public';

	nice_loader( 'includes/plugin-integrations/nice-testimonials/' );
	nice_loader( 'includes/plugin-integrations/nice-testimonials/' . $context . '/' );
}
endif;

if ( ! function_exists( 'nice_load_infoboxes' ) ) :
add_action( 'nice_load', 'nice_load_infoboxes' );
/**
 * Load Infoboxes integration.
 *
 * @since 1.0.0
 */
function nice_load_infoboxes() {
	if ( ! class_exists( 'Nice_Infoboxes_Plugin' ) ) {
		return;
	}

	$context = is_admin() ? 'admin' : 'public';

	nice_loader( 'includes/plugin-integrations/nice-infoboxes/' );
	nice_loader( 'includes/plugin-integrations/nice-infoboxes/' . $context . '/' );
}
endif;

if ( ! function_exists( 'nice_load_team' ) ) :
add_action( 'nice_load', 'nice_load_team' );
/**
 * Load Team integration.
 *
 * @since 1.0.0
 */
function nice_load_team() {
	if ( ! class_exists( 'Nice_Team_Plugin' ) ) {
		return;
	}

	$context = is_admin() ? 'admin' : 'public';

	nice_loader( 'includes/plugin-integrations/nice-team/' );
	nice_loader( 'includes/plugin-integrations/nice-team/' . $context . '/' );
}
endif;

if ( ! function_exists( 'nice_load_portfolio' ) ) :
add_action( 'nice_load', 'nice_load_portfolio' );
/**
 * Load Portfolio integration.
 *
 * @since 1.0.0
 */
function nice_load_portfolio() {
	if ( ! class_exists( 'Nice_Portfolio_Plugin' ) ) {
		return;
	}

	$context = is_admin() ? 'admin' : 'public';

	nice_loader( 'includes/plugin-integrations/nice-portfolio/' );
	nice_loader( 'includes/plugin-integrations/nice-portfolio/' . $context . '/' );
}
endif;

if ( ! function_exists( 'nice_load_widgets' ) ) :
add_action( 'nice_load', 'nice_load_widgets' );
/**
 * Load Theme Widgets.
 *
 * @since 1.0.0
 */
function nice_load_widgets() {
	// Include the widgets inside the widgets folder.
	nice_loader( 'includes/widgets/' );
}
endif;

if ( ! function_exists( 'nice_load_post_formats' ) ) :
add_action( 'nice_load', 'nice_load_post_formats' );
/**
 * Load custom integration for supported post formats.
 *
 * @since 1.0.0
 */
function nice_load_post_formats() {
	nice_loader( 'includes/post-formats/' );
}
endif;

if ( ! function_exists( 'nice_load_post_types' ) ) :
add_action( 'nice_load', 'nice_load_post_types' );
/**
 * Load custom integration for supported post types.
 *
 * @since 1.0.0
 */
function nice_load_post_types() {
	nice_loader( 'includes/post-types/page/' );
	nice_loader( 'includes/post-types/post/' );
	nice_loader( 'includes/post-types/slide/' );
}
endif;

if ( ! function_exists( 'nice_load_template_functions' ) ) :
add_action( 'nice_load', 'nice_load_template_functions' );
/**
 * Load custom integration for template functions.
 *
 * @since 1.0.0
 */
function nice_load_template_functions() {
	if ( is_admin() && ! nice_doing_ajax() ) {
		return;
	}

	nice_loader( 'includes/public/template-functions/' );
}
endif;

if ( ! function_exists( 'nice_load_homepage' ) ) :
add_action( 'nice_load', 'nice_load_homepage' );
/**
 * Load custom integration for the homepage template.
 *
 * @since 1.0.0
 */
function nice_load_homepage() {
	if ( is_admin() || nice_is_homepage() ) {
		return;
	}

	nice_loader( 'includes/public/template-functions/home/' );
}
endif;

if ( ! function_exists( 'nice_load_admin_functions' ) ) :
add_action( 'nice_load', 'nice_load_admin_functions' );
/**
 * Load admin functions in `includes/admin/` folder.
 *
 * @since 1.0.0
 */
function nice_load_admin_functions() {
	if ( ! is_admin() || ! current_user_can( 'manage_options' ) ) {
		return;
	}

	nice_loader( 'includes/admin/' );
}
endif;

if ( ! function_exists( 'nice_yoast_seo_link_watcher_compat' ) ) :
add_action( 'after_setup_theme', 'nice_yoast_seo_link_watcher_compat', -999 );
/**
 * Implement compatibility with Yoast SEO's Link Watcher.
 *
 * @since 1.1
 */
function nice_yoast_seo_link_watcher_compat() {
	global $pagenow;

	static $loaded = false;

	if ( ! class_exists( 'WPSEO_Link_Watcher' ) ) {
		return;
	}

	if ( ! is_admin() ) {
		return;
	}

	if ( 'post.php' !== $pagenow ) {
		return;
	}

	if ( empty( $_POST['action'] ) || ! wp_unslash( $_POST['action'] ) ) { // WPCS: CSRF ok
		return;
	}

	if ( $loaded ) {
		return;
	}

	// Set content as mixed during load.
	add_filter( 'nice_is_mixed_content', '__return_true' );

	// Fire all functions hooked to `nice_load` again.
	did_action( 'nice_load' ) && do_action( 'nice_load' );

	$loaded = true;
}
endif;

/**
 * @hook nice_load
 *
 * Load plugin-integrations and dependencies here, allowing child themes and
 * plugins to hook in.
 *
 * @since 1.0.0
 */
do_action( 'nice_load' );
