<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to implement theme options.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_options' ) ) :
add_action( 'after_setup_theme', 'nice_options', -9999 );
/**
 * Set up theme options.
 *
 * @since 1.0.0
 */
function nice_options() {
	global $wp_version;

	$prefix = NICE_PREFIX;

	$nice_options = array();

	/**
	 * Design & Styles
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Design & Styles', 'smart' ),
		'type' => 'heading',
		'icon' => '<i class="bi_setting-wrench"></i>',
	);

	/**
	 * Design & Styles > General
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'General', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_music-eq-a"></i>',
	);

	// Make favicon setting available only WP version is < 4.3.
	if ( version_compare( $wp_version, '4.3', '<' ) ) {
		$nice_options[] = array(
			'name'  => esc_html__( 'Favicon', 'smart' ),
			'desc'  => esc_html__( 'Upload a favicon.', 'smart' ),
			'id'    => $prefix . '_favicon',
			'std'   => nice_default_setting( 'favicon' ),
			'type'  => 'upload',
			'extra' => array( 'type' => 'image' ),
		);
	}

	$nice_options[] = array(
		'name'    => esc_html__( 'Content Skin', 'smart' ),
		'desc'    => esc_html__( 'Select the general content skin.', 'smart' ),
		'id'      => $prefix . '_content_skin',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'content_skin' ),
		'tip'     => '',
		'options' => array(
			'light' => array(
				'label' => esc_html__( 'Light', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-light.png' ),
			),
			'dark'  => array(
				'label' => esc_html__( 'Dark', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-dark.png' ),
			),
		),
	);

	/**
	 * Design & Styles > Colors
	 */

	$nice_options[] = array(
		'name'              => esc_html__( 'Colors', 'smart' ),
		'type'              => 'group',
		'id'                => $prefix . '_palette',
		'icon'              => '<i class="bi_tool-paint-roler"></i>',
		'ignore_customizer' => true,
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Color Palette', 'smart' ),
		'desc'              => esc_html__( 'Define all the colors you will need.', 'smart' ),
		'id'                => $prefix . '_colors',
		'user_item_prefix'  => $prefix . '_user_color',
		'type'              => 'list_item',
		'std'               => nice_default_setting( 'colors' ),
		'tip'               => '',
		'sortable'          => true,
		'editable'          => true,
		'edit_defaults'     => false,
		'ignore_customizer' => true,
		'option_name_label' => esc_html__( 'Color name', 'smart' ),
		'settings'          => array(
			array(
				'name'      => esc_html__( 'Color', 'smart' ),
				'desc'      => esc_html__( 'Choose the color. You can also adjust its opacity.', 'smart' ),
				'id'        => 'default',
				'type'      => 'color',
				'class'     => 'nice-color-opacity',
				'std'       => '',
				'tip'       => '',
			),
		),
	);

	/**
	 * Design & Styles > Images
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Images', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_media-image-d"></i>',
	);

	$nice_options[] = array(
		'name'  => esc_html__( '"Image Not Available" placeholder', 'smart' ),
		'desc'  => esc_html__( 'Upload an image to show as a placeholder when featured images are not available.', 'smart' ),
		'id'    => $prefix . '_image_not_available',
		'std'   => nice_default_setting( 'image_not_available' ),
		'type'  => 'upload',
		'extra' => array( 'type' => 'image' ),
	);

	/**
	 * Design & Styles > Page Loader
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Page Loader', 'smart' ),
		'type' => 'group',
		'id'   => $prefix . '_loader',
		'icon' => '<i class="bi_music-repeat"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Select the Page Loader', 'smart' ),
		'desc'    => esc_html__( 'Select the page loader for your website.', 'smart' ),
		'id'      => $prefix . '_page_loader',
		'type'    => 'select',
		'std'     => nice_default_setting( 'page_loader' ),
		'tip'     => '',
		'options' => array(
			''          => esc_html__( 'None', 'smart' ),
			'top_bar'   => esc_html__( 'Top Bar', 'smart' ),
			'full_page' => esc_html__( 'Full Page Overlay', 'smart' ),
		),
		'extra'   => array(
			'type' => 'radio-buttonset',
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Page Loader Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the page loader color.', 'smart' ),
		'id'        => $prefix . '_page_loader_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'page_loader_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_page_loader:is(top_bar)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Page Loader Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the page loader background color.', 'smart' ),
		'id'        => $prefix . '_page_loader_full_page_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'page_loader_full_page_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_page_loader:is(full_page)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Page Loader Icon', 'smart' ),
		'desc'      => esc_html__( 'Choose the page loader icon.', 'smart' ),
		'id'        => $prefix . '_page_loader_full_page_loader_icon',
		'type'      => 'select',
		'std'       => nice_default_setting( 'page_loader_full_page_loader_icon' ),
		'options'   => array(
			'spin' => esc_html__( 'Spin', 'smart' ),
			'beat' => esc_html__( 'Beat', 'smart' ),
		),
		'condition' => $prefix . '_page_loader:is(full_page)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Page Loader Icon Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the page loader icon color.', 'smart' ),
		'id'        => $prefix . '_page_loader_full_page_loader_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'page_loader_full_page_loader_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_page_loader:is(full_page)',
		'operator'  => 'and',
	);


	$nice_options[] = array(
		'name'  => esc_html__( 'Google Maps Embed Code', 'smart' ),
		'desc'  => esc_html__( 'Insert the Google Maps embed code for the contact template.', 'smart' ),
		'id'    => $prefix . '_google_map',
		'std'   => nice_default_setting( 'google_map' ),
		'tip'   => '',
		'type'  => 'textarea',
		'extra' => array(
			'type'    => 'code',
			'choices' => array(
				'language' => 'xml',
				'theme'    => 'monokai',
			),
		),
	);

	/**
	 * Header
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Header', 'smart' ),
		'type' => 'heading',
		'icon' => '<i class="bi_layout-header"></i>',
	);

	/**
	 * Header > Layout
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Layout', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-sidebar-l"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Navigation Style', 'smart' ),
		'desc'    => esc_html__( 'Choose your navigation style.', 'smart' ) . '<br />' . esc_html__( 'Top (default): horizontal top header with inline navigation.', 'smart' ) . '<br />' . esc_html__( 'Side: vertical left menu with inline navigation.', 'smart' ) . '<br />' . esc_html__( 'Overlay: horizontal top header with toggleable overlay navigation.', 'smart' ),
		'id'      => $prefix . '_header_navigation',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'header_navigation' ),
		'tip'     => '',
		'options' => array(
			'default'  => array(
				'label' => esc_html__( 'Top', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-top.png' ),
			),
			'vertical' => array(
				'label' => esc_html__( 'Side', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-vertical.png' ),
			),
			'overlay'  => array(
				'label' => esc_html__( 'Overlay', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-overlay.png' ),
			),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Navigation Alignment', 'smart' ),
		'desc'      => esc_html__( 'Choose your top header navigation alignment.', 'smart' ),
		'id'        => $prefix . '_header_top_navigation_alignment',
		'type'      => 'radio_image',
		'std'       => nice_default_setting( 'header_top_navigation_alignment' ),
		'tip'       => '',
		'options'   => array(
			'navigation-left'      => array(
				'label' => esc_html__( 'Left-Aligned Navigation', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-top-left.png' ),
			),
			'navigation-center'    => array(
				'label' => esc_html__( 'Centered Navigation', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-top-center.png' ),
			),
			'navigation-right'     => array(
				'label' => esc_html__( 'Right-Aligned Navigation', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-top-right.png' ),
			),
			'logo-centered'        => array(
				'label' => esc_html__( 'Centered Logo', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-centered.png' ),
			),
			'logo-centered-inline' => array(
				'label' => esc_html__( 'Centered Inline Logo', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-centered-inline.png' ),
			),
		),
		'condition' => $prefix . '_header_navigation:is(default)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Full Width Header', 'smart' ),
		'desc'      => esc_html__( 'Make the header contents take the full width of the page.', 'smart' ),
		'id'        => $prefix . '_header_full_width',
		'std'       => nice_default_setting( 'header_full_width' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Menu Width', 'smart' ),
		'desc'      => esc_html__( 'Select the width of your vertical menu.', 'smart' ),
		'id'        => $prefix . '_header_vertical_width',
		'std'       => nice_default_setting( 'header_vertical_width' ),
		'type'      => 'slider',
		'condition' => $prefix . '_header_navigation:is(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Initially Hidden', 'smart' ),
		'desc'      => esc_html__( 'Hide your vertical menu until you click a toggle button.', 'smart' ),
		'id'        => $prefix . '_header_vertical_hidden',
		'std'       => nice_default_setting( 'header_vertical_hidden' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:is(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Navigation Vertical Alignment', 'smart' ),
		'desc'      => esc_html__( 'Choose your vertical navigation vertical alignment.', 'smart' ),
		'id'        => $prefix . '_header_vertical_align',
		'type'      => 'radio_image',
		'std'       => nice_default_setting( 'header_vertical_align' ),
		'tip'       => '',
		'options'   => array(
			'top'    => array(
				'label' => esc_html__( 'Top', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-vertical-top.png' ),
			),
			'middle' => array(
				'label' => esc_html__( 'Middle', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-vertical-middle.png' ),
			),
			'bottom' => array(
				'label' => esc_html__( 'Bottom', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-vertical-bottom.png' ),
			),
		),
		'condition' => $prefix . '_header_navigation:is(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Keep logo on top', 'smart' ),
		'desc'      => esc_html__( 'Avoid aligning your site\'s logo to the navigation menu.', 'smart' ),
		'id'        => $prefix . '_header_vertical_logo_top',
		'std'       => nice_default_setting( 'header_vertical_logo_top' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:is(vertical),' . $prefix . '_header_vertical_align:not(top)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Navigation Horizontal Alignment', 'smart' ),
		'desc'      => esc_html__( 'Choose your vertical navigation horizontal alignment.', 'smart' ),
		'id'        => $prefix . '_header_vertical_justify',
		'type'      => 'radio_image',
		'std'       => nice_default_setting( 'header_vertical_justify' ),
		'tip'       => '',
		'options'   => array(
			'left'   => array(
				'label' => esc_html__( 'Left', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-vertical-left.png' ),
			),
			'center' => array(
				'label' => esc_html__( 'Center', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-vertical-center.png' ),
			),
			'right'  => array(
				'label' => esc_html__( 'Right', 'smart' ),
				'image' => nice_get_file_uri( 'includes/assets/images/layout/header-vertical-right.png' ),
			),
		),
		'condition' => $prefix . '_header_navigation:is(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Site Content Width', 'smart' ),
		'desc'      => esc_html__( 'Choose the maximum horizontal space to use for your content.', 'smart' ),
		'id'        => $prefix . '_header_vertical_content_width',
		'type'      => 'select',
		'std'       => nice_default_setting( 'header_vertical_content_width' ),
		'tip'       => '',
		'options'   => array(
			'full-width' => esc_html__( 'Use all available width', 'smart' ),
			'custom'     => esc_html__( 'Set custom width', 'smart' ),
		),
		'condition' => $prefix . '_header_navigation:is(vertical),' . $prefix . '_layout_type:is(full)',
		'operator'  => 'and',
		'extra'     => array(
			'type' => 'radio-buttonset',
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Custom Site Content Width', 'smart' ),
		'desc'      => esc_html__( 'Set the maximum width of your content area.', 'smart' ),
		'id'        => $prefix . '_header_vertical_content_custom_width',
		'std'       => nice_default_setting( 'header_vertical_content_custom_width' ),
		'tip'       => '',
		'type'      => 'slider',
		'condition' => $prefix . '_header_navigation:is(vertical),' . $prefix . '_layout_type:is(full),' . $prefix . '_header_vertical_content_width:is(custom)',
		'operator'  => 'and',
	);

	/**
	 * Header > Design
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Design', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_setting-wrench"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Header Skin', 'smart' ),
		'desc'    => esc_html__( 'Select the header content skin.', 'smart' ),
		'id'      => $prefix . '_header_skin',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'header_skin' ),
		'tip'     => '',
		'options' => array(
			'light' => array( 'label' => esc_html__( 'Light', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-light.png' ) ),
			'dark'  => array( 'label' => esc_html__( 'Dark', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-dark.png' ) ),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the header background color.', 'smart' ),
		'id'        => $prefix . '_header_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'header_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Background Color (Dark)', 'smart' ),
		'desc'      => esc_html__( 'Choose the header background color.', 'smart' ),
		'id'        => $prefix . '_header_background_color_dark',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'header_background_color_dark' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Background Image', 'smart' ),
		'desc'      => esc_html__( 'Upload or choose the header background image.', 'smart' ),
		'id'        => $prefix . '_header_background_image',
		'std'       => nice_default_setting( 'header_background_image' ),
		'type'      => 'upload',
		'extra'     => array( 'type' => 'image' ),

	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Background Image Repeat', 'smart' ),
		'desc'      => esc_html__( 'Set if and how to repeat the header background image.', 'smart' ),
		'id'        => $prefix . '_header_background_image_repeat',
		'std'       => nice_default_setting( 'header_background_image_repeat' ),
		'type'      => 'select',
		'tip'       => '',
		'options'   => array(
			'no-repeat' => esc_html__( 'No Repeat', 'smart' ),
			'repeat'    => esc_html__( 'Repeat', 'smart' ),
			'repeat-x'  => esc_html__( 'Repeat horizontally', 'smart' ),
			'repeat-y'  => esc_html__( 'Repeat vertically', 'smart' ),
		),
		'condition' => $prefix . '_header_background_image:not()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Background Image Position', 'smart' ),
		'desc'      => esc_html__( 'Set the position of the header background image.', 'smart' ),
		'id'        => $prefix . '_header_background_image_position',
		'std'       => nice_default_setting( 'header_background_image_position' ),
		'type'      => 'select',
		'tip'       => '',
		'options'   => array(
			'left top'      => esc_html__( 'Left Top', 'smart' ),
			'left center'   => esc_html__( 'Left Center', 'smart' ),
			'left bottom'   => esc_html__( 'Left Bottom', 'smart' ),
			'center top'    => esc_html__( 'Center Top', 'smart' ),
			'center center' => esc_html__( 'Center Center', 'smart' ),
			'center bottom' => esc_html__( 'Center Bottom', 'smart' ),
			'right top'     => esc_html__( 'Right Top', 'smart' ),
			'right center'  => esc_html__( 'Right Center', 'smart' ),
			'right bottom'  => esc_html__( 'Right Bottom', 'smart' ),
		),
		'condition' => $prefix . '_header_background_image:not()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Transparent Header', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent.', 'smart' ),
		'id'        => $prefix . '_header_background_transparent',
		'std'       => nice_default_setting( 'header_background_transparent' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Transparent Header (Mobile)', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent in smaller viewports.', 'smart' ),
		'id'        => $prefix . '_header_background_transparent_mobile',
		'std'       => nice_default_setting( 'header_background_transparent_mobile' ),
		'type'      => 'checkbox',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Transparent Header Content Skin', 'smart' ),
		'desc'    => esc_html__( 'Select the transparent header content skin.', 'smart' ),
		'id'      => $prefix . '_header_background_transparent_skin',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'header_background_transparent_skin' ),
		'tip'     => '',
		'options' => array(
			'light' => array( 'label' => esc_html__( 'Light', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-light.png' ) ),
			'dark'  => array( 'label' => esc_html__( 'Dark', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-dark.png' ) ),
		),
		'condition' => $prefix . '_header_background_transparent:is(true),' . $prefix . '_header_background_transparent_mobile:is(true)',
		'operator'  => 'or',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Overlay Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the overlay skin. The overlay is used for the search and, if selected, for the Overlay style navigation menu.', 'smart' ),
		'id'        => $prefix . '_header_overlay_skin',
		'type'      => 'select',
		'std'       => nice_default_setting( 'header_overlay_skin' ),
		'tip'       => '',
		'options'   => array(
			'dark'   => esc_html__( 'Dark', 'smart' ),
			'light'  => esc_html__( 'Light', 'smart' ),
			'custom' => esc_html__( 'Custom', 'smart' ),
		),
		'extra'     => array(
			'type' => 'radio-buttonset',
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Overlay Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the overlay background color.', 'smart' ),
		'id'        => $prefix . '_header_overlay_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'header_overlay_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_header_overlay_skin:is(custom)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Border', 'smart' ),
		'desc'      => esc_html__( 'Add a semi-transparent border at the bottom of the header.', 'smart' ),
		'id'        => $prefix . '_header_border',
		'std'       => nice_default_setting( 'header_border' ),
		'type'      => 'checkbox',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Shadow', 'smart' ),
		'desc'      => esc_html__( 'Add a shadow to the header.', 'smart' ),
		'id'        => $prefix . '_header_shadow',
		'std'       => nice_default_setting( 'header_shadow' ),
		'type'      => 'checkbox',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Overlay Background Color Opacity', 'smart' ),
		'desc'      => esc_html__( 'Adjust the overlay background color opacity.', 'smart' ),
		'id'        => $prefix . '_header_overlay_background_color_opacity',
		'std'       => nice_default_setting( 'header_overlay_background_color_opacity' ),
		'type'      => 'slider',
		'condition' => $prefix . '_header_overlay_skin:is(custom),' . $prefix . '_header_overlay_background_color:not()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Overlay Text Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the overlay text color. Make sure it contrasts with the overlay background color.', 'smart' ),
		'id'        => $prefix . '_header_overlay_accent_color',
		'std'       => nice_default_setting( 'header_overlay_accent_color' ),
		'tip'       => '',
		'type'      => 'color',
		'condition' => $prefix . '_header_overlay_skin:is(custom)',
		'operator'  => 'and',
	);

	/**
	 * Header > Logo
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Logo', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_media-image-d"></i>',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Text-Based Logo', 'smart' ),
		'desc' => sprintf( esc_html__( 'Use text-based site title and tagline instead of an image logo. You can set them up in %1$sSettings > General%1$s.', 'smart' ), sprintf( '<a href="%s">', admin_url( 'options-general.php' ) ), '</a>' ),
		'id'   => $prefix . '_text_title',
		'std'  => nice_default_setting( 'text_title' ),
		'type' => 'checkbox',
	);

	$nice_options[] = array(
		'name'        => esc_html__( 'Site Title Typography', 'smart' ),
		'desc'        => esc_html__( 'Change the site title typography.', 'smart' ),
		'id'          => $prefix . '_font_site_title',
		'std'         => nice_default_setting( 'font_site_title' ),
		'min'         => 0,
		'max'         => 100,
		'type'        => 'typography',
		'units'       => array( 'px', 'em', '%' ),
		'font_styles' => array(
			'normal'      => esc_html__( 'Normal', 'smart' ),
			'italic'      => esc_html__( 'Italic', 'smart' ),
			'bold'        => esc_html__( 'Bold', 'smart' ),
			'italic bold' => esc_html__( 'Italic/Bold', 'smart' ),
		),
		'condition'   => $prefix . '_text_title:is(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Tagline', 'smart' ),
		'desc'      => esc_html__( "Show the site's tagline.", 'smart' ),
		'id'        => $prefix . '_text_tagline',
		'std'       => nice_default_setting( 'text_tagline' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_text_title:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'        => esc_html__( 'Tagline Typography', 'smart' ),
		'desc'        => esc_html__( 'Change the tagline typography.', 'smart' ),
		'id'          => $prefix . '_font_tagline',
		'std'         => nice_default_setting( 'font_tagline' ),
		'min'         => 0,
		'max'         => 100,
		'type'        => 'typography',
		'units'       => array( 'px', 'em', '%' ),
		'font_styles' => array(
			'normal'      => esc_html__( 'Normal', 'smart' ),
			'italic'      => esc_html__( 'Italic', 'smart' ),
			'bold'        => esc_html__( 'Bold', 'smart' ),
			'italic bold' => esc_html__( 'Italic/Bold', 'smart' ),
		),
		'condition'   => $prefix . '_text_title:is(true),' . $prefix . '_text_tagline:is(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'  => esc_html__( 'Custom Logo', 'smart' ),
		'desc'  => esc_html__( 'Upload a custom logo.', 'smart' ),
		'id'    => $prefix . '_logo',
		'std'   => nice_default_setting( 'logo' ),
		'type'  => 'upload',
		'extra' => array( 'type' => 'image' ),
		'condition'   => $prefix . '_text_title:not(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'  => esc_html__( 'Custom Logo (Retina)', 'smart' ),
		'desc'  => esc_html__( 'Upload a custom logo for Retina displays. The image size should be exactly 2x of your standard custom logo.', 'smart' ),
		'id'    => $prefix . '_logo_retina',
		'std'   => nice_default_setting( 'logo_retina' ),
		'type'  => 'upload',
		'extra' => array( 'type' => 'image' ),
		'condition'   => $prefix . '_text_title:not(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'  => esc_html__( 'Custom Logo (Dark Skin)', 'smart' ),
		'desc'  => esc_html__( 'Upload a custom logo.', 'smart' ),
		'id'    => $prefix . '_logo_dark',
		'std'   => nice_default_setting( 'logo_dark' ),
		'type'  => 'upload',
		'extra' => array( 'type' => 'image' ),
		'condition'   => $prefix . '_text_title:not(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'  => esc_html__( 'Custom Logo (Dark Skin, Retina)', 'smart' ),
		'desc'  => esc_html__( 'Upload a custom logo for Retina displays. The image size should be exactly 2x of your standard custom logo.', 'smart' ),
		'id'    => $prefix . '_logo_dark_retina',
		'std'   => nice_default_setting( 'logo_dark_retina' ),
		'type'  => 'upload',
		'extra' => array( 'type' => 'image' ),
		'condition'   => $prefix . '_text_title:not(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Hide Logo', 'smart' ),
		'desc'      => esc_html__( 'Don\'t display the logo image on page load.', 'smart' ),
		'id'        => $prefix . '_hide_logo',
		'std'       => nice_default_setting( 'hide_logo' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Hide Logo On Mobile Viewports', 'smart' ),
		'desc'      => esc_html__( 'Don\'t display the logo image in smaller viewports.', 'smart' ),
		'id'        => $prefix . '_hide_logo_mobile',
		'std'       => nice_default_setting( 'hide_logo_mobile' ),
		'type'      => 'checkbox',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Logo Height', 'smart' ),
		'desc'      => esc_html__( 'Change the logo height. This setting will standardize the logo height for Retina devices.', 'smart' ),
		'id'        => $prefix . '_logo_height',
		'std'       => nice_default_setting( 'logo_height' ),
		'type'      => 'slider',
		'condition' => $prefix . '_text_title:not(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Logo Padding', 'smart' ),
		'desc'      => esc_html__( 'Change the logo padding. This setting will make sure the logo and navigation menu are correctly aligned.', 'smart' ),
		'id'        => $prefix . '_logo_padding',
		'std'       => nice_default_setting( 'logo_padding' ),
		'type'      => 'slider',
		'condition' => $prefix . '_header_top_navigation_alignment:not(logo-centered)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Logo Padding (Top)', 'smart' ),
		'desc'      => esc_html__( 'Change the logo top padding.', 'smart' ),
		'id'        => $prefix . '_logo_padding_top',
		'std'       => nice_default_setting( 'logo_padding_top' ),
		'type'      => 'slider',
		'condition' => $prefix . '_header_navigation:is(default),' . $prefix . '_header_top_navigation_alignment:is(logo-centered)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Logo Padding (Bottom)', 'smart' ),
		'desc'      => esc_html__( 'Change the logo top padding.', 'smart' ),
		'id'        => $prefix . '_logo_padding_bottom',
		'std'       => nice_default_setting( 'logo_padding_bottom' ),
		'type'      => 'slider',
		'condition' => $prefix . '_header_navigation:is(default),' . $prefix . '_header_top_navigation_alignment:is(logo-centered)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Remove Horizontal Padding', 'smart' ),
		'desc'      => esc_html__( "Don't add an horizontal padding to the logo.", 'smart' ),
		'id'        => $prefix . '_logo_padding_remove_horizontal',
		'std'       => nice_default_setting( 'logo_padding_remove_horizontal' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:is(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'  => esc_html__( 'Custom Logo (Mobile Only)', 'smart' ),
		'desc'  => esc_html__( 'Upload a custom logo.', 'smart' ),
		'id'    => $prefix . '_logo_mobile',
		'std'   => nice_default_setting( 'logo_mobile' ),
		'type'  => 'upload',
		'extra' => array( 'type' => 'image' ),
		'condition'   => $prefix . '_text_title:not(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'  => esc_html__( 'Custom Logo (Mobile Only, Retina)', 'smart' ),
		'desc'  => esc_html__( 'Upload a custom logo for Retina displays. The image size should be exactly 2x of your standard custom logo.', 'smart' ),
		'id'    => $prefix . '_logo_mobile_retina',
		'std'   => nice_default_setting( 'logo_mobile_retina' ),
		'type'  => 'upload',
		'extra' => array( 'type' => 'image' ),
	);

	$nice_options[] = array(
		'name'  => esc_html__( 'Custom Logo (Dark Skin, Mobile Only)', 'smart' ),
		'desc'  => esc_html__( 'Upload a custom logo.', 'smart' ),
		'id'    => $prefix . '_logo_mobile_dark',
		'std'   => nice_default_setting( 'logo_mobile_dark' ),
		'type'  => 'upload',
		'extra' => array( 'type' => 'image' ),
		'condition'   => $prefix . '_text_title:not(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'  => esc_html__( 'Custom Logo (Dark Skin, Mobile Only, Retina)', 'smart' ),
		'desc'  => esc_html__( 'Upload a custom logo for Retina displays. The image size should be exactly 2x of your standard custom logo.', 'smart' ),
		'id'    => $prefix . '_logo_mobile_dark_retina',
		'std'   => nice_default_setting( 'logo_mobile_dark_retina' ),
		'type'  => 'upload',
		'extra' => array( 'type' => 'image' ),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Use Custom Settings for Mobile Logo', 'smart' ),
		'desc'      => esc_html__( 'Apply custom height and padding settings to mobile logo.', 'smart' ),
		'id'        => $prefix . '_logo_mobile_custom_settings',
		'std'       => nice_default_setting( 'logo_mobile_custom_settings' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_logo_mobile:is(),' . $prefix . '_logo_mobile_dark:is()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Logo Height (Mobile Only)', 'smart' ),
		'desc'      => esc_html__( 'Change the logo height. This setting will standardize the logo height for Retina devices.', 'smart' ),
		'id'        => $prefix . '_logo_mobile_height',
		'std'       => nice_default_setting( 'logo_mobile_height' ),
		'type'      => 'slider',
		'condition' => $prefix . '_logo_mobile:not(),' . $prefix . '_logo_mobile_dark:not(),' . $prefix . '_logo_mobile_custom_settings:is(true)',
		'operator'  => 'or',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Logo Padding (Mobile Only)', 'smart' ),
		'desc'      => esc_html__( 'Change the logo padding. This setting will make sure the logo and navigation menu are correctly aligned.', 'smart' ),
		'id'        => $prefix . '_logo_mobile_padding',
		'std'       => nice_default_setting( 'logo_mobile_padding' ),
		'type'      => 'slider',
		'condition' => $prefix . '_logo_mobile:not(),' . $prefix . '_logo_mobile_dark:not(),' . $prefix . '_logo_mobile_custom_settings:is(true)',
		'operator'  => 'or',
	);

	/**
	 * Header > Animation
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Animation', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_tool-magic-wand"></i>',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Fixed Position Header', 'smart' ),
		'desc'      => esc_html__( 'Fix the header at the top of the page.', 'smart' ),
		'id'        => $prefix . '_header_fixed',
		'std'       => nice_default_setting( 'header_fixed' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Fixed Position Header (Mobile)', 'smart' ),
		'desc'      => esc_html__( 'Fix the header at the top of the page in smaller viewports.', 'smart' ),
		'id'        => $prefix . '_header_fixed_mobile',
		'std'       => nice_default_setting( 'header_fixed_mobile' ),
		'type'      => 'checkbox',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Hide Logo', 'smart' ),
		'desc'      => esc_html__( 'Don\'t display the logo image when the header is fixed.', 'smart' ),
		'id'        => $prefix . '_header_fixed_hide_logo',
		'std'       => nice_default_setting( 'header_fixed_hide_logo' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:not(vertical),' . $prefix . '_header_fixed:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Shrinking Header', 'smart' ),
		'desc'      => esc_html__( 'Make the header shrink automatically.', 'smart' ),
		'id'        => $prefix . '_header_shrink',
		'std'       => nice_default_setting( 'header_shrink' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_fixed:is(true),' . $prefix . '_header_navigation:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Shrinking Effect Duration', 'smart' ),
		'desc'      => esc_html__( 'Determine for how long (in milliseconds) the shrinking animation will run.', 'smart' ),
		'id'        => $prefix . '_header_transition_duration',
		'std'       => nice_default_setting( 'header_transition_duration' ),
		'type'      => 'slider',
		'condition' => $prefix . '_header_shrink:is(true),' . $prefix . '_header_fixed:is(true),' . $prefix . '_header_navigation:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Hide Header Until Scroll', 'smart' ),
		'desc'      => esc_html__( 'Make the header invisible until the page is scrolled.', 'smart' ),
		'id'        => $prefix . '_header_hide_until_scroll',
		'std'       => nice_default_setting( 'header_hide_until_scroll' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_fixed:is(true),' . $prefix . '_header_navigation:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Scroll Breakpoint Height', 'smart' ),
		'desc'      => esc_html__( 'Set how many pixels the page should be scrolled before displaying the header.', 'smart' ),
		'id'        => $prefix . '_header_hide_until_scroll_breakpoint',
		'std'       => nice_default_setting( 'header_hide_until_scroll_breakpoint' ),
		'type'      => 'slider',
		'condition' => $prefix . '_header_fixed:is(true),' . $prefix . '_header_navigation:not(vertical),' . $prefix . '_header_hide_until_scroll:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Auto-hide Header', 'smart' ),
		'desc'      => esc_html__( 'Make the header hide automatically while scrolling.', 'smart' ),
		'id'        => $prefix . '_header_autohide',
		'std'       => nice_default_setting( 'header_autohide' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_fixed:is(true),' . $prefix . '_header_navigation:not(vertical),' . $prefix . '_header_hide_until_scroll:not(true)',
		'operator'  => 'and',
	);

	/**
	 * Header > Navigation Menu
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Navigation Menu', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_editorial-write"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Navigation Sub-Menu Content Skin', 'smart' ),
		'desc'    => esc_html__( 'Select the navigation sub-menu content skin.', 'smart' ),
		'id'      => $prefix . '_header_submenu_skin',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'header_submenu_skin' ),
		'tip'     => '',
		'options' => array(
			'light' => array( 'label' => esc_html__( 'Light', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-light.png' ) ),
			'dark'  => array( 'label' => esc_html__( 'Dark', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-dark.png' ) ),
		),
		'condition' => $prefix . '_header_navigation:not(overlay)',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Uppercase Menu Items', 'smart' ),
		'desc' => esc_html__( 'Display the menu links in uppercase.', 'smart' ),
		'id'   => $prefix . '_header_menu_uppercase',
		'std'  => nice_default_setting( 'header_menu_uppercase' ),
		'type' => 'checkbox',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Uppercase Sub-Menu Items', 'smart' ),
		'desc' => esc_html__( 'Display the sub-menu links in uppercase.', 'smart' ),
		'id'   => $prefix . '_header_submenu_uppercase',
		'std'  => nice_default_setting( 'header_submenu_uppercase' ),
		'type' => 'checkbox',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Hide Arrows Indicating Sub-Menus', 'smart' ),
		'desc'      => esc_html__( 'Hide sub-menu arrows to make them look like regular menu links.', 'smart' ),
		'id'        => $prefix . '_header_menu_hide_arrows',
		'std'       => nice_default_setting( 'header_menu_hide_arrows' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:not(overlay)',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Remove Border From Sub-Menus', 'smart' ),
		'desc'      => esc_html__( 'Check to remove the colored border from sub-menus.', 'smart' ),
		'id'        => $prefix . '_header_menu_remove_border',
		'std'       => nice_default_setting( 'header_menu_remove_border' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:not(overlay)',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Hide Mega Menu Separators', 'smart' ),
		'desc'      => esc_html__( 'Display mega menus (those with the ".megamenu" class) in an undivided container.', 'smart' ),
		'id'        => $prefix . '_header_menu_hide_separators',
		'std'       => nice_default_setting( 'header_menu_hide_separators' ),
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:not(overlay)',
	);

	/**
	 * Header > Top Bar
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Top Bar', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_web-browser-a"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Display Top Bar', 'smart' ),
		'desc'    => esc_html__( 'Show a navigation bar before your site\'s header.', 'smart' ),
		'id'      => $prefix . '_top_bar',
		'std'     => nice_default_setting( 'top_bar' ),
		'options' => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Top Bar Padding', 'smart' ),
		'desc' => esc_html__( 'Change the top bar padding.', 'smart' ),
		'id'   => $prefix . '_top_bar_padding',
		'std'  => nice_default_setting( 'top_bar_padding' ),
		'type' => 'slider',
		'operator'  => 'and',
		'condition' => $prefix . '_top_bar:is(true)',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Fixed Position Top Bar', 'smart' ),
		'desc'      => esc_html__( 'Fix the top bar at the top of the page.', 'smart' ),
		'id'        => $prefix . '_top_bar_fixed',
		'std'       => nice_default_setting( 'top_bar_fixed' ),
		'type'      => 'checkbox',
		'operator'  => 'and',
		'condition' => $prefix . '_top_bar:is(true)',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Top Bar Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the top bar background color.', 'smart' ),
		'id'        => $prefix . '_top_bar_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'top_bar_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'operator'  => 'and',
		'condition' => $prefix . '_top_bar:is(true)',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Top Bar Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the top bar skin.', 'smart' ),
		'id'        => $prefix . '_top_bar_skin',
		'type'      => 'radio_image',
		'std'       => nice_default_setting( 'top_bar_skin' ),
		'tip'       => '',
		'options'   => array(
			'light' => array(
				'label' => esc_html__( 'Light', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-light.png' ),
			),
			'dark'  => array(
				'label' => esc_html__( 'Dark', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-dark.png' ),
			),
		),
		'operator'  => 'and',
		'condition' => $prefix . '_top_bar:is(true)',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Top Bar Left Content', 'smart' ),
		'desc'      => esc_html__( 'Enter text for the left side of the top bar.', 'smart' ),
		'id'        => $prefix . '_top_bar_content_left',
		'std'       => nice_default_setting( 'top_bar_content_left' ),
		'type'      => 'textarea',
		'tip'       => '',
		'operator'  => 'and',
		'condition' => $prefix . '_top_bar:is(true)',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Top Bar Right Content', 'smart' ),
		'desc'      => esc_html__( 'Enter text for the right side of the top bar.', 'smart' ),
		'id'        => $prefix . '_top_bar_content_right',
		'std'       => nice_default_setting( 'top_bar_content_right' ),
		'type'      => 'textarea',
		'tip'       => '',
		'operator'  => 'and',
		'condition' => $prefix . '_top_bar:is(true)',
	);

	/**
	 * Header > Extras
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Extras', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_interface-star-a"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Display Search', 'smart' ),
		'desc'    => esc_html__( "Show a link to the site's search in the header.", 'smart' ),
		'id'      => $prefix . '_header_display_search',
		'std'     => nice_default_setting( 'header_display_search' ),
		'options' => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'    => esc_html__( 'Display a list of the social Icons in the header.', 'smart' ),
		'id'      => $prefix . '_header_display_social',
		'std'     => nice_default_setting( 'header_display_social' ),
		'options' => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	/**
	 * Page & Post Title Bar
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Title Bar', 'smart' ),
		'type' => 'heading',
		'icon' => '<i class="bi_layout-third-h"></i>',
	);

	/**
	 * Title Bar > Layout
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Layout', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-sidebar-l"></i>',
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Height', 'smart' ),
		'id'                => $prefix . '_heading_height',
		'type'              => 'measurement',
		'std'               => nice_default_setting( 'heading_height' ),
		'desc'              => esc_html__( 'Define the custom height for the title area in px or in %.', 'smart' ),
		'ignore_customizer' => true,
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Minimum height', 'smart' ),
		'id'                => $prefix . '_heading_height_min',
		'type'              => 'measurement',
		'std'               => nice_default_setting( 'heading_height_min' ),
		'desc'              => esc_html__( 'Enter a minimum height for the heading (in pixels).', 'smart' ),
		'ignore_customizer' => true,
	);

	$nice_options[] = array(
		'name'     => esc_html__( 'Title Horizontal Alignment', 'smart' ),
		'id'       => $prefix . '_heading_alignment',
		'type'     => 'select',
		'std'      => nice_default_setting( 'heading_alignment' ),
		'options'  => array(
			'left'   => esc_html__( 'Left', 'smart' ),
			'center' => esc_html__( 'Center', 'smart' ),
			'right'  => esc_html__( 'Right', 'smart' ),
		),
		'desc'     => esc_html__( 'Select the horizontal alignment you would like for your title and subtitle.', 'smart' ),
	);

	$nice_options[] = array(
		'name'     => esc_html__( 'Title Vertical Alignment', 'smart' ),
		'id'       => $prefix . '_heading_alignment_v',
		'type'     => 'select',
		'std'      => nice_default_setting( 'heading_alignment_v' ),
		'options'  => array(
			'top'    => esc_html__( 'Top', 'smart' ),
			'middle' => esc_html__( 'Middle', 'smart' ),
			'bottom' => esc_html__( 'Bottom', 'smart' ),
		),
		'desc'     => esc_html__( 'Select the horizontal alignment you would like for your title and subtitle.', 'smart' ),
	);

	/**
	 * Page Title > Design
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Design', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_setting-wrench"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Heading Background Color', 'smart' ),
		'desc'    => esc_html__( 'Choose the heading background color.', 'smart' ),
		'id'      => $prefix . '_heading_background_color',
		'type'    => 'select_color',
		'std'     => nice_default_setting( 'heading_background_color' ),
		'class'   => 'nice-select-color',
		'options' => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Heading Skin', 'smart' ),
		'desc'    => esc_html__( 'Select the heading skin.', 'smart' ),
		'id'      => $prefix . '_heading_skin',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'heading_skin' ),
		'tip'     => '',
		'options' => array(
			'light' => array(
				'label' => esc_html__( 'Light', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-light.png' ),
			),
			'dark'  => array(
				'label' => esc_html__( 'Dark', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-dark.png' ),
			),
		),
	);

	$nice_options[] = array(
		'name'     => esc_html__( 'Title Text Transform', 'smart' ),
		'id'       => $prefix . '_heading_text_transform',
		'type'     => 'select',
		'std'      => nice_default_setting( 'heading_text_transform' ),
		'options'  => array(
			'default'    => esc_html__( 'None', 'smart' ),
			'uppercase'  => esc_html__( 'Uppercase', 'smart' ),
			'lowercase'  => esc_html__( 'Lowercase', 'smart' ),
			'capitalize' => esc_html__( 'Capitalize', 'smart' ),
		),
		'desc'     => esc_html__( 'Select the title text transformation.', 'smart' ),
		'operator' => 'and',
	);

	$nice_options[] = array(
		'name'     => esc_html__( 'Title Font Weight', 'smart' ),
		'id'       => $prefix . '_heading_font_weight',
		'type'     => 'select',
		'std'      => nice_default_setting( 'heading_font_weight' ),
		'options'  => nice_font_weight(),
		'desc'     => esc_html__( 'Select the title font weight.', 'smart' ),
		'operator' => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Heading Font Size', 'smart' ),
		'id'        => $prefix . '_heading_font_size',
		'type'      => 'select',
		'std'       => nice_default_setting( 'heading_font_size' ),
		'options'   => array(
			'h1'           => esc_html__( 'h1', 'smart' ),
			'h2'           => esc_html__( 'h2', 'smart' ),
			'h3'           => esc_html__( 'h3', 'smart' ),
			'h4'           => esc_html__( 'h4', 'smart' ),
			'h5'           => esc_html__( 'h5', 'smart' ),
			'h6'           => esc_html__( 'h6', 'smart' ),
			'fontsize-12'  => esc_html__( 'Size 12px', 'smart' ),
			'fontsize-40'  => esc_html__( 'Size 40px', 'smart' ),
			'fontsize-50'  => esc_html__( 'Size 50px', 'smart' ),
			'fontsize-75'  => esc_html__( 'Size 75px', 'smart' ),
			'fontsize-100' => esc_html__( 'Size 100px', 'smart' ),
			'fontsize-125' => esc_html__( 'Size 125px', 'smart' ),
			'fontsize-150' => esc_html__( 'Size 150px', 'smart' ),
		),
		'desc'      => esc_html__( 'Select the title font size.', 'smart' ),
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'     => esc_html__( 'Heading Background Image', 'smart' ),
		'id'       => $prefix . '_heading_background_image',
		'type'     => 'upload',
		'std'      => nice_default_setting( 'heading_background_image' ),
		'desc'     => esc_html__( 'Upload/select a background image.', 'smart' ),
		'operator' => 'and',
	);

	$nice_options[] = array(
		'name'     => esc_html__( 'Parallax for Background Image', 'smart' ),
		'id'       => $prefix . '_heading_background_image_parallax',
		'std'      => nice_default_setting( 'heading_background_image_parallax' ),
		'type'     => 'checkbox',
		'desc'     => esc_html__( 'Add a parallax effect to the background image.', 'smart' ),
		'operator' => 'and',
		'condition' => $prefix . '_heading_background_image:not()',
	);

	$nice_options[] = array(
		'name'     => esc_html__( 'Background Image Repeat', 'smart' ),
		'id'       => $prefix . '_heading_background_repeat',
		'type'     => 'select',
		'std'      => nice_default_setting( 'heading_background_repeat' ),
		'options'  => array(
			'no-repeat' => esc_html__( 'No Repeat', 'smart' ),
			'repeat'    => esc_html__( 'Repeat All', 'smart' ),
			'repeat-x'  => esc_html__( 'Repeat Horizontally', 'smart' ),
			'repeat-y'  => esc_html__( 'Repeat Vertically', 'smart' ),
		),
		'desc'     => esc_html__( 'Select how your background image should be repeated.', 'smart' ),
		'operator' => 'and',
		'condition' => $prefix . '_heading_background_image:not(),' . $prefix . '_heading_background_image_parallax:is(false)',
	);

	$nice_options[] = array(
		'name'     => esc_html__( 'Background Image Position', 'smart' ),
		'id'       => $prefix . '_heading_background_position',
		'type'     => 'select',
		'std'      => nice_default_setting( 'heading_background_position' ),
		'options'  => array(
			'left top'      => esc_html__( 'Left Top', 'smart' ),
			'left center'   => esc_html__( 'Left Center', 'smart' ),
			'left bottom'   => esc_html__( 'Left Bottom', 'smart' ),
			'center top'    => esc_html__( 'Center Top', 'smart' ),
			'center center' => esc_html__( 'Center Center', 'smart' ),
			'center bottom' => esc_html__( 'Center Bottom', 'smart' ),
			'right top'     => esc_html__( 'Right Center', 'smart' ),
			'right center'  => esc_html__( 'Right Center', 'smart' ),
			'right bottom'  => esc_html__( 'Right Center', 'smart' ),
		),
		'desc'     => esc_html__( 'Select where your background image should be positioned.', 'smart' ),
		'operator' => 'and',
		'condition' => $prefix . '_heading_background_image:not(),' . $prefix . '_heading_background_image_parallax:is(false)',
	);

	$nice_options[] = array(
		'name'     => esc_html__( 'Background Image Size', 'smart' ),
		'id'       => $prefix . '_heading_background_size',
		'type'     => 'select',
		'std'      => nice_default_setting( 'heading_background_size' ),
		'options'  => array(
			'auto'    => esc_html__( 'Auto', 'smart' ),
			'cover'   => esc_html__( 'Cover', 'smart' ),
			'contain' => esc_html__( 'Contain', 'smart' ),
		),
		'desc'     => esc_html__( 'Select the size for you background image.', 'smart' ),
		'operator' => 'and',
		'condition' => $prefix . '_heading_background_image:not(),' . $prefix . '_heading_background_image_parallax:is(false)',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Image Attachment', 'smart' ),
		'id'        => $prefix . '_heading_background_attachment',
		'type'      => 'select',
		'std'       => nice_default_setting( 'heading_background_attachment' ),
		'options'   => array(
			'scroll' => esc_html__( 'Scroll', 'smart' ),
			'fixed'  => esc_html__( 'Fixed', 'smart' ),
		),
		'desc'      => esc_html__( 'Select how your background image should be attached to the page.', 'smart' ),
		'condition' => $prefix . '_heading_background_image:not(),' . $prefix . '_heading_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	/**
	 * Footer
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Footer', 'smart' ),
		'type' => 'heading',
		'icon' => '<i class="bi_layout-footer"></i>',
	);

	/**
	 * Footer > Layout
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Footer Layout', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_music-eq-a"></i>',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Full Width Footer', 'smart' ),
		'desc'      => esc_html__( 'Make the footer contents take the full available width.', 'smart' ),
		'id'        => $prefix . '_footer_full_width',
		'std'       => nice_default_setting( 'footer_full_width' ),
		'tip'       => '',
		'type'      => 'checkbox',
		'condition' => $prefix . '_header_navigation:not(vertical),' . $prefix . '_layout_type:is(full)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Footer Skin', 'smart' ),
		'desc'    => esc_html__( 'Select the footer skin.', 'smart' ),
		'id'      => $prefix . '_footer_skin',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'footer_skin' ),
		'tip'     => '',
		'options' => array(
			'light' => array( 'label' => esc_html__( 'Light', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-light.png' ) ),
			'dark'  => array( 'label' => esc_html__( 'Dark', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-dark.png' ) ),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Transparent Footer', 'smart' ),
		'desc'      => esc_html__( 'Make the footer background transparent.', 'smart' ),
		'id'        => $prefix . '_footer_transparent',
		'std'       => nice_default_setting( 'footer_transparent' ),
		'tip'       => '',
		'type'      => 'checkbox',
		'operator'  => 'and',
	);

	/**
	 * Footer > Widgets
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Footer Widgets', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_interface-dashboard"></i>',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Footer Columns', 'smart' ),
		'desc' => esc_html__( 'Set the number of columns that the footer will have.', 'smart' ),
		'id'   => $prefix . '_footer_columns',
		'std'  => nice_default_setting( 'footer_columns' ),
		'type' => 'slider',
	);

	/**
	 * Footer > Extended
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Footer Extended', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-footer"></i>',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Custom Copyright', 'smart' ),
		'desc' => esc_html__( 'Write your own copyright text.', 'smart' ),
		'id'   => $prefix . '_custom_copyright_enable',
		'std'  => nice_default_setting( 'custom_copyright_enable' ),
		'tip'  => '',
		'type' => 'checkbox',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Custom Copyright Text', 'smart' ),
		'desc'      => esc_html__( 'Enter your copyright section text (i.e. "All Rights Reserved, NiceThemes").', 'smart' ),
		'id'        => $prefix . '_custom_copyright_text',
		'std'       => nice_default_setting( 'custom_copyright_text' ),
		'tip'       => '',
		'type'      => 'text',
		'condition' => $prefix . '_custom_copyright_enable:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'    => esc_html__( 'Display a list of the social Icons in the footer.', 'smart' ),
		'id'      => $prefix . '_footer_display_social',
		'std'     => nice_default_setting( 'footer_display_social' ),
		'options' => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	/**
	 * Footer > Back To Top
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Back To Top', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_interface-top-r"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( '"Back To Top" Button', 'smart' ),
		'desc'    => esc_html__( 'Show a "Back To Top button" in the bottom right corner of the site.', 'smart' ),
		'id'      => $prefix . '_back_to_top',
		'std'     => nice_default_setting( 'back_to_top' ),
		'options' => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	$nice_options[] = array(
		'name'      => esc_html__( '"Back To Top" Button Style', 'smart' ),
		'desc'      => esc_html__( 'Select the "Back To Top" button style.', 'smart' ),
		'id'        => $prefix . '_back_to_top_style',
		'type'      => 'radio_image',
		'std'       => nice_default_setting( 'back_to_top_style' ),
		'tip'       => '',
		'options'   => array(
			''            => array(
				'label' => esc_html__( 'Default', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-slider-nav-default.png' ),
			),
			'outline' => array(
				'label' => esc_html__( 'Outlined', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-slider-nav-outlined.png' ),
			),
			'solid'   => array(
				'label' => esc_html__( 'Solid Background', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-slider-nav-solid.png' ),
			),
		),
		'condition' => $prefix . '_back_to_top:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( '"Back To Top" Button Shape', 'smart' ),
		'desc'      => esc_html__( 'Select the "Back To Top" button shape.', 'smart' ),
		'id'        => $prefix . '_back_to_top_shape',
		'type'      => 'select',
		'std'       => nice_default_setting( 'back_to_top_shape' ),
		'tip'       => '',
		'options'   => array(
			''       => esc_html__( 'Default', 'smart' ),
			'round'  => esc_html__( 'Round', 'smart' ),
			'circle' => esc_html__( 'Circle', 'smart' ),
			'square' => esc_html__( 'Square', 'smart' ),
		),
		'condition' => $prefix . '_back_to_top:is(true),' . $prefix . '_back_to_top_style:not()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( '"Back To Top"  Button Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the "Back To Top" button background color.', 'smart' ),
		'id'        => $prefix . '_back_to_top_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'back_to_top_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_back_to_top:is(true),' . $prefix . '_back_to_top_style:is(solid),',
		'operator'  => 'and',
	);


	/**
	 * Layout
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Layout', 'smart' ),
		'type' => 'heading',
		'icon' => '<i class="bi_doc-paper-stack"></i>',
		'id'   => $prefix . '_layout'
	);

	/**
	 * Layout > General
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'General', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_music-eq-a"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Layout Type', 'smart' ),
		'desc'    => esc_html__( 'Select the layout type.', 'smart' ),
		'id'      => $prefix . '_layout_type',
		'type'    => 'select',
		'std'     => nice_default_setting( 'layout_type' ),
		'tip'     => '',
		'options' => array(
			'boxed' => esc_html__( 'Boxed', 'smart' ),
			'full'  => esc_html__( 'Full Width', 'smart' ),
		),
		'extra'   => array(
			'type' => 'radio-buttonset',
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Body Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the body background color.', 'smart' ),
		'id'        => $prefix . '_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_layout_type:is(boxed)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Body Background Image', 'smart' ),
		'desc'      => esc_html__( 'Upload or choose the body background image.', 'smart' ),
		'id'        => $prefix . '_background_image',
		'std'       => nice_default_setting( 'background_image' ),
		'type'      => 'upload',
		'condition' => $prefix . '_layout_type:is(boxed)',
		'operator'  => 'and',
		'extra'     => array( 'type' => 'image' ),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Body Background Image Repeat', 'smart' ),
		'desc'      => esc_html__( 'Set if and how to repeat the body background image.', 'smart' ),
		'id'        => $prefix . '_background_image_repeat',
		'std'       => nice_default_setting( 'background_image_repeat' ),
		'type'      => 'select',
		'tip'       => '',
		'options'   => array(
			'no-repeat' => esc_html__( 'No Repeat', 'smart' ),
			'repeat'    => esc_html__( 'Repeat', 'smart' ),
			'repeat-x'  => esc_html__( 'Repeat horizontally', 'smart' ),
			'repeat-y'  => esc_html__( 'Repeat vertically', 'smart' ),
		),
		'condition' => $prefix . '_layout_type:is(boxed),' . $prefix . '_background_image:not()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Body Background Image Position', 'smart' ),
		'desc'      => esc_html__( 'Set the position of the body background image.', 'smart' ),
		'id'        => $prefix . '_background_image_position',
		'std'       => nice_default_setting( 'background_image_position' ),
		'type'      => 'select',
		'tip'       => '',
		'options'   => array(
			'left top'      => esc_html__( 'Left Top', 'smart' ),
			'left center'   => esc_html__( 'Left Center', 'smart' ),
			'left bottom'   => esc_html__( 'Left Bottom', 'smart' ),
			'center top'    => esc_html__( 'Center Top', 'smart' ),
			'center center' => esc_html__( 'Center Center', 'smart' ),
			'center bottom' => esc_html__( 'Center Bottom', 'smart' ),
			'right top'     => esc_html__( 'Right Top', 'smart' ),
			'right center'  => esc_html__( 'Right Center', 'smart' ),
			'right bottom'  => esc_html__( 'Right Bottom', 'smart' ),
		),
		'condition' => $prefix . '_layout_type:is(boxed),' . $prefix . '_background_image:not()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Body Background Image Attachment', 'smart' ),
		'desc'      => esc_html__( 'Set whether the body background image should be attached to a fixed position, or scroll with the rest of the page.', 'smart' ),
		'id'        => $prefix . '_background_image_attachment',
		'std'       => nice_default_setting( 'background_image_attachment' ),
		'type'      => 'select',
		'tip'       => '',
		'options'   => array(
			'scroll' => esc_html__( 'Scroll', 'smart' ),
			'fixed'  => esc_html__( 'Fixed', 'smart' ),
		),
		'condition' => $prefix . '_layout_type:is(boxed),' . $prefix . '_background_image:not()',
		'operator'  => 'and',
		'extra'     => array(
			'type' => 'radio-buttonset',
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Content Width', 'smart' ),
		'desc'      => esc_html__( 'Choose the maximum horizontal space to use for your content.', 'smart' ),
		'id'        => $prefix . '_site_content_width',
		'type'      => 'select',
		'std'       => nice_default_setting( 'site_content_width' ),
		'tip'       => '',
		'options'   => array(
			''      => esc_html__( 'Default', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_header_navigation:not(vertical)',
		'operator'  => 'and',
		'extra'     => array(
			'type' => 'radio-buttonset',
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Custom Site Content Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the content area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_site_content_width_value',
		'std'       => nice_default_setting( 'site_content_width_value' ),
		'tip'       => '',
		'type'      => 'measurement',
		'condition' => $prefix . '_header_navigation:not(vertical),' . $prefix . '_site_content_width:is(limit)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Sidebar Position', 'smart' ),
		'desc'    => esc_html__( 'Set the position of the sidebar.', 'smart' ),
		'id'      => $prefix . '_sidebar_position',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'sidebar_position' ),
		'tip'     => '',
		'options' => array(
			'right' => array(
				'label' => esc_html__( 'Right Sidebar', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/layout-sidebar-right.png' ),
			),
			'left'  => array(
				'label' => esc_html__( 'Left Sidebar', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/layout-sidebar-left.png' ),
			),
		),
	);

	/**
	 * Layout > Blog & Posts
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Blog & Posts', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-article"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Masonry Blog Posts Load Method', 'smart' ),
		'desc'    => esc_html__( 'Select the method for loading masonry blog posts.', 'smart' ),
		'id'      => $prefix . '_masonry_posts_load_method',
		'type'    => 'select',
		'std'     => nice_default_setting( 'masonry_posts_load_method' ),
		'tip'     => '',
		'options' => array(
			'on_scroll' => esc_html__( 'On Scroll', 'smart' ),
			'on_button' => esc_html__( 'On Clicking Button', 'smart' ),
		),
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Masonry Blog Posts Loader Icon', 'smart' ),
		'desc'    => esc_html__( 'Select the loader for masonry blog posts.', 'smart' ),
		'id'      => $prefix . '_masonry_posts_loader_icon',
		'type'    => 'select',
		'std'     => nice_default_setting( 'masonry_posts_loader_icon' ),
		'tip'     => '',
		'options' => array(
			'beat' => esc_html__( 'Beat', 'smart' ),
			'spin' => esc_html__( 'Spin', 'smart' ),
		),
	);

	/**
	 * Layout > Posts
	 */

	$nice_options[] = array(
		'name'   => esc_html__( 'Posts', 'smart' ),
		'type'   => 'heading',
		'icon'   => '<i class="bi_doc-article-b"></i>',
		'id'     => $prefix . '_layout_posts',
		'parent' => $prefix . '_layout',
	);

	/**
	 * Layout > Posts > Header
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Header', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-header"></i>',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Header', 'smart' ),
		'desc'      => esc_html__( 'Show the header for posts.', 'smart' ),
		'id'        => $prefix . '_post_header',
		'std'       => nice_default_setting( 'post_header' ),
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Navigation Menu', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation menu to use for posts.', 'smart' ),
		'id'        => $prefix . '_post_navigation_menu',
		'std'       => nice_default_setting( 'post_navigation_menu' ),
		'type'      => 'select',
		'options'   => nice_get_navigation_menus(),
		'condition' => $prefix . '_post_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Navigation Style', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation style to use for posts.', 'smart' ),
		'id'        => $prefix . '_post_navigation_style',
		'std'       => nice_default_setting( 'post_navigation_style' ),
		'type'      => 'select',
		'options'   => array(
			''         => esc_html__( 'Inherit', 'smart' ),
			'default'  => esc_html__( 'Top', 'smart' ),
			'vertical' => esc_html__( 'Side', 'smart' ),
			'overlay'  => esc_html__( 'Overlay', 'smart' ),
		),
		'condition' => $prefix . '_post_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Transparent Header', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent.', 'smart' ),
		'id'        => $prefix . '_post_header_background_transparent',
		'std'       => nice_default_setting( 'post_header_background_transparent' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_post_header:not(false),' . $prefix . '_post_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Transparent Header (Mobile)', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent in smaller viewports. This option only works when the transparent header is enabled on desktop.', 'smart' ),
		'id'        => $prefix . '_post_header_background_transparent_mobile',
		'std'       => nice_default_setting( 'post_header_background_transparent_mobile' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_post_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the header content skin to use for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_header_skin',
		'std'       => nice_default_setting( 'post_header_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_post_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a background color.', 'smart' ),
		'id'        => $prefix . '_post_header_background_color',
		'std'       => nice_default_setting( 'post_header_background_color' ),
		'type'      => 'select_color',
		'options'   => nice_theme_colors_dropdown_values(),
		'class'     => 'nice-select-color',
		'condition' => $prefix . '_post_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Navigation Sub-Menu Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation sub-menu content skin to use for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_navigation_submenu_skin',
		'std'       => nice_default_setting( 'post_navigation_submenu_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_post_header:not(false),' . $prefix . '_post_navigation_style:not(overlay)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Width', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to make the header contents take the full width for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_header_width',
		'std'       => nice_default_setting( 'post_header_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_post_header:not(false),' . $prefix . '_post_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the header area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_post_header_width_value',
		'std'       => nice_default_setting( 'post_header_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_post_header:not(false),' . $prefix . '_post_navigation_style:not(vertical),' . $prefix . '_post_header_width:is(limit)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Search', 'smart' ),
		'desc'      => esc_html__( "Select whether or not to show a link to the site's search in the header for the default post template.", 'smart' ),
		'id'        => $prefix . '_post_header_display_search',
		'std'       => nice_default_setting( 'post_header_display_search' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_post_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'      => esc_html__( "Select whether or not to show a the social icons in the header for the default post template.", 'smart' ),
		'id'        => $prefix . '_post_header_display_social',
		'std'       => nice_default_setting( 'post_header_display_social' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_post_header:not(false)',
		'operator'  => 'and',
	);

	/**
	 * Layout > Posts > Title Bar
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Title Bar', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-third-h"></i>',
		'id'     => $prefix . '_layout_posts_title_bar',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Title Bar', 'smart' ),
		'desc'      => esc_html__( 'Show the title bar section for this post.', 'smart' ),
		'id'        => $prefix . '_post_heading',
		'std'       => nice_default_setting( 'post_heading' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),

	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Post Title in the Title Bar', 'smart' ),
		'desc'      => esc_html__( 'Show the post title in the title bar.', 'smart' ),
		'id'        => $prefix . '_post_title_heading',
		'std'       => nice_default_setting( 'post_title_heading' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Post Categories in the Title Bar', 'smart' ),
		'desc'      => esc_html__( 'Show the post categories in the title bar (they go above the title).', 'smart' ),
		'id'        => $prefix . '_post_categories_heading',
		'std'       => nice_default_setting( 'post_categories_heading' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Post Categories Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a color.', 'smart' ),
		'id'        => $prefix . '_post_categories_heading_color',
		'std'       => nice_default_setting( 'post_categories_heading_color' ),
		'type'      => 'select_color',
		'options'   => nice_theme_colors_dropdown_values(),
		'class'     => 'nice-select-color',
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_categories_heading:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Post Categories Shape', 'smart' ),
		'desc'      => esc_html__( 'Choose a shape.', 'smart' ),
		'id'        => $prefix . '_post_categories_heading_shape',
		'type'      => 'select',
		'std'       => nice_default_setting( 'post_categories_heading_shape' ),
		'tip'       => '',
		'options'   => array(
			''       => esc_html__( 'Default', 'smart' ),
			'round'  => esc_html__( 'Round', 'smart' ),
			'circle' => esc_html__( 'Circle', 'smart' ),
			'square' => esc_html__( 'Square', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_categories_heading:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Post Categories Style', 'smart' ),
		'desc'      => esc_html__( 'Choose a style.', 'smart' ),
		'id'        => $prefix . '_post_categories_heading_style',
		'type'      => 'select',
		'std'       => nice_default_setting( 'post_categories_heading_style' ),
		'tip'       => '',
		'options'   => array(
			''        => esc_html__( 'Default', 'smart' ),
			'outline' => esc_html__( 'Outlined', 'smart' ),
			'solid'   => esc_html__( 'Solid Background', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_categories_heading:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Horizontal Alignment', 'smart' ),
		'desc'      => esc_html__( 'Select the horizontal alignment you would like for your title and subtitle.', 'smart' ),
		'id'        => $prefix . '_post_title_alignment',
		'std'       => nice_default_setting( 'post_title_alignment' ),
		'type'      => 'select',
		'options'   => array(
			''       => esc_html__( 'Inherit', 'smart' ),
			'left'   => esc_html__( 'Left', 'smart' ),
			'center' => esc_html__( 'Center', 'smart' ),
			'right'  => esc_html__( 'Right', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Vertical Alignment', 'smart' ),
		'desc'      => esc_html__( 'Select the vertical alignment you would like for your title and subtitle (warning: bottom alignment may overlap with scroll down arrow).', 'smart' ),
		'id'        => $prefix . '_post_title_alignment_v',
		'std'       => nice_default_setting( 'post_title_alignment_v' ),
		'type'      => 'select',
		'options'   => array(
			''       => esc_html__( 'Inherit', 'smart' ),
			'top'    => esc_html__( 'Top', 'smart' ),
			'middle' => esc_html__( 'Middle', 'smart' ),
			'bottom' => esc_html__( 'Bottom', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Width', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to make the contents of the title bar take the full width for posts.', 'smart' ),
		'id'        => $prefix . '_post_title_width',
		'std'       => nice_default_setting( 'post_title_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the title bar area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_post_title_width_value',
		'std'       => nice_default_setting( 'post_title_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_navigation_style:not(vertical),' . $prefix . '_post_title_width:is(limit)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Height', 'smart' ),
		'desc'              => esc_html__( 'Define the custom height for the title area in px or in %. Leave blank to use default theme settings.', 'smart' ),
		'id'                => $prefix . '_post_title_height',
		'std'               => nice_default_setting( 'post_title_height' ),
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'condition'         => $prefix . '_post_heading:not(false)',
		'operator'          => 'and',
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Minimum height', 'smart' ),
		'desc'              => esc_html__( 'Enter a minimum height for the header (in pixels). Leave blank to use default theme settings.', 'smart' ),
		'id'                => $prefix . '_post_title_height_min',
		'std'               => nice_default_setting( 'post_title_height_min' ),
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'condition'         => $prefix . '_post_heading:not(false)',
		'operator'          => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Text Transform', 'smart' ),
		'desc'      => esc_html__( 'Select the title text transformation.', 'smart' ),
		'id'        => $prefix . '_post_title_text_transform',
		'std'       => nice_default_setting( 'post_title_text_transform' ),
		'type'      => 'select',
		'options'   => array(
			''           => esc_html__( 'Inherit', 'smart' ),
			'default'    => esc_html__( 'Default CSS', 'smart' ),
			'uppercase'  => esc_html__( 'Uppercase', 'smart' ),
			'lowercase'  => esc_html__( 'Lowercase', 'smart' ),
			'capitalize' => esc_html__( 'Capitalize', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Font Weight', 'smart' ),
		'desc'      => esc_html__( 'Select the title font weight.', 'smart' ),
		'id'        => $prefix . '_post_title_font_weight',
		'std'       => nice_default_setting( 'post_title_font_weight' ),
		'type'      => 'select',
		'options'   => nice_font_weight(),
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Font Size', 'smart' ),
		'desc'      => esc_html__( 'Select the title font size.', 'smart' ),
		'id'        => $prefix . '_post_title_font_size',
		'std'       => nice_default_setting( 'post_title_font_size' ),
		'type'      => 'select',
		'options'   => array(
			''             => esc_html__( 'Inherit', 'smart' ),
			'h1'           => esc_html__( 'h1', 'smart' ),
			'h2'           => esc_html__( 'h2', 'smart' ),
			'h3'           => esc_html__( 'h3', 'smart' ),
			'h4'           => esc_html__( 'h4', 'smart' ),
			'h5'           => esc_html__( 'h5', 'smart' ),
			'h6'           => esc_html__( 'h6', 'smart' ),
			'fontsize-12'  => esc_html__( 'Size 12px', 'smart' ),
			'fontsize-40'  => esc_html__( 'Size 40px', 'smart' ),
			'fontsize-50'  => esc_html__( 'Size 50px', 'smart' ),
			'fontsize-75'  => esc_html__( 'Size 75px', 'smart' ),
			'fontsize-100' => esc_html__( 'Size 100px', 'smart' ),
			'fontsize-125' => esc_html__( 'Size 125px', 'smart' ),
			'fontsize-150' => esc_html__( 'Size 150px', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Post Title Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the heading skin. "Light" equals light background with dark color contents, and "Dark" equals dark background with light color contents.', 'smart' ),
		'id'        => $prefix . '_post_heading_skin',
		'std'       => nice_default_setting( 'post_heading_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Post Title Background Image', 'smart' ),
		'desc'      => esc_html__( 'Upload/select a background image.', 'smart' ),
		'id'        => $prefix . '_post_background_image',
		'std'       => nice_default_setting( 'post_background_image' ),
		'type'      => 'upload',
		'condition' => $prefix . '_post_heading:not(false), ' . $prefix . '_post_background_solid_color:not(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Parallax for Background Image', 'smart' ),
		'desc'      => esc_html__( 'Add a parallax effect to the background image.', 'smart' ),
		'id'        => $prefix . '_post_background_image_parallax',
		'std'       => nice_default_setting( 'post_background_image_parallax' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_background_image:not()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Image Repeat', 'smart' ),
		'desc'      => esc_html__( 'Select how your background image should be repeated.', 'smart' ),
		'id'        => $prefix . '_post_background_repeat',
		'std'       => nice_default_setting( 'post_background_repeat' ),
		'type'      => 'select',
		'options' => array(
			''          => esc_html__( 'Inherit', 'smart' ),
			'no-repeat' => esc_html__( 'No Repeat', 'smart' ),
			'repeat'    => esc_html__( 'Repeat All', 'smart' ),
			'repeat-x'  => esc_html__( 'Repeat Horizontally', 'smart' ),
			'repeat-y'  => esc_html__( 'Repeat Vertically', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_background_image:not(),' . $prefix . '_post_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Image Position', 'smart' ),
		'desc'      => esc_html__( 'Select where your background image should be positioned.', 'smart' ),
		'id'        => $prefix . '_post_background_position',
		'std'       => nice_default_setting( 'post_background_position' ),
		'type'      => 'select',
		'options' => array(
			''              => esc_html__( 'Inherit', 'smart' ),
			'left top'      => esc_html__( 'Left Top', 'smart' ),
			'left center'   => esc_html__( 'Left Center', 'smart' ),
			'left bottom'   => esc_html__( 'Left Bottom', 'smart' ),
			'center top'    => esc_html__( 'Center Top', 'smart' ),
			'center center' => esc_html__( 'Center Center', 'smart' ),
			'center bottom' => esc_html__( 'Center Bottom', 'smart' ),
			'right top'     => esc_html__( 'Right Top', 'smart' ),
			'right center'  => esc_html__( 'Right Center', 'smart' ),
			'right bottom'  => esc_html__( 'Right Bottom', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_background_image:not(),' . $prefix . '_post_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Image Size', 'smart' ),
		'desc'      => esc_html__( 'Select the size for you background image.', 'smart' ),
		'id'        => $prefix . '_post_background_size',
		'std'       => nice_default_setting( 'post_background_size' ),
		'type'      => 'select',
		'options' => array(
			''        => esc_html__( 'Inherit', 'smart' ),
			'auto'    => esc_html__( 'Auto', 'smart' ),
			'cover'   => esc_html__( 'Cover', 'smart' ),
			'contain' => esc_html__( 'Contain', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_background_image:not(),' . $prefix . '_post_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Image Attachment', 'smart' ),
		'desc'      => esc_html__( 'Select how your background image should be attached to the post.', 'smart' ),
		'id'        => $prefix . '_post_background_attachment',
		'std'       => nice_default_setting( 'post_background_attachment' ),
		'type'      => 'select',
		'options' => array(
			''        => esc_html__( 'Inherit', 'smart' ),
			'scroll'  => esc_html__( 'Scroll', 'smart' ),
			'fixed'   => esc_html__( 'Fixed', 'smart' ),
		),
		'condition' => $prefix . '_post_heading:not(false),' . $prefix . '_post_background_image:not(),' . $prefix . '_post_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Post Title Bar Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a background color. If a background image is set from Theme Options, your selected color will show instead as a solid background.', 'smart' ),
		'id'        => $prefix . '_post_background_color',
		'std'       => nice_default_setting( 'post_background_color' ),
		'type'      => 'select_color',
		'options'   => nice_theme_colors_dropdown_values(),
		'class'     => 'nice-select-color',
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Scroll Down Arrow Button', 'smart' ),
		'desc'      => esc_html__( 'Show the scroll down arrow button.', 'smart' ),
		'id'        => $prefix . '_post_scroll_down_arrow',
		'std'       => nice_default_setting( 'post_scroll_down_arrow' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_post_heading:not(false)',
		'operator'  => 'and',
	);

	/**
	 * Layout > Posts > Content
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Content', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-binder-three"></i>',
		'id'     => $prefix . '_layout_posts_content',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Post Title in Content', 'smart' ),
		'desc'      => esc_html__( 'Show the post title in the content area.', 'smart' ),
		'id'        => $prefix . '_post_title_content',
		'std'       => nice_default_setting( 'post_title_content' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),

	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Post Featured Image in Content', 'smart' ),
		'desc'      => esc_html__( 'Show the post featured image in the content area.', 'smart' ),
		'id'        => $prefix . '_post_thumbnail_content',
		'std'       => nice_default_setting( 'post_thumbnail_content' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the content skin for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_content_skin',
		'std'       => nice_default_setting( 'post_content_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),

	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Content Width', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to limit the content width for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_content_width',
		'std'       => nice_default_setting( 'post_content_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Custom Width', 'smart' ),
		'desc'              => esc_html__( 'Define the custom width for the content area (in px or in %).', 'smart' ),
		'id'                => $prefix . '_post_content_width_value',
		'std'               => nice_default_setting( 'post_content_width_value' ),
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'condition'         => $prefix . '_post_content_width:not(full)',
		'operator'          => 'and',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Post Author Box', 'smart' ),
		'desc' => sprintf( esc_html__( 'Show the post author box on the single posts page. You can edit your author description in %1$sUsers > Your Profile%2$s.', 'smart' ), sprintf( '<a href="%s">', admin_url( 'profile.php' ) ), '</a>' ),
		'id'   => $prefix . '_post_author',
		'std'  => nice_default_setting( 'post_author' ),
		'tip'  => '',
		'type' => 'checkbox',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Post Navigation Skin', 'smart' ),
		'desc'    => esc_html__( 'Select the post navigation skin.', 'smart' ),
		'id'      => $prefix . '_post_navigation_skin',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'post_navigation_skin' ),
		'tip'     => '',
		'options' => array(
			'light' => array( 'label' => esc_html__( 'Light', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-light.png' ) ),
			'dark'  => array( 'label' => esc_html__( 'Dark', 'smart' ), 'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-dark.png' ) ),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Post Navigation Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the post navigation background color.', 'smart' ),
		'id'        => $prefix . '_post_navigation_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'post_navigation_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'operator'  => 'and',
	);

	/**
	 * Layout > Posts > Sidebar
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Sidebar', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-sidebar-r-a"></i>',
		'id'   => $prefix . '_layout_posts_sidebar',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Sidebar', 'smart' ),
		'desc'      => esc_html__( 'Show a sidebar for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_sidebar',
		'std'       => nice_default_setting( 'post_sidebar' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Select Sidebar', 'smart' ),
		'desc'      => esc_html__( 'Select the sidebar for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_sidebar_id',
		'std'       => nice_default_setting( 'post_sidebar_id' ),
		'type'      => 'select_sidebar',
		'condition' => $prefix . '_post_sidebar:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Sidebar Position', 'smart' ),
		'desc'      => esc_html__( 'Set the position of the sidebar for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_sidebar_position',
		'type'      => 'select',
		'std'       => nice_default_setting( 'post_sidebar_position' ),
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
		'condition' => $prefix . '_post_sidebar:not(false)',
		'operator'  => 'and',
	);

	/**
	 * Layout > Posts > Footer
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Footer', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-footer"></i>',
		'id'     => $prefix . '_layout_posts_footer',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Footer', 'smart' ),
		'desc'      => esc_html__( 'Show the footer for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_footer',
		'std'       => nice_default_setting( 'post_footer' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Footer Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the footer skin for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_footer_skin',
		'std'       => nice_default_setting( 'post_footer_skin' ),
		'type'      => 'select',
		'options' => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
		),
		'condition' => $prefix . '_post_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Footer Widgets Area', 'smart' ),
		'desc'      => esc_html__( 'Show the footer widgets area for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_footer_widgets',
		'std'       => nice_default_setting( 'post_footer_widgets' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_post_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Copyright Area', 'smart' ),
		'desc'      => esc_html__( 'Show the footer copyright area for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_footer_extended',
		'std'       => nice_default_setting( 'post_footer_extended' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_post_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to show a the social icons in the footer for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_footer_display_social',
		'std'       => nice_default_setting( 'post_footer_display_social' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_post_footer:not(false),' . $prefix . '_post_footer_extended:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Footer Width', 'smart' ),
		'desc'      => esc_html__( 'Select the width of the footer contents for the default post template.', 'smart' ),
		'id'        => $prefix . '_post_footer_width',
		'std'       => nice_default_setting( 'post_footer_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_post_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the footer area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_post_footer_width_value',
		'std'       => nice_default_setting( 'post_footer_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_post_footer:not(false),' . $prefix . '_post_footer_width:is(limit)',
		'operator'  => 'and',
	);

	/**
	 * Layout > Pages
	 */

	$nice_options[] = array(
		'name'   => esc_html__( 'Pages', 'smart' ),
		'type'   => 'heading',
		'icon'   => '<i class="bi_doc-article-b"></i>',
		'id'     => $prefix . '_layout_pages',
		'parent' => $prefix . '_layout',
	);

	/**
	 * Layout > Pages > Header
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Header', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-header"></i>',
		'id'   => $prefix . '_layout_page_header',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Header', 'smart' ),
		'desc'      => esc_html__( 'Show the header for pages.', 'smart' ),
		'id'        => $prefix . '_page_header',
		'std'       => nice_default_setting( 'page_header' ),
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Navigation Menu', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation menu to use for pages.', 'smart' ),
		'id'        => $prefix . '_page_navigation_menu',
		'std'       => nice_default_setting( 'page_navigation_menu' ),
		'type'      => 'select',
		'options'   => nice_get_navigation_menus(),
		'condition' => $prefix . '_page_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Navigation Style', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation style to use for pages.', 'smart' ),
		'id'        => $prefix . '_page_navigation_style',
		'std'       => nice_default_setting( 'page_navigation_style' ),
		'type'      => 'select',
		'options'   => array(
			''         => esc_html__( 'Inherit', 'smart' ),
			'default'  => esc_html__( 'Top', 'smart' ),
			'vertical' => esc_html__( 'Side', 'smart' ),
			'overlay'  => esc_html__( 'Overlay', 'smart' ),
		),
		'condition' => $prefix . '_page_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Transparent Header', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent.', 'smart' ),
		'id'        => $prefix . '_page_header_background_transparent',
		'std'       => nice_default_setting( 'page_header_background_transparent' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_page_header:not(false),' . $prefix . '_page_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Transparent Header (Mobile)', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent in smaller viewports. This option only works when the transparent header is enabled on desktop.', 'smart' ),
		'id'        => $prefix . '_page_header_background_transparent_mobile',
		'std'       => nice_default_setting( 'page_header_background_transparent_mobile' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_page_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the header content skin to use for pages.', 'smart' ),
		'id'        => $prefix . '_page_header_skin',
		'std'       => nice_default_setting( 'page_header_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_page_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a background color.', 'smart' ),
		'id'        => $prefix . '_page_header_background_color',
		'std'       => nice_default_setting( 'page_header_background_color' ),
		'type'      => 'select_color',
		'options'   => nice_theme_colors_dropdown_values(),
		'class'     => 'nice-select-color',
		'condition' => $prefix . '_page_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Navigation Sub-Menu Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation sub-menu content skin to use for pages.', 'smart' ),
		'id'        => $prefix . '_page_navigation_submenu_skin',
		'std'       => nice_default_setting( 'page_navigation_submenu_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_page_header:not(false),' . $prefix . '_page_navigation_style:not(overlay)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Header Width', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to make the header contents take the full width for pages.', 'smart' ),
		'id'        => $prefix . '_page_header_width',
		'std'       => nice_default_setting( 'page_header_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_page_header:not(false),' . $prefix . '_page_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the header area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_page_header_width_value',
		'std'       => nice_default_setting( 'page_header_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_page_header:not(false),' . $prefix . '_page_navigation_style:not(vertical),' . $prefix . '_page_header_width:is(limit)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Search', 'smart' ),
		'desc'      => esc_html__( "Select whether or not to show a link to the site's search in the header for pages.", 'smart' ),
		'id'        => $prefix . '_page_header_display_search',
		'std'       => nice_default_setting( 'page_header_display_search' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_page_header:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'      => esc_html__( "Select whether or not to show a the social icons in the header for pages.", 'smart' ),
		'id'        => $prefix . '_page_header_display_social',
		'std'       => nice_default_setting( 'page_header_display_social' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_page_header:not(false)',
		'operator'  => 'and',
	);

	/**
	 * Layout > Pages > Title Bar
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Title Bar', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-third-h"></i>',
		'id'   => $prefix . '_layout_page_title_bar',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Title Bar', 'smart' ),
		'desc'      => esc_html__( 'Show the title bar section for this post.', 'smart' ),
		'id'        => $prefix . '_page_heading',
		'std'       => nice_default_setting( 'page_heading' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Page Title in the Title Bar', 'smart' ),
		'desc'      => esc_html__( 'Show the post title in the title bar.', 'smart' ),
		'id'        => $prefix . '_page_title_heading',
		'std'       => nice_default_setting( 'page_title_heading' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_page_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Page Subtitle', 'smart' ),
		'desc'      => esc_html__( 'Enter a subtitle (optional).', 'smart' ),
		'id'        => $prefix . '_page_subtitle',
		'std'       => nice_default_setting( 'page_subtitle' ),
		'type'      => 'text',
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_title_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Horizontal Alignment', 'smart' ),
		'desc'      => esc_html__( 'Select the horizontal alignment you would like for your title and subtitle.', 'smart' ),
		'id'        => $prefix . '_page_title_alignment',
		'std'       => nice_default_setting( 'page_title_alignment' ),
		'type'      => 'select',
		'options'   => array(
			''       => esc_html__( 'Inherit', 'smart' ),
			'left'   => esc_html__( 'Left', 'smart' ),
			'center' => esc_html__( 'Center', 'smart' ),
			'right'  => esc_html__( 'Right', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Vertical Alignment', 'smart' ),
		'desc'      => esc_html__( 'Select the vertical alignment you would like for your title and subtitle (warning: bottom alignment may overlap with scroll down arrow).', 'smart' ),
		'id'        => $prefix . '_page_title_alignment_v',
		'std'       => nice_default_setting( 'page_title_alignment_v' ),
		'type'      => 'select',
		'options'   => array(
			''       => esc_html__( 'Inherit', 'smart' ),
			'top'    => esc_html__( 'Top', 'smart' ),
			'middle' => esc_html__( 'Middle', 'smart' ),
			'bottom' => esc_html__( 'Bottom', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Width', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to make the contents of the title bar take the full width for pages.', 'smart' ),
		'id'        => $prefix . '_page_title_width',
		'std'       => nice_default_setting( 'page_title_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the title bar area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_page_title_width_value',
		'std'       => nice_default_setting( 'page_title_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_navigation_style:not(vertical),' . $prefix . '_page_title_width:is(limit)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Height', 'smart' ),
		'desc'              => esc_html__( 'Define the custom height for the title area in px or in %. Leave blank to use default theme settings.', 'smart' ),
		'id'                => $prefix . '_page_title_height',
		'std'               => nice_default_setting( 'page_title_height' ),
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'condition'         => $prefix . '_page_heading:not(false)',
		'operator'          => 'and',
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Minimum height', 'smart' ),
		'desc'              => esc_html__( 'Enter a minimum height for the header (in pixels). Leave blank to use default theme settings.', 'smart' ),
		'id'                => $prefix . '_page_title_height_min',
		'std'               => nice_default_setting( 'page_title_height_min' ),
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'condition'         => $prefix . '_page_heading:not(false)',
		'operator'          => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Text Transform', 'smart' ),
		'desc'      => esc_html__( 'Select the title text transformation.', 'smart' ),
		'id'        => $prefix . '_page_title_text_transform',
		'std'       => nice_default_setting( 'page_title_text_transform' ),
		'type'      => 'select',
		'options'   => array(
			''           => esc_html__( 'Inherit', 'smart' ),
			'default'    => esc_html__( 'Default CSS', 'smart' ),
			'uppercase'  => esc_html__( 'Uppercase', 'smart' ),
			'lowercase'  => esc_html__( 'Lowercase', 'smart' ),
			'capitalize' => esc_html__( 'Capitalize', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_title_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Font Weight', 'smart' ),
		'desc'      => esc_html__( 'Select the title font weight.', 'smart' ),
		'id'        => $prefix . '_page_title_font_weight',
		'std'       => nice_default_setting( 'page_title_font_weight' ),
		'type'      => 'select',
		'options'   => nice_font_weight(),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_title_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Title Font Size', 'smart' ),
		'desc'      => esc_html__( 'Select the title font size.', 'smart' ),
		'id'        => $prefix . '_page_title_font_size',
		'std'       => nice_default_setting( 'page_title_font_size' ),
		'type'      => 'select',
		'options'   => array(
			''             => esc_html__( 'Inherit', 'smart' ),
			'h1'           => esc_html__( 'h1', 'smart' ),
			'h2'           => esc_html__( 'h2', 'smart' ),
			'h3'           => esc_html__( 'h3', 'smart' ),
			'h4'           => esc_html__( 'h4', 'smart' ),
			'h5'           => esc_html__( 'h5', 'smart' ),
			'h6'           => esc_html__( 'h6', 'smart' ),
			'fontsize-12'  => esc_html__( 'Size 12px', 'smart' ),
			'fontsize-40'  => esc_html__( 'Size 40px', 'smart' ),
			'fontsize-50'  => esc_html__( 'Size 50px', 'smart' ),
			'fontsize-75'  => esc_html__( 'Size 75px', 'smart' ),
			'fontsize-100' => esc_html__( 'Size 100px', 'smart' ),
			'fontsize-125' => esc_html__( 'Size 125px', 'smart' ),
			'fontsize-150' => esc_html__( 'Size 150px', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_title_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Page Title Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the heading skin. "Light" equals light background with dark color contents, and "Dark" equals dark background with light color contents.', 'smart' ),
		'id'        => $prefix . '_page_heading_skin',
		'std'       => nice_default_setting( 'page_heading_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Page Title Background Image', 'smart' ),
		'desc'      => esc_html__( 'Upload/select a background image.', 'smart' ),
		'id'        => $prefix . '_page_background_image',
		'std'       => nice_default_setting( 'page_background_image' ),
		'type'      => 'upload',
		'extra'     => array( 'type' => 'image' ),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_background_solid_color:not(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Parallax for Background Image', 'smart' ),
		'desc'      => esc_html__( 'Add a parallax effect to the background image.', 'smart' ),
		'id'        => $prefix . '_page_background_image_parallax',
		'std'       => nice_default_setting( 'page_background_image_parallax' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_background_image:not()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Image Repeat', 'smart' ),
		'desc'      => esc_html__( 'Select how your background image should be repeated.', 'smart' ),
		'id'        => $prefix . '_page_background_repeat',
		'std'       => nice_default_setting( 'page_background_repeat' ),
		'type'      => 'select',
		'options' => array(
			''          => esc_html__( 'Inherit', 'smart' ),
			'no-repeat' => esc_html__( 'No Repeat', 'smart' ),
			'repeat'    => esc_html__( 'Repeat All', 'smart' ),
			'repeat-x'  => esc_html__( 'Repeat Horizontally', 'smart' ),
			'repeat-y'  => esc_html__( 'Repeat Vertically', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_background_image:not(),' . $prefix . '_page_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Image Position', 'smart' ),
		'desc'      => esc_html__( 'Select where your background image should be positioned.', 'smart' ),
		'id'        => $prefix . '_page_background_position',
		'std'       => nice_default_setting( 'page_background_position' ),
		'type'      => 'select',
		'options' => array(
			''              => esc_html__( 'Inherit', 'smart' ),
			'left top'      => esc_html__( 'Left Top', 'smart' ),
			'left center'   => esc_html__( 'Left Center', 'smart' ),
			'left bottom'   => esc_html__( 'Left Bottom', 'smart' ),
			'center top'    => esc_html__( 'Center Top', 'smart' ),
			'center center' => esc_html__( 'Center Center', 'smart' ),
			'center bottom' => esc_html__( 'Center Bottom', 'smart' ),
			'right top'     => esc_html__( 'Right Top', 'smart' ),
			'right center'  => esc_html__( 'Right Center', 'smart' ),
			'right bottom'  => esc_html__( 'Right Bottom', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_background_image:not(),' . $prefix . '_page_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Image Size', 'smart' ),
		'desc'      => esc_html__( 'Select the size for you background image.', 'smart' ),
		'id'        => $prefix . '_page_background_size',
		'std'       => nice_default_setting( 'page_background_size' ),
		'type'      => 'select',
		'options' => array(
			''        => esc_html__( 'Inherit', 'smart' ),
			'auto'    => esc_html__( 'Auto', 'smart' ),
			'cover'   => esc_html__( 'Cover', 'smart' ),
			'contain' => esc_html__( 'Contain', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_background_image:not(),' . $prefix . '_page_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Image Attachment', 'smart' ),
		'desc'      => esc_html__( 'Select how your background image should be attached to the post.', 'smart' ),
		'id'        => $prefix . '_page_background_attachment',
		'std'       => nice_default_setting( 'page_background_attachment' ),
		'type'      => 'select',
		'options' => array(
			''        => esc_html__( 'Inherit', 'smart' ),
			'scroll'  => esc_html__( 'Scroll', 'smart' ),
			'fixed'   => esc_html__( 'Fixed', 'smart' ),
		),
		'condition' => $prefix . '_page_heading:not(false),' . $prefix . '_page_background_image:not(),' . $prefix . '_page_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Page Title Bar Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a background color. If a background image is set from Theme Options, your selected color will show instead as a solid background.', 'smart' ),
		'id'        => $prefix . '_page_background_color',
		'std'       => nice_default_setting( 'page_background_color' ),
		'type'      => 'select_color',
		'options'   => nice_theme_colors_dropdown_values(),
		'class'     => 'nice-select-color',
		'condition' => $prefix . '_page_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Scroll Down Arrow Button', 'smart' ),
		'desc'      => esc_html__( 'Show the scroll down arrow button.', 'smart' ),
		'id'        => $prefix . '_page_scroll_down_arrow',
		'std'       => nice_default_setting( 'page_scroll_down_arrow' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_page_heading:not(false)',
		'operator'  => 'and',
	);


	/**
	 * Layout > Pages > Content
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Content', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-binder-three"></i>',
		'id'   => $prefix . '_layout_page_content',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Content Skin', 'smart' ),
		'desc'    => esc_html__( 'Select the content skin for this page.', 'smart' ),
		'id'      => $prefix . '_page_content_skin',
		'std'     => nice_default_setting( 'page_content_skin' ),
		'type'    => 'select',
		'options' => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Display Page Title in Content', 'smart' ),
		'desc'    => esc_html__( 'Show the page title in the content area.', 'smart' ),
		'id'      => $prefix . '_page_title_content',
		'std'       => nice_default_setting( 'page_title_content' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Content Width', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to limit the content width for this page.', 'smart' ),
		'id'        => $prefix . '_page_content_width',
		'std'       => nice_default_setting( 'page_content_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),

	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Custom Width', 'smart' ),
		'desc'              => esc_html__( 'Define the custom width for the content area (in px or in %).', 'smart' ),
		'id'                => $prefix . '_page_content_width_value',
		'std'               => nice_default_setting( 'page_content_width_value' ),
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'condition'         => $prefix . '_page_content_width:not(full),' . $prefix . '_page_content_width:not()',
		'operator'          => 'and',
	);

	/**
	 * Layout > Pages > Sidebar
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Sidebar', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-sidebar-r-a"></i>',
		'id'   => $prefix . '_layout_page_sidebar',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Sidebar', 'smart' ),
		'desc'      => esc_html__( 'Show a sidebar for pages.', 'smart' ),
		'id'        => $prefix . '_page_sidebar',
		'std'       => nice_default_setting( 'page_sidebar' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Select Sidebar', 'smart' ),
		'desc'      => esc_html__( 'Select the sidebar for the pages.', 'smart' ),
		'id'        => $prefix . '_page_sidebar_id',
		'std'       => nice_default_setting( 'page_sidebar_id' ),
		'type'      => 'select_sidebar',
		'condition' => $prefix . '_page_sidebar:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Sidebar Position', 'smart' ),
		'desc'      => esc_html__( 'Set the position of the sidebar for pages.', 'smart' ),
		'id'        => $prefix . '_page_sidebar_position',
		'type'      => 'select',
		'std'       => nice_default_setting( 'page_sidebar_position' ),
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
		'condition' => $prefix . '_page_sidebar:not(false)',
		'operator'  => 'and',
	);

	/**
	 * Layout > Pages > Footer
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Footer', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-footer"></i>',
		'id'   => $prefix . '_layout_page_footer',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Footer', 'smart' ),
		'desc'      => esc_html__( 'Show the footer for pages.', 'smart' ),
		'id'        => $prefix . '_page_footer',
		'std'       => nice_default_setting( 'page_footer' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),

	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Footer Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the footer skin for pages.', 'smart' ),
		'id'        => $prefix . '_page_footer_skin',
		'std'       => nice_default_setting( 'page_footer_skin' ),
		'type'      => 'select',
		'options' => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
		),
		'condition' => $prefix . '_page_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Footer Widgets Area', 'smart' ),
		'desc'      => esc_html__( 'Show the footer widgets area for pages.', 'smart' ),
		'id'        => $prefix . '_page_footer_widgets',
		'std'       => nice_default_setting( 'page_footer_widgets' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_page_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Copyright Area', 'smart' ),
		'desc'      => esc_html__( 'Show the footer copyright area for pages.', 'smart' ),
		'id'        => $prefix . '_page_footer_extended',
		'std'       => nice_default_setting( 'page_footer_extended' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_page_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to show a the social icons in the footer for pages.', 'smart' ),
		'id'        => $prefix . '_page_footer_display_social',
		'std'       => nice_default_setting( 'page_footer_display_social' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'true'  => esc_html__( 'Yes', 'smart' ),
			'false' => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_page_footer:not(false),' . $prefix . '_page_footer_extended:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Footer Width', 'smart' ),
		'desc'      => esc_html__( 'Select the width of the footer contents for pages.', 'smart' ),
		'id'        => $prefix . '_page_footer_width',
		'std'       => nice_default_setting( 'page_footer_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_page_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the footer area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_page_footer_width_value',
		'std'       => nice_default_setting( 'page_footer_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_page_footer:not(false),' . $prefix . '_page_footer_width:is(limit)',
		'operator'  => 'and',
	);

	/**
	 * Customize
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Customize', 'smart' ),
		'type' => 'heading',
		'icon' => '<i class="bi_misc-cube"></i>',
		'id'   => $prefix . '_customize_section',
	);

	/**
	 * Customize > General
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'General', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_web-internet-a"></i>',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'HTML Background Color', 'smart' ),
		'desc'      => esc_html__( 'Set the HTML background color.', 'smart' ),
		'id'        => $prefix . '_html_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'html_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	/**
	 * Customize > Light Skin
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Light Skin', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-binder-blank"></i>',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Light Skin background color.', 'smart' ),
		'id'        => $prefix . '_light_skin_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'light_skin_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Text Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Light Skin text color.', 'smart' ),
		'id'        => $prefix . '_light_skin_text_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'light_skin_text_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Link Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Light Skin link color.', 'smart' ),
		'id'        => $prefix . '_light_skin_link_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'light_skin_link_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Headings Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Light Skin headings color.', 'smart' ),
		'id'        => $prefix . '_light_skin_heading_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'light_skin_heading_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Primary Menu Text Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Light Skin Primary Menu Text Color.', 'smart' ),
		'id'        => $prefix . '_light_skin_nav_text_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'light_skin_nav_text_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Secondary Menu Text Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Light Skin Secondary Menu Text Color.', 'smart' ),
		'id'        => $prefix . '_light_skin_subnav_text_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'light_skin_subnav_text_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Secondary Menu Background Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Light Skin Secondary Menu Text Color.', 'smart' ),
		'id'        => $prefix . '_light_skin_subnav_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'light_skin_subnav_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Footer Background Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Light Skin Footer Background Color.', 'smart' ),
		'id'        => $prefix . '_light_skin_footer_background_color',
		'type'      => 'select_color',
		'std'       => '',
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Footer Extended Background Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Light Skin Footer Extended Background Color.', 'smart' ),
		'id'        => $prefix . '_light_skin_footer_extended_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'light_skin_footer_extended_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	/**
	 * Customize > Dark Skin
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Dark Skin', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-binder-blank dark-background"></i>',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Background Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Dark Skin background color.', 'smart' ),
		'id'        => $prefix . '_dark_skin_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'dark_skin_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Text Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Dark Skin text color.', 'smart' ),
		'id'        => $prefix . '_dark_skin_text_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'dark_skin_text_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Link Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Dark Skin link color.', 'smart' ),
		'id'        => $prefix . '_dark_skin_link_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'dark_skin_link_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Headings Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Dark Skin headings color.', 'smart' ),
		'id'        => $prefix . '_dark_skin_heading_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'dark_skin_heading_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Primary Menu Text Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Dark Skin Primary Menu Text Color.', 'smart' ),
		'id'        => $prefix . '_dark_skin_nav_text_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'dark_skin_nav_text_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Secondary Menu Text Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Dark Skin Secondary Menu Text Color.', 'smart' ),
		'id'        => $prefix . '_dark_skin_subnav_text_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'dark_skin_subnav_text_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Secondary Menu Background Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Dark Skin Secondary Menu Text Color.', 'smart' ),
		'id'        => $prefix . '_dark_skin_subnav_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'dark_skin_subnav_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

		$nice_options[] = array(
		'name'      => esc_html__( 'Footer Background Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Dark Skin Footer Background Color.', 'smart' ),
		'id'        => $prefix . '_dark_skin_footer_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'dark_skin_footer_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Footer Extended Background Color', 'smart' ),
		'desc'      => esc_html__( 'Set the Dark Skin Footer Extended Background Color.', 'smart' ),
		'id'        => $prefix . '_dark_skin_footer_extended_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'dark_skin_footer_extended_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	/**
	 * Customize > Navigation
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Navigation', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_interface-hamburger"></i>',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Menu Hover Effect', 'smart' ),
		'desc'      => esc_html__( 'Select the effect for menu links on hover.', 'smart' ),
		'id'        => $prefix . '_menu_hover_effect',
		'type'      => 'select',
		'std'       => nice_default_setting( 'menu_hover_effect' ),
		'tip'       => '',
		'options'   => array(
			''                   => esc_html__( 'Default', 'smart' ),
			'color'              => esc_html__( 'Color highlight', 'smart' ),
			'underline'          => esc_html__( 'Underline', 'smart' ),
			'underline-animated' => esc_html__( 'Underline animated', 'smart' ),
		)
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Menu Highlight Color', 'smart' ),
		'desc'      => esc_html__( 'Set the menu hover and active effect color (by default an opaque version of the menu color will be used).', 'smart' ),
		'id'        => $prefix . '_menu_highlight_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'menu_highlight_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	/**
	 * Customize > Buttons
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Buttons', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_tool-mouse"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Default Button Shape', 'smart' ),
		'desc'    => esc_html__( 'Select the default shape for your site\'s buttons.', 'smart' ),
		'id'      => $prefix . '_btn_shape',
		'type'    => 'radio_image',
		'std'     => nice_default_setting( 'btn_shape' ),
		'tip'     => '',
		'options' => array(
			'' => array(
				'label' => esc_html__( 'Default', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-general-default.png' ),
			),
			'round' => array(
				'label' => esc_html__( 'Round', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-general-round.png' ),
			),
			'circle'  => array(
				'label' => esc_html__( 'Circle', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-general-circle.png' ),
			),
			'square'  => array(
				'label' => esc_html__( 'Square', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-general-square.png' ),
			),
		),
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Default Button Color', 'smart' ),
		'desc'    => esc_html__( 'Select the default color for your site\'s buttons.', 'smart' ),
		'id'      => $prefix . '_btn_color',
		'type'    => 'select_color',
		'class'   => 'nice-select-color',
		'std'     => nice_default_setting( 'btn_color' ),
		'tip'     => '',
		'options' => nice_theme_colors_dropdown_values(),
	);

	/**
	 * Customize > Custom Code & Scripts
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Custom Code & Scripts', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_web-code"></i>',
	);

	/**
	 *
	 * @hook nice_use_custom_css
	 *
	 * Allow using your custom CSS from the theme.
	 *
	 * @since 1.0.0
	 */
	if ( version_compare( $wp_version, '4.7', '<' ) || apply_filters( 'nice_use_custom_css', true ) ) {
		$nice_options[] = array(
			'name'  => esc_html__( 'Custom CSS', 'smart' ),
			'desc'  => esc_html__( 'Quickly add some CSS to your theme by adding it to this block.', 'smart' ),
			'id'    => $prefix . '_custom_css',
			'std'   => nice_default_setting( 'custom_css' ),
			'tip'   => '',
			'type'  => 'textarea',
			'extra' => array(
				'type'    => 'code',
				'choices' => array(
					'language' => 'css',
					'theme'    => 'monokai',
				),
			),
		);
	}

	$nice_options[] = array(
		'name'  => esc_html__( 'Custom JavaScript', 'smart' ),
		'desc'  => esc_html__( 'Quickly add some JavaScript to your theme by adding it to this block.', 'smart' ),
		'id'    => $prefix . '_custom_js',
		'std'   => nice_default_setting( 'custom_js' ),
		'tip'   => '',
		'type'  => 'textarea',
		'extra' => array(
			'type'    => 'code',
			'choices' => array(
				'language' => 'js',
				'theme'    => 'monokai',
			),
		),
	);

	/**
	 *
	 * @hook nice_use_tracking_code
	 *
	 * Allow using your custom tracking code from the theme.
	 *
	 * @since 1.0.0
	 */
	if ( apply_filters( 'nice_use_tracking_code', true ) ) {
		$nice_options[] = array(
			'name'  => esc_html__( 'Tracking Code', 'smart' ),
			'desc'  => esc_html__( 'Insert your tracking code if you have one (i.e. from Google Analytics).', 'smart' ),
			'id'    => $prefix . '_tracking_code',
			'std'   => nice_default_setting( 'tracking_code' ),
			'tip'   => '',
			'type'  => 'textarea',
			'extra' => array(
				'type'    => 'code',
				'choices' => array(
					'language' => 'xml',
					'theme'    => 'monokai',
				),
			),
		);
	}

	/**
	 * Customize > Admin
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Admin', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_interface-dashboard"></i>',
	);

	$nice_options[] = array(
		'name'    => esc_html__( 'Display Theme Admin Bar Menu', 'smart' ),
		'desc'    => esc_html__( 'Show the Theme Admin Bar Menu when viewing the theme.', 'smart' ),
		'id'      => $prefix . '_admin_bar_menu',
		'std'     => nice_default_setting( 'admin_bar_menu' ),
		'options' => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);


	/**
	 * Typography
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Typography', 'smart' ),
		'id'   => $prefix . '_custom_typography_section',
		'type' => 'heading',
		'icon' => '<i class="bi_editorial-pen"></i>',
	);

	/**
	 * Typography > Custom Fonts
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Custom Fonts', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_editorial-pen"></i>',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Custom Typographies', 'smart' ),
		'desc' => esc_html__( 'Pick your own fonts, and set their properties.', 'smart' ),
		'id'   => $prefix . '_custom_typography',
		'std'  => nice_default_setting( 'custom_typography' ),
		'type' => 'checkbox',
	);

	$nice_options[] = array(
		'name'        => esc_html__( 'General Typography', 'smart' ),
		'desc'        => esc_html__( 'Choose the general font, and set its properties.', 'smart' ),
		'id'          => $prefix . '_font_body',
		'std'         => nice_default_setting( 'font_body' ),
		'min'         => 0,
		'max'         => 100,
		'units'       => array( 'px', 'em', '%' ),
		'type'        => 'typography',
		'font_styles' => array(
			'normal'      => esc_html__( 'Normal', 'smart' ),
			'italic'      => esc_html__( 'Italic', 'smart' ),
			'bold'        => esc_html__( 'Bold', 'smart' ),
			'italic bold' => esc_html__( 'Italic/Bold', 'smart' ),
		),
		'condition'   => $prefix . '_custom_typography:is(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'        => esc_html__( 'Navigation Menu', 'smart' ),
		'desc'        => esc_html__( 'Choose the navigation menu font, and set its properties.', 'smart' ),
		'id'          => $prefix . '_font_menu',
		'std'         => nice_default_setting( 'font_menu' ),
		'min'         => 0,
		'max'         => 100,
		'type'        => 'typography',
		'units'       => array( 'px', 'em', '%' ),
		'font_styles' => array(
			'normal'      => esc_html__( 'Normal', 'smart' ),
			'italic'      => esc_html__( 'Italic', 'smart' ),
			'bold'        => esc_html__( 'Bold', 'smart' ),
			'italic bold' => esc_html__( 'Italic/Bold', 'smart' ),
		),
		'condition'   => $prefix . '_custom_typography:is(true),' . $prefix . '_header_navigation:not(overlay)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'        => esc_html__( 'Navigation Sub-Menus', 'smart' ),
		'desc'        => esc_html__( 'Choose the navigation sub-menus font, and set its properties.', 'smart' ),
		'id'          => $prefix . '_font_submenu',
		'std'         => nice_default_setting( 'font_submenu' ),
		'min'         => 0,
		'max'         => 100,
		'type'        => 'typography',
		'units'       => array( 'px', 'em', '%' ),
		'font_styles' => array(
			'normal'      => esc_html__( 'Normal', 'smart' ),
			'italic'      => esc_html__( 'Italic', 'smart' ),
			'bold'        => esc_html__( 'Bold', 'smart' ),
			'italic bold' => esc_html__( 'Italic/Bold', 'smart' ),
		),
		'condition'   => $prefix . '_custom_typography:is(true),' . $prefix . '_header_navigation:not(overlay)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'        => esc_html__( 'Top Bar', 'smart' ),
		'desc'        => esc_html__( 'Choose the top bar font, and set its properties.', 'smart' ),
		'id'          => $prefix . '_font_top_bar',
		'std'         => nice_default_setting( 'font_top_bar' ),
		'min'         => 0,
		'max'         => 100,
		'type'        => 'typography',
		'units'       => array( 'px', 'em', '%' ),
		'font_styles' => array(
			'normal'      => esc_html__( 'Normal', 'smart' ),
			'italic'      => esc_html__( 'Italic', 'smart' ),
			'bold'        => esc_html__( 'Bold', 'smart' ),
			'italic bold' => esc_html__( 'Italic/Bold', 'smart' ),
		),
		'condition'   => $prefix . '_custom_typography:is(true)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'        => esc_html__( 'Overlay Navigation Menu', 'smart' ),
		'desc'        => esc_html__( 'Choose the overlay navigation menu font, and set its properties.', 'smart' ),
		'id'          => $prefix . '_font_overlay_menu',
		'std'         => nice_default_setting( 'font_overlay_menu' ),
		'min'         => 0,
		'max'         => 100,
		'type'        => 'typography',
		'units'       => array(),
		'font_styles' => array( 'normal' => esc_html__( 'Normal', 'smart' ) ),
		'condition'   => $prefix . '_custom_typography:is(true),' . $prefix . '_header_navigation:is(overlay)',
		'operator'    => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Headings', 'smart' ),
		'desc'      => esc_html__( 'Choose the headings font, and set its properties.', 'smart' ),
		'id'        => $prefix . '_font_headings',
		'std'       => nice_default_setting( 'font_headings' ),
		'min'       => 0,
		'max'       => 100,
		'type'      => 'typography',
		'condition' => $prefix . '_custom_typography:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Buttons', 'smart' ),
		'desc'      => esc_html__( 'Choose the buttons font, and set its properties.', 'smart' ),
		'id'        => $prefix . '_font_buttons',
		'std'       => nice_default_setting( 'font_buttons' ),
		'min'       => 0,
		'max'       => 100,
		'type'      => 'typography',
		'condition' => $prefix . '_custom_typography:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Secondary Typography', 'smart' ),
		'desc'      => esc_html__( 'The secondary typography is used across the theme in places like page navigation and special links.', 'smart' ),
		'id'        => $prefix . '_font_secondary',
		'std'       => nice_default_setting( 'font_secondary' ),
		'type'      => 'typography',
		'condition' => $prefix . '_custom_typography:is(true)',
		'operator'  => 'and',
	);

	/**
	 * Typography > Font Sizes
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Font Sizes', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_editorial-left-align"></i>',
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Font Size H1', 'smart' ),
		'id'                => $prefix . '_heading_h1',
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'std'               => nice_default_setting( 'heading_h1' ),
		'desc'              => esc_html__( 'Define the font size for H1 in px or in %.', 'smart' ),
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Font Size H2', 'smart' ),
		'id'                => $prefix . '_heading_h2',
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'std'               => nice_default_setting( 'heading_h2' ),
		'desc'              => esc_html__( 'Define the font size for H2 in px or in %.', 'smart' ),
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Font Size H3', 'smart' ),
		'id'                => $prefix . '_heading_h3',
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'std'               => nice_default_setting( 'heading_h3' ),
		'desc'              => esc_html__( 'Define the font size for H3 in px or in %.', 'smart' ),
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Font Size H4', 'smart' ),
		'id'                => $prefix . '_heading_h4',
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'std'               => nice_default_setting( 'heading_h4' ),
		'desc'              => esc_html__( 'Define the font size for H4 in px or in %.', 'smart' ),
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Font Size H5', 'smart' ),
		'id'                => $prefix . '_heading_h5',
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'std'               => nice_default_setting( 'heading_h5' ),
		'desc'              => esc_html__( 'Define the font size for H5 in px or in %.', 'smart' ),
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Font Size H6', 'smart' ),
		'id'                => $prefix . '_heading_h6',
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'std'               => nice_default_setting( 'heading_h6' ),
		'desc'              => esc_html__( 'Define the font size for H6 in px or in %.', 'smart' ),
	);


	/**
	 * Social Media.
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Social Media', 'smart' ),
		'type' => 'heading',
		'icon' => '<i class="bi_web-share-b"></i>',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Open in New Tab', 'smart' ),
		'desc' => esc_html__( 'Open social links in a new tab.', 'smart' ),
		'id'   => $prefix . '_social_links_new_tab',
		'std'  => nice_default_setting( 'social_links_new_tab' ),
		'tip'  => '',
		'type' => 'checkbox',
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Social Links', 'smart' ),
		'desc'              => esc_html__( 'Define all the social links you will need.', 'smart' ),
		'id'                => $prefix . '_social_links',
		'user_item_prefix'  => $prefix . '_user_social',
		'type'              => 'list_item',
		'std'               => nice_default_setting( 'social_links' ),
		'tip'               => '',
		'sortable'          => true,
		'editable'          => true,
		'edit_defaults'     => false,
		'ignore_customizer' => true,
		'option_name_label' => esc_html__( 'Social Network', 'smart' ),
		'settings'          => array(
			array(
				'name' => esc_html__( 'URL', 'smart' ),
				'desc' => esc_html__( 'Enter the full URL for your social media profile.', 'smart' ),
				'id'   => 'url',
				'type' => 'text',
				'std'  => '',
				'tip'  => '',
			),
			array(
				'name' => esc_html__( 'Icon Class', 'smart' ),
				'desc' => esc_html__( 'Enter the class for your icon.', 'smart' ),
				'id'   => 'icon_class',
				'type' => 'text',
				'std'  => '',
				'tip'  => '',
			),
			array(
				'name' => esc_html__( 'Show in header', 'smart' ),
				'desc' => esc_html__( 'Check if you want to display your icon in the header.', 'smart' ),
				'id'   => 'show_in_menu',
				'type' => 'checkbox',
				'std'  => '',
				'tip'  => '',
			),
			array(
				'name' => esc_html__( 'Show in top bar', 'smart' ),
				'desc' => esc_html__( 'Check if you want to display your icon in the top bar.', 'smart' ),
				'id'   => 'show_in_top_bar',
				'type' => 'checkbox',
				'std'  => '',
				'tip'  => '',
			),
			array(
				'name' => esc_html__( 'Show in footer', 'smart' ),
				'desc' => esc_html__( 'Check if you want to display your icon in the footer.', 'smart' ),
				'id'   => 'show_in_footer',
				'type' => 'checkbox',
				'std'  => '',
				'tip'  => '',
			),
		),
	);

	/**
	 * Home
	 */

	$nice_options[] = array(
		'id'   => $prefix . '_homepage',
		'name' => esc_html__( 'Home Template', 'smart' ),
		'type' => 'heading',
		'icon' => '<i class="bi_interface-home-a"></i>',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'General', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_web-internet-a"></i>',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Home Page Sections', 'smart' ),
		'desc' => esc_html__( 'Define and order the sections you want to show in the home page. Recommended plugins may add new sections, so make sure you have them all active to see all available placeholders.', 'smart' ),
		'id'   => $prefix . '_homepage_elements',
		'std'  => nice_default_setting( 'homepage_elements' ),
		'type' => 'textarea',
		'tip'  => '',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Display Content Section', 'smart' ),
		'desc' => esc_html__( 'Show the content section in the home page.', 'smart' ),
		'id'   => $prefix . '_homepage_content',
		'std'  => nice_default_setting( 'homepage_content' ),
		'type' => 'checkbox',
		'tip'  => '',
	);
	$nice_options[] = array(
		'name'      => esc_html__( 'Content Section Title', 'smart' ),
		'desc'      => esc_html__( "Set the title of your content section. Leave it blank if you don't want to use one.", 'smart' ),
		'id'        => $prefix . '_homepage_content_title',
		'std'       => nice_default_setting( 'homepage_content_title' ),
		'type'      => 'text',
		'tip'       => '',
		'condition' => $prefix . '_homepage_content:is(true)',
		'operator'  => 'and',
	);
	$nice_options[] = array(
		'name'      => esc_html__( 'Content Section Description', 'smart' ),
		'desc'      => esc_html__( "Set the description of your content section. Leave it blank if you don't want to use one.", 'smart' ),
		'id'        => $prefix . '_homepage_content_description',
		'std'       => nice_default_setting( 'homepage_content_description' ),
		'type'      => 'text',
		'tip'       => '',
		'condition' => $prefix . '_homepage_content:is(true)',
		'operator'  => 'and',
	);
	$nice_options[] = array(
		'name'      => esc_html__( 'Content Background Image', 'smart' ),
		'desc'      => esc_html__( 'Upload or choose a background image for the content section.', 'smart' ),
		'id'        => $prefix . '_homepage_content_background_image',
		'std'       => nice_default_setting( 'homepage_content_background_image' ),
		'type'      => 'upload',
		'extra'     => array( 'type' => 'image' ),
		'condition' => $prefix . '_homepage_content:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Content Overlay Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a color for the content section overlay background. It will be displayed in front of the background image.', 'smart' ),
		'id'        => $prefix . '_homepage_content_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'homepage_content_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_homepage_content:is(true)',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Content Overlay Background Color Opacity', 'smart' ),
		'desc'      => esc_html__( 'Adjust the opacity of the content overlay background color to make it slightly transparent.', 'smart' ),
		'id'        => $prefix . '_homepage_content_background_color_opacity',
		'std'       => nice_default_setting( 'homepage_content_background_color_opacity' ),
		'type'      => 'slider',
		'condition' => $prefix . '_homepage_content:is(true),' . $prefix . '_homepage_content_background_color:not()',
		'operator'  => 'and',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Content Section Skin', 'smart' ),
		'desc'      => esc_html__( 'Choose a skin for the content section.', 'smart' ),
		'id'        => $prefix . '_homepage_content_text_skin',
		'type'      => 'select',
		'std'       => nice_default_setting( 'homepage_content_text_skin' ),
		'tip'       => '',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark ' => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_homepage_content:is(true)',
		'operator'  => 'and',
	);

	/**
	 * Performance
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Performance', 'smart' ),
		'type' => 'heading',
		'icon' => '<i class="bi_interface-dashboard"></i>',
	);

	/**
	 * Performance > Images
	 */

	$nice_options[] = array(
		'name' => esc_html__( 'Images', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_media-image-d"></i>',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'JPEG Quality', 'smart' ),
		'desc' => esc_html__( 'Change the JPEG compression-level of uploaded images and thumbnails. Default is 90.', 'smart' ),
		'id'   => $prefix . '_jpeg_quality',
		'std'  => nice_default_setting( 'jpeg_quality' ),
		'type' => 'slider',
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Enable LazyLoad for images', 'smart' ),
		'desc' => esc_html__( 'Only load images when they\'re about to enter the viewport while scrolling. This can make your pages load faster and help reduce server load.', 'smart' ),
		'id'   => $prefix . '_lazyload_images',
		'std'  => nice_default_setting( 'lazyload_images' ),
		'tip'  => '',
		'type' => 'checkbox',
	);

	$nice_options[] = array(
		'name'      => esc_html__( 'Apply LazyLoad to logo images', 'smart' ),
		'desc'      => esc_html__( 'Check if you want to apply LazyLoad to your logo images too. Not recommended if you want your logo to be displayed right away.', 'smart' ),
		'id'        => $prefix . '_lazyload_images_logo',
		'std'       => nice_default_setting( 'lazyload_images_logo' ),
		'tip'       => '',
		'type'      => 'checkbox',
		'condition' => $prefix . '_lazyload_images:is(true)',
		'operator'  => 'and',
	);

	/**
	 * Performance > CSS
	 */

	$nice_options[] = array(
		'name'              => esc_html__( 'CSS', 'smart' ),
		'type'              => 'group',
		'icon'              => '<i class="bi_web-code"></i>',
		'ignore_customizer' => true,
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Load CSS asynchronously', 'smart' ),
		'desc'              => esc_html__( 'Check this option to load non-prioritary CSS files in separated threads, so your pages can load faster. Keep in mind that, when using this feature, some styling may be applied a little later than usual.', 'smart' ),
		'id'                => $prefix . '_async_styles',
		'std'               => nice_default_setting( 'async_styles' ),
		'tip'               => '',
		'type'              => 'checkbox',
		'ignore_customizer' => true,
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Load Google Fonts asynchronously', 'smart' ),
		'desc'              => esc_html__( 'Check this option to load Google Fonts in a separated thread, so your pages can load faster. Keep in mind that some styling may be applied a little later than usual.', 'smart' ),
		'id'                => $prefix . '_async_google_fonts',
		'std'               => nice_default_setting( 'async_google_fonts' ),
		'tip'               => '',
		'type'              => 'checkbox',
		'condition'         => $prefix . '_async_styles:is(true)',
		'operator'          => 'and',
		'ignore_customizer' => true,
	);

	$nice_options[] = array(
		'name' => esc_html__( 'JavaScript', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_web-code"></i>',
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Load JavaScript files asynchronously', 'smart' ),
		'desc'              => esc_html__( 'Load some JavaScript files in different threads, and only load dependencies when they are needed. This can make your pages load faster and help reduce server load.', 'smart' ),
		'id'                => $prefix . '_load_js_on_demand',
		'std'               => nice_default_setting( 'load_js_on_demand' ),
		'tip'               => '',
		'type'              => 'checkbox',
		'ignore_customizer' => true,
	);

	$nice_options[] = array(
		'name' => esc_html__( 'Load minified JavaScript files', 'smart' ),
		'desc' => esc_html__( 'Reduce JavaScript filesize by loading processed files instead of their development versions. This can make your pages load faster and help reduce server load. Disabling this option is not recommended for production websites.', 'smart' ),
		'id'   => $prefix . '_load_minified_js',
		'std'  => nice_default_setting( 'load_minified_js' ),
		'tip'  => '',
		'type' => 'checkbox',
	);

	/**
	 * Performance > Advanced
	 */

	$nice_options[] = array(
		'name'              => esc_html__( 'Advanced', 'smart' ),
		'type'              => 'group',
		'icon'              => '<i class="bi_music-eq-a"></i>',
		'ignore_customizer' => true,
	);

	$nice_options[] = array(
		'name'              => esc_html__( 'Enable Development Mode', 'smart' ),
		'desc'              => esc_html__( 'Development mode can help you debug potential issues while building your site. It is not recommended for production websites. If you run into an issue and create a support ticket, we may ask you to temporarily activate this setting.', 'smart' ),
		'id'                => $prefix . '_development_mode',
		'std'               => nice_default_setting( 'development_mode' ),
		'tip'               => '',
		'type'              => 'checkbox',
		'ignore_customizer' => true,
	);

	/**
	 * @hook nice_options
	 *
	 * Let other functions add, remove or modify options.
	 *
	 * @see nice_woocommerce_options()
	 */
	$nice_options = apply_filters( 'nice_options', $nice_options );

	if ( serialize( get_option( 'nice_template' ) ) !== serialize( $nice_options ) ) {
		update_option( 'nice_template', $nice_options );
	}
}
endif;

if ( ! function_exists( 'nice_options_homepage_elements_after' ) ) :
add_action( 'nice_option_nice_homepage_elements_after', 'nice_options_homepage_elements_after' );
/**
 * Add a link to reset to default values for home page elements.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_options_homepage_elements_after() {
	$output  = '<p>' . esc_html__( 'Available placeholders:', 'smart' ) . '</p>';
	$output .= '<a style="cursor: pointer; text-decoration: underline;" id="nice-homepage-elements-reset-values" data-focus="#nice_homepage_elements" data-defaults="' . nice_options_homepage_default_elements() . '" onclick="jQuery( jQuery( this ).data( \'focus\' ) ).val( jQuery( this ).data( \'defaults\' ) );">' . esc_html__( 'Reset to default sections', 'smart' ) . '</a>';

	return $output;
}
endif;

if ( ! function_exists( 'nice_options_homepage_default_elements' ) ) :
/**
 * Return default home page elements.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_options_homepage_default_elements() {
	$default_elements = '';

	$elements = array(
		'content',
	);

	if ( post_type_exists( 'slide' ) ) {
		array_unshift( $elements, 'slides' );
	}

	/**
	 * @hook nice_options_homepage_default_elements
	 *
	 * Hook here to change the default home page elements.
	 *
	 * @since 1.0.0
	 */
	$elements = apply_filters( 'nice_options_homepage_default_elements', $elements );

	if ( ! empty( $elements ) && is_array( $elements ) ) {
		$formatted_elements = array();

		foreach ( $elements as $element ) {
			$formatted_elements[] = '[' . esc_attr( $element ) . ']';
		}
	}

	if ( ! empty( $formatted_elements ) ) {
		$default_elements = join( ' ', $formatted_elements );
	}

	return $default_elements;
}
endif;
