<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to add custom fields for Nice Infoboxes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_infoboxes_integration_metabox_info_fields' ) ) :
add_filter( 'nice_infoboxes_metabox_info_fields', 'nice_infoboxes_integration_metabox_info_fields' );
/**
 * Register post meta fields.
 *
 * @since  1.0.0
 *
 * @param  array $fields Current fields in meta box.
 *
 * @return array
 */
function nice_infoboxes_integration_metabox_info_fields( array $fields = array() ) {
	$text_align = array(
		'type'    => 'select',
		'label'   => esc_html__( 'Text Alignment', 'smart' ),
		'name'    => '_infobox_text_align',
		'std'     => is_rtl() ? 'right' : 'left',
		'options' => array(
			'left'   => esc_html__( 'Left', 'smart' ),
			'center' => esc_html__( 'Center', 'smart' ),
			'right'  => esc_html__( 'Right', 'smart' ),
		),
		'desc'    => esc_html__( 'How do you wish to align the infobox text.', 'smart' ),
	);

	$fields[] = $text_align;

	$icon_align = array(
		'type'    => 'select',
		'label'   => esc_html__( 'Icon Alignment', 'smart' ),
		'name'    => '_infobox_icon_align',
		'std'     => is_rtl() ? 'right' : 'left',
		'options' => array(
			'left'   => esc_html__( 'Left', 'smart' ),
			'center' => esc_html__( 'Center (Will be placed on top of the text)', 'smart' ),
			'right'  => esc_html__( 'Right', 'smart' ),
		),
		'desc'    => esc_html__( 'Where do you want the icon to be displayed. It will only take effect if there is an icon', 'smart' ),
	);

	$fields[] = $icon_align;

	return $fields;

}
endif;

if ( ! function_exists( 'nice_infoboxes_integration_register_meta' ) ) :
add_action( 'nice_infoboxes_post_type_admin_created', 'nice_infoboxes_integration_register_meta' );
/**
 * Register post meta fields.
 *
 * `register_meta()` calls are implemented as previous to WP 4.6.0.
 *
 * @see   register_meta()
 *
 * @since 1.0.0
 */
function nice_infoboxes_integration_register_meta() {
	/** @noinspection PhpParamsInspection */
	register_meta( 'post', '_infobox_text_align', 'sanitize_text_field', '__return_true' );
	/** @noinspection PhpParamsInspection */
	register_meta( 'post', '_infobox_icon_align', 'sanitize_text_field', '__return_true' );
}
endif;
