<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage styles for Infoboxes by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Remove FontAwesome source from plugin.
 *
 * @since 1.0.0
 */
remove_action( 'nice_infoboxes_admin_enqueue_styles', 'nice_infoboxes_enqueue_font_awesome_styles' );

if ( ! function_exists( 'nice_infoboxes_integration_remove_options' ) ) :
add_action( 'current_screen', 'nice_infoboxes_integration_remove_options', 0 );
/**
 * Remove options from Infoboxes settings panel.
 *
 * @since  1.0.0
 *
 * @param WP_Screen $current_screen
 */
function nice_infoboxes_integration_remove_options( WP_Screen $current_screen ) {
	$slug = nice_infoboxes_plugin_slug();

	// Return early if we're not in the page we want.
	if ( nice_infoboxes_post_type_name() . '_page_' . $slug !== $current_screen->id ) {
		return;
	}

	global $wp_settings_fields;

	if ( ! isset( $wp_settings_fields[ $slug ][ $slug ] ) ) {
		return;
	}

	$settings = $wp_settings_fields[ $slug ][ $slug ];

	/**
	 * Remove "avoid CSS" option.
	 *
	 * @since 1.0.0
	 */
	if ( ! empty( $settings['avoidcss'] ) ) {
		unset( $settings['avoidcss'] );
	}

	$wp_settings_fields[ $slug ][ $slug ] = $settings;
}
endif;

if ( ! function_exists( 'nice_infoboxes_integration_enqueue_font_awesome_admin_styles' ) ) :
add_action( 'nice_infoboxes_admin_enqueue_styles', 'nice_infoboxes_integration_enqueue_font_awesome_admin_styles' );
/**
 * Load FontAwesome styles in the admin area from the theme instead of the plugin.
 *
 * @since 1.0.0
 */
function nice_infoboxes_integration_enqueue_font_awesome_admin_styles() {
	if ( ! apply_filters( 'nice_infoboxes_integration_enable_font_awesome_admin_styles', true ) ) {
		return;
	}

	if ( ! is_admin() ) {
		return;
	}

	$screen = get_current_screen();
	if ( nice_infoboxes_post_type_name() !== $screen->post_type ) {
		return;
	}

	// Load source.
	wp_register_style( 'nice-font-awesome-source', nice_get_file_uri( 'includes/assets/css/font-awesome.min.css' ) );
	wp_enqueue_style( 'nice-font-awesome-source' );
}
endif;
