<?php
/**
 * Smart by NiceThemes.
 *
 * Manage infoboxes in home page template.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_homepage_infoboxes_get_options' ) ) :
/**
 * Obtain theme options mixed up with infoboxes defaults for homepage.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_homepage_infoboxes_get_options() {
	// Allow bypass.
	if ( $nice_options = apply_filters( 'nice_homepage_infoboxes_get_options', null ) ) {
		return $nice_options;
	}

	$nice_options = wp_parse_args( nice_get_options(), array(
			'nice_homepage_infoboxes'             => false,
			'nice_homepage_infoboxes_title'       => '',
			'nice_homepage_infoboxes_description' => '',
			'nice_homepage_infoboxes_columns'     => 3,
			'nice_homepage_infoboxes_limit'       => 6,
		)
	);

	return $nice_options;
}
endif;

if ( ! function_exists( 'nice_homepage_infoboxes' ) ) :
/**
 * Display Infoboxes for homepage.
 *
 * @since  1.0.0
 *
 * @param  bool              $echo Choose to display HTML or not.
 *
 * @return string
 */
function nice_homepage_infoboxes( $echo = true ) {
	// Allow bypass.
	if ( $output = apply_filters( 'nice_homepage_infoboxes', '', $echo ) ) {
		return $output;
	}

	if ( function_exists( 'nice_infoboxes' ) ) {
		if ( ! nice_bool( nice_get_option( 'nice_homepage_infoboxes' ) ) ) {
			return $output;
		}

		if ( ! $echo ) {
			ob_start();
		}

		$title       = nice_get_option( 'nice_homepage_infoboxes_title' );
		$description = nice_get_option( 'nice_homepage_infoboxes_description' );

		?>
			<div id="homepage-infoboxes" class="<?php nice_homepage_block_class( 'infoboxes' ); ?>">
				<div class="inner">
					<div class="overlay"></div>
					<div class="block-wrapper col-full">
						<div id="homepage-infoboxes-container" class="homepage-container">
							<?php if ( $title or $description ) : ?>

								<header class="homepage-section-title homepage-infoboxes-title">

									<?php if ( $title ) : ?>
										<h2 class="infoboxes-title title"><?php echo esc_html( $title ); ?></h2>
									<?php endif; ?>

									<?php if ( $description ) : ?>
										<div class="infoboxes-description description">
											<?php echo wpautop( $description ); ?>
										</div>
									<?php endif; ?>

								</header>

							<?php endif; ?>

							<?php
								/*
								 * Display Info Boxes here.
								 */
								do_action( 'nice_infoboxes', array(
										'echo'          => true,
										'columns'       => nice_get_option( 'nice_homepage_infoboxes_columns' ),
										'limit'         => nice_get_option( 'nice_homepage_infoboxes_limit' ),
										'image_width'   => 290,
										'image_height'  => 290,
									)
								);
							?>
						</div>
					</div>
				</div>
			</div>
		<?php

		if ( ! $echo ) {
			$output = ob_get_contents();
			ob_end_clean();
		}
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_homepage_infoboxes_styles' ) ) :
add_filter( 'nice_homepage_styles', 'nice_homepage_infoboxes_styles' );
/**
 * Add inline styles for infoboxes section.
 *
 * @since  1.0.0
 *
 * @param  string $styles Default inline CSS.
 *
 * @return string
 */
function nice_homepage_infoboxes_styles( $styles = '' ) {
	if ( ! class_exists( 'Nice_Infoboxes_Plugin' ) ) {
		return $styles;
	}

	return $styles . nice_homepage_block_styles( 'infoboxes' );
}
endif;
