<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage styles for Infoboxes by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_infoboxes_integration_remove_styles' ) ) :
add_action( 'after_setup_theme', 'nice_infoboxes_integration_remove_styles' );
/**
 * Prevent Infoboxes CSS from loading.
 *
 * @since 1.0.0
 */
function nice_infoboxes_integration_remove_styles() {
	remove_action( 'nice_infoboxes_plugin_enqueue_styles', 'nice_infoboxes_enqueue_styles' );
}
endif;

if ( ! function_exists( 'nice_infoboxes_integration_styles' ) ) :
add_action( 'nice_register_styles', 'nice_infoboxes_integration_styles' );
/**
 * Load our custom styles for Infoboxes.
 *
 * @since 1.0.0
 *
 * @param string $template_directory_uri
 */
function nice_infoboxes_integration_styles( $template_directory_uri = '' ) {
	$handle = nice_infoboxes_plugin_slug() . '-styles';

	wp_register_style( $handle, $template_directory_uri . '/includes/plugin-integrations/nice-infoboxes/css/nice-infoboxes.css' );
	wp_enqueue_style( $handle );
}
endif;

if ( ! function_exists( 'nice_infoboxes_integration_add_css_classes' ) ) :
add_filter( 'nice_infoboxes_post_class', 'nice_infoboxes_integration_add_css_classes', -10, 2 );
/**
 * Add CSS classes according to the metaboxes defined on this theme
 *
 * @since 1.0.0
 *
 * @param string $class
 * @param WP_Post $post
 *
 * @return string
 */
function nice_infoboxes_integration_add_css_classes( $class, $post ) {
	$text_align = get_post_meta( $post->ID, '_infobox_text_align', true );

	switch ( $text_align ) {
		case 'center' :
			$text_align_class = ' text-align-center';
			break;
		case 'left' :
			$text_align_class = ' text-align-left';
			break;
		case 'right' :
			$text_align_class = ' text-align-right';
			break;
		default :
			$text_align_class = ' text-align-left';
	}

	$has_icon   = get_post_meta( $post->ID, '_infobox_link_icon',  true );
	$icon_align = get_post_meta( $post->ID, '_infobox_icon_align', true );
	$icon_align_class = '';

	if ( ! empty( $has_icon['id'] ) ) {
		switch ( $icon_align ) {
			case 'center' :
				$icon_align_class = ' icon-align-center';
				break;
			case 'right' :
				$icon_align_class = ' icon-align-right';
				break;
			default :
				$icon_align_class = ' icon-align-left';
		}
	}

	return $class . $text_align_class . $icon_align_class;

}
endif;

if ( ! function_exists( 'nice_infoboxes_integration_inline_styles' ) ) :
add_filter( 'nice_inline_styles', 'nice_infoboxes_integration_inline_styles' );
/**
 * Add inline styles for Infoboxes integration.
 *
 * @since  1.0.0
 *
 * @param  string $output Unfiltered inline styles.
 *
 * @return string
 */
function nice_infoboxes_integration_inline_styles( $output = '' ) {
	$output .= '/* Custom styles for infoboxes. */' . "\n";
	$output .= '.nice-infoboxes.default-styles .nice-infobox-thumb i { color: ' . nice_infoboxes_icon_default_color() . ' !important; }' . "\n";

	if ( $nice_accent_color = nice_get_option( 'nice_accent_color' ) ) {
		$output .= '.nice-infoboxes .item:hover a.read-more { border-bottom-color:' . $nice_accent_color . '; }' . "\n";
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_infoboxes_integration_post_template' ) ) :
add_filter( 'nice_infoboxes_post_template', 'nice_infoboxes_integration_post_template', 10, 3 );
/**
 * Add inline styles for Infoboxes integration.
 *
 * @since  1.0.0
 *
 * @param  string  $tpl
 * @param  array   $args
 * @param  WP_Post $post
 *
 * @return string
 */
function nice_infoboxes_integration_post_template( $tpl = '', $args = array(), $post ) {
	$infobox_meta = nice_infoboxes_get_post_meta( $post );

	$tpl = '
			<div class="nice-infobox %%CLASS%%">
				<div class="nice-infobox-thumb">%%IMAGE%%</div>
				<div class="nice-infobox-content-wrapper">
					<div class="nice-infobox-title">%%TITLE%%</div>
					<div class="nice-infobox-content">%%CONTENT%%</div>
					' . ( nice_bool( $infobox_meta['infobox_link_display'] ) ? '<div class="nice-infobox-view-more">%%VIEW_MORE%%</div>' : '' ) . '
				</div>
			</div>';

	return $tpl;
}
endif;
