<?php
/**
 * Smart by NiceThemes.
 *
 * Manage settings in Nice Likes Admin UI.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.2
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_likes_integration_remove_options' ) ) :
add_action( 'current_screen', 'nice_likes_integration_remove_options', 10 );
/**
 * Remove some options from Likes settings panel.
 *
 * @since  1.0.0
 *
 * @param  WP_Screen $current_screen
 */
function nice_likes_integration_remove_options( WP_Screen $current_screen ) {
	$slug = nice_likes_plugin_slug();

	// Return early if we're not in the page we want.
	if ( 'settings_page_' . $slug !== $current_screen->id ) {
		return;
	}

	global $wp_settings_fields;

	$settings = $wp_settings_fields[ $slug ][ $slug ];

	/**
	 * Remove "avoid CSS" option.
	 *
	 * @since 1.0.0
	 */
	if ( ! empty( $settings['avoidcss'] ) ) {
		unset( $settings['avoidcss'] );
	}

	/**
	 * Remove Likes position option.
	 *
	 * @since 1.0.0
	 */
	if ( ! empty( $settings['position'] ) ) {
		unset( $settings['position'] );
	}

	/**
	 * Remove the "I don't like this anymore" text option.
	 *
	 * @since 1.0.0
	 */
	if ( ! empty( $settings['unlike_text'] ) ) {
		unset( $settings['unlike_text'] );
	}

	$wp_settings_fields[ $slug ][ $slug ] = $settings;
}
endif;