<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage styles for Likes by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_likes_integration_styles' ) ) :
add_action( 'nice_register_styles', 'nice_likes_integration_styles' );
/**
 * Load our custom styles for Likes.
 *
 * @since 1.0.0
 *
 * @param string $template_directory_uri
 */
function nice_likes_integration_styles( $template_directory_uri ) {
	$handle = nice_likes_plugin_slug() . '-styles';

	wp_register_style( $handle, $template_directory_uri . '/includes/plugin-integrations/nice-likes/css/nice-likes.css' );
	wp_enqueue_style( $handle );

	/**
	 * @hook nice_likes_integration_inline_styles
	 *
	 * Inline styles for the plugin are defined here.
	 *
	 * @since 1.0.0
	 *
	 * Hooked here:
	 * @see nice_likes_integration_inline_styles()
	 */
	wp_add_inline_style( $handle, apply_filters( 'nice_likes_integration_inline_styles', '' ) );
}
endif;

if ( ! function_exists( 'nice_likes_integration_inline_styles' ) ) :
add_filter( 'nice_likes_integration_inline_styles', 'nice_likes_integration_inline_styles' );
/**
 * Add inline styles for Likes integration.
 *
 * @since  1.0.0
 *
 * @param  string $output Unfiltered inline styles.
 *
 * @return string
 */
function nice_likes_integration_inline_styles( $output = '' ) {
	if ( $color = nice_get_option( 'nice_accent_color' ) ) {
		$output .= '/* Custom styles for likes. */' . "\n";
		$output .= 'a.nice-likes.liked i, a.nice-likes:hover i, a.nice-likes.liking { color: ' . $color . ' }' . "\n";
		$output .= '.grid .item .item-content .entry-likes a.liked i { color: ' . $color . ' }' . "\n";
	}

	return $output;
}
endif;
