<?php
/**
 * Smart by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://www.nicethemes.com/theme-page
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_portfolio_integration_options' ) ) :
add_filter( 'nice_options', 'nice_portfolio_integration_options', 20 );
/**
 * Add Nice Portfolio specific options to theme options.
 *
 * @since 1.0.0
 *
 * @param array $nice_options
 *
 * @return array
 */
function nice_portfolio_integration_options( array $nice_options = array() ) {
	// Obtain the prefix for the option fields.
	$prefix = NICE_PREFIX;

	$nice_portfolio_homepage_extra_options[] = array(
		'name'   => esc_html__( 'Portfolio Projects', 'smart' ),
		'id'     => $prefix . '_portfolio_homepage_extra_section',
		'type'   => 'group',
		'icon'   => '<i class="bi_editorial-brush"></i>',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name' => esc_html__( 'Enable Portfolio Section', 'smart' ),
		'desc' => esc_html__( 'Show the portfolio projects section in the home page.', 'smart' ),
		'id'   => $prefix . '_homepage_portfolio',
		'std'  => nice_default_setting( 'homepage_portfolio' ),
		'type' => 'checkbox',
		'tip'  => '',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Portfolio Section Title', 'smart' ),
		'desc'      => esc_html__( "Set the title for your portfolio section. Leave it blank if you don't want to use one.", 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_title',
		'std'       => nice_default_setting( 'homepage_portfolio_title' ),
		'type'      => 'text',
		'tip'       => '',
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Portfolio Section Description', 'smart' ),
		'desc'      => esc_html__( "Set the description for your portfolio section. Leave it blank if you don't want to use one.", 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_description',
		'std'       => nice_default_setting( 'homepage_portfolio_description' ),
		'type'      => 'text',
		'tip'       => '',
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Columns', 'smart' ),
		'desc'      => esc_html__( 'Set the number of columns that will be used to display portfolio projects in the home page.', 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_columns',
		'std'       => nice_default_setting( 'homepage_portfolio_columns' ),
		'type'      => 'slider',
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Limit', 'smart' ),
		'desc'      => esc_html__( 'Set the maximum number of portfolio projects to show in the home page.', 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_limit',
		'std'       => nice_default_setting( 'homepage_portfolio_limit' ),
		'type'      => 'text',
		'tip'       => '',
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Prevent Grid Gap', 'smart' ),
		'desc'      => esc_html__( 'Remove the default gap between projects in the home page.', 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_prevent_gap',
		'type'      => 'checkbox',
		'std'       => nice_default_setting( 'homepage_portfolio_prevent_gap' ),
		'tip'       => '',
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Grid Style', 'smart' ),
		'desc'      => esc_html__( 'Select the style for project grids in the home page.', 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_grid',
		'type'      => 'select',
		'std'       => nice_default_setting( 'homepage_portfolio_grid' ),
		'tip'       => '',
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
		'options'   => array(
			'style-default' => esc_html__( 'Default', 'smart' ),
			'style-masonry' => esc_html__( 'Masonry', 'smart' ),
			'style-metro'   => esc_html__( 'Metro', 'smart' ),
		),
		'extra'     => array(
			'type' => 'radio-buttonset',
		),
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Full Width', 'smart' ),
		'desc'      => esc_html__( 'Use all available horizontal space.', 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_full_width',
		'type'      => 'checkbox',
		'std'       => nice_default_setting( 'homepage_portfolio_full_width' ),
		'tip'       => '',
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Portfolio Background Image', 'smart' ),
		'desc'      => esc_html__( 'Upload or choose a background image for the portfolio section.', 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_background_image',
		'std'       => nice_default_setting( 'homepage_portfolio_background_image' ),
		'type'      => 'upload',
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
		'extra'     => array( 'type' => 'image' ),
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Portfolio Overlay Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a color for the portfolio section overlay background. It will be displayed in front of the background image', 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'homepage_portfolio_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Portfolio Overlay Background Color Opacity', 'smart' ),
		'desc'      => esc_html__( 'Adjust the opacity of the overlay background color to make it slightly transparent.', 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_background_color_opacity',
		'std'       => nice_default_setting( 'homepage_portfolio_background_color_opacity' ),
		'type'      => 'slider',
		'condition' => $prefix . '_homepage_portfolio:is(true),' . $prefix . '_homepage_portfolio_background_color:not()',
		'operator'  => 'and',
	);

	$nice_portfolio_homepage_extra_options[] = array(
		'name'      => esc_html__( 'Portfolio Section Skin', 'smart' ),
		'desc'      => esc_html__( 'Choose a skin for the portfolio section.', 'smart' ),
		'id'        => $prefix . '_homepage_portfolio_text_skin',
		'type'      => 'select',
		'std'       => nice_default_setting( 'homepage_portfolio_text_skin' ),
		'tip'       => '',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark ' => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_homepage_portfolio:is(true)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'   => esc_html__( 'Portfolio', 'smart' ),
		'id'     => $prefix . '_portfolio_integration_section',
		'type'   => 'heading',
		'icon'   => '<i class="bi_editorial-brush"></i>',
		'parent' => $prefix . '_layout',
	);

	$nice_portfolio_integration_options[] = array(
		'name' => esc_html__( 'General', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-briefcase-d"></i>',
		'id'   => $prefix . '_layout_portfolio_general',
	);

	$nice_portfolio_integration_options[] = array(
		'name'     => esc_html__( 'Default Grid Gap', 'smart' ),
		'desc'     => esc_html__( 'Allow the default gap between projects.', 'smart' ),
		'id'       => $prefix . '_portfolio_allow_gap',
		'type'     => 'checkbox',
		'std'      => nice_default_setting( 'portfolio_allow_gap' ),
		'tip'      => '',
		'operator' => 'and',
		'extra'    => array(
			'required' => array(
				array(
					'setting'  => 'nice_options[' . $prefix . '_homepage_portfolio]',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
	);

	$nice_portfolio_integration_options[] = array(
		'name'    => esc_html__( 'Grid Style', 'smart' ),
		'desc'    => esc_html__( 'Select the default style for portfolio project grids.', 'smart' ),
		'id'      => $prefix . '_portfolio_default_grid',
		'type'    => 'select',
		'std'     => nice_default_setting( 'portfolio_default_grid' ),
		'tip'     => '',
		'options' => array(
			'style-default' => esc_html__( 'Default', 'smart' ),
			'style-masonry' => esc_html__( 'Masonry', 'smart' ),
			'style-metro'   => esc_html__( 'Metro', 'smart' ),
		),
		'extra'   => array(
			'type' => 'radio-buttonset',
		),
	);

	/**
	 * Layout > Portfolio > Header
	 */

	$nice_portfolio_integration_options[] = array(
		'name' => esc_html__( 'Header', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-header"></i>',
		'id'   => $prefix . '_layout_portfolio_header',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Header', 'smart' ),
		'desc'      => esc_html__( 'Show the header for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_header',
		'std'       => nice_default_setting( 'portfolio_project_header' ),
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Navigation Menu', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation menu to use for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_navigation_menu',
		'std'       => nice_default_setting( 'portfolio_project_navigation_menu' ),
		'type'      => 'select',
		'options'   => nice_get_navigation_menus(),
		'condition' => $prefix . '_portfolio_project_header:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Navigation Style', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation style to use for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_navigation_style',
		'std'       => nice_default_setting( 'portfolio_project_navigation_style' ),
		'type'      => 'select',
		'options'   => array(
			''         => esc_html__( 'Inherit', 'smart' ),
			'default'  => esc_html__( 'Top', 'smart' ),
			'vertical' => esc_html__( 'Side', 'smart' ),
			'overlay'  => esc_html__( 'Overlay', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_header:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Transparent Header', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_header_background_transparent',
		'std'       => nice_default_setting( 'portfolio_project_header_background_transparent' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_header:not(false),' . $prefix . '_portfolio_project_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Transparent Header (Mobile)', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent in smaller viewports. This option only works when the transparent header is enabled on desktop.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_header_background_transparent_mobile',
		'std'       => nice_default_setting( 'portfolio_project_header_background_transparent_mobile' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_header:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Header Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the header content skin to use for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_header_skin',
		'std'       => nice_default_setting( 'portfolio_project_header_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_header:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Header Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a background color.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_header_background_color',
		'std'       => nice_default_setting( 'portfolio_project_header_background_color' ),
		'type'      => 'select_color',
		'options'   => nice_theme_colors_dropdown_values(),
		'class'     => 'nice-select-color',
		'condition' => $prefix . '_portfolio_project_header:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Navigation Sub-Menu Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation sub-menu content skin to use for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_navigation_submenu_skin',
		'std'       => nice_default_setting( 'portfolio_project_navigation_submenu_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_header:not(false),' . $prefix . '_portfolio_project_navigation_style:not(overlay)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Header Width', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to make the header contents take the full width for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_header_width',
		'std'       => nice_default_setting( 'portfolio_project_header_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_header:not(false),' . $prefix . '_portfolio_project_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the header area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_portfolio_project_header_width_value',
		'std'       => nice_default_setting( 'portfolio_project_header_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_portfolio_project_header:not(false),' . $prefix . '_portfolio_project_navigation_style:not(vertical),' . $prefix . '_portfolio_project_header_width:is(limit)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Search', 'smart' ),
		'desc'      => esc_html__( "Select whether or not to show a link to the site's search in the header for portfolio projects.", 'smart' ),
		'id'        => $prefix . '_portfolio_project_header_display_search',
		'std'       => '',
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_header:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'      => esc_html__( "Select whether or not to show a the social icons in the header for portfolio projects.", 'smart' ),
		'id'        => $prefix . '_portfolio_project_header_display_social',
		'std'       => nice_default_setting( 'portfolio_project_header_display_social' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_header:not(false)',
		'operator'  => 'and',
	);

	/**
	 * Layout > Portfolio > Title Bar
	 */

	$nice_portfolio_integration_options[] = array(
		'name' => esc_html__( 'Title Bar', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-third-h"></i>',
		'id'   => $prefix . '_layout_portfolio_title_bar',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Title Bar', 'smart' ),
		'desc'      => esc_html__( 'Show the title bar section for the portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_heading',
		'std'       => nice_default_setting( 'portfolio_project_heading' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Portfolio Title in the Title Bar', 'smart' ),
		'desc'      => esc_html__( 'Show the portfolio project title in the title bar.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_title_heading',
		'std'       => nice_default_setting( 'portfolio_project_title_heading' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Portfolio Project Subtitle', 'smart' ),
		'desc'      => esc_html__( 'Enter a subtitle (optional).', 'smart' ),
		'id'        => $prefix . '_portfolio_project_subtitle',
		'std'       => nice_default_setting( 'portfolio_project_subtitle' ),
		'type'      => 'text',
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_title_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Title Horizontal Alignment', 'smart' ),
		'desc'      => esc_html__( 'Select the horizontal alignment you would like for your title and subtitle.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_title_alignment',
		'std'       => nice_default_setting( 'portfolio_project_title_alignment' ),
		'type'      => 'select',
		'options'   => array(
			''       => esc_html__( 'Inherit', 'smart' ),
			'left'   => esc_html__( 'Left', 'smart' ),
			'center' => esc_html__( 'Center', 'smart' ),
			'right'  => esc_html__( 'Right', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Title Vertical Alignment', 'smart' ),
		'desc'      => esc_html__( 'Select the vertical alignment you would like for your title and subtitle (warning: bottom alignment may overlap with scroll down arrow).', 'smart' ),
		'id'        => $prefix . '_portfolio_project_title_alignment_v',
		'std'       => nice_default_setting( 'portfolio_project_title_alignment_v' ),
		'type'      => 'select',
		'options'   => array(
			''       => esc_html__( 'Inherit', 'smart' ),
			'top'    => esc_html__( 'Top', 'smart' ),
			'middle' => esc_html__( 'Middle', 'smart' ),
			'bottom' => esc_html__( 'Bottom', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Width', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to make the contents of the title bar take the full width for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_title_width',
		'std'       => nice_default_setting( 'portfolio_project_title_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the title bar area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_portfolio_project_title_width_value',
		'std'       => nice_default_setting( 'portfolio_project_title_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_navigation_style:not(vertical),' . $prefix . '_portfolio_project_title_width:is(limit)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'              => esc_html__( 'Height', 'smart' ),
		'desc'              => esc_html__( 'Define the custom height for the title area in px or in %. Leave blank to use default theme settings.', 'smart' ),
		'id'                => $prefix . '_portfolio_project_title_height',
		'std'               => nice_default_setting( 'portfolio_project_title_height' ),
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'condition'         => $prefix . '_portfolio_project_heading:not(false)',
		'operator'          => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'              => esc_html__( 'Minimum height', 'smart' ),
		'desc'              => esc_html__( 'Enter a minimum height for the header (in pixels). Leave blank to use default theme settings.', 'smart' ),
		'id'                => $prefix . '_portfolio_project_title_height_min',
		'std'               => nice_default_setting( 'portfolio_project_title_height_min' ),
		'type'              => 'measurement',
		'ignore_customizer' => true,
		'condition'         => $prefix . '_portfolio_project_heading:not(false)',
		'operator'          => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Title Text Transform', 'smart' ),
		'desc'      => esc_html__( 'Select the title text transformation.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_title_text_transform',
		'std'       => nice_default_setting( 'portfolio_project_title_text_transform' ),
		'type'      => 'select',
		'options'   => array(
			''           => esc_html__( 'Inherit', 'smart' ),
			'default'    => esc_html__( 'Default CSS', 'smart' ),
			'uppercase'  => esc_html__( 'Uppercase', 'smart' ),
			'lowercase'  => esc_html__( 'Lowercase', 'smart' ),
			'capitalize' => esc_html__( 'Capitalize', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_title_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Title Font Weight', 'smart' ),
		'desc'      => esc_html__( 'Select the title font weight.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_title_font_weight',
		'std'       => nice_default_setting( 'portfolio_project_title_font_weight' ),
		'type'      => 'select',
		'options'   => nice_font_weight(),
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_title_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Title Font Size', 'smart' ),
		'desc'      => esc_html__( 'Select the title font size.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_title_font_size',
		'std'       => nice_default_setting( 'portfolio_project_title_font_size' ),
		'type'      => 'select',
		'options'   => array(
			''             => esc_html__( 'Inherit', 'smart' ),
			'h1'           => esc_html__( 'h1', 'smart' ),
			'h2'           => esc_html__( 'h2', 'smart' ),
			'h3'           => esc_html__( 'h3', 'smart' ),
			'h4'           => esc_html__( 'h4', 'smart' ),
			'h5'           => esc_html__( 'h5', 'smart' ),
			'h6'           => esc_html__( 'h6', 'smart' ),
			'fontsize-12'  => esc_html__( 'Size 12px', 'smart' ),
			'fontsize-40'  => esc_html__( 'Size 40px', 'smart' ),
			'fontsize-50'  => esc_html__( 'Size 50px', 'smart' ),
			'fontsize-75'  => esc_html__( 'Size 75px', 'smart' ),
			'fontsize-100' => esc_html__( 'Size 100px', 'smart' ),
			'fontsize-125' => esc_html__( 'Size 125px', 'smart' ),
			'fontsize-150' => esc_html__( 'Size 150px', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_title_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Page Title Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the heading skin. "Light" equals light background with dark color contents, and "Dark" equals dark background with light color contents.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_heading_skin',
		'std'       => nice_default_setting( 'portfolio_project_heading_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Page Title Background Image', 'smart' ),
		'desc'      => esc_html__( 'Upload/select a background image.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_background_image',
		'std'       => nice_default_setting( 'portfolio_project_background_image' ),
		'type'      => 'upload',
		'condition' => $prefix . '_portfolio_project_heading:not(false), ' . $prefix . '_portfolio_project_background_solid_color:not(true)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Parallax for Background Image', 'smart' ),
		'desc'      => esc_html__( 'Add a parallax effect to the background image.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_background_image_parallax',
		'std'       => nice_default_setting( 'portfolio_project_background_image_parallax' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_background_image:not()',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Background Image Repeat', 'smart' ),
		'desc'      => esc_html__( 'Select how your background image should be repeated.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_background_repeat',
		'std'       => nice_default_setting( 'portfolio_project_background_repeat' ),
		'type'      => 'select',
		'options' => array(
			''          => esc_html__( 'Inherit', 'smart' ),
			'no-repeat' => esc_html__( 'No Repeat', 'smart' ),
			'repeat'    => esc_html__( 'Repeat All', 'smart' ),
			'repeat-x'  => esc_html__( 'Repeat Horizontally', 'smart' ),
			'repeat-y'  => esc_html__( 'Repeat Vertically', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_background_image:not(),' . $prefix . '_portfolio_project_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Background Image Position', 'smart' ),
		'desc'      => esc_html__( 'Select where your background image should be positioned.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_background_position',
		'std'       => nice_default_setting( 'portfolio_project_background_position' ),
		'type'      => 'select',
		'options' => array(
			''              => esc_html__( 'Inherit', 'smart' ),
			'left top'      => esc_html__( 'Left Top', 'smart' ),
			'left center'   => esc_html__( 'Left Center', 'smart' ),
			'left bottom'   => esc_html__( 'Left Bottom', 'smart' ),
			'center top'    => esc_html__( 'Center Top', 'smart' ),
			'center center' => esc_html__( 'Center Center', 'smart' ),
			'center bottom' => esc_html__( 'Center Bottom', 'smart' ),
			'right top'     => esc_html__( 'Right Top', 'smart' ),
			'right center'  => esc_html__( 'Right Center', 'smart' ),
			'right bottom'  => esc_html__( 'Right Bottom', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_background_image:not(),' . $prefix . '_portfolio_project_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Background Image Size', 'smart' ),
		'desc'      => esc_html__( 'Select the size for you background image.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_background_size',
		'std'       => nice_default_setting( 'portfolio_project_background_size' ),
		'type'      => 'select',
		'options' => array(
			''        => esc_html__( 'Inherit', 'smart' ),
			'auto'    => esc_html__( 'Auto', 'smart' ),
			'cover'   => esc_html__( 'Cover', 'smart' ),
			'contain' => esc_html__( 'Contain', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_background_image:not(),' . $prefix . '_portfolio_project_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Background Image Attachment', 'smart' ),
		'desc'      => esc_html__( 'Select how your background image should be attached to the portfolio project.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_background_attachment',
		'std'       => nice_default_setting( 'portfolio_project_background_attachment' ),
		'type'      => 'select',
		'options' => array(
			''        => esc_html__( 'Inherit', 'smart' ),
			'scroll'  => esc_html__( 'Scroll', 'smart' ),
			'fixed'   => esc_html__( 'Fixed', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false),' . $prefix . '_portfolio_project_background_image:not(),' . $prefix . '_portfolio_project_background_image_parallax:is(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Page Title Bar Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a background color. If a background image is set from Theme Options, your selected color will show instead as a solid background.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_background_color',
		'std'       => nice_default_setting( 'portfolio_project_background_color' ),
		'type'      => 'select_color',
		'options'   => nice_theme_colors_dropdown_values(),
		'class'     => 'nice-select-color',
		'condition' => $prefix . '_portfolio_project_heading:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Scroll Down Arrow Button', 'smart' ),
		'desc'      => esc_html__( 'Show the scroll down arrow button.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_scroll_down_arrow',
		'std'       => nice_default_setting( 'portfolio_project_scroll_down_arrow' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_portfolio_project_heading:not(false)',
		'operator'  => 'and',
	);

	/**
	 * Layout > Portfolio > Content
	 */
	$nice_portfolio_integration_options[] = array(
		'name' => esc_html__( 'Content', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-binder-three"></i>',
		'id'   => $prefix . '_layout_portfolio_content',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the content skin.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_content_skin',
		'std'       => nice_default_setting( 'portfolio_project_content_skin' ),
		'type'      => 'select',
		'options' => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
	);


	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Project Media', 'smart' ),
		'desc'      => esc_html__( 'Show the project media in the content area.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_media_content',
		'std'       => nice_default_setting( 'portfolio_project_media_content' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_portfolio_integration_options[] = array(
		'name'    => esc_html__( 'Content Width', 'smart' ),
		'desc'    => esc_html__( 'Select whether or not to limit the content width for this project.', 'smart' ),
		'id'      => $prefix . '_portfolio_project_content_width',
		'std'     => nice_default_setting( 'portfolio_project_content_width' ),
		'type'    => 'select',
		'options' => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the content area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_portfolio_project_content_width_value',
		'std'       => nice_default_setting( 'portfolio_project_content_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_portfolio_project_content_width:is(limit)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Project Navigation Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation skin to use for this post.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_navigation_skin',
		'std'       => nice_default_setting( 'portfolio_project_navigation_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Project Navigation Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a background color.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_navigation_background_color',
		'std'       => nice_default_setting( 'portfolio_project_navigation_background_color' ),
		'type'      => 'select_color',
		'options'   => nice_theme_colors_dropdown_values(),
		'class'     => 'nice-select-color',
	);

	/**
	 * Layout > Portfolio > Details
	 */

	$nice_portfolio_integration_options[] = array(
		'name' => esc_html__( 'Portfolio Details', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-briefcase-d"></i>',
		'id'   => $prefix . '_layout_portfolio_details',
	);


	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Project Details', 'smart' ),
		'desc'      => esc_html__( 'Show the details for this project.', 'smart' ),
		'id'        => $prefix . '_portfolio_details',
		'std'       => nice_default_setting( 'portfolio_details' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_portfolio_integration_options[] = array( // @TODO: reemplazar esto en CF
		'name'      => esc_html__( 'Display Project Title in Details', 'smart' ),
		'desc'      => esc_html__( 'Show the project title in the content area.', 'smart' ),
		'id'        => $prefix . '_post_title_content',
		'std'       => nice_default_setting( 'post_title_content' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_portfolio_details:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Project Details Position', 'smart' ),
		'desc'      => esc_html__( 'Choose where to show the project details.', 'smart' ),
		'id'        => $prefix . '_portfolio_details_layout',
		'std'       => nice_default_setting( 'portfolio_details_layout' ),
		'type'      => 'select',
		'options'   => array(
			'portfolio_top'    => esc_html__( 'Top', 'smart' ),
			'sidebar_left'     => esc_html__( 'Left', 'smart' ),
			'sidebar_right'    => esc_html__( 'Right', 'smart' ),
			'portfolio_bottom' => esc_html__( 'Bottom', 'smart' ),
		),

		'condition' => $prefix . '_portfolio_details:not(false)',
		'operator'  => 'and',
	);

	/**
	 * Layout > Portfolio > Footer
	 */

	$nice_portfolio_integration_options[] = array(
		'name' => esc_html__( 'Footer', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-footer"></i>',
		'id'   => $prefix . '_layout_portfolio_footer',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Footer', 'smart' ),
		'desc'      => esc_html__( 'Show the footer for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_footer',
		'std'       => nice_default_setting( 'portfolio_project_footer' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Footer Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the footer skin for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_footer_skin',
		'std'       => nice_default_setting( 'portfolio_project_footer_skin' ),
		'type'      => 'select',
		'options' => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Footer Widgets Area', 'smart' ),
		'desc'      => esc_html__( 'Show the footer widgets area for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_footer_widgets',
		'std'       => nice_default_setting( 'portfolio_project_footer_widgets' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_portfolio_project_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Copyright Area', 'smart' ),
		'desc'      => esc_html__( 'Show the footer copyright area for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_footer_extended',
		'std'       => nice_default_setting( 'portfolio_project_footer_extended' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_portfolio_project_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to show a the social icons in the footer for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_footer_display_social',
		'std'       => nice_default_setting( 'portfolio_project_footer_display_social' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_footer:not(false),' . $prefix . '_portfolio_project_footer_extended:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Footer Width', 'smart' ),
		'desc'      => esc_html__( 'Select the width of the footer contents for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_portfolio_project_footer_width',
		'std'       => nice_default_setting( 'portfolio_project_footer_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_portfolio_project_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_portfolio_integration_options[] = array(
		'name'      => esc_html__( 'Custom Width', 'smart' ),
		'desc'      => esc_html__( 'Define the custom width for the footer area (in px or in %).', 'smart' ),
		'id'        => $prefix . '_portfolio_project_footer_width_value',
		'std'       => nice_default_setting( 'portfolio_project_footer_width_value' ),
		'type'      => 'measurement',
		'condition' => $prefix . '_portfolio_project_footer:not(false),' . $prefix . '_portfolio_project_footer_width:is(limit)',
		'operator'  => 'and',
	);

	$homepage_extra_splice_key        = $prefix . '_homepage_content_text_skin';
	$portfolio_integration_splice_key = $prefix . '_customize_section';

	if ( class_exists( 'Nice_Infoboxes_Plugin' ) ) {
		$homepage_extra_splice_key = $prefix . '_homepage_infoboxes_text_skin';
	}

	$nice_options = nice_options_enqueue( $nice_options, $nice_portfolio_homepage_extra_options, $homepage_extra_splice_key, false );
	$nice_options = nice_options_enqueue( $nice_options, $nice_portfolio_integration_options, $portfolio_integration_splice_key, true );

	return $nice_options;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_options_homepage_default_elements' ) ) :
add_filter( 'nice_options_homepage_default_elements', 'nice_portfolio_integration_options_homepage_default_elements', 20 );
/**
 * Add Portfolio to default home page elements.
 *
 * @since  1.0.0
 *
 * @param  array $default_elements
 *
 * @return array
 */
function nice_portfolio_integration_options_homepage_default_elements( array $default_elements ) {
	return array_merge( $default_elements, array( 'portfolio' ) );
}
endif;
