<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions for templating purposes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/** ==========================================================================
 *  Content Getters.
 *  ======================================================================= */

if ( ! function_exists( 'nice_portfolio_integration_get_class' ) ) :
/**
 * Add classes to portfolio class.
 *
 * @since 1.0.0
 *
 * @param array $class
 *
 * @return array
 */
function nice_portfolio_integration_get_class( array $class = array() ) {
	if ( nice_is_homepage() ) {
		$prevent_gap = nice_bool( nice_get_option( 'nice_homepage_portfolio_prevent_gap' ) );
		$style       = nice_get_option( 'nice_homepage_portfolio_grid' );

	} elseif ( nice_portfolio_doing_shortcode() && $shortcode = nice_portfolio_current_shortcode() ) {
		$prevent_gap = ! nice_bool( $shortcode->atts['gap'] );
		$style       = $shortcode->atts['style'];

	} else {
		$prevent_gap = ! nice_bool( nice_get_option( 'nice_portfolio_allow_gap' ) );
		$style       = nice_get_option( 'nice_portfolio_default_grid' );
	}

	$style_default = ( 'style-default' === $style );

	// Add "grid" class in case we don't have it already.
	$class[] = 'grid';

	if ( $prevent_gap && $style_default ) {
		$class[] = 'no-gap-h';
		$class[] = 'no-gap-v';

	} elseif ( $prevent_gap ) {
		$class[] = 'no-gap';

	} elseif ( $style_default ) {
		$class[] = 'single-gutter-h';
		$class[] = 'single-gutter-v';

	} else {
		$class[] = 'single-gutter';
	}

	$class[] = $style;

	if ( ! nice_is_homepage() || nice_portfolio_doing_shortcode() ) {
		$class[] = 'isotope-grid';
		$class[] = 'js-resize';
	}

	// Apply dark skin to grids.
	$class[] = 'dark';

	// Disable some default classes.
	$disable_classes = array(
		'default-styles',
	);
	foreach ( $class as $key => $value ) {
		if ( in_array( $value, $disable_classes, true ) ) {
			unset( $class[ $key ] );
		}
	}

	return $class;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_get_project_class' ) ) :
add_filter( 'nice_portfolio_project_class', 'nice_portfolio_integration_get_project_class' );
/**
 * Redefine classes for portfolio projects.
 *
 * @since 1.0.0
 *
 * @param array $class
 *
 * @return array
 */
function nice_portfolio_integration_get_project_class( array $class = array() ) {
	if ( ! is_singular( nice_portfolio_post_type_name() ) ) {
		$colors = nice_theme_colors();

		$class = array_merge( $class, array(
			'item',
			'type-' . nice_portfolio_post_type_name(),
			nice_portfolio_post_type_name() . '-' . get_the_ID(),
			'text-overlay',
			'text-animated',
			'item-text-padding-reduced',
			'multiple-click',
			'content-padding-h-2x',
			'content-padding-v-2x',
			'overlay-color-' . $colors['nice_black_color']['css_id'],
			'overlay-animated',
			'image-animated',
			'text-center',
			'vertical-position-middle',
		) );
	}

	return $class;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_get_container_class' ) ) :
/**
 * Obtain additional class names to container element depending on the current
 * portfolio page.
 *
 * @since  1.0.0
 *
 * @param  string $class HTML class.
 * @return string
 */
function nice_portfolio_integration_get_container_class( $class ) {
	if ( nice_portfolio_is_page() ) {
		$class[] = 'portfolio-page';
		$class[] = 'full-width';

	} elseif ( nice_portfolio_is_single() ) {
		$class[] = 'portfolio-project';

	} elseif ( nice_portfolio_is_category() ) {
		$class[] = 'portfolio-category';
		$class[] = 'full-width';

	} elseif ( nice_portfolio_is_tag() ) {
		$class[] = 'portfolio-tag';
		$class[] = 'full-width';

	} elseif ( nice_portfolio_is_archive() ) {
		$class[] = 'portfolio-archive';
		$class[] = 'full-width';

	} elseif ( nice_portfolio_is_project_post_type() ) {
		$class[] = 'portfolio-post-type';
	}

	return $class;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_get_single_project_gallery' ) ) :
/**
 * Obtain gallery array for a specific portfolio project.
 *
 * @since  1.0
 *
 * @param  int              $project_id
 * @return array|mixed|void
 */
function nice_portfolio_integration_get_single_project_gallery( $project_id = null ) {
	// Obtain project ID if not given.
	$project_id = nice_portfolio_get_valid_ID( $project_id );

	// Allow bypass.
	/**
	 * @hook nice_portfolio_integration_single_project_gallery
	 *
	 * Hook here if you want to bypass the result of this function.
	 *
	 * @since 1.0.0
	 */
	if ( $gallery = apply_filters( 'nice_portfolio_integration_single_project_gallery', null, $project_id ) ) {
		return $gallery;
	}

	// Obtain original gallery.
	if ( $gallery = nice_portfolio_get_project_field( $project_id, 'gallery' ) ) {
		$gallery = explode( ',', $gallery );

		foreach ( $gallery as $key => $image_id ) {
			if ( ! is_numeric( $image_id ) ) {
				$gallery[ $key ] = nice_portfolio_get_attachment_id_by_name( $image_id );
			}
		}
	}
	$gallery = is_array( $gallery ) ? $gallery : array();

	// Check if we have a video embed.
	$embed = nice_portfolio_get_project_field( $project_id, 'embed' );

	// Add video embed to the array.
	if ( $embed ) {
		array_unshift( $gallery, $embed );
	}

	// Add the ID of current post's thumbnail to the array.
	if ( ! $embed && $thumbnail_id = get_post_thumbnail_id( $project_id ) ) {
		array_unshift( $gallery, $thumbnail_id );
	}

	return $gallery;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_project_thumbnail' ) ) :
/**
 * Show an image for a portfolio project.
 *
 * @since  1.0
 *
 * @param  int   $thumbnail_id
 * @param  int   $project_id
 * @param  array $args
 *
 * @return string
 */
function nice_portfolio_integration_project_thumbnail( $thumbnail_id, $project_id = null, $args = array() ) {
	$project_id = nice_portfolio_get_valid_ID( $project_id );

	// Allow bypass.
	/**
	 * @hook nice_portfolio_integration_project_thumbnail
	 *
	 * Hook here if you want to bypass the output of the thumbnail.
	 *
	 * @since 1.0.0
	 */
	if ( $output = apply_filters( 'nice_portfolio_integration_project_thumbnail', '', $thumbnail_id, $project_id, $args ) ) {
		return $output;
	}

	/**
	 * Make sure the thumbnail belongs to the project gallery.
	 */
	if ( ! in_array( $thumbnail_id, nice_portfolio_integration_get_single_project_gallery(), true ) ) {
		return null;
	}

	// Initialize defaults.
	/**
	 * @hook nice_portfolio_integration_project_thumbnail_default_args
	 *
	 * Hook here if you want to modify the default arguments to obtain the
	 * project thumbnail.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_portfolio_integration_project_thumbnail_default_args', array(
			'size'   => nice_has_sidebar() ? 'large' : 'nice-extra-large',
			'class'  => 'wp-post-image',
			'id'     => $thumbnail_id,
		), $thumbnail_id, $project_id, $args
	);

	// Obtain arguments.
	$args = wp_parse_args( $args, $defaults );
	/**
	 * @hook nice_portfolio_integration_project_thumbnail_args
	 *
	 * Hook here if you want to modify the arguments to obtain the project
	 * thumbnail.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_portfolio_integration_project_thumbnail_args', $args, $thumbnail_id, $project_id );

	return nice_image( $args );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_get_homepage_options' ) ) :
/**
 * Obtain theme options mixed up with portfolio defaults for homepage.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_portfolio_integration_get_homepage_options() {
	$options = nice_get_options();

	$nice_options = array_merge( array(
			'nice_homepage_portfolio'              => false,
			'nice_homepage_portfolio_title'        => '',
			'nice_homepage_portfolio_description'  => '',
			'nice_homepage_portfolio_columns'      => 3,
			'nice_homepage_portfolio_limit'        => 6,
			'nice_homepage_portfolio_image_width'  => 350,
			'nice_homepage_portfolio_image_height' => 350,
			'nice_homepage_portfolio_prevent_gap'  => false,
			'nice_homepage_portfolio_grid'         => 'default',
			'nice_homepage_portfolio_full_width'   => false,
		), $options
	);

	/**
	 * @hook nice_portfolio_integration_homepage_options
	 *
	 * Hook here to modify homepage options for portfolio.
	 *
	 * @since 1.0.0
	 */
	$nice_options = apply_filters( 'nice_portfolio_integration_homepage_options', $nice_options );

	return $nice_options;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_homepage_args' ) ) :
/**
 * Obtain arguments to print out projects in the homepage block.
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_homepage_args() {
	$args = array(
		'columns'      => nice_get_option( 'nice_homepage_portfolio_columns' ),
		'limit'        => nice_get_option( 'nice_homepage_portfolio_limit' ),
		'image_width'  => nice_get_option( 'nice_homepage_portfolio_image_width' ),
		'image_height' => nice_get_option( 'nice_homepage_portfolio_image_width' ),
	);

	/**
	 * @hook nice_portfolio_integration_homepage_args
	 *
	 * Hook here to modify these arguments.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_portfolio_integration_homepage_args', $args );

	return $args;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_loop_comments' ) ) :
/**
 * Display comments for looped project.
 *
 * @since 1.0.0
 *
 * @param null|int $project_id
 */
function nice_portfolio_integration_loop_comments( $project_id = null ) {
	$project_id = nice_portfolio_get_valid_ID( $project_id );

	/**
	 * Display comments if open.
	 */
	if ( comments_open( $project_id ) ) {
		$text = get_comments_number_text( '0', '1', '%' );

		nice_comments_link_section( $project_id, array(
				'echo'       => true,
				'text'       => $text,
				'before'     => '<section class="entry-comments entry-meta inline-block inherit-skin">',
				'after'      => '</section>',
				'icon_class' => 'icon-comment fa fa-comment-o',
			)
		);
	}
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_next_posts_text' ) ) :
/**
 * Text for Older Projects link in page navigation.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_portfolio_integration_next_posts_text() {
	return esc_html__( 'Older Projects', 'smart' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_prev_posts_text' ) ) :
/**
 * Text for Newer Projects link in page navigation.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_portfolio_integration_prev_posts_text() {
	return esc_html__( 'Newer Projects', 'smart' );
}
endif;

/** ==========================================================================
 *  Widget.
 *  ======================================================================= */
if ( ! function_exists( 'nice_portfolio_integration_widget_title' ) ) :
/**
 * Print title for widgets.
 *
 * @since 1.0.0
 *
 * @param string $output
 * @param string $title
 */
function nice_portfolio_integration_widget_title( $output, $title ) {
	if ( ! $title ) {
		return;
	}

	echo '<h4 class="widget-title">' . esc_html( $title ) . '</h4>';
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_widget_class' ) ) :
/**
 * Obtain additional classes for the current widget.
 *
 * @since  1.0.0
 *
 * @param  array $class
 *
 * @return array
 */
function nice_portfolio_integration_widget_class( $class = array() ) {
	$widget = nice_portfolio_current_widget();

	if ( $widget instanceof Nice_Portfolio_Categories_Widget ) {
		$class[] = 'widget_categories';
	}

	return $class;
}
endif;
