<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions for sub template-loaders.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/** ==========================================================================
 *  Template Loaders.
 *  ======================================================================= */

if ( ! function_exists( 'nice_portfolio_integration_homepage' ) ) :
/**
 * Display portfolio projects in the homepage.
 *
 * @since  1.0.0
 */
function nice_portfolio_integration_homepage() {
	// Hide category filter for this iteration.
	add_filter( 'nice_portfolio_can_display_category_filter', '__return_false', 99 );

	nice_portfolio_get_template_part( 'home' );

	// Restore category filter to its previous state.
	remove_filter( 'nice_portfolio_can_display_category_filter', '__return_false', 99 );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_single_heading' ) ) :
/**
 * Add a link back to the portfolio page on single portfolio projects
 *
 * @since  1.0.0
 */
function nice_portfolio_integration_single_heading() {
	nice_portfolio_get_template_part( 'single-project/heading' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_single_project_details' ) ) :
/**
 * Show details for portfolio single projects.
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_single_project_details() {
	nice_portfolio_get_template_part( 'single-project/details' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_single_project_excerpt' ) ) :
/**
 * Show excerpt for portfolio single projects.
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_single_project_excerpt() {
	nice_portfolio_get_template_part( 'single-project/excerpt' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_loop_project_permalink' ) ) :
/**
 * Overlay for looped project.
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_loop_project_permalink() {
	nice_portfolio_get_template_part( 'loop/project/permalink' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_loop_project_content' ) ) :
/**
 * Content for looped project.
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_loop_project_content() {
	nice_portfolio_get_template_part( 'loop/project/content' );
}
endif;
