<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles modifications to the plugin's templating system.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

remove_action( 'nice_portfolio_loop_project', 'nice_portfolio_loop_project_title', 30 );

/** ==========================================================================
 *  Initial basic setup.
 *  ======================================================================= */

if ( ! function_exists( 'nice_portfolio_integration_template_paths' ) ) :
add_filter( 'nice_portfolio_template_paths', 'nice_portfolio_integration_template_paths' );
/**
 * Add template paths to the plugin list.
 *
 * This function defines which will be the directories where templates should
 * be placed within this theme.
 *
 * @since  1.0.3
 *
 * @param  array $file_paths
 *
 * @return array
 */
function nice_portfolio_integration_template_paths( array $file_paths = array() ) {
	$file_paths[5]  = trailingslashit( get_stylesheet_directory() ) . 'includes/plugin-integrations/nice-portfolio/templates/';
	$file_paths[15] = trailingslashit( get_template_directory() ) . 'includes/plugin-integrations/nice-portfolio/templates/';

	return $file_paths;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_setup_current_page' ) ) :
remove_action( 'nice_portfolio_setup_page', 'nice_portfolio_setup_current_page' );
add_action( 'nice_portfolio_setup_page', 'nice_portfolio_integration_setup_current_page' );
/**
 * Setup hooks for the current page.
 *
 * All actions that generate specific HTML output for different portfolio
 * pages should be hooked to the actions that are fired within the
 * following function.
 *
 * @uses  Nice_Portfolio_Setup_Page::init()
 *
 * @see   nice_portfolio_setup_page()
 * @see   nice_portfolio_setup_category_page()
 * @see   nice_portfolio_setup_tag_page()
 * @see   nice_portfolio_setup_archive_page()
 *
 * Hook origin:
 * @see Nice_Portfolio_PublicDisplayResponder::setup_page()
 *
 * @since 1.0
 */
function nice_portfolio_integration_setup_current_page() {
	Nice_PortfolioIntegration_Setup_Page::init();
}
endif;

/** ==========================================================================
 *  Page setup.
 *  ======================================================================= */

if ( ! function_exists( 'nice_portfolio_integration_single_project_setup' ) ) :
add_action( 'nice_portfolio_single_project', 'nice_portfolio_integration_single_project_setup' );
/**
 * Set actions for single project pages.
 *
 * @since  1.0.0
 */
function nice_portfolio_integration_single_project_setup() {
	/**
	 * Remove the metadata display from the portfolio single item title.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 *
	 * @uses nice_page_title_use_meta()
	 */
	add_filter( 'nice_page_title_use_meta', '__return_false' );

	/**
	 * Add ´portfolio_project´ to the list of content types capable of having
	 * the subtitle functionality.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 *
	 * @see nice_page_title_meta()
	 */

	add_filter( 'nice_page_subtitle_post_types', 'nice_portfolio_integration_subtitle_enable' );

	/**
	 * Add excerpt after title.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see nice_portfolio_integration_single_project_excerpt()
	 *
	 * @uses nice_portfolio_header()
	 */

	add_action( 'nice_portfolio_header', 'nice_portfolio_integration_single_project_excerpt', 20 );

	/**
	 * Relocate project navigation before the footer area.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see nice_portfolio_integration_single_project_nav_footer()
	 *
	 * @uses nice_footer()
	 */
	remove_action( 'nice_portfolio_after_single_project', 'nice_portfolio_single_project_navigation' );
	add_action( 'nice_footer', 'nice_post_navigation', 0 );

	/**
	 * Include the project details (defaults in content/sidebar layout)
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see details.php template.
	 *
	 * @uses nice_portfolio_integration_single_project_details()
	 */
	add_action( 'nice_sidebar', 'nice_portfolio_integration_single_project_details' );

}
endif;

if ( ! function_exists( 'nice_portfolio_integration_archive_setup' ) ) :
add_action( 'nice_portfolio_archive_page', 'nice_portfolio_integration_archive_setup' );
/**
 * Set actions for portfolio archive page.
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_archive_setup() {
	/**
	 * Set text for Older Projects link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_next_posts_text', 'nice_portfolio_integration_next_posts_text' );

	/**
	 * Set text for Newer Projects link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_prev_posts_text', 'nice_portfolio_integration_prev_posts_text' );

	/**
	 * Remove plugin's archive title.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see nice_portfolio_get_title()
	 */
	remove_filter( 'nice_portfolio_the_title', 'nice_portfolio_get_archive_title' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_category_setup' ) ) :
add_action( 'nice_portfolio_category_page', 'nice_portfolio_integration_category_setup' );
/**
 * Set actions for portfolio category page.
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_category_setup() {
	/**
	 * Set text for Older Projects link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_next_posts_text', 'nice_portfolio_integration_next_posts_text' );

	/**
	 * Set text for Newer Projects link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_prev_posts_text', 'nice_portfolio_integration_prev_posts_text' );

	/**
	 * Remove plugin's category title.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see nice_portfolio_get_title()
	 */
	remove_filter( 'nice_portfolio_the_title', 'nice_portfolio_get_category_title' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_tag_setup' ) ) :
add_action( 'nice_portfolio_tag_page', 'nice_portfolio_integration_tag_setup' );
/**
 * Set actions for portfolio tag page.
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_tag_setup() {
	/**
	 * Set text for Older Projects link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_next_posts_text', 'nice_portfolio_integration_next_posts_text' );

	/**
	 * Set text for Newer Projects link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_prev_posts_text', 'nice_portfolio_integration_prev_posts_text' );

	/**
	 * Remove plugin's tag title.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see nice_portfolio_get_title()
	 */
	remove_filter( 'nice_portfolio_the_title', 'nice_portfolio_get_tag_title' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_subtitle_enable' ) ) :
add_action( 'nice_portfolio_tag_page', 'nice_portfolio_integration_subtitle_enable' );
/**
 * Add portfolio_project as a type that can have subtitle in the singular template.
 *
 * @since  1.0.0
 *
 * @param  array $post_types
 *
 * @return array
 */
function nice_portfolio_integration_subtitle_enable( $post_types ) {
	$post_types[] = nice_portfolio_post_type_name();

	return $post_types;
}
endif;
