<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the theming for Portfolio by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_portfolio_integration_single_title_display' ) ) :
add_action( 'nice_portfolio_single_project', 'nice_portfolio_integration_single_title_display' );
/**
 * Display title in content or not.
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_single_title_display() {
	if ( ! nice_portfolio_is_single() ) {
		return;
	}

	$display_title = get_post_meta( get_the_ID(), '_post_title_content', true );

	if ( nice_bool( $display_title ) ) {
		return;
	}

	$display_title = nice_get_option( '_portfolio_project_title_content' );

	if ( nice_bool( $display_title ) ) {
		return;
	}

	remove_action( 'nice_portfolio_header', 'nice_portfolio_title' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_single_media_display' ) ) :
add_action( 'nice_portfolio_single_project', 'nice_portfolio_integration_single_media_display' );
/**
 * Display media in content or not
 *
 * @since 1.0.0
 */
function nice_portfolio_integration_single_media_display() {
	if ( ! nice_portfolio_is_single() ) {
		return;
	}

	$display_media = get_post_meta( get_the_ID(), '_post_media_content', true );

	if ( $display_media !== '' && nice_bool( $display_media ) ) {
		return;
	}

	$display_media = nice_get_option( '_portfolio_project_media_content' );

	if ( empty( $display_media ) || nice_bool( $display_media ) ) {
		return;
	}

	remove_action( 'nice_portfolio_single_project_content', 'nice_portfolio_single_project_gallery' );
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_single_details_display' ) ) :
add_action( 'nice_portfolio_single_project', 'nice_portfolio_integration_single_details_display' );
/**
 * See if we should include the portfolio details or not.
 *
 * Locate the portfolio details according to the user selection or the default
 * positioning.
 *
 * @since  1.0.0
 */
function nice_portfolio_integration_single_details_display() {
	if ( ! nice_portfolio_is_single() ) {
		return;
	}

	$display    = nice_portfolio_integration_get_single_details_display();
	$layout     = nice_portfolio_integration_get_single_details_layout();
	$in_sidebar = in_array( $layout, array( 'sidebar_left', 'sidebar_right' ), true );

	if ( 'on' !== $display ) { // If the user decides to not display the details, remove the actions.
		remove_action( 'nice_portfolio_single_project_content', 'nice_portfolio_integration_single_project_details' );
		remove_action( 'nice_sidebar', 'nice_portfolio_integration_single_project_details' );

		return;
	}

	if ( ! $in_sidebar ) { // If the location is on top/bottom, remove the action hooked to the sidebar in template-setup.php
		remove_action( 'nice_sidebar', 'nice_portfolio_integration_single_project_details' );
	}

	if ( 'portfolio_bottom' === $layout ) {
		add_action( 'nice_portfolio_after_single_project_content', 'nice_portfolio_integration_single_project_details' );
		return;
	}

	// by default if it's empty it will display before the content.
	add_action( 'nice_portfolio_before_single_project_content', 'nice_portfolio_integration_single_project_details' );
}
endif;


if ( ! function_exists( 'nice_portfolio_integration_single_sidebar_body_class' ) ) :
add_filter( 'body_class', 'nice_portfolio_integration_single_sidebar_body_class' );
/**
 * See if we need to modify the sidebar body classes according to the
 * single-portfolio details
 *
 * @since 1.0.0
 *
 * @param  array $classes
 * @return array $classes
 */
function nice_portfolio_integration_single_sidebar_body_class( $classes ) {
	if ( ! nice_portfolio_is_single() ) {
		return $classes;
	}

	$has_sidebar = true;
	$display     = nice_portfolio_integration_get_single_details_display();
	$layout      = nice_portfolio_integration_get_single_details_layout();

	if ( ( 'on' !== $display ) || in_array( $layout, array( 'portfolio_top', 'portfolio_bottom' ), true ) ) {
		$has_sidebar = false;
	}

	if ( $has_sidebar ) {
		$classes[] = 'has-sidebar';
	}

	return $classes;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_sidebar_position' ) ) :
add_filter( 'nice_sidebar_position', 'nice_portfolio_integration_sidebar_position' );
/**
 * Set the current position of the sidebar for single project pages.
 *
 * @since  1.0.0
 *
 * @param  string $position
 *
 * @return string
 */
function nice_portfolio_integration_sidebar_position( $position = 'none' ) {
	if ( ! nice_portfolio_is_single() ) {
		return $position;
	}

	$display = nice_portfolio_integration_get_single_details_display();

	if ( 'on' !== $display ) {
		return 'none';
	}

	$layout = nice_portfolio_integration_get_single_details_layout();

	switch ( $layout ) {
		case 'sidebar_left':
			$position = 'left';
			break;
		case 'sidebar_right':
			$position = 'right';
			break;
		default:
			$position = 'none';
			break;
	}

	return $position;
}
endif;

if ( ! function_exists( 'nice_portfolio_integration_details_display' ) ) :
/**
 * Return if the details should be displayed or not
 *
 * @since 1.1
 */
function nice_portfolio_integration_get_single_details_display() {
	if ( ! nice_portfolio_is_single() ) {
		return;
	}

	$display = get_post_meta( get_the_ID(), '_portfolio_details', true );

	if ( $display !== '' ) {
		return $display;
	}

	$display = nice_get_option( '_portfolio_details' );

	if ( ! empty( $display ) ) {

		// return on/off for backwards compatibility
		if ( ! nice_bool( $display ) ) {
			return 'off';
		} else {
			return 'on';
		}
	}

}
endif;

if ( ! function_exists( 'nice_portfolio_integration_get_single_details_layout' ) ) :
/**
 * Return the portfolio details layout position
 *
 * @since 1.1
 */
function nice_portfolio_integration_get_single_details_layout() {
	if ( ! nice_portfolio_is_single() ) {
		return;
	}

	$layout = get_post_meta( get_the_ID(), '_portfolio_details_layout', true );

	if ( $layout !== '' ) {
		return $layout;
	}

	$layout = nice_get_option( '_portfolio_details_layout' );

	if ( ! empty( $layout ) ) {
		return $layout;
	}


}
endif;
