<?php
/**
 * Smart by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://www.nicethemes.com/theme-page
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_team_integration_options' ) ) :
add_filter( 'nice_options', 'nice_team_integration_options', 30 );
/**
 * Add Nice Team specific options to theme options.
 *
 * @since 1.0.0
 *
 * @param array $nice_options
 *
 * @return array
 */
function nice_team_integration_options( array $nice_options = array() ) {
	// Obtain the prefix for the option fields.
	$prefix = NICE_PREFIX;

	$nice_team_integration_options[] = array(
		'name'   => esc_html__( 'Team Members', 'smart' ),
		'id'     => $prefix . '_team_integration_section',
		'type'   => 'group',
		'icon'   => '<i class="bi_user-single"></i>',
	);

	$nice_team_integration_options[] = array(
		'name' => esc_html__( 'Enable Team Section', 'smart' ),
		'desc' => esc_html__( 'Show the team members section in the homepage.', 'smart' ),
		'id'   => $prefix . '_homepage_team',
		'std'  => nice_default_setting( 'homepage_team' ),
		'type' => 'checkbox',
		'tip'  => '',
	);

	$nice_team_integration_options[] = array(
		'name'      => esc_html__( 'Team Section Title', 'smart' ),
		'desc'      => esc_html__( "Set the title for your team section. Leave it blank if you don't want to use one.", 'smart' ),
		'id'        => $prefix . '_homepage_team_title',
		'std'       => nice_default_setting( 'homepage_team_title' ),
		'type'      => 'text',
		'tip'       => '',
		'condition' => $prefix . '_homepage_team:is(true)',
		'operator'  => 'and',
	);

	$nice_team_integration_options[] = array(
		'name'      => esc_html__( 'Team Section Description', 'smart' ),
		'desc'      => esc_html__( "Set the description for your team section. Leave it blank if you don't want to use one.", 'smart' ),
		'id'        => $prefix . '_homepage_team_description',
		'std'       => nice_default_setting( 'homepage_team_description' ),
		'type'      => 'text',
		'tip'       => '',
		'condition' => $prefix . '_homepage_team:is(true)',
		'operator'  => 'and',
	);

	$nice_team_integration_options[] = array(
		'name'      => esc_html__( 'Columns', 'smart' ),
		'desc'      => esc_html__( 'Set the number of columns that will be used to display team members in the home page.', 'smart' ),
		'id'        => $prefix . '_homepage_team_columns',
		'std'       => nice_default_setting( 'homepage_team_columns' ),
		'type'      => 'slider',
		'tip'       => '',
		'condition' => $prefix . '_homepage_team:is(true)',
		'operator'  => 'and',
	);

	$nice_team_integration_options[] = array(
		'name'      => esc_html__( 'Limit', 'smart' ),
		'desc'      => esc_html__( 'Set the maximum number of team members to show in the home page.', 'smart' ),
		'id'        => $prefix . '_homepage_team_limit',
		'std'       => nice_default_setting( 'homepage_team_limit' ),
		'type'      => 'text',
		'tip'       => '',
		'condition' => $prefix . '_homepage_team:is(true)',
		'operator'  => 'and',
	);

	$nice_team_integration_options[] = array(
		'name'      => esc_html__( 'Team Background Image', 'smart' ),
		'desc'      => esc_html__( 'Upload or choose a background image for the team section.', 'smart' ),
		'id'        => $prefix . '_homepage_team_background_image',
		'std'       => nice_default_setting( 'homepage_team_background_image' ),
		'type'      => 'upload',
		'condition' => $prefix . '_homepage_team:is(true)',
		'operator'  => 'and',
		'extra'     => array( 'type' => 'image' ),
	);

	$nice_team_integration_options[] = array(
		'name'      => esc_html__( 'Team Overlay Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a color for the team section overlay background. It will be displayed in front of the background image', 'smart' ),
		'id'        => $prefix . '_homepage_team_background_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'homepage_team_background_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_homepage_team:is(true)',
		'operator'  => 'and',
	);

	$nice_team_integration_options[] = array(
		'name'      => esc_html__( 'Team Overlay Background Color Opacity', 'smart' ),
		'desc'      => esc_html__( 'Adjust the opacity of the background color to make it slightly transparent.', 'smart' ),
		'id'        => $prefix . '_homepage_team_background_color_opacity',
		'std'       => nice_default_setting( 'homepage_team_background_color_opacity' ),
		'type'      => 'slider',
		'condition' => $prefix . '_homepage_team:is(true),' . $prefix . '_homepage_team_background_color:not()',
		'operator'  => 'and',
	);

	$nice_team_integration_options[] = array(
		'name'      => esc_html__( 'Team Section Skin', 'smart' ),
		'desc'      => esc_html__( 'Choose the team section skin.', 'smart' ),
		'id'        => $prefix . '_homepage_team_text_skin',
		'type'      => 'select',
		'std'       => nice_default_setting( 'homepage_team_text_skin' ),
		'tip'       => '',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark ' => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_homepage_team:is(true)',
		'operator'  => 'and',
	);

	$splice_key = $prefix . '_homepage_content_text_skin';

	if ( class_exists( 'Nice_Portfolio_Plugin' ) ) {
		$splice_key = $prefix . '_homepage_portfolio_text_skin';
	} elseif ( class_exists( 'Nice_Infoboxes_Plugin' ) ) {
		$splice_key = $prefix . '_homepage_infoboxes_text_skin';
	}

	$nice_options = nice_options_enqueue( $nice_options, $nice_team_integration_options, $splice_key, false );

	return $nice_options;
}
endif;


if ( ! function_exists( 'nice_team_integration_options_homepage_default_elements' ) ) :
add_filter( 'nice_options_homepage_default_elements', 'nice_team_integration_options_homepage_default_elements', 30 );
/**
 * Add Team to default home page elements.
 *
 * @since  1.0.0
 *
 * @param  array $default_elements
 *
 * @return array
 */
function nice_team_integration_options_homepage_default_elements( $default_elements ) {
	return array_merge( $default_elements, array( 'team' ) );
}
endif;
