<?php
/**
 * Smart by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'Nice_TeamIntegration_Setup_Page' ) ) :
/**
 * Class Nice_TeamIntegration_Setup_Page
 *
 * This class extends Nice_Team_Setup_Page to also manage theme-specific
 * hooks than need to be fired on each kind of team page.
 *
 * @since 1.0
 */
class Nice_TeamIntegration_Setup_Page extends Nice_Team_Setup_Page {
	/**
	 * Initialize an instance of this class and setup the current page.
	 *
	 * @since 1.0
	 *
	 * @param Nice_Team_Setup_Page $setup
	 */
	public static function init( Nice_Team_Setup_Page $setup = null ) {
		if ( ! $setup ) {
			$setup = new self;
		}

		parent::init( $setup );
	}

	/**
	 * Obtain an internal name for the current page.
	 *
	 * @since 1.0.0
	 *
	 * @return null|string
	 */
	public function get_current_page() {
		if ( nice_is_homepage() ) {
			$this->current_page = 'homepage';
		}

		return parent::get_current_page();
	}

	/**
	 * Fire custom actions depending on current page.
	 *
	 * @since 1.0.0
	 */
	public function setup_page() {
		if ( 'homepage' === $this->current_page ) {
			/**
			 * @hook nice_team_integration_home_page
			 *
			 * All specific actions for team elements that need to run in
			 * the home page should be hooked here.
			 *
			 * @since 1.0.0
			 */
			do_action( 'nice_team_integration_homepage' );
		}
	}
}
endif;
