<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions that are fired within templates.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/** ==========================================================================
 *  Content Getters.
 *  ======================================================================= */

if ( ! function_exists( 'nice_team_integration_get_class' ) ) :
/**
 * Add classes to team class.
 *
 * @since 1.0.0
 *
 * @param array $class
 *
 * @return array
 */
function nice_team_integration_get_class( array $class = array() ) {
	if ( ! is_singular( nice_team_post_type_name() ) ) {
		$class = array_merge( $class, array(
				'single-gutter-v',
				'style-default',
			)
		);

		if ( ! nice_team_doing_widget() && nice_team_get_grid_columns() > 1 ) {
			$class[] = 'single-gutter-h';
		} else {
			$class[] = 'no-gap-h';
		}

		if ( nice_team_doing_widget() ) {
			$class[] = 'grid';
		}

		switch ( nice_team_integration_get_text_skin() ) {
			case 'light':
				$class[] = 'light';
				break;
			case 'dark':
				$class[] = 'dark';
				break;
			default:
				break;
		}

		// Disable some default classes.
		$disable_classes = array(
			'default-styles',
		);
		foreach ( $class as $key => $value ) {
			if ( in_array( $value, $disable_classes, true ) ) {
				unset( $class[ $key ] );
			}
		}
	}

	return $class;
}
endif;

if ( ! function_exists( 'nice_team_integration_get_member_class' ) ) :
/**
 * Add classes to looped member class.
 *
 * @since 1.0.0
 *
 * @param array $class
 *
 * @return array
 */
function nice_team_integration_get_member_class( array $class = array() ) {
	if ( ! is_singular( nice_team_post_type_name() ) ) {
		$class = array_merge( $class, array(
				'type-' . nice_team_post_type_name(),
				'multiple-click',
				'image-animated',
				'text-center',
				'content-padding-h-2x',
				'content-padding-v-2x',
			)
		);

		if ( nice_team_doing_widget() ) {
			$class[] = 'columns-1';
		}
	}

	return $class;
}
endif;

if ( ! function_exists( 'nice_team_integration_get_container_class' ) ) :
/**
 * Obtain additional class names to container element depending on the current
 * team page.
 *
 * @since  1.0.0
 *
 * @param  string $class HTML class.
 * @return string
 */
function nice_team_integration_get_container_class( $class ) {
	if ( nice_team_is_single() ) {
		$class[] = 'team-project';

	} elseif ( nice_team_is_category() ) {
		$class[] = 'team-category';
		$class[] = 'full-width';

	} elseif ( nice_team_is_archive() ) {
		$class[] = 'team-archive';
		$class[] = 'full-width';

	} elseif ( nice_team_is_team_member_post_type() ) {
		$class[] = 'team-post-type';
	}

	return $class;
}
endif;

if ( ! function_exists( 'nice_team_integration_get_homepage_options' ) ) :
/**
 * Obtain theme options mixed up with team defaults for homepage.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_team_integration_get_homepage_options() {
	$nice_options = wp_parse_args( nice_get_options(), array(
			'nice_homepage_team'             => false,
			'nice_homepage_team_title'       => '',
			'nice_homepage_team_description' => '',
			'nice_homepage_team_columns'     => 4,
			'nice_homepage_team_limit'       => 4,
		)
	);

	/**
	 * @hook nice_team_integration_homepage_options
	 *
	 * Hook here to modify homepage options for team.
	 *
	 * @since 1.0.0
	 */
	$nice_options = apply_filters( 'nice_team_integration_homepage_options', $nice_options );

	return $nice_options;
}
endif;

if ( ! function_exists( 'nice_team_integration_homepage_args' ) ) :
/**
 * Obtain arguments to print out members in the homepage block.
 *
 * @since 1.0.0
 */
function nice_team_integration_homepage_args() {
	$args = array(
		'echo'         => true,
		'image_size'   => 600,
		'columns'      => nice_get_option( 'nice_homepage_team_columns' ),
		'limit'        => nice_get_option( 'nice_homepage_team_limit' ),
		'image_width'  => 230,
		'image_height' => 230,
	);

	/**
	 * @hook nice_team_integration_homepage_args
	 *
	 * Hook here to modify these arguments.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_team_integration_homepage_args', $args );

	return $args;
}
endif;

/** ==========================================================================
 *  Navigation.
 *  ======================================================================= */

if ( ! function_exists( 'nice_team_integration_next_posts_text' ) ) :
/**
 * Text for Next Page link in page navigation.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_team_integration_next_posts_text() {
	return esc_html__( 'Next Page', 'smart' );
}
endif;

if ( ! function_exists( 'nice_team_integration_prev_posts_text' ) ) :
/**
 * Text for Previous Page link in page navigation.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_team_integration_prev_posts_text() {
	return esc_html__( 'Previous Page', 'smart' );
}
endif;

/** ==========================================================================
 *  Loop.
 *  ======================================================================= */

if ( ! function_exists( 'nice_team_integration_loop_member_content_start' ) ) :
/**
 * Print opening tag for looped team member's content.
 *
 * @since 1.0.0
 */
function nice_team_integration_loop_member_content_start() {
?>
	<div class="item-content">
		<div class="item-content-inner">
<?php
}
endif;

if ( ! function_exists( 'nice_team_integration_loop_member_content_end' ) ) :
/**
 * Print closing tag for looped team member's content.
 *
 * @since 1.0.0
 */
function nice_team_integration_loop_member_content_end() {
?>
		</div>
	</div>
<?php
}
endif;

if ( ! function_exists( 'nice_team_integration_loop_member_separator' ) ) :
/**
 * Print content separator for looped team member.
 *
 * @since 1.0.0
 */
function nice_team_integration_loop_member_separator() {
	if ( ! get_the_title() && ! get_the_excerpt() ) {
		return;
	}
?>
	<hr class="entry-separator reduced">
<?php
}
endif;

if ( ! function_exists( 'nice_team_integration_loop_member_overlay' ) ) :
/**
 * Add overlay markup to looped team member.
 *
 * @since 1.0.0
 */
function nice_team_integration_loop_member_overlay() {
?>
	<div class="item-caption-overlay <?php nice_theme_color_background_class( 'dark-color-1', true ); ?> animated" data-opacity="15"></div>
<?php
}
endif;

/** ==========================================================================
 *  Widget.
 *  ======================================================================= */
if ( ! function_exists( 'nice_team_integration_widget_members_title' ) ) :
/**
 * Print title for members widget.
 *
 * @since 1.0.0
 *
 * @param string $output
 * @param string $title
 */
function nice_team_integration_widget_members_title( $output, $title ) {
	if ( ! $title ) {
		return;
	}

	echo '<h4 class="widget-title">' . esc_html( $title ) . '</h4>';
}
endif;

/** ==========================================================================
 *  Other.
 *  ======================================================================= */

if ( ! function_exists( 'nice_team_integration_get_text_skin' ) ) :
/**
 * Obtain the text skin for the current grid.
 *
 * @since 1.0.0
 *
 * @return string
 */
function nice_team_integration_get_text_skin() {
	$section_skin = '';

	if ( nice_is_homepage() ) {
		$section_skin = nice_get_option( 'nice_homepage_team_text_skin' );
	} elseif ( nice_team_doing_shortcode() || nice_team_doing_widget() ) {
		$section_skin = get_post_meta( get_query_var( 'p' ), '_post_content_skin', true );
	}

	return $section_skin;
}
endif;
