<?php
/**
 * Smart by NiceThemes.
 *
 * This file adds actions and filters to hooks that are fired within templates,
 * setting up the visibility of single members, team pages and other
 * plugin elements within the theme.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/** ==========================================================================
 *  HTML wrappers.
 *  ======================================================================= */
/**
 * Remove default content wrappers. We're using our own wrappers inside templates.
 *
 * @since 1.0.0
 *
 * Hook origin:
 * @see All team page templates.
 */
remove_action( 'nice_team_before_main_content', 'nice_team_wrapper_start', 10 );
remove_action( 'nice_team_after_main_content', 'nice_team_wrapper_end', 10 );

/** ==========================================================================
 *  Navigation.
 *  ======================================================================= */

/**
 * Remove default page navigation. We're replacing it with the custom theme
 * functionality inside templates.
 *
 * @since 1.0.0
 *
 * Hook origin:
 * @see All team page templates.
 */
remove_action( 'nice_team_after_main_content', 'nice_team_loop_members_page_navigation', 0 );

/** ==========================================================================
 *  Content.
 *  ======================================================================= */

/**
 * Add additional classes to container element depending on the current team page.
 *
 * @since  1.0.0
 *
 * Hook origin:
 * @see nice_get_container_class()
 *
 * @uses nice_team_integration_get_container_class()
 */
add_filter( 'nice_container_class', 'nice_team_integration_get_container_class' );

/**
 * Remove default title from single member pages.
 *
 * @since 1.0
 *
 * Hook origin:
 * @see Single member title template.
 */
remove_action( 'nice_team_single_member_content', 'nice_team_single_member_position', 10 );

/**
 * Remove single member meta from its default location. We're gonna be calling
 * it from the description template.
 *
 * @since 1.0.0
 *
 * Hook origin:
 * @see Single member content template.
 */
remove_action( 'nice_team_single_member_content', 'nice_team_single_member_meta', 30 );

/**
 * Print permalink for looped team member.
 *
 * @since 1.0.0
 *
 * Hook origin:
 * @see nice_team_loop_members()
 */
add_action( 'nice_team_loop_member', 'nice_team_integration_loop_member_permalink', 15 );

/**
 * Print opening tag for looped team member's content.
 *
 * @since 1.0.0
 *
 * Hook origin:
 * @see nice_team_loop_members()
 */
add_action( 'nice_team_loop_member', 'nice_team_integration_loop_member_content_start', 21 );

/**
 * Print closing tag for looped team member's content.
 *
 * @since 1.0.0
 *
 * Hook origin:
 * @see nice_team_loop_members()
 */
add_action( 'nice_team_loop_member', 'nice_team_integration_loop_member_content_end', 55 );

/**
 * Print content separator for looped team member.
 *
 * @since 1.0.0
 *
 * Hook origin:
 * @see Looped member title template.
 */
add_action( 'nice_team_loop_after_member_title', 'nice_team_integration_loop_member_separator', 20 );

/** ==========================================================================
 *  Widget.
 *  ======================================================================= */
/**
 * Modify markup for widget title.
 *
 * Hook origin:
 * @see Nice_Team_WP_Widget::widget_title()
 */
add_filter( 'nice_team_widget_title', 'nice_team_integration_widget_members_title', 10, 2 );

/** ==========================================================================
 *  Other.
 *  ======================================================================= */

/**
 * Add classes to team class.
 *
 * @since 1.0.0
 *
 * Hook origin:
 * @see nice_team_get_class()
 *
 * @uses nice_team_integration_get_class()
 */
add_filter( 'nice_team_class', 'nice_team_integration_get_class' );

/**
 * Add classes to looped member container.
 *
 * @since 1.0.0
 *
 * Hook origin:
 * @see nice_team_get_member_class()
 *
 * @uses nice_team_integration_get_member_class()
 */
add_filter( 'nice_team_member_class', 'nice_team_integration_get_member_class' );

