<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles modifications to the plugin's templating system.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/** ==========================================================================
 *  Initial basic setup.
 *  ======================================================================= */

if ( ! function_exists( 'nice_team_integration_template_paths' ) ) :
add_filter( 'nice_team_template_paths', 'nice_team_integration_template_paths' );
/**
 * Add template paths to the plugin list.
 *
 * This function defines which will be the directories where templates should
 * be placed within this theme.
 *
 * @since  1.0.3
 *
 * @param  array $file_paths
 *
 * @return array
 */
function nice_team_integration_template_paths( array $file_paths = array() ) {
	$file_paths[5]  = trailingslashit( get_stylesheet_directory() ) . 'includes/plugin-integrations/nice-team/templates/';
	$file_paths[15] = trailingslashit( get_template_directory() ) . 'includes/plugin-integrations/nice-team/templates/';

	return $file_paths;
}
endif;

if ( ! function_exists( 'nice_team_integration_setup_current_page' ) ) :
remove_action( 'nice_team_setup_page', 'nice_team_setup_current_page' );
add_action( 'nice_team_setup_page', 'nice_team_integration_setup_current_page' );
/**
 * Setup hooks for the current page.
 *
 * All actions that generate specific HTML output for different team
 * pages should be hooked to the actions that are fired within the
 * following function.
 *
 * @uses  Nice_Team_Setup_Page::init()
 *
 * @see   nice_team_setup_category_page()
 * @see   nice_team_setup_archive_page()
 *
 * Hook origin:
 * @see Nice_Team_PublicDisplayResponder::setup_page()
 *
 * @since 1.0
 */
function nice_team_integration_setup_current_page() {
	Nice_TeamIntegration_Setup_Page::init();
}
endif;

/** ==========================================================================
 *  Page setup.
 *  ======================================================================= */
if ( ! function_exists( 'nice_team_integration_single_member_setup' ) ) :
add_action( 'nice_team_single_member_page', 'nice_team_integration_single_member_setup' );
/**
 * Set actions for single member pages.
 *
 * @since  1.0.0
 */
function nice_team_integration_single_member_setup() {
	/**
	 * Remove member title from its original location.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see Single member template.
	 */
	remove_action( 'nice_team', 'nice_team_loop_member_title', 30 );

	/**
	 * Add content to heading for single member pages.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see nice_heading()
	 *
	 * @uses nice_team_integration_single_heading_title()
	 */
	add_action( 'nice_heading_title', 'nice_team_integration_single_member_position' );

	/**
	 * Remove post meta from single member pages.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see nice_page_title_meta()
	 */
	add_filter( 'nice_page_title_use_meta', '__return_false', 10 );

	/**
	 * Show member thumbnail inside thumbnail.
	 *
	 * @since 1.0.0
	 *
	 * Hook origin:
	 * @see Single member content template.
	 */
	add_action( 'nice_team_single_member_content', 'nice_team_integration_single_member_thumbnail', 0 );

	/**
	 * Remove navigation for single members.
	 *
	 * @since 1.0
	 *
	 * Hook origin:
	 * @see Single member content template.
	 */
	remove_action( 'nice_team_after_single_member', 'nice_team_single_member_navigation', 10 );
}
endif;

if ( ! function_exists( 'nice_team_integration_archive_setup' ) ) :
add_action( 'nice_team_archive_page', 'nice_team_integration_archive_setup' );
/**
 * Set actions for team archive page.
 *
 * @since 1.0.0
 */
function nice_team_integration_archive_setup() {
	/**
	 * Set text for Older Members link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_next_posts_text', 'nice_team_integration_next_posts_text' );

	/**
	 * Set text for Newer Members link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_prev_posts_text', 'nice_team_integration_prev_posts_text' );
}
endif;

if ( ! function_exists( 'nice_team_integration_category_setup' ) ) :
add_action( 'nice_team_category_page', 'nice_team_integration_category_setup' );
/**
 * Set actions for team category page.
 *
 * @since 1.0.0
 */
function nice_team_integration_category_setup() {
	/**
	 * Set text for Older Members link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_next_posts_text', 'nice_team_integration_next_posts_text' );

	/**
	 * Set text for Newer Members link in page navigation.
	 *
	 * @since  1.0.0
	 *
	 * Hook origin:
	 * @see nice_pagenavi()
	 */
	add_filter( 'nice_prev_posts_text', 'nice_team_integration_prev_posts_text' );
}
endif;

/** ==========================================================================
 *  Widget setup.
 *  ======================================================================= */

if ( ! function_exists( 'nice_team_integration_widget_members_template_hooks' ) ) :
add_filter( 'nice_team_widget_members_template_hooks', 'nice_team_integration_widget_members_template_hooks' );
/**
 * Setup widget hooks.
 *
 * @since 1.0.0
 *
 * @param array $hooks
 *
 * @return array
 */
function nice_team_integration_widget_members_template_hooks( $hooks ) {
	$hooks = array_merge( $hooks, array(
			array(
				'tag' => 'nice_team_widget_member_content',
				'function' => 'nice_team_integration_loop_member_permalink',
				'priority' => 5,
			),
			array(
				'tag' => 'nice_team_widget_member_content',
				'function' => 'nice_team_integration_loop_member_content_start',
				'priority' => 15,
			),
			array(
				'tag' => 'nice_team_widget_member_content',
				'function' => 'nice_team_integration_loop_member_content_end',
				'priority' => 50,
			),
		)
	);

	return $hooks;
}
endif;
