<?php
/**
 * Smart by NiceThemes.
 *
 * Manage testimonials in home page template.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.1
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_homepage_testimonials_get_options' ) ) :
/**
 * Obtain theme options mixed up with testimonials defaults for homepage.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_homepage_testimonials_get_options() {
	// Allow bypass.
	if ( $nice_options = apply_filters( 'nice_homepage_testimonials_get_options', null ) ) {
		return $nice_options;
	}

	$nice_options = wp_parse_args( nice_get_options(), array(
			'nice_homepage_testimonials'             => false,
			'nice_homepage_testimonials_title'       => '',
			'nice_homepage_testimonials_description' => '',
			'nice_homepage_testimonials_limit'       => 4,
		)
	);

	return $nice_options;
}
endif;

if ( ! function_exists( 'nice_homepage_testimonials' ) ) :
/**
 * Display testimonials for homepage.
 *
 * @since  1.0.0
 *
 * @param  bool              $echo Choose to display HTML or not.
 *
 * @return mixed|string|null
 */
function nice_homepage_testimonials( $echo = true ) {
	// Allow bypass.
	if ( $output = apply_filters( 'nice_homepage_testimonials', '' ) ) {
		return $output;
	}

	if ( function_exists( 'nice_testimonials' ) ) {
		if ( ! nice_bool( nice_get_option( 'nice_homepage_testimonials' ) ) ) {
			return $output;
		}

		$title = nice_get_option( 'nice_homepage_testimonials_title' );
		$description = nice_get_option( 'nice_homepage_testimonials_description' );

		if ( ! $echo ) {
			ob_start();
		}

		?>
			<div id="homepage-testimonials" class="<?php nice_homepage_block_class( 'testimonials' ); ?>">
				<div class="inner">
					<div class="overlay"></div>
					<div class="block-wrapper col-full">

						<?php if ( $title or $description ) : ?>

							<header class="homepage-section-title homepage-testimonials-title">
								<?php if ( $title ) : ?>
									<h2 class="testimonials-title title"><?php echo esc_html( $title ); ?></h2>
								<?php endif; ?>

								<?php if ( $description ) : ?>
									<div class="testimonials-description description">
										<?php echo wpautop( $description ); // WPCS: XSS Ok ?>
									</div>
								<?php endif; ?>

							</header>

						<?php endif; ?>

						<div id="homepage-testimonials-container" class="flexslider slider text-slider" data-animation="fade" data-direction-nav="true">
							<ul class="slides">
								<?php
								nice_testimonials( array(
										'columns'    => 1,
										'limit'      => nice_get_option( 'nice_homepage_testimonials_limit' ),
										'image_size' => 100,
									)
								);
								?>
							</ul>
						</div>
					</div>
				</div>
			</div>
		<?php

		if ( ! $echo ) {
			$output = ob_get_contents();
			ob_end_clean();
		}
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_homepage_testimonials_post_template' ) ) :
add_filter( 'nice_testimonials_post_template', 'nice_homepage_testimonials_post_template' );
/**
 * Use a different template for testimonials when viewing homepage.
 *
 * @since  1.0.0
 *
 * @param  string $template
 *
 * @return string
 */
function nice_homepage_testimonials_post_template( $template = '' ) {
	if ( nice_is_homepage() ) {
		$template = '
		<li class="nice-testimonial slide">
			<blockquote class="nice-testimonial-content">
				%%IMAGE%%
				<div class="nice-testimonial-quote">
					%%CONTENT%%
					<cite class="nice-testimonial-author">%%TITLE%%</cite>
				</div>
			</blockquote>
		</li>';
	}

	return $template;
}
endif;

if ( ! function_exists( 'nice_homepage_testimonials_post_use_container' ) ) :
add_filter( 'nice_testimonials_post_use_container', 'nice_homepage_testimonials_post_use_container' );
/**
 * Disable default testimonials container in home page.
 *
 * @since  1.0.0
 *
 * @param  bool $use
 *
 * @return bool
 */
function nice_homepage_testimonials_post_use_container( $use = true ) {
	if ( nice_is_homepage() ) {
		return false;
	}

	return $use;
}
endif;

if ( ! function_exists( 'nice_homepage_testimonials_styles' ) ) :
add_filter( 'nice_homepage_styles', 'nice_homepage_testimonials_styles' );
/**
 * Add inline styles for testimonials section.
 *
 * @since  1.0.0
 *
 * @param  string $styles Default inline CSS.
 *
 * @return string
 */
function nice_homepage_testimonials_styles( $styles = '' ) {
	if ( ! class_exists( 'Nice_Testimonials_Plugin' ) ) {
		return $styles;
	}

	return $styles . nice_homepage_block_styles( 'testimonials' );
}
endif;
