/**
 * Smart by NiceThemes.
 *
 * Google Maps implementation
 *
 * @since   1.0.0
 * @package Smart
 */

(function() {
	'use strict';
	var nice_vc_gmaps_init = function() {
		var gmaps_single = function($el) {
			// set your google maps parameters
			var map_id     = jQuery($el).attr('id'),
				latitude   = jQuery($el).data('lat'),
				longitude  = jQuery($el).data('lon'),
				map_zoom   = jQuery($el).data('zoom'),
				main_color = jQuery($el).data('color'),
				ui_color   = jQuery($el).data('ui'),
				brightness_value = jQuery($el).data('brightness'),
				saturation_value = jQuery($el).data('saturation'),
				draggable  = jQuery($el).data('draggable'),
				style,
				marker;
			// we define here the style of the map
			if ( main_color !== undefined && main_color !== '' ) {
				style = [{
						// set saturation for the labels on the map
						elementType: 'labels',
						stylers: [{
							saturation: saturation_value
						}]
					}, { // poi stands for point of interest - don't show these lables on the map
						featureType: 'poi',
						elementType: 'labels',
						stylers: [{
							visibility: 'off'
						}]
					}, {
						featureType: 'road',
						elementType: 'labels.icon',
						stylers: [{
							visibility: 'off'
						}]
					}, {
						// don't show highways lables on the map
						featureType: 'road.highway',
						elementType: 'labels',
						stylers: [{
							visibility: 'off'
						}]
					}, {
						// don't show local road lables on the map
						featureType: 'road.local',
						elementType: 'labels.icon',
						stylers: [{
							visibility: 'off'
						}]
					}, {
						// don't show arterial road lables on the map
						featureType: 'road.arterial',
						elementType: 'labels.icon',
						stylers: [{
							visibility: 'off'
						}]
					}, {
						// don't show road lables on the map
						featureType: 'road',
						elementType: 'geometry.stroke',
						stylers: [{
							visibility: 'off'
						}]
					},
					// style different elements on the map
					{
						featureType: 'transit',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'off'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'poi',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'off'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'poi.government',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'off'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'poi.sport_complex',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'off'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'poi.attraction',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'off'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'poi.business',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'off'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'transit',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'off'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'transit.station',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'off'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'transit.station',
						stylers: [{
							visibility: 'off'
						}]
					}, {
						featureType: 'landscape',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'on'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'road',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'on'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'road.highway',
						elementType: 'geometry.fill',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'on'
						}, {
							lightness: 100
						}, {
							saturation: saturation_value
						}]
					}, {
						featureType: 'transit.line',
						elementType: 'labels',
						stylers: [{
							visibility: 'off'
						}]
					}, {
						featureType: 'water',
						elementType: 'geometry',
						stylers: [{
							hue: main_color
						}, {
							visibility: 'on'
						}, {
							lightness: brightness_value
						}, {
							saturation: saturation_value
						}]
					},
				];
			}

			// set google map options
			var map_options = {
				panControl        : false,
				zoomControl       : ((ui_color !== undefined && ui_color !== '') ? false : true),
				mapTypeControl    : ((ui_color !== undefined && ui_color !== '') ? false : true),
				streetViewControl : false,
				scrollwheel       : false,
				draggable         : draggable,
				styles            : style,
				zoom              : map_zoom,
				center            : new google.maps.LatLng(latitude, longitude),
				mapTypeId         : google.maps.MapTypeId.ROADMAP,
			};
			// inizialize the map
			var map = new google.maps.Map( $el, map_options );
			if ( ui_color !== undefined && ui_color !== '' ) {
				var custom_icon = {
					path: 'M-0.7-425.882c-85.1,0-154.334,62.824-154.334,140.043c0,31.102,21.887,81.808,66.908,155.017 c31.846,51.78,63.168,94.954,64.484,96.766L-0.7-2.5l22.941-31.555c1.317-1.813,32.641-44.986,64.483-96.766 c45.023-73.21,66.908-123.915,66.908-155.017C153.633-363.058,84.399-425.882-0.7-425.882L-0.7-425.882z M-0.7-211.438 c-39.682,0-71.852-31.343-71.852-70c0-38.656,32.17-70,71.852-70c39.684,0,71.852,31.344,71.852,70 C71.152-242.781,38.984-211.438-0.7-211.438z',
					fillColor: ui_color,
					fillOpacity: 1,
					strokeColor: ui_color,
					strokeWeight: 0,
					scale: 0.1,
				};
				marker = new google.maps.Marker({
					position: new google.maps.LatLng(latitude, longitude),
					map: map,
					visible: true,
					optimized: false,
					title: 'spot',
					icon: custom_icon,
				});
			} else {
				marker = new google.maps.Marker({
					position: new google.maps.LatLng(latitude, longitude),
					map: map,
					visible: true,
					optimized: false,
					title: 'spot',
				});
			}
			// add the resize event to the map
			google.maps.event.addDomListener(window, 'resize', function() {
				var center = map.getCenter();
				google.maps.event.trigger(map, 'resize');
				map.setCenter(center);
			});
			// add custom buttons for the zoom-in/zoom-out on the map
			var CustomZoomControl = function(controlDiv, map) {
				// grap the zoom elements from the DOM and insert them in the map
				var controlUIzoomIn = document.getElementById(map_id + '-zoom-in'),
					controlUIzoomOut = document.getElementById(map_id + '-zoom-out');
					controlUIzoomIn.innerHTML = '<i class="fa fa-plus"></i>';
					controlUIzoomOut.innerHTML = '<i class="fa fa-minus"></i>';
					controlDiv.appendChild(controlUIzoomIn);
					controlDiv.appendChild(controlUIzoomOut);
				// Setup the click event listeners and zoom-in or out according to the clicked element
				google.maps.event.addDomListener(controlUIzoomIn, 'click', function() {
					map.setZoom(map.getZoom() + 1);
				});
				google.maps.event.addDomListener(controlUIzoomOut, 'click', function() {
					map.setZoom(map.getZoom() - 1);
				});
			};
			if ( ui_color !== undefined && ui_color !== '' ) {
				var zoomControlDiv = document.createElement('div');
				var zoomControl = new CustomZoomControl(zoomControlDiv, map);
				map.controls[google.maps.ControlPosition.LEFT_TOP].push(zoomControlDiv);
			}
			//add a custom marker to the map
			google.maps.event.addListener(map, 'idle', function() {
				jQuery('.gmap-buttons', $el).css('opacity', '1');
			});
		};
		jQuery('.nice-vc-gmaps-wrapper').each(function() {
			gmaps_single(this);
	});
	};
	google.maps.event.addDomListener( window, 'load', nice_vc_gmaps_init );
}());