/**
 * Smart by NiceThemes.
 *
 * NiceVCOnePage
 *
 * Manage single-page navigation for VC.
 *
 * @since   1.0.0
 * @package Smart
 */
var NiceVCOnePage = ( function( $ ) {
	// Tell browsers we're not doing anything silly.
	'use strict';

	var initOnePager = function () {
		var $onePagers  = $( '.vc-active div[data-parent="true"]' ),
			useOnePager = ( $onePagers.length ) ? true : false;

		if ( useOnePager ) {
			$( '<nav class="nice-nav-onepage"><ul></ul></nav>' ).prependTo( 'body' );
		}

		$.each( $onePagers, function ( index ) {
			$( this ).attr( 'data-section', index );

			if ( useOnePager ) {
				var label,
					name;

				if ( $( this ).attr( 'data-label' ) !== undefined ) {
					label = $( this ).attr( 'data-label' );
				}

				if ( $( this ).attr( 'data-name' ) === undefined ) {
					name = index;
				} else {
					name = $( this ).attr( 'data-name' );
				}

				if ( label !== '' ) {
					label = '<span class="button-label">' + label + '</span>';
					$( '.nice-nav-onepage ul' ).append( '<li><a data-index="' + index + '" href="#' + name + '"><span class="button-container"><span class="dot"></span></span>' + label + '</a></li>' );
				}

			}
		} );

		if ( useOnePager ) {
			$( '.nice-nav-onepage ul li a' ).click( function ( event ) {
				event.preventDefault();
				$( this ).parent().addClass( 'is-active' ).siblings().removeClass( 'is-active' );

				var section_name = $( this ).attr( 'href' );
				section_name     = section_name.replace( '#', '' );

				$( 'html,body' ).animate( {
					scrollTop : $( 'div[data-name=' + section_name + ']' ).offset().top
				}, 500 );

			} );

			$( '.nice-nav-onepage ul li:first-child' ).addClass( 'is-active' );

			var parents = $( 'div[data-parent=true]' );

			parents.each( function() {
				var parent = $( this );

				parent.NiceWaypoint( function( direction ) {
					if ( direction === 'down' ) {
						$( '.nice-nav-onepage ul li a[href="#' + parent.attr( 'data-name' ) + '"]' )
							.parent()
							.addClass( 'is-active' )
							.siblings()
							.removeClass( 'is-active' );
					}
				}, {
					offset: '75%',
					triggerOnce: false
				});

				parent.NiceWaypoint( function( direction ) {
					if ( direction === 'up' ) {
						$( '.nice-nav-onepage ul li a[href="#' + parent.attr( 'data-name' ) + '"]' )
							.parent()
							.addClass( 'is-active' )
							.siblings()
							.removeClass( 'is-active' );
					}
				}, {
					offset: '-5%',
					triggerOnce: false
				});

			} );
		}
	},

	/**
	 * Fire events on document ready, and bind other events.
	 *
	 * @since 1.0.0
	 */
	ready = function() {
		initOnePager();
	};

	// Expose the ready function to the world.
	return {
		ready: ready
	};

} )( jQuery );

jQuery( NiceVCOnePage.ready );