/**
 * Smart by NiceThemes.
 *
 * NiceVCRowLayout
 *
 * Manage row layout for VC.
 *
 * @since   1.0.0
 * @package Smart
 */
var NiceVCRowLayout = ( function( $ ) {
	'use strict';

	/**
	 * Setup row layout resizing.
	 *
	 * @since 1.0.0
	 */
	var initLayout = function() {
		resizeLayout();
		$( window ).bind( 'resize', resizeLayout );
	},

	/**
	 * Resize row layout.
	 *
	 * @since 1.0.0
	 */
	resizeLayout = function() {
		var parentRow = [];

		$( '.vc_row-o-equal-height .vc_row.vc_inner' ).each( function () {
			var $currentRow      = $( this ),
				currentRowHeight = $currentRow.data( 'height' ),
				parentRowHeight;

			if ( 'undefined' !== typeof currentRowHeight ) {
				// if this row is 0, we need to calculate the percentage from a sibling
				if ( $currentRow.height() ) {
					$currentRow.siblings().each( function () {
						var $sibling = $( this );

						if ( $sibling.height() && ( 'undefined' !== typeof $sibling.data( 'height' ) ) ) {
							var $column       = $sibling.find( '.wpb_column' ),
								paddingTop    = parseInt( $column.css( 'padding-top' ) ),
								paddingBottom = parseInt( $column.css( 'padding-bottom' ) ),
								paddings      = paddingTop + paddingBottom,
								columnHeight  = paddings + parseInt( $( this ).find( '.vc_column-inner' ).outerHeight() );

							parentRowHeight  = ( 100 * columnHeight ) / $sibling.data('height');

							return false;
						}
					} );
				} else {
					var $column       = $( this ).find( '.wpb_column' ),
						paddingTop    = parseInt( $column.css( 'padding-top' ) ),
						paddingBottom = parseInt( $column.css( 'padding-bottom' ) ),
						paddings      = paddingTop + paddingBottom,
						columnHeight  = paddings + parseInt( $( this ).find( '.vc_column-inner' ).outerHeight() );

					parentRowHeight = ( 100 * columnHeight ) / $( this ).data( 'height' );
				}

				$( this ).height( currentRowHeight + '%' );
			}

			parentRow.push( parseInt( parentRowHeight ) );

			$currentRow.parents( '.nice_row-inner' ).height( '100%' );

			if ( $( window ).width() < 768 ) {
				$( this ).parents( '.vc_row' ).height( 'auto' );
			} else {
				$( this ).parents( '.vc_row' ).height( Math.max.apply( Math, parentRow ) );
			}
		} );
	},

	ready = function() {
		initLayout();
	};

	return {
		ready: ready
	};
} )( jQuery );

jQuery( NiceVCRowLayout.ready );