<?php
/**
 * Smart by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
if ( ! class_exists( 'Nice_VCIntegration_Cards_Gallery' ) ) :
/**
 * Class Nice_VCIntegration_Cards_Gallery
 *
 * Extend VC for custom counter implementation.
 *
 * @since 1.0.0
 */
class Nice_VCIntegration_Cards_Gallery extends WPBakeryShortCode {

	/**
	 * Construct instance.
	 *
	 * @param array $settings
	 */
	public function __construct( $settings ) {
		parent::__construct( $settings );
	}

	/**
	 * Obtain the value of a shortcode attribute by its name.
	 *
	 * @param mixed       $attr
	 * @param null|mixed  $default
	 *
	 * @return null|mixed
	 */
	public function attr( $attr, $default = null ) {
		if ( isset( $this->atts[ $attr ] ) ) {
			return $this->atts[ $attr ];
		}

		return $default;
	}

	/**
	 * Obtain shortcode template.
	 *
	 * @param string $content
	 *
	 * @return string
	 */
	public function template( $content = '' ) {
		return $this->contentAdmin( $this->atts );
	}

		/**
	 * Obtain images.
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	public function get_images() {
		if ( is_null( $this->images ) ) {
			$this->set_images();
		}

		return $this->images;
	}

	/**
	 * Set images.
	 *
	 * @since 1.0.0
	 */
	protected function set_images() {
		$gallery_images = array();

		$attributes = vc_map_get_attributes( $this->getShortcode(), $this->getAtts() );

		$images = $attributes['images'];

		if ( $images ) {
			$images = explode( ',', $images );

			foreach ( $images as $i => $image ) {

				if ( $image > 0 ) {
					$image_id      = $image;
					$img           = wpb_getImageBySize( array(
						'attach_id'  => $image,
						'thumb_size' => 'large',
						'class'      => 'nice-image',
					) );
					$thumbnail     = $img['thumbnail'];
				}

				$href   = '';
				$target = '';
				$rel    = '';
				$class  = array();

				if ( ! empty( $image_id ) ) {
					$gallery_images[] = new Nice_VCIntegration_Gallery_Image( array(
						'id'     => $image_id,
						'img'    => $thumbnail,
						'href'   => $href,
						'target' => $target,
						'rel'    => $rel,
						'class'  => $class,
					) );
				}
			}
		}

		$this->images = $gallery_images;
	}

	/**
	 * Load shortcode template.
	 *
	 * @param array       $atts
	 * @param null|string $content
	 *
	 * @return mixed|null|void
	 */
	protected function loadTemplate( $atts, $content = null ) {
		// Globalize current shortcode object.
		nice_vc_integration_cards_gallery_current_shortcode( $this );

		// Initialize properties.
		$this->set_images();

		return parent::loadTemplate( $atts, $content );
	}

	/**
	 * Obtain whether or not this shortcode has images.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	public function has_images() {
		$images = $this->get_images();

		return ! empty( $images );
	}

}
endif;
