<?php
/**
 * Smart by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'Nice_VCIntegration_Gallery_Image' ) ) :
/**
 * Class Nice_VCIntegration_Gallery_Image
 *
 * Helper class to manage internal data of gallery images looped through the VC Gallery shortcode.
 *
 * @since 1.0.0
 */
class Nice_VCIntegration_Gallery_Image {
	/**
	 * @var int $id
	 */
	protected $id = 0;

	/**
	 * @var string $img
	 */
	protected $img = '';

	/**
	 * @var string $href
	 */
	protected $href = '';

	/**
	 * @var string $target
	 */
	protected $target = '';

	/**
	 * @var string $rel
	 */
	protected $rel = '';

	/**
	 * @var array $class
	 */
	protected $class = array();


	/**
	 * Obtain ID.
	 *
	 * @since 1.0.0
	 *
	 * @return int
	 */
	public function get_id() {
		return $this->id;
	}


	/**
	 * Construct instance.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args
	 */
	public function __construct( array $args = array() ) {
		if ( isset( $args['id'] ) ) {
			$this->id = intval( $args['id'] );
		}

		if ( isset( $args['img'] ) && $args['img'] ) {
			$this->img = $args['img'];
		}

		if ( isset( $args['href'] ) && $args['href'] ) {
			$this->href = $args['href'];
		}

		if ( isset( $args['target'] ) && $args['target'] ) {
			$this->target = $args['target'];
		}

		if ( isset( $args['rel'] ) && $args['rel'] ) {
			$this->rel = $args['rel'];
		}

		if ( ! empty( $args['class'] ) && is_array( $args['class'] ) ) {
			$this->class = $args['class'];
		}
	}

	/**
	 * Obtain HTML for the image.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function get_html() {
		$href   = $this->href   ? ' href="' . $this->href . '"'                   : '';
		$target = $this->target ? ' target="' . $this->target . '"'               : '';
		$rel    = $this->rel    ? ' rel="' . $this->rel . '"'                     : '';
		$class  = $this->class  ? ' class="' . implode( ' ', $this->class ) . '"' : '';

		$link_start = $this->href ? "<a data-fancybox=\"group\" $href $target $rel $class>" : '';
		$link_end   = $this->href ? '</a>'                          : '';

		$html = $link_start . $this->img . $link_end;

		return $html;
	}


	/**
	 * Print HTML for the image.
	 *
	 * @since 1.0.0
	 */
	public function html() {
		echo $this->get_html();
	}
}
endif;
