<?php
/**
 * Smart by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'Nice_VCIntegration_Gallery_Shortcode' ) ) :
// Load dependency.
require_once vc_path_dir( 'SHORTCODES_DIR', 'vc-gallery.php' );
/**
 * Class Nice_VCIntegration_Gallery_Shortcode
 *
 * Extend VC for custom gallery implementation.
 *
 * @since 1.0.0
 */
class Nice_VCIntegration_Gallery_Shortcode extends WPBakeryShortCode_VC_gallery {
	/**
	 * @var int
	 */
	protected $id = null;

	/**
	 * @var string
	 */
	protected $type = null;

	/**
	 * @var string
	 */
	protected $title = null;

	/**
	 * @var array
	 */
	protected $images = null;

	/**
	 * @var int
	 */
	protected $image_grid_columns = null;

	/**
	 * @var int
	 */
	protected $image_grid_gutter_size = null;

	/**
	 * @var string
	 */
	protected $flexslider_animation = null;

	/**
	 * @var bool
	 */
	protected $flexslider_slideshow = null;

	/**
	 * @var int
	 */
	protected $flexslider_slideshow_speed = null;

	/**
	 * @var string
	 */
	protected $script = '';


	/**
	 * Construct instance.
	 *
	 * @param array $settings
	 */
	public function __construct( $settings ) {
		parent::__construct( $settings );

		// Print scripts.
		if ( ! is_admin() ) {
			add_action( 'wp_footer', array( $this, 'print_script' ), 9999 );
		}
	}

	/**
	 * Obtain ID.
	 *
	 * @since 1.0.0
	 *
	 * @return int
	 */
	public function get_id() {
		if ( is_null( $this->id ) ) {
			$this->set_id();
		}

		return $this->id;
	}

	/**
	 * Set ID.
	 *
	 * @since 1.0.0
	 */
	protected function set_id() {
		$this->id = rand();
	}

	/**
	 * Obtain type.
	 *
	 * @since 1.0.0
	 *
	 * @return int
	 */
	public function get_type() {
		if ( is_null( $this->type ) ) {
			$this->set_type();
		}

		return $this->type;
	}

	/**
	 * Set type.
	 *
	 * @since 1.0.0
	 */
	protected function set_type() {
		$this->type = $this->attr( 'type', 'flexslider_fade' );
	}

	/**
	 * Obtain whether or not this shortcode is an image grid.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	public function is_image_grid() {
		return ( 'image_grid' === $this->get_type() );
	}

	/**
	 * Obtain whether or not this shortcode is a FlexSlider.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	public function is_flexslider() {
		return ( 'flexslider_fade' === $this->get_type() ) || ( 'flexslider_slide' === $this->get_type() );
	}

	/**
	 * Obtain title.
	 *
	 * @since 1.0.0
	 *
	 * @return int
	 */
	public function get_title() {
		if ( is_null( $this->title ) ) {
			$this->set_title();
		}

		return $this->title;
	}

	/**
	 * Set title.
	 *
	 * @since 1.0.0
	 */
	protected function set_title() {
		$this->title = $this->attr( 'title', '' );
	}

	/**
	 * Obtain images.
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	public function get_images() {
		if ( is_null( $this->images ) ) {
			$this->set_images();
		}

		return $this->images;
	}

	/**
	 * Set images.
	 *
	 * @since 1.0.0
	 */
	protected function set_images() {
		$gallery_images = array();

		$attributes = vc_map_get_attributes( $this->getShortcode(), $this->getAtts() );

		if ( 'external_link' === $attributes['source'] ) {
			$images = vc_value_from_safe( $attributes['custom_srcs'] );
		} else {
			$images = $attributes['images'];
		}

		if ( $images ) {
			$images = explode( ',', $images );

			if ( 'custom_link' === $attributes['onclick'] ) {
				$custom_links = vc_value_from_safe( $attributes['custom_links'] );
				$custom_links = explode( ',', $custom_links );
			}

			foreach ( $images as $i => $image ) {
				switch ( $attributes['source'] ) {
					case 'media_library':
						if ( $image > 0 ) {
							$image_id      = $image;
							$img           = wpb_getImageBySize( array(
								'attach_id'  => $image,
								'thumb_size' => $attributes['img_size'],
								'class'      => 'nice-image',
							) );
							$thumbnail     = $img['thumbnail'];
							$large_img_src = $img['p_img_large'][0];
						}
						break;

					case 'external_link':
						$image_id      = $i + 1;
						$image         = esc_attr( $image );
						$dimensions    = vcExtractDimensions( $attributes['external_img_size'] );
						$hwstring      = $dimensions ? image_hwstring( $dimensions[0], $dimensions[1] ) : '';
						$thumbnail     = '<img class="nice-image" ' . $hwstring . ' src="' . $image . '" />';
						$large_img_src = $image;
						break;
				}

				$href   = '';
				$target = '';
				$rel    = '';
				$class  = array();

				switch ( $attributes['onclick'] ) {
					case 'link_image':
						$href  = $large_img_src;
						$rel   = 'group[' . $this->get_id() . ']';
						$class = array(
							'fancybox',
						);
						break;

					case 'custom_link':
						if ( ! empty( $custom_links[ $i ] ) ) {
							$href   = $custom_links[ $i ];
							$target = ! empty( $attributes['custom_links_target'] ) ? $attributes['custom_links_target'] : '';
						}
						break;
				}

				if ( ! empty( $attributes['el_class'] ) ) {
					$class = explode( ' ', esc_attr( $attributes['el_class'] ) );
				}

				if ( ! empty( $image_id ) ) {
					$gallery_images[] = new Nice_VCIntegration_Gallery_Image( array(
						'id'     => $image_id,
						'img'    => $thumbnail,
						'href'   => $href,
						'target' => $target,
						'rel'    => $rel,
						'class'  => $class,
					) );
				}
			}
		}

		$this->images = $gallery_images;
	}

	/**
	 * Obtain whether or not this shortcode has images.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	public function has_images() {
		$images = $this->get_images();

		return ! empty( $images );
	}

	/**
	 * Obtain image grid columns.
	 *
	 * @since 1.0.0
	 *
	 * @return int
	 */
	public function get_image_grid_columns() {
		if ( is_null( $this->image_grid_columns ) ) {
			$this->set_image_grid_columns();
		}

		return $this->image_grid_columns;
	}

	/**
	 * Set image grid columns.
	 *
	 * @since 1.0.0
	 */
	protected function set_image_grid_columns() {
		if ( $this->is_image_grid() ) {
			$image_grid_columns = intval( $this->attr( 'columns', '4' ) );

			if ( 1 > $image_grid_columns ) {
				$image_grid_columns = 1;
			} elseif ( 12 < $image_grid_columns ) {
				$image_grid_columns = 12;
			}

		} else {
			$image_grid_columns = 0;
		}

		$this->image_grid_columns = $image_grid_columns;
	}

	/**
	 * Obtain image grid gutter size.
	 *
	 * @since 1.0.0
	 *
	 * @return int
	 */
	public function get_image_grid_gutter_size() {
		if ( is_null( $this->image_grid_gutter_size ) ) {
			$this->set_image_grid_gutter_size();
		}

		return $this->image_grid_gutter_size;
	}

	/**
	 * Set image grid gutter size.
	 *
	 * @since 1.0.0
	 */
	protected function set_image_grid_gutter_size() {
		if ( $this->is_image_grid() ) {
			$image_grid_gutter_size = intval( $this->attr( 'gutter_size', '0' ) );

			if ( 0 > $image_grid_gutter_size ) {
				$image_grid_gutter_size = 0;
			} elseif ( 4 < $image_grid_gutter_size ) {
				$image_grid_gutter_size = 4;
			}

		} else {
			$image_grid_gutter_size = 0;
		}

		$this->image_grid_gutter_size = $image_grid_gutter_size;
	}

	/**
	 * Obtain image grid gutter size class.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function get_image_grid_gutter_size_class() {
		if ( $this->is_image_grid() ) {
			$gutter_size = $this->get_image_grid_gutter_size();

			switch ( $gutter_size ) {
				case 0:
				default :
					$gutter_size_class = 'no-gap';
					break;
				case 1:
					$gutter_size_class = 'px-gutter';
					break;
				case 2:
					$gutter_size_class = 'half-gutter';
					break;
				case 3:
					$gutter_size_class = 'single-gutter';
					break;
				case 4:
					$gutter_size_class = 'double-gutter';
					break;
			}

			return $gutter_size_class;
		}

		return '';
	}

	/**
	 * Obtain FlexSlider animation.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function get_flexslider_animation() {
		if ( is_null( $this->flexslider_animation ) ) {
			$this->set_flexslider_animation();
		}

		return $this->flexslider_animation;
	}

	/**
	 * Set FlexSlider animation.
	 *
	 * @since 1.0.0
	 */
	protected function set_flexslider_animation() {
		if ( $this->is_flexslider() ) {
			$flexslider_animation = str_replace( 'flexslider_', '', $this->get_type() );

		} else {
			$flexslider_animation = '';
		}

		$this->flexslider_animation = $flexslider_animation;
	}

	/**
	 * Obtain FlexSlider slideshow.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function get_flexslider_slideshow() {
		if ( is_null( $this->flexslider_slideshow ) ) {
			$this->set_flexslider_slideshow();
		}

		return $this->flexslider_slideshow;
	}

	/**
	 * Set FlexSlider slideshow.
	 *
	 * @since 1.0.0
	 */
	protected function set_flexslider_slideshow() {
		if ( $this->is_flexslider() ) {
			$flexslider_slideshow = ( 0 < $this->get_flexslider_slideshow_speed() );

		} else {
			$flexslider_slideshow = false;
		}

		$this->flexslider_slideshow = $flexslider_slideshow;
	}

	/**
	 * Obtain FlexSlider slideshow speed.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function get_flexslider_slideshow_speed() {
		if ( is_null( $this->flexslider_slideshow_speed ) ) {
			$this->set_flexslider_slideshow_speed();
		}

		return $this->flexslider_slideshow_speed;
	}

	/**
	 * Set FlexSlider slideshow speed.
	 *
	 * @since 1.0.0
	 */
	protected function set_flexslider_slideshow_speed() {
		if ( $this->is_flexslider() ) {
			$flexslider_slideshow_speed = intval( $this->attr( 'interval', 3 ) ) * 1000;

		} else {
			$flexslider_slideshow_speed = 0;
		}

		$this->flexslider_slideshow_speed = $flexslider_slideshow_speed;
	}


	/**
	 * Obtain filename of the shortcode's template.
	 *
	 * @return string
	 */
	protected function getFileName() {
		return 'vc_gallery';
	}

	/**
	 * Obtain the value of a shortcode attribute by its name.
	 *
	 * @param mixed       $attr
	 * @param null|mixed  $default
	 *
	 * @return null|mixed
	 */
	public function attr( $attr, $default = null ) {
		if ( isset( $this->atts[ $attr ] ) ) {
			return $this->atts[ $attr ];
		}

		return $default;
	}


	/**
	 * Load shortcode template.
	 *
	 * @param array       $atts
	 * @param null|string $content
	 *
	 * @return mixed|null|void
	 */
	protected function loadTemplate( $atts, $content = null ) {
		// Globalize current shortcode object.
		nice_vc_integration_gallery_current_shortcode( $this );

		// Process shortcode attributes.
		$atts = nice_vc_integration_gallery_shortcode_atts( $atts );

		// Initialize properties.
		$this->set_id();
		$this->set_type();
		$this->set_title();
		$this->set_images();
		$this->set_image_grid_columns();
		$this->set_image_grid_gutter_size();
		$this->set_flexslider_animation();
		$this->set_flexslider_slideshow_speed();
		$this->set_flexslider_slideshow();

		// Add script.
		$this->add_script();

		return parent::loadTemplate( $atts, $content );
	}

	/**
	 * Add code to the inline script.
	 *
	 * @since 1.0.0
	 */
	public function add_script() {
		if ( $this->is_flexslider() ) {
			$this->script .= '
				console.log( typeof generalData );
				if ( \'undefined\' !== typeof generalData ) {
					generalData.flexsliderSettings_vc_gallery_' . $this->get_id() . ' = {
						animation:      \'' . $this->get_flexslider_animation() . '\',
						slideshow:      ' . ( $this->get_flexslider_slideshow() ? 'true' : 'false' ) . ',
						slideshowSpeed: ' . $this->get_flexslider_slideshow_speed() . '
					};
				}
			';
		}
	}

	/**
	 * Print the inline script.
	 *
	 * @since 1.0.0
	 */
	public function print_script() {
		if ( ! empty( $this->script ) ) {
			?>
			<script type="text/javascript">
				//<![CDATA[
				<?php echo wp_kses( $this->script, array() ); ?>
				//]]>
			</script>
			<?php
		}
	}

}
endif;
