<?php
/**
 * Smart by NiceThemes.
 *
 * Map accordion for VC integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_accordion' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_accordion', 100 );
/**
 * Map the accordion.
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_accordion() {
	vc_map( array(
		'name'                    => esc_html__( 'Accordion', 'smart' ),
		'base'                    => 'vc_accordion',
		'show_settings_on_create' => false,
		'is_container'            => true,
		'icon'                    => 'bi_web-database',
		'category'                => esc_html__( 'Content', 'smart' ),
		'description'             => esc_html__( 'Collapsible panels', 'smart' ),
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Widget title', 'smart' ),
				'param_name'  => 'title',
				'description' => esc_html__( 'Enter text which will be used as widget title. Leave blank if no title is needed.', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Active section', 'smart' ),
				'param_name'  => 'active_tab',
				'description' => esc_html__( 'Enter section number to be active on load.', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'smart' ),
			),
		),
		'custom_markup'           => _nice_vc_integration_accordion_custom_markup(),
		'default_content'         => _nice_vc_integration_accordion_default_content(),
		'js_view' => 'VcAccordionView',
	) );

	vc_map( array(
		'name'                      => esc_html__( 'Section', 'smart' ),
		'base'                      => 'vc_accordion_tab',
		'allowed_container_element' => 'vc_row',
		'is_container'              => true,
		'content_element'           => false,
		'params'                    => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Title', 'smart' ),
				'param_name'  => 'title',
				'description' => esc_html__( 'Accordion section title.', 'smart' ),
			),
		),
		'js_view' => 'VcAccordionTabView',
	) );
}
endif;

if ( ! function_exists( '_nice_vc_integration_accordion_custom_markup' ) ) :
/**
 * Obtain custom markup for accordion shortcode.
 *
 * @internal
 *
 * @since  1.0.0
 *
 * @return string
 */
function _nice_vc_integration_accordion_custom_markup() {
	ob_start();
?>
	<div class="wpb_accordion_holder wpb_holder clearfix vc_container_for_children">
		%content%
	</div>

	<div class="tab_controls">
		<a class="add_tab" title="<?php esc_html_e( 'Add section', 'smart' ); ?>"><span class="vc_icon"></span> <span class="tab-label"><?php esc_html_e( 'Add section', 'smart' ); ?></span></a>
	</div>
<?php
	$content = ob_get_contents();
	ob_end_clean();

	return $content;
}
endif;

if ( ! function_exists( '_nice_vc_integration_accordion_default_content' ) ) :
/**
 * Obtain default content for accordion shortcode.
 *
 * @internal
 *
 * @since  1.0.0
 *
 * @return string
 */
function _nice_vc_integration_accordion_default_content() {
	ob_start();
?>
	[vc_accordion_tab title="<?php esc_html_e( 'Section 1', 'smart' ); ?>"][/vc_accordion_tab]
	[vc_accordion_tab title="<?php esc_html_e( 'Section 2', 'smart' ); ?>"][/vc_accordion_tab]
<?php
	$content = ob_get_contents();
	ob_end_clean();

	return $content;
}
endif;
