<?php
/**
 * Smart by NiceThemes.
 *
 * Nice Banner for VC integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_banner' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_banner' );
/**
 * Map with nice_banner
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_banner() {

	vc_map( array(
		'name'        => esc_html__( 'Banner', 'smart' ),
		'base'        => 'nice_banner',
		'icon'        => 'bi_doc-photo-stack',
		'php_class_name' => 'Nice_VCIntegration_Banner',
		'category'    => esc_html__( 'Content', 'smart' ),
		'description' => esc_html__( 'Simple Way To Add A Banner.', 'smart' ),
		'params'      => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Height', 'smart' ),
				'param_name'  => 'height',
				'value'       => '',
				'description' => esc_html__( 'Set the Banner Height.', 'smart' ),
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( ' Link', 'smart' ),
				'param_name'  => 'link',
				'description' => esc_html__( 'Enter URL if you want this banner to have a link.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'group'       => esc_html__( 'Content', 'smart' ),
				'heading'     => esc_html__( 'Content Skin', 'smart' ),
				'param_name'  => 'content_skin',
				'value'       => array(
					esc_html__( 'Inherit', 'smart' ) => '',
					esc_html__( 'Light', 'smart' )   => 'light',
					esc_html__( 'Dark', 'smart' )    => 'dark',
				),
				'description' => esc_html__( 'Specify the content skin.', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Content Width', 'smart' ),
				'param_name'  => 'content_width',
				'value'       => '100%',
				'description' => esc_html__( 'Set the Banner Content Box Width.', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Content Padding', 'smart' ),
				'param_name'  => 'content_padding',
				'std'         => '2x',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( '1x', 'smart' )   => '1x',
					esc_html__( '2x', 'smart' )   => '2x',
					esc_html__( '3x', 'smart' )   => '3x',
					esc_html__( '4x', 'smart' )   => '4x',
					esc_html__( '5x', 'smart' )   => '4x',
					esc_html__( '6x', 'smart' )   => '6x',
				),
				'description' => esc_html__( 'Set the Banner Content Box Padding.', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'textarea_html',
				'heading'     => esc_html__( 'Content', 'smart' ),
				'param_name'  => 'content',
				'group'       => esc_html__( 'Content', 'smart' ),
				'value'       => '',
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Text alignment', 'smart' ),
				'param_name'  => 'text_align',
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Left', 'smart' )    => 'left',
					esc_html__( 'Center', 'smart' )  => 'center',
					esc_html__( 'Right', 'smart' )   => 'right',
				),
				'description' => esc_html__( 'Specify the alignment inside the content box.', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Content Background Color', 'smart' ),
				'param_name'         => 'content_background_color',
				'value'              => nice_vc_integration_colors(),
				'std'                => '',
				'param_holder_class' => 'vc_colored-dropdown',
				'weight'             => 10,
				'group'              => esc_html__( 'Content', 'smart' ),
				'description'        => esc_html__( 'Select the content background color.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'group'       => esc_html__( 'Content', 'smart' ),
				'heading'     => esc_html__( 'Horizontal Position', 'smart' ),
				'param_name'  => 'position_horizontal',
				'weight'      => 3,
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Left', 'smart' ) => 'left',
					esc_html__( 'Center', 'smart' )    => 'center',
					esc_html__( 'Right', 'smart' )    => 'right',
				),
				'description' => esc_html__( 'Specify the horizontal position of the content if you have decreased the width value..', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'group'       => esc_html__( 'Content', 'smart' ),
				'heading'     => esc_html__( 'Vertical Position', 'smart' ),
				'param_name'  => 'position_vertical',
				'weight'      => 3,
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Top', 'smart' ) => 'top',
					esc_html__( 'Middle', 'smart' ) => 'middle',
					esc_html__( 'Bottom', 'smart' ) => 'bottom',
				),
				'description' => esc_html__( 'Specify the vertical position of the content.', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Background Color', 'smart' ),
				'param_name'         => 'background_color',
				'value'              => nice_vc_integration_colors(),
				'std'                => '',
				'param_holder_class' => 'vc_colored-dropdown',
				'weight'             => 10,
				'group'              => esc_html__( 'Style', 'smart' ),
				'description'        => esc_html__( 'Select the background color.', 'smart' ),
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Background Image', 'smart' ),
				'param_name'  => 'background_image',
				'value'       => '',
				'description' => esc_html__( 'Select image from media library.', 'smart' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Padding', 'smart' ),
				'param_name'  => 'background_padding',
				'std'         => '2x',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( '1x', 'smart' )   => '1x',
					esc_html__( '2x', 'smart' )   => '2x',
					esc_html__( '3x', 'smart' )   => '3x',
					esc_html__( '4x', 'smart' )   => '4x',
					esc_html__( '5x', 'smart' )   => '4x',
					esc_html__( '6x', 'smart' )   => '6x',
				),
				'description' => esc_html__( 'Set the Banner Padding.', 'smart' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Repeat', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background repeat. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/cssref/pr_background-repeat.asp' ), '</a>' ),
				'param_name'  => 'background_repeat',
				'value'       => array(
					esc_html__( 'background-repeat', 'smart' ) => '',
					esc_html__( 'No Repeat', 'smart' ) => 'no-repeat',
					esc_html__( 'Repeat All', 'smart' ) => 'repeat',
					esc_html__( 'Repeat Horizontally', 'smart' ) => 'repeat-x',
					esc_html__( 'Repeat Vertically', 'smart' ) => 'repeat-y',
					esc_html__( 'Inherit', 'smart' ) => 'inherit',
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Position', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background position. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/cssref/pr_background-position.asp' ), '</a>' ),
				'param_name'  => 'background_position',
				'value'       => array(
					esc_html__( 'background-position', 'smart' ) => '',
					esc_html__( 'Left Top', 'smart' ) => 'left top',
					esc_html__( 'Left Center', 'smart' ) => 'left center',
					esc_html__( 'Left Bottom', 'smart' ) => 'left bottom',
					esc_html__( 'Center Top', 'smart' ) => 'center top',
					esc_html__( 'Center Center', 'smart' ) => 'center center',
					esc_html__( 'Center Bottom', 'smart' ) => 'center bottom',
					esc_html__( 'Right Top', 'smart' ) => 'right top',
					esc_html__( 'Right Center', 'smart' ) => 'right center',
					esc_html__( 'Right Bottom', 'smart' ) => 'right bottom',
				),
				'group'      => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Attachment', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background attachment. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/cssref/pr_background-attachment.asp' ), '</a>' ),
				'param_name'  => 'background_attachment',
				'value'       => array(
					esc_html__( 'background-attachement', 'smart' ) => '',
					esc_html__( 'Fixed', 'smart' ) => 'fixed',
					esc_html__( 'Scroll', 'smart' ) => 'scroll',
					esc_html__( 'Inherit', 'smart' ) => 'inherit',
				),
				'group' => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Hover Effect', 'smart' ),
				'param_name'  => 'background_effect',
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Zoom', 'smart' ) => 'zoom-in',
					esc_html__( 'Blur', 'smart' ) => 'blur',
					esc_html__( 'Fade Out', 'smart' ) => 'fade-out',
				),
				'description' => esc_html__( 'Select the backgroundimage hover effect.', 'smart' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Overlay Color', 'smart' ),
				'param_name'         => 'overlay_color',
				'value'              => nice_vc_integration_colors(),
				'std'                => '',
				'param_holder_class' => 'vc_colored-dropdown',
				'weight'             => 10,
				'description'        => esc_html__( 'Select overlay color.', 'smart' ),
				'group'              => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Overlay Opacity', 'smart' ),
				'param_name'  => 'overlay_opacity',
				'value'       => 50,
				'min'         => 0,
				'max'         => 100,
				'step'        => 1,
				'weight'      => 10,
				'description' => esc_html__( 'Set the overlay opacity.', 'smart' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'smart' ),
			),
			nice_vc_integration_add_responsive_desktop(),
			nice_vc_integration_add_responsive_tablet(),
			nice_vc_integration_add_responsive_mobile(),
			array(
				'type'        => 'css_editor',
				'heading'     => esc_html__( 'CSS box', 'smart' ),
				'param_name'  => 'css',
				'group'       => esc_html__( 'Design Options', 'smart' ),
			),
			// backward compatibility. since 4.6
			array(
				'type'        => 'hidden',
				'param_name'  => 'img_link_large',
			),
		),
	) );
}
endif;

