<?php
/**
 * Smart by NiceThemes.
 *
 * Button
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_button' ) ) :
add_action( 'vc_before_init', 'nice_vc_integration_map_button' );
/**
 * Map the vc_button shortcode
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_button() {
	vc_map( array(
		'name'        => esc_html__( 'Button', 'smart' ),
		'base'        => 'vc_button',
		'weight'      => 97,
		'icon'        => 'bi_interface-out-link',
		'php_class_name' => 'Nice_VCIntegration_Generic_Admin',
		'category'    => esc_html__( 'Content', 'smart' ),
		'description' => esc_html__( 'Button element', 'smart' ),
		'params' => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Text', 'smart' ),
				'admin_label' => true,
				'param_name'  => 'content',
				'value'       => esc_html__( 'Text on the button', 'smart' ),
				'description' => esc_html__( 'Text on the button', 'smart' ),
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'URL (Link)', 'smart' ),
				'param_name'  => 'link',
				'description' => esc_html__( 'Button link.', 'smart' ),
			),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'Button color', 'smart' ),
				'param_name'  => 'button_color',
				'param_holder_class' => 'vc_colored-dropdown',
				'description' => esc_html__( 'Specify the button color.', 'smart' ),
				'value'       => nice_vc_integration_colors(),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Size', 'smart' ),
				'param_name'  => 'size',
				'value'       => array(
					esc_html__( 'Standard', 'smart' ) => '',
					esc_html__( 'Small', 'smart' ) => 'sm',
					esc_html__( 'Medium', 'smart' ) => 'md',
					esc_html__( 'Large', 'smart' ) => 'lg',
					esc_html__( 'Extra-Large', 'smart' ) => 'xl',
					esc_html__( 'Standard link', 'smart' ) => 'link',
				),
				'admin_label' => true,
				'description' => esc_html__( 'Button size.', 'smart' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Shape', 'smart' ),
				'param_name'  => 'shape',
				'description' => esc_html__( 'You can shape the button with the corners round, squared or circle.', 'smart' ),
				'value' => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Round', 'smart' ) => 'round',
					esc_html__( 'Circle', 'smart' ) => 'circle',
					esc_html__( 'Square', 'smart' ) => 'square',
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Fluid', 'smart' ),
				'param_name'  => 'wide',
				'description' => esc_html__( 'Fluid buttons has 100% width.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Fixed width', 'smart' ),
				'param_name'  => 'width',
				'description' => esc_html__( 'Add a fixed width in pixel.', 'smart' ),
				'dependency'  => array(
					'element'  => 'wide',
					'is_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Outlined', 'smart' ),
				'param_name'  => 'outline',
				'description' => esc_html__( 'Outlined buttons doesn\'t have a full background color.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes' ,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Shadow', 'smart' ),
				'param_name'  => 'shadow',
				'description' => esc_html__( 'Button shadow.', 'smart' ),
				'value' => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Italic text', 'smart' ),
				'param_name'  => 'italic',
				'description' => esc_html__( 'Button with italic text style.', 'smart' ),
				'value' => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Text transform', 'smart' ),
				'param_name'  => 'transform',
				'description' => esc_html__( 'Specify the text transformation.', 'smart' ),
				'value'       => nice_vc_integration_text_transform(),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Layout display', 'smart' ),
				'param_name'  => 'display',
				'description' => esc_html__( 'Specify the display mode.', 'smart' ),
				'value' => array(
					esc_html__( 'Block', 'smart' ) => '',
					esc_html__( 'Inline', 'smart' ) => 'inline',
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Margin top', 'smart' ),
				'param_name'  => 'top_margin',
				'description' => esc_html__( 'Activate to add the top margin.', 'smart' ),
				'value' => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'dependency' => array(
					'element' => 'display',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Icon library', 'smart' ),
				'value'       => array(
					'' => '',
					esc_html__( 'Font Awesome', 'smart' )  => 'fontawesome',
					esc_html__( 'Open Iconic', 'smart' )   => 'openiconic',
					esc_html__( 'Typicons', 'smart' )      => 'typicons',
					esc_html__( 'Entypo', 'smart' )        => 'entypo',
					esc_html__( 'Linecons', 'smart' )      => 'linecons',
					esc_html__( 'ET Line Icons', 'smart' ) => 'etlineicons',
					esc_html__( 'Linea Icons', 'smart' )   => 'lineaicons',
				),
				'admin_label' => false,
				'param_name'  => 'icon_type',
				'description' => esc_html__( 'Select icon library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_fontawesome',
				'value'       => '',
				'settings'    => array(
					'emptyIcon'    => true,
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'fontawesome',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'       => 'iconpicker',
				'heading'    => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_openiconic',
				'value'      => '',
				'settings'   => array(
					'emptyIcon'    => true,
					'type'         => 'openiconic',
					'iconsPerPage' => 4000,
				),
				'dependency'  => array(
					'element' => 'icon_type',
					'value'   => 'openiconic',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_typicons',
				'value'       => 'typcn typcn-adjust-brightness',
				'settings'    => array(
					'emptyIcon'    => true,
					'type'         => 'typicons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'typicons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_entypo',
				'value'       => '',
				'settings'    => array(
					'emptyIcon'    => true,
					'type'         => 'entypo',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'entypo',
				),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_linecons',
				'value'       => '',
				'settings'    => array(
					'emptyIcon'    => true,
					'type'         => 'linecons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'linecons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_etlineicons',
				'settings'    => array(
					'emptyIcon' => true,
					'type'      => 'etlineicons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'etlineicons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_lineaicons',
				'value'       => '', // default value to backend editor admin_label
				'settings'    => array(
					'emptyIcon' => false,
					'type'      => 'lineaicons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'type',
					'value'       => 'lineaicons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Icon position', 'smart' ),
				'param_name'  => 'icon_position',
				'description' => esc_html__( 'Choose the position of the icon.', 'smart' ),
				'value' => array(
					esc_html__( 'Left', 'smart' ) => 'left',
					esc_html__( 'Right', 'smart' ) => 'right',
				),
				'dependency' => array(
					'element' => 'icon_type',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Rel attribute', 'smart' ),
				'param_name'  => 'rel',
				'description' => wp_kses(__( 'Here you can add value for the rel attribute.<br>Example values: <b%value>nofollow</b>, <b%value>lightbox</b>.', 'smart' ), array( 'br' => array(), 'b' => array() ) ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'onClick', 'smart' ),
				'param_name'  => 'onclick',
				'description' => esc_html__( 'Advanced JavaScript code for onClick action.', 'smart' ),
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'group'       => esc_html__( 'Extra', 'smart' ),
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'smart' ),
			),
		),
		'js_view' => 'VcButtonView',
	));

}
endif;
