<?php
/**
 * Smart by NiceThemes.
 *
 * Map column for VC integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_column' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_column' );
/**
 * Map the [vc_column] params.
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_column() {

	vc_map( array(
		'name'            => esc_html__( 'Column', 'smart' ),
		'base'            => 'vc_column',
		'icon'            => 'icon-wpb-row',
		'is_container'    => true,
		'content_element' => false,
		'description'     => esc_html__( 'Place content elements inside the column', 'smart' ),
		'params'          => array(
			array(
				'type'        => 'dropdown',
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'heading'     => esc_html__( 'Text alignment', 'smart' ),
				'param_name'  => 'text_align',
				'weight'      => 1,
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Left', 'smart' )    => 'left',
					esc_html__( 'Center', 'smart' )  => 'center',
					esc_html__( 'Right', 'smart' )   => 'right',
				),
				'description' => esc_html__( 'Specify the alignment inside the content box.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'weight'      => 2,
				'heading'     => esc_html__( 'Content Skin', 'smart' ),
				'param_name'  => 'style',
				'value'       => array(
					esc_html__( 'Inherit', 'smart' ) => '',
					esc_html__( 'Light', 'smart' )   => 'light',
					esc_html__( 'Dark', 'smart' )    => 'dark',
				),
				'description' => esc_html__( 'Specify the content skin.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'heading'     => esc_html__( 'Column Content Width', 'smart' ),
				'param_name'  => 'column_width_unit',
				'weight'      => 3,
				'value'       => array(
					esc_html__( '%', 'smart' ) => 'percent',
					esc_html__( 'px', 'smart' )    => 'pixel',
				),
				'description' => esc_html__( 'Select the unit of the content width value.', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'heading'     => esc_html__( 'Column Width', 'smart' ),
				'param_name'  => 'column_width_percent',
				'weight'      => 4,
				'value'       => 100,
				'min'         => 0,
				'max'         => 100,
				'step'        => 1,
				'dependency' => array(
					'element' => 'column_width_unit',
					'value'   => 'percent',
				),
				'description' => esc_html__( 'Select the content width value.', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Column Width', 'smart' ),
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'param_name'  => 'column_width_pixel',
				'value'       => '',
				'description' => esc_html__( 'Insert the content width value', 'smart' ),
				'dependency'  => array(
					'element'   => 'column_width_unit',
					'value'     => 'pixel',
				),
			),
			array(
				'type'        => 'dropdown',
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'heading'     => esc_html__( 'Horizontal Position', 'smart' ),
				'param_name'  => 'position_horizontal',
				'weight'      => 3,
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Left', 'smart' ) => 'left',
					esc_html__( 'Center', 'smart' )    => 'center',
					esc_html__( 'Right', 'smart' )    => 'right',
				),
				'description' => esc_html__( 'Specify the horizontal position of the content if you have decreased the width value..', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'heading'     => esc_html__( 'Vertical Position', 'smart' ),
				'param_name'  => 'position_vertical',
				'weight'      => 3,
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Top', 'smart' ) => 'top',
					esc_html__( 'Middle', 'smart' ) => 'middle',
					esc_html__( 'Bottom', 'smart' ) => 'bottom',
				),
				'description' => esc_html__( 'Specify the vertical position of the content.', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Custom padding', 'smart' ),
				'param_name'  => 'override_padding',
				'description' => esc_html__( 'Activate this to define custom paddings.', 'smart' ),
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'value' => array(
					'' => 'yes',
				),
			) ,
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Custom padding', 'smart' ),
				'param_name'  => 'column_padding',
				'min'         => 0,
				'max'         => 5,
				'step'        => 1,
				'value'       => 2,
				'description' => esc_html__( 'Set the column padding', 'smart' ),
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'dependency'  => array(
					'element' => 'override_padding',
					'value' => array(
						'yes',
					),
				),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Background Color', 'smart' ),
				'param_name'         => 'background_color',
				'value'              => nice_vc_integration_colors(),
				'std'                => '',
				'param_holder_class' => 'vc_colored-dropdown',
				'weight'             => 10,
				'group'              => esc_html__( 'Style', 'smart' ),
				'description'        => esc_html__( 'Select the background color.', 'smart' ),
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Background Image', 'smart' ),
				'param_name'  => 'background_image',
				'value'       => '',
				'description' => esc_html__( 'Select image from media library.', 'smart' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Repeat', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background repeat. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/cssref/pr_background-repeat.asp' ), '</a>' ),
				'param_name'  => 'background_repeat',
				'value'       => array(
					esc_html__( 'background-repeat', 'smart' ) => '',
					esc_html__( 'No Repeat', 'smart' ) => 'no-repeat',
					esc_html__( 'Repeat All', 'smart' ) => 'repeat',
					esc_html__( 'Repeat Horizontally', 'smart' ) => 'repeat-x',
					esc_html__( 'Repeat Vertically', 'smart' ) => 'repeat-y',
					esc_html__( 'Inherit', 'smart' ) => 'inherit',
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Position', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background position. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/cssref/pr_background-position.asp' ), '</a>' ),
				'param_name'  => 'background_position',
				'value'       => array(
					esc_html__( 'background-position', 'smart' ) => '',
					esc_html__( 'Left Top', 'smart' ) => 'left top',
					esc_html__( 'Left Center', 'smart' ) => 'left center',
					esc_html__( 'Left Bottom', 'smart' ) => 'left bottom',
					esc_html__( 'Center Top', 'smart' ) => 'center top',
					esc_html__( 'Center Center', 'smart' ) => 'center center',
					esc_html__( 'Center Bottom', 'smart' ) => 'center bottom',
					esc_html__( 'Right Top', 'smart' ) => 'right top',
					esc_html__( 'Right Center', 'smart' ) => 'right center',
					esc_html__( 'Right Bottom', 'smart' ) => 'right bottom',
				),
				'group'      => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Attachment', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background attachment. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/cssref/pr_background-attachment.asp' ), '</a>' ),
				'param_name'  => 'background_attachment',
				'value'       => array(
					esc_html__( 'background-attachement', 'smart' ) => '',
					esc_html__( 'Fixed', 'smart' ) => 'fixed',
					esc_html__( 'Scroll', 'smart' ) => 'scroll',
					esc_html__( 'Inherit', 'smart' ) => 'inherit',
				),
				'group' => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Shift x-axis', 'smart' ),
				'param_name'  => 'shift_x',
				'min'         => -5,
				'max'         => 5,
				'step'        => 1,
				'value'       => 0,
				'description' => esc_html__( 'Set how much the element has to shift in the X axis.', 'smart' ),
				'group'       => esc_html__( 'Off-grid', 'smart' ),
			) ,
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Shift x-axis fixed', 'smart' ),
				'param_name'  => 'shift_x_fixed',
				'description' => esc_html__( 'Deactive shift-x responsiveness.', 'smart' ),
				'group'       => esc_html__( 'Off-grid', 'smart' ),
				'value'       => array(
					'' => 'yes',
				),
			) ,
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Shift y-axis', 'smart' ),
				'param_name'  => 'shift_y',
				'min'         => -5,
				'max'         => 5,
				'step'        => 1,
				'value'       => 0,
				'description' => esc_html__( 'Set how much the element has to shift in the Y axis.', 'smart' ),
				'group'       => esc_html__( 'Off-grid', 'smart' ),
			) ,
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Shift y-axis fixed', 'smart' ),
				'param_name'  => 'shift_y_fixed',
				'description' => esc_html__( 'Deactive shift-y responsiveness.', 'smart' ),
				'group'       => esc_html__( 'Off-grid', 'smart' ),
				'value'       => array(
					'' => 'yes',
				),
			) ,
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Custom z-index', 'smart' ),
				'param_name'  => 'z_index',
				'min'         => 0,
				'max'         => 20,
				'step'        => 1,
				'value'       => 0,
				'description' => esc_html__( 'Set a custom z-index to ensure the visibility of the element.', 'smart' ),
				'group'       => esc_html__( 'Off-grid', 'smart' ),
			),
			nice_vc_integration_add_responsive_desktop(),
			nice_vc_integration_add_responsive_tablet(),
			nice_vc_integration_add_responsive_mobile(),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'smart' ),
				'group'       => esc_html__( 'Custom', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Width', 'smart' ),
				'param_name'  => 'width',
				'value'       => array(
					esc_html__( '1 column - 1/12', 'smart' ) => '1/12',
					esc_html__( '2 columns - 1/6', 'smart' ) => '1/6',
					esc_html__( '3 columns - 1/4', 'smart' ) => '1/4',
					esc_html__( '4 columns - 1/3', 'smart' ) => '1/3',
					esc_html__( '5 columns - 5/12', 'smart' ) => '5/12',
					esc_html__( '6 columns - 1/2', 'smart' ) => '1/2',
					esc_html__( '7 columns - 7/12', 'smart' ) => '7/12',
					esc_html__( '8 columns - 2/3', 'smart' ) => '2/3',
					esc_html__( '9 columns - 3/4', 'smart' ) => '3/4',
					esc_html__( '10 columns - 5/6', 'smart' ) => '5/6',
					esc_html__( '11 columns - 11/12', 'smart' ) => '11/12',
					esc_html__( '12 columns - 1/1', 'smart' ) => '1/1',
				),
				'group'       => esc_html__( 'Responsive Options', 'smart' ),
				'description' => esc_html__( 'Select column width.', 'smart' ),
				'std'         => '1/1',
			),
			array(
				'type'        => 'column_offset',
				'heading'     => esc_html__( 'Responsiveness', 'smart' ),
				'param_name'  => 'offset',
				'group'       => esc_html__( 'Responsive Options', 'smart' ),
				'description' => esc_html__( 'Adjust column for different screen sizes. Control width, offset and visibility settings.', 'smart' ),
			),
		),
		'js_view' => 'VcColumnView',
	) );

}
endif;
