<?php
/**
 * Smart by NiceThemes.
 *
 * Counter
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_counter' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_counter' );
/**
 * Map the counter.
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_counter() {

	vc_map( array(
		'name'           => esc_html__( 'Counter', 'smart' ),
		'base'           => 'nice_counter',
		'icon'           => 'bi_interface-dashboard',
		'php_class_name' => 'Nice_VCIntegration_Counter',
		'category'       => esc_html__( 'Content', 'smart' ),
		'description'    => esc_html__( 'Animated counter', 'smart' ),
		'params'         => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Counter value', 'smart' ),
				'param_name'  => 'value',
				'description' => esc_html__( 'Input counter value here.', 'smart' ),
				'value'       => '1000',
				'admin_label' => true,
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Prefix', 'smart' ),
				'param_name'  => 'prefix',
				'description' => esc_html__( 'Input a prefix to the value.', 'smart' ),
				'value'       => '',
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Suffix', 'smart' ),
				'param_name'  => 'suffix',
				'description' => esc_html__( 'Input a suffix to the value.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Counter font size', 'smart' ),
				'param_name'  => 'size',
				'description' => esc_html__( 'Specify the counter font dimension.', 'smart' ),
				'value'       => nice_vc_integration_heading_size(),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Counter font weight', 'smart' ),
				'param_name'  => 'weight',
				'description' => esc_html__( 'Specify the counter font weight.', 'smart' ),
				'value'      => nice_vc_integration_font_weight(),
			),
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Counter letter spacing', 'smart' ),
				'param_name'         => 'letter_spacing',
				'description'        => esc_html__( 'Specify Letter Spacing.', 'smart' ),
				'value'              => nice_vc_integration_letter_spacing(),
				'param_holder_class' => 'nice_letter-spacing-dropdown',
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Counter text color', 'smart' ),
				'param_name'         => 'text_color',
				'param_holder_class' => 'vc_colored-dropdown',
				'description'        => esc_html__( 'Specify the text color.', 'smart' ),
				'value'              => nice_vc_integration_colors(),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Use theme default font family in title?', 'smart' ),
				'param_name'  => 'use_theme_fonts',
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'description' => esc_html__( 'Use the default font family from the theme. If unchecked you can pick any other font from Google Fonts.', 'smart' ),
				'std'         => 'yes',
			),
			array(
				'type'        => 'google_fonts',
				'param_name'  => 'google_fonts',
				'value'       => 'font_family:ABeeZee|font_style:400%20regular%3A400%3Anormal',
				'settings'    => array(
					'fields' => array(
						'font_family_description' => esc_html__( 'Select font family.', 'smart' ),
						'font_style_description'  => esc_html__( 'Select font styling.', 'smart' ),
					),
				),
				'dependency' => array(
					'element'            => 'use_theme_fonts',
					'value_not_equal_to' => 'yes',
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Text under', 'smart' ),
				'param_name'  => 'text',
				'description' => esc_html__( 'Input a text under the counter.', 'smart' ),
				'value'       => '',
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Separator', 'smart' ),
				'param_name'  => 'separator',
				'description' => esc_html__( 'Activate this to add a separator between the value and the description.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes' ),
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Font size', 'smart' ),
				'param_name'  => 'text_under_size',
				'description' => esc_html__( 'Specify the font dimension.', 'smart' ),
				'value'       => nice_vc_integration_heading_size(),
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Font weight', 'smart' ),
				'param_name'  => 'text_under_weight',
				'description' => esc_html__( 'Specify the font weight.', 'smart' ),
				'value'       => nice_vc_integration_font_weight(),
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Line height', 'smart' ),
				'param_name'  => 'text_under_line_height',
				'description' => esc_html__( 'Specify the line height.', 'smart' ),
				'value'       => '',
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Text transform', 'smart' ),
				'param_name'  => 'text_under_transform',
				'description' => esc_html__( 'Specify the text transformation.', 'smart' ),
				'value'       => nice_vc_integration_text_transform(),
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Letter spacing', 'smart' ),
				'param_name'         => 'text_under_letter_spacing',
				'description'        => esc_html__( 'Specify letter spacing.', 'smart' ),
				'value'              => nice_vc_integration_letter_spacing(),
				'param_holder_class' => 'nice_letter-spacing-dropdown',
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Text color', 'smart' ),
				'param_name'         => 'text_under_color',
				'param_holder_class' => 'vc_colored-dropdown',
				'description'        => esc_html__( 'Specify the text color.', 'smart' ),
				'value'              => nice_vc_integration_colors(),
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Use theme default font family?', 'smart' ),
				'param_name'  => 'text_under_use_theme_fonts',
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'description' => esc_html__( 'Use the default font family from the theme. If unchecked you can pick any other font from Google Fonts.', 'smart' ),
				'std'         => 'yes',
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
			array(
				'type'        => 'google_fonts',
				'param_name'  => 'text_under_google_fonts',
				'value'       => 'font_family:ABeeZee|font_style:400%20regular%3A400%3Anormal',
				'settings'    => array(
					'fields' => array(
						'font_family_description' => esc_html__( 'Select font family.', 'smart' ),
						'font_style_description'  => esc_html__( 'Select font styling.', 'smart' ),
					),
				),
				'dependency' => array(
					'element'            => 'text_under_use_theme_fonts',
					'value_not_equal_to' => 'yes',
				),
				'group'       => esc_html__( 'Text Under', 'smart' ),
			),
		),
	) );
}
endif;
