<?php
/**
 * Smart by NiceThemes.
 *
 * Custom Heading
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_custom_heading' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_custom_heading' );
/**
 * Map the custom heading.
 *
 * @since  1.0.0
 *
 */
function nice_vc_integration_map_custom_heading() {
	vc_map( array(
		'name'        => esc_html__( 'Heading', 'smart' ),
		'base'        => 'vc_custom_heading',
		'icon'        => 'icon-wpb-ui-custom_heading',
		'show_settings_on_create' => true,
		'category'    => esc_html__( 'Content', 'smart' ),
		'description' => esc_html__( 'Text with Google fonts', 'smart' ),
		'params'      => array(
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Text source', 'smart' ),
				'param_name'  => 'source',
				'value'       => array(
					esc_html__( 'Custom text', 'smart' ) => '',
					esc_html__( 'Post or Page Title', 'smart' ) => 'post_title',
				),
				'std'         => '',
				'description' => esc_html__( 'Select text source.', 'smart' ),
			),
			array(
				'type'        => 'textarea',
				'heading'     => esc_html__( 'Text', 'smart' ),
				'param_name'  => 'text',
				'admin_label' => true,
				'value'       => esc_html__( 'This is custom heading element', 'smart' ),
				'description' => esc_html__( 'Note: If you are using non-latin characters be sure to activate them under Settings/Visual Composer/General Settings.', 'smart' ),
				'dependency'  => array(
					'element'  => 'source',
					'is_empty' => true,
				),
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'URL (Link)', 'smart' ),
				'param_name'  => 'link',
				'description' => esc_html__( 'Add link to custom heading.', 'smart' ),
			),
			array(
				'type'        => 'font_container',
				'param_name'  => 'font_container',
				'value'       => 'tag:h2',
				'settings'    => array(
					'fields'  => array(
						'tag' => 'h2', // default value h2
						'font_size',
						'line_height',
						'tag_description'         => esc_html__( 'Select element tag.', 'smart' ),
						'font_size_description'   => esc_html__( 'Enter font size.', 'smart' ),
						'line_height_description' => esc_html__( 'Enter line height.', 'smart' ),
					),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title font weight', 'smart' ),
				'param_name'  => 'weight',
				'description' => esc_html__( 'Specify the title font weight.', 'smart' ),
				'value'      => nice_vc_integration_font_weight(),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title Text alignment', 'smart' ),
				'param_name'  => 'text_align',
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Left', 'smart' ) => 'left',
					esc_html__( 'Center', 'smart' ) => 'center',
					esc_html__( 'Right', 'smart' ) => 'right',
				),
				'description' => esc_html__( 'Specify the text alignment. By default inherited from the parent container.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title text transform', 'smart' ),
				'param_name'  => 'transform',
				'description' => esc_html__( 'Specify the text transformation.', 'smart' ),
				'value'       => nice_vc_integration_text_transform(),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title letter spacing', 'smart' ),
				'param_name'  => 'letter_spacing',
				'description' => esc_html__( 'Specify Letter Spacing.', 'smart' ),
				'value'       => nice_vc_integration_letter_spacing(),
				'param_holder_class' => 'nice_letter-spacing-dropdown',
			),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'Title text color', 'smart' ),
				'param_name'  => 'text_color',
				'param_holder_class' => 'vc_colored-dropdown',
				'description' => esc_html__( 'Specify the text color.', 'smart' ),
				'value'       => nice_vc_integration_colors(),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Use theme default font family?', 'smart' ),
				'param_name'  => 'use_theme_fonts',
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'description' => esc_html__( 'Use the default font family from the theme. If unchecked you can pick any other font from Google Fonts.', 'smart' ),
				'std'         => 'yes',
			),
			array(
				'type'        => 'google_fonts',
				'param_name'  => 'google_fonts',
				'value'       => 'font_family:ABeeZee|font_style:400%20regular%3A400%3Anormal',
				'settings'    => array(
					'fields' => array(
						'font_family_description' => esc_html__( 'Select font family.', 'smart' ),
						'font_style_description'  => esc_html__( 'Select font styling.', 'smart' ),
					),
				),
				'dependency' => array(
					'element'            => 'use_theme_fonts',
					'value_not_equal_to' => 'yes',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Separator', 'smart' ),
				'param_name'  => 'separator',
				'description' => esc_html__( 'Activate the separator. This will appear under the text.', 'smart' ),
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( 'Under heading', 'smart' ) => 'yes',
					esc_html__( 'Under subheading', 'smart' ) => 'under',
					esc_html__( 'Over heading', 'smart' ) => 'over',
				),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Separator colored', 'smart' ),
				'param_name'  => 'separator_color',
				'description' => esc_html__( 'Color the separator with the accent color.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes', 'smart' ) => 'yes',
				),
				'dependency' => array(
					'element'   => 'separator',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Separator double space', 'smart' ),
				'param_name'  => 'separator_double',
				'description' => esc_html__( 'Activate to increase the separator space.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes', 'smart' ) => 'yes',
				),
				'dependency' => array(
					'element' => 'separator',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'textarea',
				'heading'     => esc_html__( 'Subheading', 'smart' ),
				'param_name'  => 'subheading',
				'description' => esc_html__( 'Add a subheading text.', 'smart' ),
				'group'       => esc_html__( 'Subheading', 'smart' ),
				'admin_label' => true,
			),
			array(
				'type'        => 'font_container',
				'param_name'  => 'subheading_font_container',
				'value'       => '',
				'settings'    => array(
					'fields'  => array(
						'font_size',
						'line_height',
						'tag_description'         => esc_html__( 'Select element tag.', 'smart' ),
						'font_size_description'   => esc_html__( 'Enter font size.', 'smart' ),
						'line_height_description' => esc_html__( 'Enter line height.', 'smart' ),
					),
				),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Font weight', 'smart' ),
				'param_name'  => 'subheading_weight',
				'description' => esc_html__( 'Specify the subheading font weight.', 'smart' ),
				'value'       => nice_vc_integration_font_weight(),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Text alignment', 'smart' ),
				'param_name'  => 'subheading_text_align',
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Left', 'smart' ) => 'left',
					esc_html__( 'Center', 'smart' ) => 'center',
					esc_html__( 'Right', 'smart' ) => 'right',
				),
				'description' => esc_html__( 'Specify the text alignment. By default inherited from the parent container.', 'smart' ),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Text transform', 'smart' ),
				'param_name'  => 'subheading_transform',
				'description' => esc_html__( 'Specify the text transformation.', 'smart' ),
				'value'       => nice_vc_integration_text_transform(),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Letter spacing', 'smart' ),
				'param_name'         => 'subheading_letter_spacing',
				'description'        => esc_html__( 'Specify Letter Spacing.', 'smart' ),
				'value'              => nice_vc_integration_letter_spacing(),
				'param_holder_class' => 'nice_letter-spacing-dropdown',
				'group'              => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Subheading text color', 'smart' ),
				'param_name'         => 'subheading_text_color',
				'param_holder_class' => 'vc_colored-dropdown',
				'description'        => esc_html__( 'Specify the text color.', 'smart' ),
				'value'              => nice_vc_integration_colors(),
				'group'              => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Use theme default font family?', 'smart' ),
				'param_name'  => 'subheading_use_theme_fonts',
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'description' => esc_html__( 'Use the default font family from the theme. If unchecked you can pick any other font from Google Fonts.', 'smart' ),
				'std'         => 'yes',
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'google_fonts',
				'param_name'  => 'subheading_google_fonts',
				'value'       => 'font_family:ABeeZee|font_style:400%20regular%3A400%3Anormal',
				'settings'    => array(
					'fields' => array(
						'font_family_description' => esc_html__( 'Select font family.', 'smart' ),
						'font_style_description'  => esc_html__( 'Select font styling.', 'smart' ),
					),
				),
				'dependency' => array(
					'element'            => 'subheading_use_theme_fonts',
					'value_not_equal_to' => 'yes',
				),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Text lead', 'smart' ),
				'param_name'  => 'sub_lead',
				'description' => esc_html__( 'Transform the text to leading text. This will make it look bigger.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Reduce subheading top space', 'smart' ),
				'param_name'  => 'sub_reduced',
				'description' => esc_html__( 'Activate this to reduce the subheading top margin.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Subheading', 'smart' ),
			),
			nice_vc_integration_add_responsive_desktop(),
			nice_vc_integration_add_responsive_tablet(),
			nice_vc_integration_add_responsive_mobile(),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'smart' ),
			),
			array(
				'type'        => 'css_editor',
				'heading'     => esc_html__( 'CSS box', 'smart' ),
				'param_name'  => 'css',
				'group'       => esc_html__( 'Design Options', 'smart' ),
			),
		),
	) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_subheading_values' ) ) :
/**
 * Obtain subheading values for custom VC integration.
 *
 * @since 1.0.0
 */
function nice_vc_integration_subheading_values( $shortcode_object, $atts, $fields ) {
	/**
	 * Get default values from VC_MAP.
	 **/
	$google_fonts_field        = isset( $fields['subheading_google_fonts'] ) ? $fields['subheading_google_fonts'] : '';
	$font_container_field      = isset( $fields['subheading_font_container'] ) ? $fields['subheading_font_container'] : '';
	$subheading_font_container = isset( $atts['subheading_font_container'] ) ? $atts['subheading_font_container'] : '';
	$subheading_google_fonts   = isset( $atts['subheading_google_fonts'] ) ? $atts['subheading_google_fonts'] : '';

	$font_container_obj = new Vc_Font_Container();
	$google_fonts_obj = new Vc_Google_Fonts();
	$font_container_field_settings = isset( $font_container_field['settings'], $font_container_field['settings']['fields'] ) ? $font_container_field['settings']['fields'] : array();
	$google_fonts_field_settings = isset( $google_fonts_field['settings'], $google_fonts_field['settings']['fields'] ) ? $google_fonts_field['settings']['fields'] : array();
	$font_container_data = $font_container_obj->_vc_font_container_parse_attributes( $font_container_field_settings, $subheading_font_container );
	$google_fonts_data = strlen( $subheading_google_fonts ) > 0 ? $google_fonts_obj->_vc_google_fonts_parse_attributes( $google_fonts_field_settings, $subheading_google_fonts ) : '';

	return array(
		'subheading_font_container_data' => $font_container_data,
		'subheading_google_fonts_data'   => $google_fonts_data,
	);
}
endif;
