<?php
/**
 * Smart by NiceThemes.
 *
 * Gallery
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_gallery' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_gallery' );
/**
 * Map options for galleries.
 *
 * Options list:
 * @uses nice_vc_integration_gallery_options()
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_gallery() {
	/**
	 * You can find the options list in the function below:
	 * @see nice_vc_integration_gallery_options()
	 */
	vc_map( nice_vc_integration_gallery_options() );
}
endif;


if ( ! function_exists( 'nice_vc_integration_gallery_options' ) ) :
/**
 * Obtain options for galleries.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_gallery_options() {
	$gallery_options = array(
		'name'           => esc_html__( 'Image Gallery', 'smart' ),
		'base'           => 'vc_gallery',
		'php_class_name' => 'Nice_VCIntegration_Gallery_Shortcode',
		'icon'           => 'bi_media-image-b',
		'category'       => esc_html__( 'Content', 'smart' ),
		'description'    => esc_html__( 'Responsive image gallery', 'smart' ),
		'params'         => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Widget title', 'smart' ),
				'param_name'  => 'title',
				'description' => esc_html__( 'Enter text used as widget title (Note: located above content element).', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Gallery type', 'smart' ),
				'param_name'  => 'type',
				'value'       => array(
					esc_html__( 'FlexSlider fade', 'smart' )  => 'flexslider_fade',
					esc_html__( 'FlexSlider slide', 'smart' ) => 'flexslider_slide',
					esc_html__( 'Image grid', 'smart' )       => 'image_grid',
				),
				'description' => esc_html__( 'Select gallery type.', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Grid columns', 'smart' ),
				'param_name'  => 'columns',
				'description' => esc_html__( 'Quantity of columns of the image grid (1 to 12).', 'smart' ),
				'value'       => '4',
				'admin_label' => true,
				'dependency'  => array(
					'element' => 'type',
					'value'   => array(
						'image_grid',
					),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Items gap', 'smart' ),
				'param_name'  => 'gutter_size',
				'std'         => 0,
				'value'       => array(
					esc_html__( 'No gap', 'smart' )      => '0',
					esc_html__( 'Small', 'smart' )       => '1',
					esc_html__( 'Medium', 'smart' )      => '2',
					esc_html__( 'Large', 'smart' )       => '3',
					esc_html__( 'Extra Large', 'smart' ) => '4',
				),
				'description' => esc_html__( 'Set the items gap.', 'smart' ),
				'dependency'  => array(
					'element' => 'type',
					'value'   => array(
						'image_grid',
					),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Auto rotate', 'smart' ),
				'param_name'  => 'interval',
				'value'       => array(
					3,
					5,
					10,
					15,
					esc_html__( 'Disable', 'smart' ) => 0,
				),
				'description' => esc_html__( 'Auto rotate slides each X seconds.', 'smart' ),
				'dependency'  => array(
					'element' => 'type',
					'value'   => array(
						'flexslider_fade',
						'flexslider_slide',
					),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image source', 'smart' ),
				'param_name'  => 'source',
				'value'       => array(
					esc_html__( 'Media library', 'smart' )  => 'media_library',
					esc_html__( 'External links', 'smart' ) => 'external_link',
				),
				'std'         => 'media_library',
				'description' => esc_html__( 'Select image source.', 'smart' ),
			),
			array(
				'type'        => 'attach_images',
				'heading'     => esc_html__( 'Images', 'smart' ),
				'param_name'  => 'images',
				'value'       => '',
				'description' => esc_html__( 'Select images from media library.', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'   => 'media_library',
				),
			),
			array(
				'type'        => 'exploded_textarea_safe',
				'heading'     => esc_html__( 'External links', 'smart' ),
				'param_name'  => 'custom_srcs',
				'description' => esc_html__( 'Enter external link for each gallery image (Note: divide links with linebreaks (Enter)).', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'   => 'external_link',
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Image size', 'smart' ),
				'param_name'  => 'img_size',
				'value'       => 'thumbnail',
				'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'   => 'media_library',
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Image size', 'smart' ),
				'param_name'  => 'external_img_size',
				'value'       => '',
				'description' => esc_html__( 'Enter image size in pixels. Example: 200x100 (Width x Height).', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'   => 'external_link',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'On click action', 'smart' ),
				'param_name'  => 'onclick',
				'value'       => array(
					esc_html__( 'None', 'smart' )             => '',
					esc_html__( 'Open Fancybox', 'smart' )    => 'link_image',
					esc_html__( 'Open custom link', 'smart' ) => 'custom_link',
				),
				'description' => esc_html__( 'Select action for click action.', 'smart' ),
				'std'         => '',
			),
			array(
				'type'        => 'exploded_textarea_safe',
				'heading'     => esc_html__( 'Custom links', 'smart' ),
				'param_name'  => 'custom_links',
				'description' => esc_html__( 'Enter links for each slide (Note: divide links with linebreaks (Enter)).', 'smart' ),
				'dependency'  => array(
					'element' => 'onclick',
					'value'   => array( 'custom_link' ),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Custom link target', 'smart' ),
				'param_name'  => 'custom_links_target',
				'description' => esc_html__( 'Select where to open custom links.', 'smart' ),
				'dependency'  => array(
					'element' => 'onclick',
					'value'   => array(
						'custom_link',
						'img_link_large',
					),
				),
				'value'       => vc_target_param_list(),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'smart' ),
			),
		),
	);

	return apply_filters( 'nice_vc_integration_gallery_options', $gallery_options );
}
endif;
