<?php
/**
 * Smart by NiceThemes.
 *
 * Map Google Maps for VC integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_gmaps' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_gmaps' );
/**
 * Map with vc_gmaps
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_gmaps() {

	vc_map( array(
		'name'        => esc_html__( 'Google Maps', 'smart' ),
		'base'        => 'vc_gmaps',
		'icon'        => 'bi_location-pin-regular',
		'category'    => esc_html__( 'Content', 'smart' ),
		'description' => esc_html__( 'Google Maps Block', 'smart' ),
		'params'      => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Widget title', 'smart' ),
				'param_name'  => 'title',
				'description' => esc_html__( 'Enter text used as widget title (Note: located above content element).', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Latitude, Longitude', 'smart' ),
				'param_name'  => 'latlon',
				'description' => wp_kses( sprintf( __('To get the Latitude and Longitude of any address, follow the instructions %1$shere%2$s.%3$s1) Use the directions under the section "Get the coordinates of a place".%3$s2) Copy the coordinates.%3$s3) Paste the coordinates in the field with the "comma" sign.', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'https://support.google.com/maps/answer/18539?source=gsearch&hl=en' ), '</a>', '<br />' ), array( 'a' => array( 'href' => array(), 'target' => array() ), 'br' => array() ) ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Map height', 'smart' ),
				'param_name'  => 'size',
				'admin_label' => true,
				'description' => esc_html__( 'Enter map height in pixels. Example: 300 or leave it empty to make map responsive (in this case you need to declare a minimun height for the row and the column equal height or expanded).', 'smart' ),
			),
			array(
				'type'        => 'textarea_safe',
				'heading'     => esc_html__( 'Address', 'smart' ),
				'param_name'  => 'address',
				'description' => esc_html__( 'Insert here the address in case you want it to be display on the bottom of the map.', 'smart' ),
			),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'Map color', 'smart' ),
				'param_name'  => 'map_color',
				'value'       => nice_vc_integration_colors(),
				'description' => esc_html__( 'Specify the map base color.', 'smart' ),
				'param_holder_class' => 'vc_colored-dropdown',
			),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'UI color', 'smart' ),
				'param_name'  => 'ui_color',
				'value'       => nice_vc_integration_colors(),
				'description' => esc_html__( 'Specify the UI color.', 'smart' ),
				'param_holder_class' => 'vc_colored-dropdown',
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Zoom', 'smart' ),
				'param_name'  => 'zoom',
				'min'         => 0,
				'max'         => 19,
				'step'        => 1,
				'value'       => 10,
				'description' => esc_html__( 'Set map zoom level.', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Saturation', 'smart' ),
				'param_name'  => 'map_saturation',
				'min'         => -100,
				'max'         => 100,
				'step'        => 1,
				'value'       => -20,
				'description' => esc_html__( 'Set map color saturation.', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Brightness', 'smart' ),
				'param_name'  => 'map_brightness',
				'min'         => -100,
				'max'         => 100,
				'step'        => 1,
				'value'       => 5,
				'description' => esc_html__( 'Set map color brightness.', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Mobile no draggable', 'smart' ),
				'param_name'  => 'mobile_no_drag',
				'description' => esc_html__( 'Deactivate the drag function on mobile devices.', 'smart' ),
				'group'       => esc_html__( 'Mobile', 'smart' ),
				'value'       => array(
					'' => 'yes',
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'group'       => esc_html__( 'Extra', 'smart' ),
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'smart' ),
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
		),
	) );
}
endif;
