<?php
/**
 * Smart by NiceThemes.
 *
 * Icon Box [vc_icon]
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_icon' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_icon' );
/**
 * Create the icon box, map with vc_icon
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_icon() {

	$icon_sizes = array(
		esc_html__( 'Standard', 'smart' ) => '',
		esc_html__( '2x', 'smart' )       => 'icon-2x',
		esc_html__( '3x', 'smart' )       => 'icon-3x',
		esc_html__( '4x', 'smart' )       => 'icon-4x',
		esc_html__( '5x', 'smart' )       => 'icon-5x',
	);

	$heading_semantic = array(
		esc_html__( 'h1', 'smart' ) => 'h1',
		esc_html__( 'h2', 'smart' ) => 'h2',
		esc_html__( 'h3', 'smart' ) => 'h3',
		esc_html__( 'h4', 'smart' ) => 'h4',
		esc_html__( 'h5', 'smart' ) => 'h5',
		esc_html__( 'h6', 'smart' ) => 'h6',
		esc_html__( 'p', 'smart' ) => 'p',
		esc_html__( 'div', 'smart' ) => 'div',
	);

	$heading_size = array(
		esc_html__( 'Default CSS', 'smart' ) => '',
		esc_html__( 'h1', 'smart' )          => 'h1',
		esc_html__( 'h2', 'smart' )          => 'h2',
		esc_html__( 'h3', 'smart' )          => 'h3',
		esc_html__( 'h4', 'smart' )          => 'h4',
		esc_html__( 'h5', 'smart' )          => 'h5',
		esc_html__( 'h6', 'smart' )          => 'h6',
	);

	vc_map( array(
		'name'        => esc_html__( 'Icon Box', 'smart' ),
		'base'        => 'vc_icon',
		'icon'        => 'bi_sport-flag-a',
		'weight'      => 96,
		'category'    => esc_html__( 'Content', 'smart' ),
		'description' => esc_html__( 'Icon box from icon library', 'smart' ),
		'params' => array(
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Icon library', 'smart' ),
				'value'       => array(
					esc_html__( 'Font Awesome', 'smart' )  => 'fontawesome',
					esc_html__( 'Open Iconic', 'smart' )   => 'openiconic',
					esc_html__( 'Typicons', 'smart' )      => 'typicons',
					esc_html__( 'Entypo', 'smart' )        => 'entypo',
					esc_html__( 'Linecons', 'smart' )      => 'linecons',
					esc_html__( 'ET Line Icons', 'smart' ) => 'etlineicons',
					esc_html__( 'Linea Icons', 'smart' )   => 'lineaicons',
				),
				'param_name'  => 'type',
				'description' => esc_html__( 'Select icon library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_fontawesome',
				'value'       => 'fa fa-smile-o',
				'settings'    => array(
					'emptyIcon'    => false,
					'iconsPerPage' => 4000, // default 100, how many icons per/page to display, we use (big number) to display all icons in single page
				),
				'dependency' => array(
					'element' => 'type',
					'value'   => 'fontawesome',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'       => 'iconpicker',
				'heading'    => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_openiconic',
				'value'      => '', // default value to backend editor admin_label
				'settings'   => array(
					'emptyIcon'    => false, // Default true, display an "empty" icon?.
					'type'         => 'openiconic',
					'iconsPerPage' => 4000, // Default 100, how many icons per/page to display.
				),
				'dependency'  => array(
					'element' => 'type',
					'value'   => 'openiconic',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_typicons',
				'value'       => '', // default value to backend editor admin_label
				'settings'    => array(
					'emptyIcon'    => false, // Default true, display an "empty" icon?.
					'type'         => 'typicons',
					'iconsPerPage' => 4000, // Default 100, how many icons per/page to display.
				),
				'dependency' => array(
					'element' => 'type',
					'value'   => 'typicons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_entypo',
				'value'       => '', // default value to backend editor admin_label
				'settings'    => array(
					'emptyIcon'    => false,
					'type'         => 'entypo',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'type',
					'value'       => 'entypo',
				),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_linecons',
				'value'       => 'vc_li vc_li-heart',
				'settings'    => array(
					'emptyIcon'    => false,
					'type'         => 'linecons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'type',
					'value'   => 'linecons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_etlineicons',
				'settings'    => array(
					'emptyIcon' => false,
					'type'      => 'etlineicons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'type',
					'value'       => 'etlineicons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_lineaicons',
				'value'       => '', // default value to backend editor admin_label
				'settings'    => array(
					'emptyIcon' => false,
					'type'      => 'lineaicons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'type',
					'value'       => 'lineaicons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Module position', 'smart' ),
				'param_name'  => 'position',
				'value'       => array(
					esc_html__( 'Icon top', 'smart' ) => '',
					esc_html__( 'Icon bottom', 'smart' ) => 'bottom',
					esc_html__( 'Icon left', 'smart' ) => 'left',
					esc_html__( 'Icon right', 'smart' ) => 'right',
				),
				'description' => esc_html__( 'Specify where the icon is positioned inside the module.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Layout display', 'smart' ),
				'param_name'  => 'display',
				'description' => esc_html__( 'Specify the display mode.', 'smart' ),
				'value'       => array(
					esc_html__( 'Block', 'smart' ) => '',
					esc_html__( 'Inline', 'smart' ) => 'inline',
				),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Media icon', 'smart' ),
				'param_name'  => 'icon_image',
				'value'       => '',
				'description' => esc_html__( 'Specify a media icon from the media library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Icon animated', 'smart' ),
				'param_name'  => 'icon_animated',
				'description' => esc_html__( 'Animate your icon. Works only if you selected an SVG image.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'dependency' => array(
					'element'   => 'icon_image',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array_merge( nice_vc_integration_add_css_animation_delay(), array(
				'param_name' => 'icon_animation_delay',
				'std'        => 600,
				'group'      => esc_html__( 'Icon', 'smart' ),
				'dependency' => array(
					'element'   => 'icon_animated',
					'not_empty' => true,
				),
			) ),
			array_merge( nice_vc_integration_add_css_animation_speed(), array(
				'param_name' => 'icon_animation_speed',
				'std'        => 200,
				'group'      => esc_html__( 'Icon', 'smart' ),
				'dependency' => array(
					'element'   => 'icon_animated',
					'not_empty' => true,
				),
			) ),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Icon outlined', 'smart' ),
				'param_name'  => 'outline',
				'description' => esc_html__( 'Outlined icon doesn\'t have a full background color.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'dependency' => array(
					'element'   => 'background_style',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'Color', 'smart' ),
				'param_name'  => 'icon_color',
				'description' => esc_html__( 'Select icon color.', 'smart' ),
				'param_holder_class' => 'vc_colored-dropdown',
				'value'       => nice_vc_integration_colors(),
				'std'         => '',
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Icon background style', 'smart' ),
				'param_name'  => 'background_style',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( 'Circle', 'smart' ) => 'icon-rounded',
					esc_html__( 'Square', 'smart' ) => 'icon-squared',
				),
				'description' => esc_html__( 'Background style for icon.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Icon size', 'smart' ),
				'param_name'  => 'size',
				'value'       => $icon_sizes,
				'std'         => '',
				'description' => esc_html__( 'Icon size.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Icon outlined', 'smart' ),
				'param_name'  => 'outline',
				'description' => esc_html__( 'Outlined icon doens\'t have a full background color.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'dependency' => array(
					'element'   => 'background_style',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Icon shadow', 'smart' ),
				'param_name'  => 'shadow',
				'description' => esc_html__( 'Icon shadow.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'dependency' => array(
					'element'   => 'background_style',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Title', 'smart' ),
				'param_name'  => 'title',
				'admin_label' => true,
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title semantic', 'smart' ),
				'param_name'  => 'heading_semantic',
				'description' => esc_html__( 'Specify element tag.', 'smart' ),
				'value'       => $heading_semantic,
				'std'         => 'h3',
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title size', 'smart' ),
				'param_name'  => 'text_size',
				'description' => esc_html__( 'Specify title size.', 'smart' ),
				'std'         => 'h3',
				'value'       => $heading_size,
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Title line height', 'smart' ),
				'param_name'  => 'title_line_height',
				'description' => esc_html__( 'Specify the title line height.', 'smart' ),
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title font weight', 'smart' ),
				'param_name'  => 'title_font_weight',
				'description' => esc_html__( 'Specify the title font weight.', 'smart' ),
				'value'       => nice_vc_integration_font_weight(),
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title text transform', 'smart' ),
				'param_name'  => 'title_text_transform',
				'description' => esc_html__( 'Specify the text transformation.', 'smart' ),
				'value'       => nice_vc_integration_text_transform(),
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Title letter spacing', 'smart' ),
				'param_name'         => 'title_letter_spacing',
				'description'        => esc_html__( 'Specify Letter Spacing.', 'smart' ),
				'value'              => nice_vc_integration_letter_spacing(),
				'param_holder_class' => 'nice_letter-spacing-dropdown',
				'group'              => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Title text color', 'smart' ),
				'param_name'         => 'title_text_color',
				'param_holder_class' => 'vc_colored-dropdown',
				'description'        => esc_html__( 'Specify the text color.', 'smart' ),
				'value'              => nice_vc_integration_colors(),
				'group'              => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Use theme default font family in title?', 'smart' ),
				'param_name'  => 'title_use_theme_fonts',
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'description' => esc_html__( 'Use the default font family from the theme. If unchecked you can pick any other font from Google Fonts.', 'smart' ),
				'std'         => 'yes',
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'        => 'google_fonts',
				'param_name'  => 'title_google_fonts',
				'value'       => 'font_family:ABeeZee|font_style:400%20regular%3A400%3Anormal',
				'settings'    => array(
					'fields' => array(
						'font_family_description' => esc_html__( 'Select font family.', 'smart' ),
						'font_style_description'  => esc_html__( 'Select font styling.', 'smart' ),
					),
				),
				'dependency' => array(
					'element'            => 'title_use_theme_fonts',
					'value_not_equal_to' => 'yes',
				),
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'        => 'textarea_html',
				'heading'     => esc_html__( 'Text', 'smart' ),
				'param_name'  => 'content',
				'group'       => esc_html__( 'Text', 'smart' ),
				'admin_label' => true,
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Reduce text top space', 'smart' ),
				'param_name'  => 'text_reduced',
				'description' => esc_html__( 'Activate this to reduce the text top margin.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Text', 'smart' ),
				'dependency'  => array(
					'element' => 'position',
					'value'   => array(
						'',
						'bottom',
					),
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Add top margin', 'smart' ),
				'param_name'  => 'add_margin',
				'description' => esc_html__( 'Add text top margin.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Text', 'smart' ),
				'dependency'  => array(
					'element' => 'position',
					'value'   => array(
						'left',
						'right',
					),
				),
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'URL (Link)', 'smart' ),
				'param_name'  => 'link',
				'description' => esc_html__( 'Add link to icon.', 'smart' ),
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Link text', 'smart' ),
				'param_name'  => 'link_text',
				'description' => esc_html__( 'Add a text link if you wish, this will be added under the text.', 'smart' ),
				'group'       => esc_html__( 'Text', 'smart' ),
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'group'       => esc_html__( 'Extra', 'smart' ),
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'smart' ),
			),
		),
	) );
}
endif;
