<?php
/**
 * Smart by NiceThemes.
 *
 * Map Image Hover for VC integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_image_hover' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_image_hover' );
/**
 * Map with nice_image_hover
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_image_hover() {

	vc_map( array(
		'name'        => esc_html__( 'Image Hover', 'smart' ),
		'base'        => 'nice_image_hover',
		'icon'        => 'bi_media-image-b',
		'php_class_name' => 'Nice_VCIntegration_Image_Hover',
		'category'    => esc_html__( 'Content', 'smart' ),
		'description' => esc_html__( 'Simple image hover with CSS animation', 'smart' ),
		'params'      => array(
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Image', 'smart' ),
				'param_name'  => 'image',
				'value'       => '',
				'description' => esc_html__( 'Select image from media library.', 'smart' ),
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Image Hover', 'smart' ),
				'param_name'  => 'image_hover',
				'value'       => '',
				'description' => esc_html__( 'Select image from media library.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image Hover Effect', 'smart' ),
				'param_name'  => 'effect',
				'value'       => array(
					esc_html__( 'Fade', 'smart' ) => '',
					esc_html__( 'Plain', 'smart' ) => 'plain',
					esc_html__( 'Crossfade', 'smart' ) => 'crossfade',
				),
				'description' => esc_html__( 'Select image hover effect.', 'smart' ),
				'admin_label' => true,

			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Image size', 'smart' ),
				'param_name'  => 'img_size',
				'value'       => 'large',
				'description' => esc_html__( 'Enter image size (Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels (Example: 200x100 (Width x Height)).', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image alignment', 'smart' ),
				'param_name'  => 'alignment',
				'value'       => array(
					esc_html__( 'Left', 'smart' ) => 'left',
					esc_html__( 'Right', 'smart' ) => 'right',
					esc_html__( 'Center', 'smart' ) => 'center',
				),
				'description' => esc_html__( 'Select image alignment.', 'smart' ),
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'Image Link', 'smart' ),
				'param_name'  => 'link',
				'description' => esc_html__( 'Enter URL if you want this image to have a link.', 'smart' ),
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'smart' ),
			),
			array(
				'type'        => 'css_editor',
				'heading'     => esc_html__( 'CSS box', 'smart' ),
				'param_name'  => 'css',
				'group'       => esc_html__( 'Design Options', 'smart' ),
			),
			// backward compatibility. since 4.6
			array(
				'type'        => 'hidden',
				'param_name'  => 'img_link_large',
			),
		),
	) );
}
endif;
