<?php
/**
 * Smart by NiceThemes.
 *
 * Map image for VC integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_single_image' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_single_image' );
/**
 * Map with vc_single_image
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_single_image() {
	vc_map( array(
		'name'        => esc_html__( 'Image', 'smart' ),
		'base'        => 'vc_single_image',
		'icon'        => 'bi_media-image-a',
		'category'    => esc_html__( 'Content', 'smart' ),
		'description' => esc_html__( 'Simple image with CSS animation', 'smart' ),
		'params'      => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Widget title', 'smart' ),
				'param_name'  => 'title',
				'description' => esc_html__( 'Enter text used as widget title (Note: located above content element).', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image source', 'smart' ),
				'param_name'  => 'source',
				'value'       => array(
					esc_html__( 'Media library', 'smart' ) => 'media_library',
					esc_html__( 'External link', 'smart' ) => 'external_link',
					esc_html__( 'Featured Image', 'smart' ) => 'featured_image',
				),
				'std'         => 'media_library',
				'description' => esc_html__( 'Select image source.', 'smart' ),
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Image', 'smart' ),
				'param_name'  => 'image',
				'value'       => '',
				'description' => esc_html__( 'Select image from media library.', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'   => 'media_library',
				),
				'admin_label' => true,
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Animated image', 'smart' ),
				'param_name'  => 'image_animated',
				'description' => esc_html__( 'Animate your image. Works only if you selected an SVG image.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'dependency' => array(
					'element'   => 'image',
					'not_empty' => true,
				),
				'group'       => null,
			),
			array_merge( nice_vc_integration_add_css_animation_delay(), array(
				'param_name' => 'image_animation_delay',
				'std'        => 600,
				'group'      => null,
				'dependency' => array(
					'element'   => 'image_animated',
					'not_empty' => true,
				),
			) ),
			array_merge( nice_vc_integration_add_css_animation_speed(), array(
				'param_name' => 'image_animation_speed',
				'std'        => 200,
				'group'      => null,
				'dependency' => array(
					'element'   => 'image_animated',
					'not_empty' => true,
				),
			) ),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'Image Color', 'smart' ),
				'param_name'  => 'image_color',
				'description' => esc_html__( 'Select image color. Works only if you selected an SVG image.', 'smart' ),
				'param_holder_class' => 'vc_colored-dropdown',
				'value'       => nice_vc_integration_colors(),
				'std'         => '',
				'dependency' => array(
					'element'   => 'image',
					'not_empty' => true,
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'External link', 'smart' ),
				'param_name'  => 'custom_src',
				'description' => esc_html__( 'Select external link.', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'   => 'external_link',
				),
				'admin_label' => true,
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Image size', 'smart' ),
				'param_name'  => 'img_size',
				'value'       => 'large',
				'description' => esc_html__( 'Enter image size (Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels (Example: 200x100 (Width x Height)).', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'   => array( 'media_library', 'featured_image' ),
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Image size', 'smart' ),
				'param_name'  => 'external_img_size',
				'value'       => '',
				'description' => esc_html__( 'Enter image size in pixels. Example: 200x100 (Width x Height).', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'       => 'external_link',
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Caption', 'smart' ),
				'param_name'  => 'caption',
				'description' => esc_html__( 'Enter text for image caption.', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'       => 'external_link',
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Add caption?', 'smart' ),
				'param_name'  => 'add_caption',
				'description' => esc_html__( 'Add image caption.', 'smart' ),
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'dependency'  => array(
					'element' => 'source',
					'value'       => array( 'media_library', 'featured_image' ),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image alignment', 'smart' ),
				'param_name'  => 'alignment',
				'value'       => array(
					esc_html__( 'Left', 'smart' ) => 'left',
					esc_html__( 'Right', 'smart' ) => 'right',
					esc_html__( 'Center', 'smart' ) => 'center',
				),
				'description' => esc_html__( 'Select image alignment.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image style', 'smart' ),
				'param_name'  => 'style',
				'value'       => getVcShared( 'single image styles' ),
				'description' => esc_html__( 'Select image display style.', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'       => array( 'media_library', 'featured_image' ),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image style', 'smart' ),
				'param_name'  => 'external_style',
				'value'       => getVcShared( 'single image external styles' ),
				'description' => esc_html__( 'Select image display style.', 'smart' ),
				'dependency'  => array(
					'element' => 'source',
					'value'       => 'external_link',
				),
			),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'Border color', 'smart' ),
				'param_name'  => 'border_color',
				'value'       => nice_vc_integration_colors(),
				'std'         => '',
				'dependency'  => array(
					'element' => 'style',
					'value'       => array(
						'vc_box_border',
						'vc_box_border_circle',
						'vc_box_outline',
						'vc_box_outline_circle',
						'vc_box_border_circle_2',
						'vc_box_outline_circle_2',
					),
				),
				'description' => esc_html__( 'Border color.', 'smart' ),
				'param_holder_class' => 'vc_colored-dropdown',
			),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'Border color', 'smart' ),
				'param_name'  => 'external_border_color',
				'value'       => nice_vc_integration_colors(),
				'std'         => '',
				'dependency'  => array(
					'element' => 'external_style',
					'value'       => array(
						'vc_box_border',
						'vc_box_border_circle',
						'vc_box_outline',
						'vc_box_outline_circle',
					),
				),
				'description' => esc_html__( 'Border color.', 'smart' ),
				'param_holder_class' => 'vc_colored-dropdown',
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'On click action', 'smart' ),
				'param_name'  => 'onclick',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( 'Link to large image', 'smart' ) => 'img_link_large',
					esc_html__( 'Open prettyPhoto', 'smart' ) => 'link_image',
					esc_html__( 'Open custom link', 'smart' ) => 'custom_link',
					esc_html__( 'Zoom', 'smart' ) => 'zoom',
				),
				'description' => esc_html__( 'Select action for click action.', 'smart' ),
				'std'         => '',
			),
			array(
				'type'        => 'href',
				'heading'     => esc_html__( 'Image link', 'smart' ),
				'param_name'  => 'link',
				'description' => esc_html__( 'Enter URL if you want this image to have a link (Note: parameters like "mailto:" are also accepted).', 'smart' ),
				'dependency'  => array(
					'element' => 'onclick',
					'value'   => 'custom_link',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Link Target', 'smart' ),
				'param_name'  => 'img_link_target',
				'value'       => vc_target_param_list(),
				'dependency'  => array(
					'element' => 'onclick',
					'value'       => array( 'custom_link', 'img_link_large' ),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Padding Bottom', 'smart' ),
				'param_name'  => 'padding_bottom',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( '1x', 'smart' )   => '1x',
					esc_html__( '2x', 'smart' )   => '2x',
					esc_html__( '3x', 'smart' )   => '3x',
					esc_html__( '4x', 'smart' )   => '4x',
					esc_html__( '5x', 'smart' )   => '4x',
					esc_html__( '6x', 'smart' )   => '6x',
				),
				'description' => esc_html__( 'Set the bottom padding.', 'smart' ),
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'smart' ),
			),
			array(
				'type'        => 'css_editor',
				'heading'     => esc_html__( 'CSS box', 'smart' ),
				'param_name'  => 'css',
				'group'       => esc_html__( 'Design Options', 'smart' ),
			),
			// backward compatibility. since 4.6
			array(
				'type'        => 'hidden',
				'param_name'  => 'img_link_large',
			),
		),
	) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_single_image_lazyload_setup' ) ) :
add_action( 'init', 'nice_vc_integration_single_image_lazyload_setup' );
/**
 * Setup LazyLoad for single images.
 *
 * @since 1.0.0
 */
function nice_vc_integration_single_image_lazyload_setup() {
	if ( function_exists( 'nice_lazyload_images' ) && ! nice_lazyload_images() ) {
		return;
	}

	add_filter( 'nice_vc_integration_single_image_tag', 'nice_lazyload_replacements' );
}
endif;
