<?php
/**
 * Smart by NiceThemes.
 *
 * Posts Box
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_posts' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_posts' );
/**
 * Map options for lists of posts.
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_posts() {
	vc_map( nice_vc_integration_posts_options() );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_options' ) ) :
/**
 * Obtain options for lists of posts.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_options() {
	$posts_options = array(
		'name'           => esc_html__( 'Posts', 'smart' ),
		'base'           => 'nice_posts',
		'weight'         => 999,
		'php_class_name' => 'Nice_VCIntegration_Posts_Shortcode',
		'icon'           => 'bi_interface-thumbnail',
		'description'    => esc_html__( 'Isotope grid layout', 'smart' ),
		'params'         => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Widget title', 'smart' ),
				'param_name'  => 'title',
				'admin_label' => true,
				'description' => esc_html__( 'Enter text which will be used as widget title. Leave blank if no title is needed.', 'smart' ),
				'group'       => esc_html__( 'General', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Widget title alignment', 'smart' ),
				'param_name'  => 'title_alignment',
				'admin_label' => true,
				'description' => esc_html__( 'Specify the alignment for the widget title.', 'smart' ),
				'std'         => is_rtl() ? 'right' : 'left',
				'value'       => array(
					esc_html__( 'Left', 'smart' )   => 'left',
					esc_html__( 'Right', 'smart' )  => 'right',
					esc_html__( 'Center', 'smart' ) => 'center',
				),
				'group'       => esc_html__( 'General', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Widget ID', 'smart' ),
				'param_name'  => 'el_id',
				'value'       => ( function_exists( 'big_rand' ) ) ? big_rand() : rand(),
				'description' => esc_html__( 'This value has to be unique. Change it in case it\'s needed.', 'smart' ),
				'group'       => esc_html__( 'General', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Module', 'smart' ),
				'param_name'  => 'index_type',
				'admin_label' => true,
				'description' => esc_html__( 'Specify the alignment inside the content box.', 'smart' ),
				'std'         => 'isotope',
				'value'       => array(
					esc_html__( 'None', 'smart' )    => '',
					esc_html__( 'Isotope', 'smart' ) => 'isotope',
				),
				'group'       => esc_html__( 'General', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Layout modes', 'smart' ),
				'param_name'  => 'isotope_mode',
				'description' => sprintf( esc_html__( 'Specify the Isotope layout mode. %s', 'smart' ), sprintf( '%1$sCheck this for reference%2$s', sprintf( '<a href="%s" target="_blank">', 'http://isotope.metafizzy.co/layout-modes.html' ), '</a>' ) ),
				'std'   => 'masonry',
				'value'       => array(
					esc_html__( 'Masonry', 'smart' )      => 'masonry',
					esc_html__( 'Fit rows', 'smart' )     => 'fitRows',
					esc_html__( 'Cells by row', 'smart' ) => 'cellsByRow',
					esc_html__( 'Vertical', 'smart' )     => 'vertical',
					esc_html__( 'Packery', 'smart' )      => 'packery',
				),
				'group'       => esc_html__( 'General', 'smart' ),
				'dependency'  => array(
					'element' => 'index_type',
					'value'   => 'isotope',
				),
			),
			array(
				'type'        => 'loop',
				'heading'     => esc_html__( 'Index content', 'smart' ),
				'param_name'  => 'loop',
				'admin_label' => true,
				'settings'    => array(
					'size'     => array(
						'hidden' => false,
						'value'  => 10,
					),
					'order_by' => array(
						'value' => 'date',
					),
				),
				'value'       => 'size:10|order_by:date|post_type:post',
				'description' => esc_html__( 'Create WordPress loop, to populate content from your site.', 'smart' ),
				'group'       => esc_html__( 'General', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Style', 'smart' ),
				'param_name'  => 'style_preset',
				'description' => esc_html__( 'Specify the alignment inside the content box.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Masonry', 'smart' ) => 'masonry',
					esc_html__( 'Metro', 'smart' )   => 'metro',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Media Height', 'smart' ),
				'param_name'  => 'media_height',
				'description' => esc_html__( 'Specify the height of the item\'s media element.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Default (Square)', 'smart' ) => '',
					esc_html__( 'Short', 'smart' )            => 'short',
					esc_html__( 'Tall', 'smart' )             => 'tall',
					esc_html__( 'Auto', 'smart' )             => 'height-auto',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'style_preset',
					'value'   => array(
						'',
					),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Items gap', 'smart' ),
				'param_name'  => 'gutter_size',
				'std'         => 2,
				'value'       => array(
					esc_html__( 'No gap', 'smart' )      => '0',
					esc_html__( 'Small', 'smart' )       => '1',
					esc_html__( 'Medium', 'smart' )      => '2',
					esc_html__( 'Large', 'smart' )       => '3',
					esc_html__( 'Extra Large', 'smart' ) => '4',
				),
				'description' => esc_html__( 'Set the items gap.', 'smart' ),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'style_preset',
					'value'   => array(
						'masonry',
						'metro',
					),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Items gap (horizontal)', 'smart' ),
				'param_name'  => 'gutter_size_h',
				'std'         => 2,
				'value'       => array(
					esc_html__( 'No gap', 'smart' )      => '0',
					esc_html__( 'Small', 'smart' )       => '1',
					esc_html__( 'Medium', 'smart' )      => '2',
					esc_html__( 'Large', 'smart' )       => '3',
					esc_html__( 'Extra Large', 'smart' ) => '4',
				),
				'description' => esc_html__( 'Set the horizontal gap between post items.', 'smart' ),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'style_preset',
					'value'   => array(
						'',
					),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Items gap (vertical)', 'smart' ),
				'param_name'  => 'gutter_size_v',
				'std'         => 2,
				'value'       => array(
					esc_html__( 'Same as horizontal', 'smart' ) => 'default',
					esc_html__( 'No gap', 'smart' )             => '0',
					esc_html__( 'Small', 'smart' )              => '1',
					esc_html__( 'Medium', 'smart' )             => '2',
					esc_html__( 'Large', 'smart' )              => '3',
					esc_html__( 'Extra Large', 'smart' )        => '4',
				),
				'description' => esc_html__( 'Set the vertical gap between post items.', 'smart' ),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'style_preset',
					'value'   => array(
						'',
					),
				),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Index background color', 'smart' ),
				'param_name'         => 'index_back_color',
				'description'        => esc_html__( 'Specify a background color for the module.', 'smart' ),
				'std'                => '',
				'value'              => nice_vc_integration_colors(),
				'group'              => esc_html__( 'Module', 'smart' ),
				'param_holder_class' => 'vc_colored-dropdown',
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Disable fluid grid', 'smart' ),
				'param_name'  => 'disable_fluid_grid',
				'description' => esc_html__( 'Activate this if you don\'t want the grid to use all the available horizontal space.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Ignore sticky posts', 'smart' ),
				'param_name'  => 'ignore_sticky_posts',
				'description' => esc_html__( 'Activate this to ignore sticky posts.', 'smart' ),
				'std'         => 'yes',
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Pagination mode', 'smart' ),
				'param_name'  => 'pagination_mode',
				'description' => esc_html__( 'Specify the pagination mode for this module. This option doesn\'t work if query order is set to random.', 'smart' ),
				'std'         => 'disabled',
				'value'       => array(
					esc_html__( 'No pagination', 'smart' )       => 'disabled',
					esc_html__( 'Standard pagination', 'smart' ) => 'standard',
					esc_html__( 'Infinite scroll', 'smart' )     => 'infinite-scroll',
					esc_html__( 'Click to load', 'smart' )       => 'click-to-load',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Pagination loader', 'smart' ),
				'param_name'  => 'pagination_loader',
				'description' => esc_html__( 'Choose a loader for the current pagination mode.', 'smart' ),
				'std'         => 'beat',
				'value'       => array(
					esc_html__( 'Beat', 'smart' ) => 'beat',
					esc_html__( 'Spin', 'smart' ) => 'spin',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'pagination_mode',
					'value'   => array(
						'standard',
						'infinite-scroll',
					),
				),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Pagination top padding', 'smart' ),
				'param_name'  => 'pagination_padding_top',
				'min'         => 0,
				'max'         => 8,
				'step'        => 1,
				'value'       => 2,
				'std'         => 2,
				'description' => esc_html__( 'Set top padding for pagination.', 'smart' ),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'pagination_mode',
					'value'   => array(
						'standard',
						'infinite-scroll',
						'click-to-load',
					),
				),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Pagination bottom padding', 'smart' ),
				'param_name'  => 'pagination_padding_bottom',
				'min'         => 0,
				'max'         => 8,
				'step'        => 1,
				'value'       => 2,
				'std'         => 2,
				'description' => esc_html__( 'Set bottom padding for pagination.', 'smart' ),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'pagination_mode',
					'value'   => array(
						'standard',
						'infinite-scroll',
						'click-to-load',
					),
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( '"Load more" button outlined', 'smart' ),
				'param_name'  => 'click_to_load_button_outlined',
				'description' => esc_html__( 'Activate this to the have the button outlined.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'pagination_mode',
					'value'   => array(
						'click-to-load',
					),
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( '"Load more" button text', 'smart' ),
				'param_name'  => 'click_to_load_button_text',
				'description' => esc_html__( 'Specify the button label. NB. The default is "Load more".', 'smart' ),
				'group'       => esc_html__( 'Module', 'smart' ),
				'std'         => esc_html__( 'Load more', 'smart' ),
				'dependency'  => array(
					'element' => 'pagination_mode',
					'value'   => array(
						'click-to-load',
					),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( '"Load more" button shape', 'smart' ),
				'param_name'  => 'click_to_load_button_shape',
				'description' => esc_html__( 'Specify the load more button shape.', 'smart' ),
				'group'       => esc_html__( 'Module', 'smart' ),
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Round', 'smart' )   => 'round',
					esc_html__( 'Circle', 'smart' )  => 'circle',
					esc_html__( 'Square', 'smart' )  => 'square',
				),
				'dependency'  => array(
					'element' => 'pagination_mode',
					'value'   => array(
						'click-to-load',
					),
				),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( '"Load more" button color', 'smart' ),
				'param_name'         => 'click_to_load_background_color',
				'description'        => esc_html__( 'Specify a background color for the load more button.', 'smart' ),
				'std'                => '',
				'value'              => nice_vc_integration_colors(),
				'param_holder_class' => 'vc_colored-dropdown',
				'group'              => esc_html__( 'Module', 'smart' ),
				'dependency'         => array(
					'element' => 'pagination_mode',
					'value'   => array(
						'click-to-load',
					),
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Filtering', 'smart' ),
				'param_name'  => 'filtering',
				'description' => esc_html__( 'Activate this to add the isotope filtering.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'index_type',
					'value'   => 'isotope',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Filter skin', 'smart' ),
				'param_name'  => 'filter_skin',
				'description' => esc_html__( 'Specify the filter skin color.', 'smart' ),
				'std'         => 'dark',
				'value'       => array(
					esc_html__( 'Light', 'smart' ) => 'light',
					esc_html__( 'Dark', 'smart' )  => 'dark',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Filter background color', 'smart' ),
				'param_name'         => 'filter_back_color',
				'description'        => esc_html__( 'Specify a background color for the filter menu.', 'smart' ),
				'std'                => '',
				'value'              => nice_vc_integration_colors(),
				'param_holder_class' => 'vc_colored-dropdown',
				'group'              => esc_html__( 'Module', 'smart' ),
				'dependency'         => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Filter menu full width', 'smart' ),
				'param_name'  => 'filtering_full_width',
				'description' => esc_html__( 'Activate this to force the full width of the filter.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Filter menu position', 'smart' ),
				'param_name'  => 'filtering_position',
				'description' => esc_html__( 'Specify the filter menu positioning.', 'smart' ),
				'std'         => 'left',
				'value'       => array(
					esc_html__( 'Left', 'smart' )   => 'left',
					esc_html__( 'Center', 'smart' ) => 'center',
					esc_html__( 'Right', 'smart' )  => 'right',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( '"Show all" opposite', 'smart' ),
				'param_name'  => 'filter_all_opposite',
				'description' => esc_html__( "Activate this to position the 'Show all' button opposite to the rest.", 'smart' ),
				'std'         => 'yes',
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Filter menu text transform', 'smart' ),
				'param_name'  => 'filtering_text_transform',
				'description' => esc_html__( 'Select the text transformation for these items.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Inherit', 'smart' )    => '',
					esc_html__( 'UPPERCASE', 'smart' )  => 'uppercase',
					esc_html__( 'lowercase', 'smart' )  => 'lowercase',
					esc_html__( 'Capitalize', 'smart' ) => 'capitalize',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Filter menu mobile hidden', 'smart' ),
				'param_name'  => 'filter_mobile_hidden',
				'description' => esc_html__( 'Activate this to hide the filter menu in mobile mode.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Filter scroll', 'smart' ),
				'param_name'  => 'filter_scroll',
				'description' => esc_html__( 'Activate this to scroll to the module when filtering.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Filter vertical padding', 'smart' ),
				'param_name'  => 'filter_padding_v',
				'min'         => 0,
				'max'         => 5,
				'step'        => 1,
				'value'       => 2,
				'std'         => 2,
				'description' => esc_html__( 'Set the vertical padding for the filtering element.', 'smart' ),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Remove gap between filter and grid.', 'smart' ),
				'param_name'  => 'filter_remove_gap',
				'description' => esc_html__( 'Activate this to remove any blank space between the filter and the grid.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Module', 'smart' ),
				'dependency'  => array(
					'element' => 'filtering',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'sorted_list',
				'heading'     => esc_html__( 'Posts', 'smart' ),
				'param_name'  => 'post_items',
				'description' => esc_html__( 'Control teasers look. Enable blocks and place them in desired order.', 'smart' ),
				'value'       => 'media,category|block|text|contrast-skin,title,date|block|text|contrast-skin,text,link|default,separator|full,author|inline-block|contrast-skin,comments|inline-block|icon-text|contrast-skin',
				'group'       => esc_html__( 'Module', 'smart' ),
				'options'     => nice_vc_integration_posts_post_item_options(),
			),
			array(
				'type'        => 'sorted_list',
				'heading'     => esc_html__( 'Pages', 'smart' ),
				'param_name'  => 'page_items',
				'description' => esc_html__( 'Control teasers look. Enable blocks and place them in desired order.', 'smart' ),
				'value'       => 'media,title,text,link|default',
				'group'       => esc_html__( 'Module', 'smart' ),
				'options'     => nice_vc_integration_posts_page_item_options(),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Block layout', 'smart' ),
				'param_name'  => 'single_text',
				'description' => esc_html__( 'Specify the text positioning inside the box.', 'smart' ),
				'value'       => array(
					esc_html__( 'Content under image', 'smart' ) => 'under',
					esc_html__( 'Content overlay', 'smart' )     => 'overlay',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Columns', 'smart' ),
				'param_name'  => 'columns',
				'description' => esc_html__( 'Specify the amount of columns.', 'smart' ),
				'std'         => '4',
				'value'       => array(
					'1'  => '1',
					'2'  => '2',
					'3'  => '3',
					'4'  => '4',
					'5'  => '5',
					'6'  => '6',
					'7'  => '7',
					'8'  => '8',
					'9'  => '9',
					'10' => '10',
					'11' => '11',
					'12' => '12',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Background color', 'smart' ),
				'param_name'         => 'single_back_color',
				'description'        => esc_html__( 'Specify a background color for the box.', 'smart' ),
				'std'                => '',
				'value'              => nice_vc_integration_colors(),
				'param_holder_class' => 'vc_colored-dropdown',
				'group'              => esc_html__( 'Blocks', 'smart' ),
				'dependency'         => array(
					'element' => 'single_text',
					'value'   => array(
						'under',
					),
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Shape', 'smart' ),
				'param_name'  => 'single_shape',
				'std'         => '',
				'value'       => array(
					esc_html__( 'Select...', 'smart' )  => '',
					esc_html__( 'Round', 'smart' )  => 'round',
					esc_html__( 'Circle', 'smart' ) => 'circle',
				),
				'description' => esc_html__( 'Specify one if you want to shape the block.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Content skin', 'smart' ),
				'param_name'  => 'single_skin',
				'std'         => '',
				'description' => esc_html__( 'Specify the skin inside the content box.', 'smart' ),
				'value'       => array(
					esc_html__( 'Inherit', 'smart' ) => '',
					esc_html__( 'Light', 'smart' ) => 'light',
					esc_html__( 'Dark', 'smart' )  => 'dark',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Overlay color', 'smart' ),
				'param_name'         => 'single_overlay_color',
				'description'        => esc_html__( 'Specify a background color for the overlay.', 'smart' ),
				'std'                => '',
				'value'              => nice_vc_integration_colors(),
				'param_holder_class' => 'vc_colored-dropdown',
				'group'              => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Overlay coloration', 'smart' ),
				'param_name'  => 'single_overlay_coloration',
				'description' => sprintf( esc_html__( 'Specify the coloration style for the overlay.%sN.B. For the gradient you can\'t customize the overlay color.', 'smart' ), '<br />' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Fully colored', 'smart' )   => '',
					esc_html__( 'Gradient top', 'smart' )    => 'top_gradient',
					esc_html__( 'Gradient bottom', 'smart' ) => 'bottom_gradient',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Overlay opacity', 'smart' ),
				'param_name'  => 'single_overlay_opacity',
				'min'         => 1,
				'max'         => 100,
				'step'        => 1,
				'value'       => 50,
				'description' => esc_html__( 'Set the overlay opacity.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Overlay text visibility', 'smart' ),
				'param_name'  => 'single_text_visible',
				'description' => esc_html__( 'Activate this to show the text as starting point.', 'smart' ),
				'value'       => array(
					esc_html__( 'Hidden', 'smart' )         => 'no',
					esc_html__( 'Visible', 'smart' )        => 'yes',
					esc_html__( 'Always Hidden', 'smart' )  => 'always_hidden',
					esc_html__( 'Always Visible', 'smart' ) => 'always_visible',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Overlay text animation', 'smart' ),
				'param_name'  => 'single_text_anim',
				'description' => esc_html__( 'Activate this to animate the text on mouse over.', 'smart' ),
				'value'       => array(
					esc_html__( 'Animated', 'smart' ) => 'yes',
					esc_html__( 'Static', 'smart' )   => 'no',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Overlay text animation type', 'smart' ),
				'param_name'  => 'single_text_anim_type',
				'description' => esc_html__( 'Specify the animation type.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Opacity', 'smart' )       => '',
					esc_html__( 'Bottom to top', 'smart' ) => 'btt',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
				'dependency'  => array(
					'element' => 'single_text_anim',
					'value'   => 'yes',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Overlay visibility', 'smart' ),
				'param_name'  => 'single_overlay_visible',
				'description' => esc_html__( 'Activate this to show the overlay as starting point.', 'smart' ),
				'std'         => 'no',
				'value'       => array(
					esc_html__( 'Hidden', 'smart' )  => 'no',
					esc_html__( 'Visible', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Overlay animation', 'smart' ),
				'param_name'  => 'single_overlay_anim',
				'description' => esc_html__( 'Activate this to animate the overlay on mouse over.', 'smart' ),
				'std'         => 'yes',
				'value'       => array(
					esc_html__( 'Animated', 'smart' ) => 'yes',
					esc_html__( 'Static', 'smart' )   => 'no',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image coloration', 'smart' ),
				'param_name'  => 'single_image_coloration',
				'description' => esc_html__( 'Specify the image coloration mode.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Standard', 'smart' )    => '',
					esc_html__( 'Desaturated', 'smart' ) => 'desaturated',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image coloration animation', 'smart' ),
				'param_name'  => 'single_image_color_anim',
				'description' => esc_html__( 'Activate this to animate the image coloration on mouse over.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Static', 'smart' )   => '',
					esc_html__( 'Animated', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image animation', 'smart' ),
				'param_name'  => 'single_image_anim',
				'description' => esc_html__( 'Activate this to animate the image on mouse over.', 'smart' ),
				'std'         => 'yes',
				'value'       => array(
					esc_html__( 'Animated', 'smart' ) => 'yes',
					esc_html__( 'Static', 'smart' )   => 'no',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Text horizontal alignment', 'smart' ),
				'param_name'  => 'single_h_align',
				'description' => esc_html__( 'Specify the horizontal alignment.', 'smart' ),
				'std'         => 'left',
				'value'       => array(
					esc_html__( 'Left', 'smart' )    => 'left',
					esc_html__( 'Center', 'smart' )  => 'center',
					esc_html__( 'Right', 'smart' )   => 'right',
					esc_html__( 'Justify', 'smart' ) => 'justify',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Text horizontal alignment mobile', 'smart' ),
				'param_name'  => 'single_h_align_mobile',
				'description' => esc_html__( 'Specify the horizontal alignment in mobile.', 'smart' ),
				'value'       => array(
					esc_html__( 'Inherit', 'smart' ) => '',
					esc_html__( 'Left', 'smart' )    => 'left',
					esc_html__( 'Center', 'smart' )  => 'center',
					esc_html__( 'Right', 'smart' )   => 'right',
					esc_html__( 'Justify', 'smart' ) => 'justify',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Content vertical position', 'smart' ),
				'param_name'  => 'single_v_position',
				'description' => esc_html__( 'Specify the text vertical position.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Middle', 'smart' ) => '',
					esc_html__( 'Top', 'smart' )    => 'top',
					esc_html__( 'Bottom', 'smart' ) => 'bottom',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
				'dependency'  => array(
					'element' => 'single_text',
					'value'   => 'overlay',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Content dimension reduced', 'smart' ),
				'param_name'  => 'single_reduced',
				'description' => esc_html__( 'Specify the text reduction amount to shrink the overlay content dimension.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( '100%', 'smart' ) => '',
					esc_html__( '75%', 'smart' )  => 'three_quarter',
					esc_html__( '50%', 'smart' )  => 'half',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
				'dependency'  => array(
					'element' => 'single_text',
					'value'   => 'overlay',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Content horizontal position', 'smart' ),
				'param_name'  => 'single_h_position',
				'description' => esc_html__( 'Specify the text horizontal position.', 'smart' ),
				'std'         => 'left',
				'value'       => array(
					esc_html__( 'Left', 'smart' )   => 'left',
					esc_html__( 'Center', 'smart' ) => 'center',
					esc_html__( 'Right', 'smart' )  => 'right',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
				'dependency'  => array(
					'element'   => 'single_reduced',
					'not_empty' => true,
				),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Horizontal padding around text', 'smart' ),
				'param_name'  => 'single_padding_h',
				'min'         => 0,
				'max'         => 5,
				'step'        => 1,
				'value'       => 2,
				'std'         => 2,
				'description' => esc_html__( 'Set the horizontal text padding', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Vertical padding around text', 'smart' ),
				'param_name'  => 'single_padding_v',
				'min'         => 0,
				'max'         => 5,
				'step'        => 1,
				'value'       => 2,
				'std'         => 2,
				'description' => esc_html__( 'Set the vertical text padding', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Reduce space between elements', 'smart' ),
				'param_name'  => 'single_text_reduced',
				'description' => esc_html__( 'Activate this to have less space between all the text elements inside the box.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Multiple click areas', 'smart' ),
				'param_name'  => 'single_elements_click',
				'description' => esc_html__( 'Activate this to make every single elements clickable instead of the whole block (when available).', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
				'dependency'  => array(
					'element' => 'single_text',
					'value'   => 'overlay',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title Font Family', 'smart' ),
				'param_name'  => 'title_font_family',
				'value'       => array(
					esc_html__( 'Inherit', 'smart' ) => '',
					esc_html__( 'Custom', 'smart' )  => 'custom',
				),
				'description' => esc_html__( 'Use the default font family from the theme or pick any other font from Google Fonts.', 'smart' ),
				'std'         => '',
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'google_fonts',
				'param_name'  => 'google_fonts',
				'value'       => 'font_family:ABeeZee|font_style:400%20regular%3A400%3Anormal',
				'settings'    => array(
					'fields' => array(
						'font_family_description' => esc_html__( 'Select font family.', 'smart' ),
						'font_style_description'  => esc_html__( 'Select font styling.', 'smart' ),
					),
				),
				'dependency' => array(
					'element' => 'title_font_family',
					'value'   => 'custom',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title Font Size', 'smart' ),
				'param_name'  => 'single_title_font_size',
				'description' => esc_html__( 'Specify the title text font size.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Default', 'smart' )    => '',
					esc_html__( 'h1', 'smart' )         => 'h1',
					esc_html__( 'h2', 'smart' )         => 'h2',
					esc_html__( 'h3', 'smart' )         => 'h3',
					esc_html__( 'h4', 'smart' )         => 'h4',
					esc_html__( 'h5', 'smart' )         => 'h5',
					esc_html__( 'h6', 'smart' )         => 'h6',
					esc_html__( 'Size 12px', 'smart' )  => 'fontsize-12',
					esc_html__( 'Size 50px', 'smart' )  => 'fontsize-50',
					esc_html__( 'Size 75px', 'smart' )  => 'fontsize-75',
					esc_html__( 'Size 100px', 'smart' ) => 'fontsize-100',
					esc_html__( 'Size 125px', 'smart' ) => 'fontsize-125',
					esc_html__( 'Size 150px', 'smart' ) => 'fontsize-150',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Title text transform', 'smart' ),
				'param_name'  => 'single_title_transform',
				'description' => esc_html__( 'Specify the title text transformation.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Default CSS', 'smart' ) => '',
					esc_html__( 'UPPERCASE', 'smart' )   => 'uppercase',
					esc_html__( 'lowercase', 'smart' )   => 'lowercase',
					esc_html__( 'Capitalize', 'smart' )  => 'capitalize',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Category pills color', 'smart' ),
				'param_name'         => 'single_category_pills_color',
				'description'        => esc_html__( 'Specify a color for your category pills.', 'smart' ),
				'std'                => '',
				'value'              => nice_vc_integration_colors(),
				'group'              => esc_html__( 'Blocks', 'smart' ),
				'param_holder_class' => 'vc_colored-dropdown',
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Category pills shape', 'smart' ),
				'param_name'  => 'single_category_pills_shape',
				'description' => esc_html__( 'Specify the shape for your category pills.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Round', 'smart' )   => 'round',
					esc_html__( 'Circle', 'smart' )  => 'circle',
					esc_html__( 'Square', 'smart' )  => 'square',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Category pills size', 'smart' ),
				'param_name'  => 'single_category_pills_size',
				'description' => esc_html__( 'Specify the size for your category pills.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
				'value'       => array(
					esc_html__( 'Default', 'smart' )     => '',
					esc_html__( 'Small', 'smart' )       => 'sm',
					esc_html__( 'Medium', 'smart' )      => 'md',
					esc_html__( 'Large', 'smart' )       => 'lg',
					esc_html__( 'Extra Large', 'smart' ) => 'xl',
				),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Category pills outlined', 'smart' ),
				'param_name'  => 'single_category_pills_outlined',
				'description' => esc_html__( 'Activate this to have the category pills outlined.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Icon library', 'smart' ),
				'std'         => 'fontawesome',
				'value'       => array(
					esc_html__( 'Font Awesome', 'smart' )  => 'fontawesome',
					esc_html__( 'Open Iconic', 'smart' )   => 'openiconic',
					esc_html__( 'Typicons', 'smart' )      => 'typicons',
					esc_html__( 'Entypo', 'smart' )        => 'entypo',
					esc_html__( 'Linecons', 'smart' )      => 'linecons',
					esc_html__( 'ET Line Icons', 'smart' ) => 'etlineicons',
					esc_html__( 'Linea Icons', 'smart' )   => 'lineaicons',
				),
				'admin_label' => false,
				'param_name'  => 'icon_type',
				'description' => esc_html__( 'Select icon library.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_fontawesome',
				'value'       => '',
				'settings'    => array(
					'emptyIcon'    => true,
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'fontawesome',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'       => 'iconpicker',
				'heading'    => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_openiconic',
				'value'      => '',
				'settings'   => array(
					'emptyIcon'    => true,
					'type'         => 'openiconic',
					'iconsPerPage' => 4000,
				),
				'dependency'  => array(
					'element' => 'icon_type',
					'value'   => 'openiconic',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_typicons',
				'value'       => 'typcn typcn-adjust-brightness',
				'settings'    => array(
					'emptyIcon'    => true,
					'type'         => 'typicons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'typicons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_entypo',
				'value'       => '',
				'settings'    => array(
					'emptyIcon'    => true,
					'type'         => 'entypo',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'entypo',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_linecons',
				'value'       => '',
				'settings'    => array(
					'emptyIcon'    => true,
					'type'         => 'linecons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'linecons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_etlineicons',
				'settings'    => array(
					'emptyIcon' => true,
					'type'      => 'etlineicons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value'   => 'etlineicons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'smart' ),
				'param_name'  => 'icon_lineaicons',
				'value'       => '', // default value to backend editor admin_label
				'settings'    => array(
					'emptyIcon' => false,
					'type'      => 'lineaicons',
					'iconsPerPage' => 4000,
				),
				'dependency' => array(
					'element' => 'type',
					'value'   => 'lineaicons',
				),
				'description' => esc_html__( 'Select icon from library.', 'smart' ),
				'group'       => esc_html__( 'Icon', 'smart' ),
			),
			array(
				/** @since 1.0.3 */
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Custom "read more" text', 'smart' ),
				'param_name'  => 'read_more_text',
				'description' => esc_html__( 'Use this field to change the default text for the "read more" link. Leave it blank if you want to use the default.', 'smart' ),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Shadow', 'smart' ),
				'param_name'  => 'single_shadow',
				'description' => esc_html__( 'Activate this to have the shadow behind the block.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Remove border', 'smart' ),
				'param_name'  => 'single_border',
				'description' => esc_html__( 'Activate this to remove the border around the block.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			nice_vc_integration_add_css_animation( array(
				'param_name' => 'single_css_animation',
				'group'      => esc_html__( 'Blocks', 'smart' ),
			) ),
			nice_vc_integration_add_css_animation_speed( array(
				'param_name' => 'single_css_animation_speed',
				'group'      => esc_html__( 'Blocks', 'smart' ),
				'dependency' => array(
					'element'   => 'single_css_animation',
					'not_empty' => true,
				),
			) ),
			nice_vc_integration_add_css_animation_delay( array(
				'param_name' => 'single_css_animation_delay',
				'group'      => esc_html__( 'Blocks', 'smart' ),
				'dependency' => array(
					'element'   => 'single_css_animation',
					'not_empty' => true,
				),
			) ),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Cascading effect', 'smart' ),
				'param_name'  => 'single_cascading',
				'description' => esc_html__( 'Activate this to trigger the animation with a cascading effect.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'dependency'  => array(
					'element'   => 'single_css_animation',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Cascading effect delay', 'smart' ),
				'param_name'  => 'single_cascading_delay',
				'description' => esc_html__( 'Select delay between elements during cascade (in ms).', 'smart' ),
				'min'         => 50,
				'max'         => 1000,
				'step'        => 1,
				'value'       => 50,
				'std'         => 50,
				'dependency'  => array(
					'element' => 'single_cascading',
					'value'   => 'yes',
				),
				'group'       => esc_html__( 'Blocks', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'smart' ),
				'group'       => esc_html__( 'Extra', 'smart' ),
			),
		),
	);

	foreach ( $posts_options['params'] as $key => $value ) {
		$posts_options['params'][ $key ]['id'] = $value['param_name'];
	}

	return apply_filters( 'nice_vc_integration_posts_options', $posts_options );
}
endif;
