<?php
/**
 * Smart by NiceThemes.
 *
 * Pricing Table
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_pricing_table_map' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_pricing_table_map' );
/**
 * Map the Pricing Table.
 *
 * @since  1.0.0
 *
 */
function nice_vc_integration_pricing_table_map() {
	vc_map( array(
		'name'           => esc_html__( 'Pricing Table', 'smart' ),
		'base'           => 'nice_pricing',
		'icon'           => 'bi_tool-calculator',
		'php_class_name' => 'Nice_VCIntegration_Pricing',
		'category'       => esc_html__( 'Content', 'smart' ),
		'description'    => esc_html__( 'Pricing table', 'smart' ),
		'params'         => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Title', 'smart' ),
				'param_name'  => 'title',
				'description' => esc_html__( 'Insert the price table title.', 'smart' ),
				'value'       => esc_html__( 'Title', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Subtitle', 'smart' ),
				'param_name'  => 'subtitle',
				'description' => esc_html__( 'Insert the price table subtitle.', 'smart' ),
				'value'       => esc_html__( 'Subtitle', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Currency', 'smart' ),
				'param_name'  => 'currency',
				'description' => esc_html__( 'Insert the currency.', 'smart' ),
				'value'       => esc_html__( '$', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Currency Position', 'smart' ),
				'param_name'  => 'currency_position',
				'value'       => array(
					esc_html__( 'Before price', 'smart' )             => 'before',
					esc_html__( 'After price', 'smart' )             => 'after',
				),
				'description' => esc_html__( 'Specify the currency position.', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Price', 'smart' ),
				'param_name'  => 'price',
				'description' => sprintf( esc_html__( 'Insert the price. Use %s as the decimal separator.', 'smart' ), '<code>' . nice_vc_integration_pricing_decimal_separator() . '</code>' ),
				'value'       => esc_html__( '50', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Price Subtitle', 'smart' ),
				'param_name'  => 'price_subtitle',
				'description' => esc_html__( 'Insert the price subtitle.', 'smart' ),
				'value'       => esc_html__( 'per month', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'textarea_safe',
				'heading'     => esc_html__( 'Body', 'smart' ),
				'param_name'  => 'body',
				'description' => esc_html__( 'Insert body text line. Every new line is a block. If you separate with a pipe | the first part will be with bold style.', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'vc_link',
				'heading'     => esc_html__( 'Button', 'smart' ),
				'param_name'  => 'button',
				'description' => esc_html__( 'Insert a link if you want a button.', 'smart' ),
				'group'       => esc_html__( 'Content', 'smart' ),
			),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'Block color', 'smart' ),
				'param_name'  => 'block_color',
				'description' => esc_html__( 'Specify a color for the block.', 'smart' ),
				'value'       => nice_vc_integration_colors(),
				'param_holder_class' => 'vc_colored-dropdown',
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => 'Colored elements',
				'param_name'  => 'col_elements',
				'value'       => array(
					esc_html__( 'Inside elements', 'smart' ) => '',
					esc_html__( 'Top and bottom', 'smart' ) => 'tb',
				),
				'description' => esc_html__( 'Specify how do you want to color the block.', 'smart' ),
				'dependency'  => array(
					'element'   => 'price_color',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Most popular', 'smart' ),
				'param_name'  => 'most',
				'description' => esc_html__( 'Activate this to make the block to stick out, like featured.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Alignment', 'smart' ),
				'param_name'  => 'align',
				'description' => esc_html__( 'Specify the text aligment.', 'smart' ),
				'value'       => array(
					esc_html__( 'Center', 'smart' ) => '',
					esc_html__( 'Left', 'smart' ) => 'left',
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
		),
	) );
}
endif;
