<?php
/**
 * Smart by NiceThemes.
 *
 * Progress bar
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_progress_bar_map' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_progress_bar_map' );
/**
 * Map the progress bar.
 *
 * @since  1.0.0
 */
function nice_vc_integration_progress_bar_map() {

	vc_map( array(
		'name'        => esc_html__( 'Progress Bar', 'smart' ),
		'base'        => 'vc_progress_bar',
		'icon'        => 'bi_web-traffic-b',
		'category'    => esc_html__( 'Content', 'smart' ),
		'description' => esc_html__( 'Animated progress bar', 'smart' ),
		'params'      => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Widget title', 'smart' ),
				'param_name'  => 'title',
				'description' => esc_html__( 'Enter text used as widget title (Note: located above content element).', 'smart' ),
			),
			array(
				'type'        => 'param_group',
				'heading'     => esc_html__( 'Values', 'smart' ),
				'param_name'  => 'values',
				'description' => esc_html__( 'Enter values for graph - value, title and color.', 'smart' ),
				'value'       => urlencode( json_encode( array(
					array(
						'label' => esc_html__( 'Development', 'smart' ),
						'value' => '90',
					),
					array(
						'label' => esc_html__( 'Design', 'smart' ),
						'value' => '80',
					),
					array(
						'label' => esc_html__( 'Marketing', 'smart' ),
						'value' => '70',
					),
				) ) ),
				'params' => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Label', 'smart' ),
						'param_name'  => 'label',
						'description' => esc_html__( 'Enter text used as title of bar.', 'smart' ),
						'admin_label' => true,
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Value', 'smart' ),
						'param_name'  => 'value',
						'description' => esc_html__( 'Enter value of bar.', 'smart' ),
						'admin_label' => true,
					),
					array(
						'type'        => 'dropdown_color',
						'heading'     => esc_html__( 'Color', 'smart' ),
						'param_name'  => 'color',
						'value'       => nice_vc_integration_colors(),
						'description' => esc_html__( 'Select single bar background color.', 'smart' ),
						'admin_label' => true,
						'param_holder_class' => 'vc_colored-dropdown',
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Width', 'smart' ),
						'param_name'  => 'width',
						'description' => esc_html__( 'Enter width of bar. Use px, em or %. An empty value will make it use all the available space.', 'smart' ),
						'admin_label' => true,
					),
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Units', 'smart' ),
				'param_name'  => 'units',
				'description' => esc_html__( 'Enter measurement units (Example: %, px, points, etc. Note: graph value and units will be appended to graph title).', 'smart' ),
			),
			array(
				'type'        => 'dropdown_color',
				'heading'     => esc_html__( 'Color', 'smart' ),
				'param_name'  => 'bgcolor',
				'value'       => nice_vc_integration_colors(),
				'description' => esc_html__( 'Select bar background color.', 'smart' ),
				'admin_label' => true,
				'param_holder_class' => 'vc_colored-dropdown',
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
		),
	) );
}
endif;
