<?php
/**
 * Smart by NiceThemes.
 *
 * Map Inner Row for VC integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_row_inner' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_row_inner' );
/**
 * Map the [vc_row_inner] params.
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_row_inner() {

	vc_map( array(
		'name'            => esc_html__( 'Inner Row', 'smart' ),
		'content_element' => false,
		'is_container'    => true,
		'base'            => 'vc_row_inner',
		'icon'            => 'bi_layout-third-h',
		'weight'          => 1000,
		'show_settings_on_create' => false,
		'description'     => esc_html__( 'Place content elements inside the inner row', 'smart' ),
		'params' => array(
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Row Height', 'smart' ),
				'param_name'  => 'row_height',
				'value'       => 100,
				'min'         => 0,
				'max'         => 100,
				'step'        => 1,
				'weight'      => 10,
				'description' => esc_html__( 'Set the row height (in %)', 'smart' ),
				'group'       => esc_html__( 'Aspect', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Background Color', 'smart' ),
				'param_name'         => 'background_color',
				'value'              => nice_vc_integration_colors(),
				'std'                => '',
				'param_holder_class' => 'vc_colored-dropdown',
				'weight'             => 10,
				'group'              => esc_html__( 'Style', 'smart' ),
				'description'        => esc_html__( 'Select the background color.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Parallax', 'smart' ),
				'param_name'  => 'video_bg_parallax',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( 'Simple', 'smart' ) => 'content-moving',
					esc_html__( 'With fade', 'smart' ) => 'content-moving-fade',
				),
				'description' => esc_html__( 'Add parallax type background for row.', 'smart' ),
				'dependency' => array(
					'element' => 'video_bg',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Parallax', 'smart' ),
				'param_name'  => 'parallax',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( 'Simple', 'smart' ) => 'content-moving',
					esc_html__( 'With fade', 'smart' ) => 'content-moving-fade',
				),
				'description' => esc_html__( 'Add parallax type background for row (Note: If no image is specified, parallax will use background image from Design Options).', 'smart' ),
				'dependency' => array(
					'element' => 'video_bg',
					'is_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Image', 'smart' ),
				'param_name'  => 'parallax_image',
				'value'       => '',
				'description' => esc_html__( 'Select image from media library.', 'smart' ),
				'dependency' => array(
					'element' => 'parallax',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Parallax speed', 'smart' ),
				'param_name'  => 'parallax_speed_video',
				'value'       => '1.5',
				'description' => esc_html__( 'Enter parallax speed ratio (Note: Default value is 1.5, min value is 1)', 'smart' ),
				'dependency' => array(
					'element' => 'video_bg_parallax',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Parallax speed', 'smart' ),
				'param_name'  => 'parallax_speed_bg',
				'value'       => '1.5',
				'description' => esc_html__( 'Enter parallax speed ratio (Note: Default value is 1.5, min value is 1)', 'smart' ),
				'dependency'  => array(
					'element'   => 'parallax',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Overlay Color', 'smart' ),
				'param_name'         => 'overlay_color',
				'value'              => nice_vc_integration_colors(),
				'std'                => '',
				'param_holder_class' => 'vc_colored-dropdown',
				'weight'             => 10,
				'description'        => esc_html__( 'Select overlay color.', 'smart' ),
				'group'              => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Overlay Opacity', 'smart' ),
				'param_name'  => 'overlay_opacity',
				'value'       => 50,
				'min'         => 0,
				'max'         => 100,
				'step'        => 1,
				'weight'      => 10,
				'description' => esc_html__( 'Set the overlay opacity.', 'smart' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Equal height', 'smart' ),
				'param_name'  => 'equal_height',
				'description' => esc_html__( 'If checked columns will be set to equal height.', 'smart' ),
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'group'       => esc_html__( 'Inner Columns', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Content position', 'smart' ),
				'param_name'  => 'content_placement',
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Top', 'smart' ) => 'top',
					esc_html__( 'Middle', 'smart' ) => 'middle',
					esc_html__( 'Bottom', 'smart' ) => 'bottom',
				),
				'description' => esc_html__( 'Select content position within columns.', 'smart' ),
				'group'       => esc_html__( 'Inner Columns', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Columns gap', 'smart' ),
				'param_name'  => 'gap',
				'value'       => array(
					'0px' => '0',
					'1px' => '1',
					'2px' => '2',
					'3px' => '3',
					'4px' => '4',
					'5px' => '5',
					'10px' => '10',
					'15px' => '15',
					'20px' => '20',
					'25px' => '25',
					'30px' => '30',
					'35px' => '35',
				),
				'std' => '0',
				'description' => esc_html__( 'Select gap between columns in row.', 'smart' ),
				'group'       => esc_html__( 'Inner Columns', 'smart' ),
			),
			nice_vc_integration_add_responsive_desktop(),
			nice_vc_integration_add_responsive_tablet(),
			nice_vc_integration_add_responsive_mobile(),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'smart' ),
				'group'       => esc_html__( 'Extra', 'smart' ),
			),
			array(
				'type'        => 'el_id',
				'heading'     => esc_html__( 'Row ID', 'smart' ),
				'param_name'  => 'el_id',
				'description' => sprintf( esc_html__( 'Enter optional row ID. Make sure it is unique, and it is valid as w3c specification: %s (Must not have spaces)', 'smart' ), '<a target="_blank" href="http://www.w3schools.com/tags/att_global_id.asp">' . esc_html__( 'link', 'smart' ) . '</a>' ),
				'group'       => esc_html__( 'Extra', 'smart' ),
			)
		),
		'js_view' => 'VcRowView',
	)
	);

}
endif;

