<?php
/**
 * Smart by NiceThemes.
 *
 * Map [vc_row] for VC integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_row' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_row' );
/**
 * Map the [vc_row] params.
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_row() {

	vc_map( array(
		'name'         => esc_html__( 'Row' , 'smart' ),
		'base'         => 'vc_row',
		'is_container' => true,
		'icon'         => 'bi_layout-third-h',
		'show_settings_on_create' => false,
		'category'     => esc_html__( 'Content', 'smart' ),
		'description'  => esc_html__( 'Place content elements inside the row', 'smart' ),
		'params'       => array(
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Row Width', 'smart' ),
				'param_name'  => 'full_width',
				'value'       => array(
					esc_html__( 'Default', 'smart' )                                              => '',
					esc_html__( 'Stretch row (content width limited to the container)', 'smart' ) => 'stretch_row',
					esc_html__( 'Stretch row and content (content width will be full)', 'smart' ) => 'stretch_row_content',
					esc_html__( 'Stretch row and content (no paddings)', 'smart' )                => 'stretch_row_content_no_spaces',
				),
				'description' => esc_html__( 'Select stretching options for row and content (Note: stretched may not work properly if parent container has "overflow: hidden" CSS property).', 'smart' ),
				'group'       => esc_html__( 'Aspect', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Padding Top', 'smart' ),
				'param_name'  => 'padding_top',
				'std'         => '2x',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( '1x', 'smart' )   => '1x',
					esc_html__( '2x', 'smart' )   => '2x',
					esc_html__( '3x', 'smart' )   => '3x',
					esc_html__( '4x', 'smart' )   => '4x',
					esc_html__( '5x', 'smart' )   => '4x',
					esc_html__( '6x', 'smart' )   => '6x',
				),
				'description' => esc_html__( 'Set the top padding.', 'smart' ),
				'group'       => esc_html__( 'Aspect', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Padding Bottom', 'smart' ),
				'param_name'  => 'padding_bottom',
				'std'         => '2x',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( '1x', 'smart' )   => '1x',
					esc_html__( '2x', 'smart' )   => '2x',
					esc_html__( '3x', 'smart' )   => '3x',
					esc_html__( '4x', 'smart' )   => '4x',
					esc_html__( '5x', 'smart' )   => '4x',
					esc_html__( '6x', 'smart' )   => '6x',
				),
				'description' => esc_html__( 'Set the bottom padding.', 'smart' ),
				'group'       => esc_html__( 'Aspect', 'smart' ),
			),
			array(

				'type'        => 'slide',
				'heading'     => esc_html__( 'Left and Right Padding', 'smart' ),
				'param_name'  => 'padding_horizontal',
				'value'       => 0,
				'min'         => 0,
				'max'         => 6,
				'step'        => 1,
				'description' => esc_html__( 'Set the left and right padding.', 'smart' ),
				'group'       => esc_html__( 'Aspect', 'smart' ),
				'dependency'  => array(
					'element'   => 'full_width',
					'value'     => 'stretch_row_content',
				),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Background Color', 'smart' ),
				'param_name'         => 'background_color',
				'value'              => nice_vc_integration_colors(),
				'std'                => '',
				'param_holder_class' => 'vc_colored-dropdown',
				'weight'             => 10,
				'group'              => esc_html__( 'Style', 'smart' ),
				'description'        => esc_html__( 'Select the background color.', 'smart' ),
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Background Image', 'smart' ),
				'param_name'  => 'background_image',
				'value'       => '',
				'description' => esc_html__( 'Select image from media library.', 'smart' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Repeat', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background repeat. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/cssref/pr_background-repeat.asp' ), '</a>' ),
				'param_name'  => 'background_repeat',
				'value'       => array(
					esc_html__( 'background-repeat', 'smart' ) => '',
					esc_html__( 'No Repeat', 'smart' ) => 'no-repeat',
					esc_html__( 'Repeat All', 'smart' ) => 'repeat',
					esc_html__( 'Repeat Horizontally', 'smart' ) => 'repeat-x',
					esc_html__( 'Repeat Vertically', 'smart' ) => 'repeat-y',
					esc_html__( 'Inherit', 'smart' ) => 'inherit',
				),
				'dependency' => array(
					'element'   => 'parallax',
					'is_empty'  => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Position', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background position. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/cssref/pr_background-position.asp' ), '</a>' ),
				'param_name'  => 'background_position',
				'value'       => array(
					esc_html__( 'background-position', 'smart' ) => '',
					esc_html__( 'Left Top', 'smart' ) => 'left top',
					esc_html__( 'Left Center', 'smart' ) => 'left center',
					esc_html__( 'Left Bottom', 'smart' ) => 'left bottom',
					esc_html__( 'Center Top', 'smart' ) => 'center top',
					esc_html__( 'Center Center', 'smart' ) => 'center center',
					esc_html__( 'Center Bottom', 'smart' ) => 'center bottom',
					esc_html__( 'Right Top', 'smart' ) => 'right top',
					esc_html__( 'Right Center', 'smart' ) => 'right center',
					esc_html__( 'Right Bottom', 'smart' ) => 'right bottom',
				),
				'dependency' => array(
					'element'   => 'parallax',
					'is_empty'  => true,
				),
				'group'      => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Attachment', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background attachment. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/cssref/pr_background-attachment.asp' ), '</a>' ),
				'param_name'  => 'background_attachment',
				'value'       => array(
					esc_html__( 'background-attachement', 'smart' ) => '',
					esc_html__( 'Fixed', 'smart' ) => 'fixed',
					esc_html__( 'Scroll', 'smart' ) => 'scroll',
					esc_html__( 'Inherit', 'smart' ) => 'inherit',
				),
				'dependency' => array(
					'element'   => 'parallax',
					'is_empty'  => true,
				),
				'group' => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Background Size', 'smart' ),
				'description' => sprintf( esc_html__( 'Define the background size. %1$sCheck this for reference%2$s', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'https://www.w3schools.com/cssref/css3_pr_background-size.asp' ), '</a>' ),
				'param_name'  => 'background_size',
				'value'       => array(
					esc_html__( 'background-size', 'smart' ) => '',
					esc_html__( 'Auto', 'smart' ) => 'auto',
					esc_html__( 'Cover', 'smart' ) => 'cover',
					esc_html__( 'Contain', 'smart' ) => 'contain',
					esc_html__( 'Initial', 'smart' ) => 'initial',
					esc_html__( 'Inherit', 'smart' ) => 'inherit',
				),
				'dependency' => array(
					'element'   => 'parallax',
					'is_empty'  => true,
				),
				'group'      => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Parallax', 'smart' ),
				'param_name'  => 'parallax',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( 'Simple', 'smart' ) => 'content-moving',
					esc_html__( 'With fade', 'smart' ) => 'content-moving-fade',
				),
				'description' => esc_html__( 'Add parallax type background for row (Note: It will use the background image)', 'smart' ),
				'dependency' => array(
					'element' => 'background_image',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Parallax speed', 'smart' ),
				'param_name'  => 'parallax_speed_bg',
				'value'       => '1.5',
				'description' => esc_html__( 'Enter parallax speed ratio (Note: Default value is 1.5, min value is 1)', 'smart' ),
				'dependency'  => array(
					'element'   => 'parallax',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Use video background?', 'smart' ),
				'param_name'  => 'video_bg',
				'description' => esc_html__( 'If checked, video will be used as row background.', 'smart' ),
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Video background (webm) file URL', 'smart' ),
				'param_name'  => 'video_webm',
				'value'       => '',
				'weight'      => 1,
				'group'       => esc_html__( 'Style', 'smart' ),
				'description' => esc_html__( 'Add the video URL.', 'smart' ),
				'dependency'  => array(
					'element'   => 'video_bg',
					'not_empty' => true,
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Video background (mp4) file URL', 'smart' ),
				'param_name'  => 'video_mp4',
				'value'       => '',
				'weight'      => 1,
				'group'       => esc_html__( 'Style', 'smart' ),
				'description' => esc_html__( 'Add the video URL.', 'smart' ),
				'dependency'  => array(
					'element'   => 'video_bg',
					'not_empty' => true,
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Video background (ogv) file URL', 'smart' ),
				'param_name'  => 'video_ogv',
				'value'       => '',
				'weight'      => 1,
				'group'       => esc_html__( 'Style', 'smart' ),
				'description' => esc_html__( 'Add the video URL.', 'smart' ),
				'dependency'  => array(
					'element'   => 'video_bg',
					'not_empty' => true,
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Parallax', 'smart' ),
				'param_name'  => 'video_bg_parallax',
				'value'       => array(
					esc_html__( 'None', 'smart' ) => '',
					esc_html__( 'Simple', 'smart' ) => 'content-moving',
					esc_html__( 'With fade', 'smart' ) => 'content-moving-fade',
				),
				'description' => esc_html__( 'Add parallax type background for row.', 'smart' ),
				'dependency' => array(
					'element' => 'video_bg',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Parallax speed', 'smart' ),
				'param_name'  => 'parallax_speed_video',
				'value'       => '1.5',
				'description' => esc_html__( 'Enter parallax speed ratio (Note: Default value is 1.5, min value is 1)', 'smart' ),
				'dependency' => array(
					'element' => 'video_bg_parallax',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Style', 'smart' ),
			),

			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Overlay Color', 'smart' ),
				'param_name'         => 'overlay_color',
				'value'              => nice_vc_integration_colors(),
				'std'                => '',
				'param_holder_class' => 'vc_colored-dropdown',
				'weight'             => 10,
				'description'        => esc_html__( 'Select overlay color.', 'smart' ),
				'group'              => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Overlay Opacity', 'smart' ),
				'param_name'  => 'overlay_opacity',
				'value'       => 50,
				'min'         => 0,
				'max'         => 100,
				'step'        => 1,
				'weight'      => 10,
				'description' => esc_html__( 'Set the overlay opacity.', 'smart' ),
				'group'       => esc_html__( 'Style', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Columns gap', 'smart' ),
				'param_name'  => 'gap',
				'value'       => array(
					'0px' => '0',
					'1px' => '1',
					'2px' => '2',
					'3px' => '3',
					'4px' => '4',
					'5px' => '5',
					'10px' => '10',
					'15px' => '15',
					'20px' => '20',
					'25px' => '25',
					'30px' => '30',
					'35px' => '35',
				),
				'std'         => '0',
				'description' => esc_html__( 'Select gap between columns in row.', 'smart' ),
				'group'       => esc_html__( 'Inner Columns', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Full height row?', 'smart' ),
				'param_name'  => 'full_height',
				'description' => esc_html__( 'If checked row will be set to full height.', 'smart' ),
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'group'       => esc_html__( 'Inner Columns', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Columns position', 'smart' ),
				'param_name'  => 'columns_placement',
				'value'       => array(
					esc_html__( 'Middle', 'smart' ) => 'middle',
					esc_html__( 'Top', 'smart' ) => 'top',
					esc_html__( 'Bottom', 'smart' ) => 'bottom',
					esc_html__( 'Stretch', 'smart' ) => 'stretch',
				),
				'description' => esc_html__( 'Select columns position within row.', 'smart' ),
				'dependency' => array(
					'element' => 'full_height',
					'not_empty' => true,
				),
				'group'       => esc_html__( 'Inner Columns', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Equal height', 'smart' ),
				'param_name'  => 'equal_height',
				'description' => esc_html__( 'If checked columns will be set to equal height.', 'smart' ),
				'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
				'group'       => esc_html__( 'Inner Columns', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Content position', 'smart' ),
				'param_name'  => 'content_placement',
				'value'       => array(
					esc_html__( 'Default', 'smart' ) => '',
					esc_html__( 'Top', 'smart' ) => 'top',
					esc_html__( 'Middle', 'smart' ) => 'middle',
					esc_html__( 'Bottom', 'smart' ) => 'bottom',
				),
				'description' => esc_html__( 'Select content position within columns.', 'smart' ),
				'group'       => esc_html__( 'Inner Columns', 'smart' ),
			),
			array(
				'type'        => 'slide',
				'heading'     => esc_html__( 'Shift y-axis', 'smart' ),
				'param_name'  => 'shift_y',
				'min'         => -5,
				'max'         => 5,
				'step'        => 1,
				'value'       => 0,
				'description' => esc_html__( 'Set how much the element has to shift in the Y axis.', 'smart' ),
				'group'       => esc_html__( 'Off-grid', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Shift y-axis fixed', 'smart' ),
				'param_name'  => 'shift_y_fixed',
				'description' => esc_html__( 'Deactive shift-y responsiveness.', 'smart' ),
				'group'       => esc_html__( 'Off-grid', 'smart' ),
				'value'       => array(
					'' => 'yes',
				),
			),
			nice_vc_integration_add_responsive_desktop(),
			nice_vc_integration_add_responsive_tablet(),
			nice_vc_integration_add_responsive_mobile(),
			array(
				'type'        => 'el_id',
				'heading'     => esc_html__( 'Row ID', 'smart' ),
				'param_name'  => 'el_id',
				'description' => sprintf( esc_html__( 'Enter row ID (Note: make sure it is unique and valid according to %1$sw3c specification%2$s).', 'smart' ), sprintf( '<a href="%s" target="_blank">', 'http://www.w3schools.com/tags/att_global_id.asp' ), '</a>' ),
				'group'       => esc_html__( 'Extra', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'smart' ),
				'group'       => esc_html__( 'Extra', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Section name', 'smart' ),
				'param_name'  => 'row_name',
				'value'       => '',
				'group'       => esc_html__( 'Extra', 'smart' ),
				'description' => esc_html__( 'Required for the one-page scroll, this gives the name to the section.', 'smart' ),
			),
			array(
				'type'        => 'css_editor',
				'heading'     => esc_html__( 'CSS box', 'smart' ),
				'param_name'  => 'css',
				'group'       => esc_html__( 'Custom', 'smart' ),
			),
		),
		'js_view' => 'VcRowView',
	) );
}
endif;
