<?php
/**
 * Smart by NiceThemes.
 *
 * Tabs
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_tabs' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_tabs', 100 );
/**
 * Map tabs for VC integration.
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_tabs() {
	vc_map( array(
		'name'                    => esc_html__( 'Tabs', 'smart' ),
		'base'                    => 'vc_tabs',
		'show_settings_on_create' => false,
		'is_container'            => true,
		'icon'                    => 'bi_doc-folder-a',
		'category'                => esc_html__( 'Content', 'smart' ),
		'description'             => esc_html__( 'Tabbed contents', 'smart' ),
		'params'                  => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Widget title', 'smart' ),
				'param_name'  => 'title',
				'description' => esc_html__( 'Enter text which will be used as widget title. Leave blank if no title is needed.', 'smart' ),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'smart' ),
			),
		),
		'custom_markup'           => _nice_vc_integration_tabs_custom_markup(),
		'default_content'         => _nice_vc_integration_tabs_default_content(),
		'js_view'                 => 'VcTabsView',
	) );

	vc_map( array(
		'name'                      => esc_html__( 'Tab', 'smart' ),
		'base'                      => 'vc_tab',
		'allowed_container_element' => 'vc_row',
		'is_container'              => true,
		'content_element'           => false,
		'params'                    => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Title', 'smart' ),
				'param_name'  => 'title',
				'description' => esc_html__( 'Tab title.', 'smart' ),
			),
			array(
				'type'        => 'tab_id',
				'heading'     => esc_html__( 'Tab ID', 'smart' ),
				'param_name'  => 'tab_id',
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Remove top margin', 'smart' ),
				'param_name'  => 'no_margin',
				'description' => esc_html__( 'Activate this to remove the top margin.', 'smart' ),
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
			),
		),
		'js_view'                   => 'VcTabView',
	) );

}
endif;

if ( ! function_exists( '_nice_vc_integration_tabs_custom_markup' ) ) :
/**
 * Custom markup for tab integration.
 *
 * @since 1.0.0
 */
function _nice_vc_integration_tabs_custom_markup() {
	ob_start();
?>
	<div class="wpb_tabs_holder wpb_holder vc_container_for_children">
		<ul class="tabs_controls">
		</ul>
		%content%
	</div>
<?php
	$content = ob_get_contents();
	ob_end_clean();

	return $content;
}
endif;

if ( ! function_exists( '_nice_vc_integration_tabs_default_content' ) ) :
/**
 * Custom markup for tab integration.
 *
 * @since 1.0.0
 */
function _nice_vc_integration_tabs_default_content() {
	$tab_id_1 = time() . '-1-' . rand( 0, 100 );
	$tab_id_2 = time() . '-2-' . rand( 0, 100 );

	ob_start();
?>
	[vc_tab title="<?php esc_html_e( 'Tab 1', 'smart' ); ?>"][/vc_tab]
	[vc_tab title="<?php esc_html_e( 'Tab 2', 'smart' ); ?>"][/vc_tab]
<?php
	$content = ob_get_contents();
	ob_end_clean();

	return $content;
}
endif;
