<?php
/**
 * Smart by NiceThemes.
 *
 * Video Lightbox for VC integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_map_video_lightbox' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_video_lightbox' );
/**
 * nice_video_lightbox
 *
 * @since  1.0.0
 */
function nice_vc_integration_map_video_lightbox() {
	vc_map( array(
		'name'           => esc_html__( 'Video Lightbox', 'smart' ),
		'base'           => 'nice_video_lightbox',
		'php_class_name' => 'Nice_VCIntegration_Video_Lightbox',
		'icon'           => 'bi_music-play',
		'category'       => esc_html__( 'Content', 'smart' ),
		'description'    => esc_html__( 'Add a Video Lightbox link', 'smart' ),
		'params'         => array(
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Link Style', 'smart' ),
				'param_name'  => 'link_style',
				'value'       => array(
					esc_html__( 'Play Button', 'smart' )                    => 'play_button',
					esc_html__( 'Play Button With Preview Image', 'smart' ) => 'play_button_image',
				),
				'description' => esc_html__( 'Select if you want to have the play button with an image or without it.', 'smart' ),
			),
			array(
				'type'               => 'dropdown_color',
				'heading'            => esc_html__( 'Play Button Color', 'smart' ),
				'param_name'         => 'play_button_color',
				'description'        => esc_html__( 'Specify a color for the play button.', 'smart' ),
				'std'                => '',
				'value'              => nice_vc_integration_colors(),
				'param_holder_class' => 'vc_colored-dropdown',
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Play Button Size', 'smart' ),
				'param_name'  => 'play_button_size',
				'std'         => 'md',
				'value'       => array(
					esc_html__( 'Default', 'smart' )     => '',
					esc_html__( 'Small', 'smart' )       => 'sm',
					esc_html__( 'Medium', 'smart' )      => 'md',
					esc_html__( 'Large', 'smart' )       => 'lg',
					esc_html__( 'Extra Large', 'smart' ) => 'xl',
				),
				'description' => esc_html__( 'Select the play button size.', 'smart' ),
			),
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Play button outlined', 'smart' ),
				'param_name'  => 'play_button_outlined',
				'description' => esc_html__( 'Activate this to the have the play button outlined.', 'smart' ),
				'std'         => '',
				'value'       => array(
					esc_html__( 'Yes, please', 'smart' ) => 'yes',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Play Button Animation', 'smart' ),
				'param_name'  => 'play_button_animation',
				'value'       => array(
					esc_html__( 'Default', 'smart' )   => '',
					esc_html__( 'Zoom In', 'smart' )  => 'zoomIn',
					esc_html__( 'Zoom Out', 'smart' ) => 'zoomOut',
				),
				'description' => esc_html__( 'Select animation when hovered.', 'smart' ),
			),
			array(
				'type'        => 'href',
				'heading'     => esc_html__( 'Video URL', 'smart' ),
				'param_name'  => 'link',
				'description' => esc_html__( 'The URL to your video on Youtube or Vimeo e.g. (eg: https://www.youtube.com/watch?v=1zPYW6Ipgok).', 'smart' ),
			),
			array(
				'type'        => 'attach_image',
				'heading'     => esc_html__( 'Image', 'smart' ),
				'param_name'  => 'image',
				'value'       => '',
				'description' => esc_html__( 'Select image from media library.', 'smart' ),
				'dependency'  => array(
					'element' => 'link_style',
					'value'   => 'play_button_image',
				),
			),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Image size', 'smart' ),
				'param_name'  => 'img_size',
				'value'       => 'thumbnail',
				'description' => esc_html__( 'Enter image size (Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels (Example: 200x100 (Width x Height)).', 'smart' ),
				'dependency'  => array(
					'element' => 'link_style',
					'value'   => 'play_button_image',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Image animation', 'smart' ),
				'param_name'  => 'img_animation',
				'value'       => array(
					esc_html__( 'Static', 'smart' )   => '',
					esc_html__( 'Zoom In', 'smart' ) => 'zoomIn',
				),
				'description' => esc_html__( 'Select image animation.', 'smart' ),
				'dependency'  => array(
					'element' => 'link_style',
					'value'   => 'play_button_image',
				),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Alignment', 'smart' ),
				'param_name'  => 'alignment',
				'value'       => array(
					esc_html__( 'Left', 'smart' )   => 'left',
					esc_html__( 'Right', 'smart' )  => 'right',
					esc_html__( 'Center', 'smart' ) => 'center',
				),
				'description' => esc_html__( 'Select video and play button alignment within the block.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Shadow', 'smart' ),
				'param_name'  => 'shadow',
				'value'       => array(
					esc_html__( 'None', 'smart' )        => 'none',
					esc_html__( 'Small', 'smart' )       => 'sm',
					esc_html__( 'Medium', 'smart' )      => 'md',
					esc_html__( 'Large', 'smart' )       => 'lg',
					esc_html__( 'Extra Large', 'smart' ) => 'xl',
				),
				'description' => esc_html__( 'Select if you want to apply shadow.', 'smart' ),
				'dependency'  => array(
					'element' => 'link_style',
					'value'   => 'play_button_image',
				),
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Extra class name', 'smart' ),
				'param_name'  => 'el_class',
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'smart' ),
			),
			array(
				'type'       => 'css_editor',
				'heading'    => esc_html__( 'CSS box', 'smart' ),
				'param_name' => 'css',
				'group'      => esc_html__( 'Design Options', 'smart' ),
			),
		),
	) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_video_lightbox_url' ) ) :
/**
 * Obtain link for video lightbox.
 *
 * @since 1.0.0
 *
 * @param  string $origin_url
 *
 * @return string
 */
function nice_vc_integration_video_lightbox_url( $origin_url ) {
	$url = $origin_url;
	$url_parts = wp_parse_url( $origin_url );

	if ( in_array( $url_parts['host'], array( 'youtube.com', 'www.youtube.com' ), true ) && '/watch' === $url_parts['path'] && isset( $url_parts['query'] ) ) {
		parse_str( $url_parts['query'], $query );

		if ( ! empty( $query['v'] )  ) {
			$url = '//youtube.com/embed/' . urldecode( $query['v'] );
		}
	} elseif ( in_array( $url_parts['host'], array( 'vimeo.com', 'www.vimeo.com' ), true ) ) {
		$url = '//player.vimeo.com/video' . urldecode( $url_parts['path'] );
	}

	return $url;
}
endif;
