<?php
/**
 * Smart by NiceThemes.
 *
 * Remove default components we don't need for this integration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_remove_default_components' ) ) :
// Hook for admin editor.
add_action( 'vc_build_admin_page', 'nice_vc_remove_default_components' );
// Hook for frontend editor.
add_action( 'vc_load_shortcode', 'nice_vc_remove_default_components' );
/**
 * Remove default components we don't want.
 *
 * @since 1.0.0
 */
function nice_vc_remove_default_components() {
	$elements_list = array(
		'vc_tta_accordion',
		'vc_tta_tour',
		'vc_tta_tabs',
		'vc_tta_pageable',
		'vc_round_chart',
		'vc_line_chart',
		'vc_text_separator',
		'vc_facebook',
		'vc_flickr',
		'vc_tweetmeme',
		'vc_googleplus',
		'vc_pinterest',
		'vc_toggle',
		'vc_images_carousel',
		'vc_tour',
		'vc_teaser_grid',
		'vc_posts_grid',
		'vc_carousel',
		'vc_posts_slider',
		'vc_btn',
		'vc_button2',
		'vc_cta',
		'vc_cta_button',
		'vc_cta_button2',
		'vc_video',
		'vc_basic_grid',
		'vc_media_grid',
		'vc_masonry_grid',
		'vc_masonry_media_grid',
		'vc_wp_meta',
		'vc_wp_rss',
		'vc_wp_search',
		'vc_wp_pages',
		'vc_wp_posts',
		'vc_wp_text',
		'vc_wp_recentcomments',
		'vc_widget_sidebar',
		'vc_wp_archives',
		'vc_wp_calendar',
		'vc_wp_categories',
		'vc_wp_custommenu',
		'vc_wp_links',
		'vc_wp_tagcloud',
		'vc_hoverbox',
		'vc_zigzag',
	);

	$elements = array();

	foreach ( $elements_list as $item ) {
		$elements[ $item ] = true;
	}

	/**
	 * @hook nice_vc_integration_remove_elements
	 *
	 * Hook in here to edit the elements to be removed from VC.
	 *
	 * @since 1.0.2
	 */
	$elements = apply_filters( 'nice_vc_integration_remove_elements', $elements );

	foreach ( $elements as $k => $v ) {
		if ( $v ) {
			vc_remove_element( $k );
		}
	}
}
endif;


if ( ! function_exists( 'nice_vc_remove_woocommerce' ) ) :
// Hook for admin editor.
add_action( 'vc_build_admin_page', 'nice_vc_remove_woocommerce', 11 );
// Hook for frontend editor.
add_action( 'vc_load_shortcode', 'nice_vc_remove_woocommerce', 11 );
/**
 * Remove components for WooCommerce we don't want.
 *
 * @since 1.0.0
 */
function nice_vc_remove_woocommerce() {
	if ( ! class_exists( 'WooCommerce' ) ) {
		return;
	}

	// If WooCommerce is active.
	$elements_list = array(
		'woocommerce_cart',
		'woocommerce_checkout',
		'woocommerce_order_tracking',
		'woocommerce_my_account',
		'recent_products',
		'featured_products',
		'product',
		'products',
		'add_to_cart',
		'add_to_cart_url',
		'product_page',
		'product_category',
		'product_categories',
		'sale_products',
		'best_selling_products',
		'top_rated_products',
		'product_attribute',
		'related_products',
	);

	$elements = array();

	foreach ( $elements_list as $item ) {
		$elements[ $item ] = true;
	}

	/**
	 * @hook nice_vc_integration_remove_woocommerce_elements
	 *
	 * Hook in here to edit the WC elements to be removed from VC.
	 *
	 * @since 1.0.2
	 */
	$elements = apply_filters( 'nice_vc_integration_remove_woocommerce_elements', $elements );

	foreach ( $elements as $k => $v ) {
		if ( $v ) {
			vc_remove_element( $k );
		}
	}
}
endif;

