<?php
/**
 * Smart by NiceThemes.
 *
 * Nice Posts functions
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_posts_current_shortcode' ) ) :
/**
 * Obtain object related to current shortcode being processed.
 *
 * @since  1.0.0
 *
 * @param  Nice_VCIntegration_Posts_Shortcode $shortcode
 *
 * @return Nice_VCIntegration_Posts_Shortcode
 */
function nice_vc_integration_posts_current_shortcode( Nice_VCIntegration_Posts_Shortcode $shortcode = null ) {
	static $current = null;

	if ( $shortcode ) {
		$current = $shortcode;
	}

	return $current;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_shortcode_collection' ) ) :
/**
 * Create a collection of all processes VC Posts shortcodes.
 *
 * @since  1.0.0
 *
 * @param  Nice_VCIntegration_Posts_Shortcode $shortcode
 *
 * @return array
 */
function nice_vc_integration_posts_shortcode_collection( Nice_VCIntegration_Posts_Shortcode $shortcode = null ) {
	static $shortcodes = array();

	if ( $shortcode && $element_id = $shortcode->attr( 'el_id' ) ) {
		$loop_args        = $shortcode->get_loop_args();
		$queried_terms    = isset( $loop_args['tax_query'][0]['terms'] ) ? $loop_args['tax_query'][0]['terms'] : array();

		$shortcodes[ $element_id ] = $shortcode->get_atts();
		$shortcodes[ $element_id ]['category'] = esc_attr( join( ',', $queried_terms ) );
		$shortcodes[ $element_id ]['origin_id'] = get_the_ID();
	}

	return $shortcodes;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_element_id' ) ) :
/**
 * Print the HTML ID for the current VC Posts widget.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_element_id() {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	echo 'id="' . esc_attr( $shortcode->attr( 'el_id' ) ) . '"';
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_element_class' ) ) :
/**
 * Print classes for the current VC Posts widget.
 *
 * @since 1.0.0
 *
 * @param mixed|string|array
 */
function nice_vc_integration_posts_element_class( $class = null ) {
	nice_css_classes( nice_vc_integration_get_posts_element_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_element_class' ) ) :
/**
 * Obtain a list of classes for the posts container.
 *
 * @since  1.0.0
 *
 * @param  mixed|string|array $custom_class
 *
 * @return array
 */
function nice_vc_integration_get_posts_element_class( $custom_class = null ) {
	$class = array(
		'nice-vc-posts-element',
	);

	// Add classes from function argument.
	if ( ! empty( $custom_class ) ) {
		if ( ! is_array( $custom_class ) ) {
			$custom_class = preg_split( '#\s+#', $custom_class );
		}

		$class = array_merge( $class, $custom_class );
	}

	$class = array_map( 'esc_attr', $class );

	return apply_filters( 'nice_vc_integration_posts_element_class', $class );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_grid_class' ) ) :
/**
 * Print classes for the posts container.
 *
 * @since 1.0.0
 *
 * @param mixed|string|array
 */
function nice_vc_integration_posts_grid_class( $class = null ) {
	nice_css_classes( nice_vc_integration_get_posts_grid_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_grid_class' ) ) :
/**
 * Obtain a list of classes for the posts container.
 *
 * @since  1.0.0
 *
 * @param  mixed|string|array $custom_class
 *
 * @return array
 */
function nice_vc_integration_get_posts_grid_class( $custom_class = null ) {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	$class = array(
		'nice-vc-posts-element-content',
		'grid',
	);

	if ( 'isotope' === $shortcode->attr( 'index_type' ) ) {
		$class[] = 'isotope-grid';
		$class[] = 'js-resize';
	}

	// Add gutter class.
	if ( $shortcode->attr( 'style_preset' ) ) {
		array_push( $class, nice_vc_integration_posts_isotope_gutter_size( $shortcode->attr( 'gutter_size', 0 ) ) );
	} else {
		$horizontal_gutter = $shortcode->attr( 'gutter_size_h', 0 );
		$vertical_gutter = $shortcode->attr( 'gutter_size_v', 0 );

		if ( 'default' === $vertical_gutter ) {
			$vertical_gutter = $horizontal_gutter;
		}

		array_push( $class, nice_vc_integration_posts_isotope_gutter_size( $horizontal_gutter ) . '-h' );
		array_push( $class, nice_vc_integration_posts_isotope_gutter_size( $vertical_gutter ) . '-v' );
	}

	// Add index type class.
	if ( $module = $shortcode->attr( 'index_type', '' ) ) {
		array_push( $class, 'module-' . $module );
	}

	// Add style class.
	if ( $style = $shortcode->attr( 'style_preset', 'default' ) ) {
		array_push( $class, 'style-' . $style );
	}

	// Add filtering class.
	if ( 'yes' === $shortcode->attr( 'filtering', '' ) ) {
		array_push( $class, 'filterable' );
	}

	// Add extra classes from user-input.
	if ( $extra_classes = $shortcode->attr( 'el_class', '' ) ) {
		array_push( $class, $extra_classes );
	}

	// Add classes from function argument.
	if ( ! empty( $custom_class ) ) {
		if ( ! is_array( $custom_class ) ) {
			$custom_class = preg_split( '#\s+#', $custom_class );
		}

		$class = array_merge( $class, $custom_class );
	}

	$class = array_map( 'esc_attr', $class );

	return apply_filters( 'nice_vc_integration_posts_grid_class', $class );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_container_class' ) ) :
/**
 * Print classes for the posts container inner.
 *
 * @since 1.0.0
 *
 * @param mixed|string|array
 */
function nice_vc_integration_posts_container_class( $class = null ) {
	nice_css_classes( nice_vc_integration_get_posts_container_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_container_class' ) ) :
/**
 * Obtain a list of classes for the posts container inner.
 *
 * @since  1.0.0
 *
 * @param  mixed|string|array $custom_class
 *
 * @return array
 */
function nice_vc_integration_get_posts_container_class( $custom_class = null ) {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	$class = array(
		'nice-vc-posts-container',
	);

	// Add background color class.
	if ( $background_color = $shortcode->attr( 'index_back_color' ) ) {
		array_push( $class, nice_theme_color_background_class( $background_color ) );
	}

	if ( 'yes' === $shortcode->attr( 'disable_fluid_grid' ) ) {
		array_push( $class, 'grid-pad-fixed' );
	} else {
		array_push( $class, 'grid-pad-fluid' );
	}

	// Add gutter class.
	if ( $shortcode->attr( 'style_preset' ) ) {
		array_push( $class, nice_vc_integration_posts_isotope_gutter_size( $shortcode->attr( 'gutter_size', 0 ) ) );
	} else {
		$horizontal_gutter = $shortcode->attr( 'gutter_size_h', 0 );
		$vertical_gutter = $shortcode->attr( 'gutter_size_v', 0 );

		if ( 'default' === $vertical_gutter ) {
			$vertical_gutter = $horizontal_gutter;
		}

		array_push( $class, nice_vc_integration_posts_isotope_gutter_size( $horizontal_gutter ) . '-h' );
		array_push( $class, nice_vc_integration_posts_isotope_gutter_size( $vertical_gutter ) . '-v' );
	}

	// Add classes from function argument.
	if ( ! empty( $custom_class ) ) {
		if ( ! is_array( $custom_class ) ) {
			$custom_class = preg_split( '#\s+#', $custom_class );
		}

		$class = array_merge( $class, $custom_class );
	}

	$class = array_map( 'esc_attr', $class );

	return apply_filters( 'nice_vc_integration_posts_container_class', $class );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_class' ) ) :
/**
 * Print classes for the current item.
 *
 * @since 1.0.0
 *
 * @param mixed|string|array
 */
function nice_vc_integration_posts_item_class( $class = null ) {
	nice_css_classes( nice_vc_integration_get_posts_item_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_item_class' ) ) :
/**
 * Obtain a list of classes for the current item.
 *
 * @since  1.0.0
 *
 * @param  mixed|string|array $custom_class
 *
 * @return array
 */
function nice_vc_integration_get_posts_item_class( $custom_class = null ) {
	$item      = nice_vc_integration_posts_current_item();
	$shortcode = $item->shortcode;

	$class = array(
		'item',
		'type-' . $item->post_type,
		$item->post_type . '-' . $item->post_id,
	);

	// Add class for post format.
	if ( 'post' !== esc_attr( $item->post_type ) ) {
		array_push( $class, esc_attr( $item->post_format ) );
	}

	// Add class for columns.
	if ( $columns = $shortcode->attr( 'columns', 1 ) ) {
		array_push( $class, 'columns-' . $columns );
	}

	// Add class for thumb.
	array_push( $class, $item->thumbnail_id ? 'thumb' : 'no-caption' );

	// Add class for overlay.
	if ( 'overlay' === $shortcode->attr( 'single_text' ) ) {
		array_push( $class, 'text-overlay' );

		// Add class for visible text.
		$single_text_visible = $shortcode->attr( 'single_text_visible' );

		switch ( $single_text_visible ) {
			case 'yes':
				array_push( $class, 'text-visible' );
				break;
			case 'always_visible':
				array_push( $class, 'text-always-visible' );
				break;
			case 'always_hidden':
				array_push( $class, 'text-always-hidden' );
				break;
			default:
				array_push( $class, 'text-hidden' );
				break;
		}

		// Add class for text animation.
		if ( 'yes' === $shortcode->attr( 'single_text_anim', 'yes' ) ) {
			array_push( $class, 'text-animated' );

			if ( $text_animation_type = $shortcode->attr( 'single_text_anim_type' ) ) {
				array_push( $class, 'text-animation-' . $text_animation_type );
			}
		}

		// Add class for reduced block.
		if ( $single_reduced = $shortcode->attr( 'single_reduced' ) ) {
			array_push( $class, 'item-reduced-' . $single_reduced );

			// Add class for horizontal position.
			if ( $h_position = $shortcode->attr( 'single_h_position', 'left' ) ) {
				array_push( $class, 'horizontal-position-' . $h_position );
			}
		}
	}

	// Add class for item height.
	if ( ! $shortcode->attr( 'style_preset' ) && $media_height = $shortcode->attr( 'media_height' ) ) {
		array_push( $class, 'item-' . esc_attr( $media_height ) );
	}

	// Add class for content padding.
	if ( 'yes' === $shortcode->attr( 'single_text_reduced' ) ) {
		array_push( $class, 'item-text-padding-reduced' );
	}

	// Add class for multiple click.
	if ( 'overlay' !== $shortcode->attr( 'single_text' ) || 'yes' === $shortcode->attr( 'single_elements_click' ) ) {
		array_push( $class, 'multiple-click' );
	}

	// Add class for shape.
	if ( $shape = $shortcode->attr( 'single_shape' ) ) {
		array_push( $class, 'shape-' . $shape );
	}

	// Add class for style.
	if ( $skin = $shortcode->attr( 'single_skin' ) ) {
		array_push( $class, $skin );
	}

	// Add class for internal horizontal padding.
	array_push( $class, 'content-padding-h-' . intval( $shortcode->attr( 'single_padding_h', 0 ) ) . 'x' );

	// Add class for internal vertical padding.
	array_push( $class, 'content-padding-v-' . intval( $shortcode->attr( 'single_padding_v', 0 ) ) . 'x' );

	// Add class for visible overlay.
	if ( 'yes' === $shortcode->attr( 'single_overlay_visible' ) ) {
		array_push( $class, 'overlay-visible' );
	}

	// Add class for visible animation.
	if ( 'yes' === $shortcode->attr( 'single_overlay_anim' ) ) {
		array_push( $class, 'overlay-animated' );
	}

	// Add class for image coloration.
	if ( $image_coloration = $shortcode->attr( 'single_image_coloration' ) ) {
		array_push( $class, 'image-coloration-' . $image_coloration );
	}

	// Add class for image color animation.
	if ( 'yes' === $shortcode->attr( 'single_image_color_anim' ) ) {
		array_push( $class, 'image-coloration-animated' );
	}

	// Add class for image animation.
	if ( 'yes' === $shortcode->attr( 'single_image_anim', 'yes' ) ) {
		array_push( $class, 'image-animated' );
	}

	// Add class for horizontal alignment.
	if ( $h_alignment = $shortcode->attr( 'single_h_align', 'left' ) ) {
		array_push( $class, 'text-' . $h_alignment );
	}

	// Add class for horizontal alignment (mobile).
	if ( $h_alignment_mobile = $shortcode->attr( 'single_h_align_mobile' ) ) {
		array_push( $class, 'align-mobile-' . $h_alignment_mobile );
	}

	// Add class for vertical position.
	if ( $v_position = $shortcode->attr( 'single_v_position', 'middle' ) ) {
		array_push( $class, 'vertical-position-' . $v_position );
	}

	// Add class for shadowed block.
	if ( 'yes' === $shortcode->attr( 'single_shadow' ) ) {
		array_push( $class, 'item-shadowed' );
	}

	// Add class to remove border.
	if ( 'yes' !== $shortcode->attr( 'single_border' ) ) {
		array_push( $class, 'has-border' );
	}

	// Add class for element animation.
	if ( $animation = $shortcode->attr( 'single_css_animation' ) ) {
		array_push( $class, nice_vc_get_css_animation( $animation ) );
	}

	// Add classes for post terms.
	$taxonomies = get_taxonomies();
	if ( ! empty( $taxonomies ) ) {
		foreach ( $taxonomies as $taxonomy ) {
			$terms = get_the_terms( $item->post_id, $taxonomy );

			if ( empty( $terms ) ) {
				continue;
			}

			foreach ( $terms as $term ) {
				array_push( $class, 'term-' . $term->term_id );
			}
		}
	}

	// Add classes from function argument.
	if ( ! empty( $custom_class ) ) {
		if ( ! is_array( $custom_class ) ) {
			$custom_class = preg_split( '#\s+#', $custom_class );
		}

		$class = array_merge( $class, $custom_class );
	}

	$class = array_map( 'esc_attr', $class );

	return apply_filters( 'nice_vc_integration_posts_item_class', $class );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_inner_class' ) ) :
/**
 * Print classes for the current item's inner.
 *
 * @since 1.0.0
 *
 * @param mixed|string|array
 */
function nice_vc_integration_posts_item_inner_class( $class = null ) {
	nice_css_classes( nice_vc_integration_get_posts_item_inner_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_item_inner_class' ) ) :
/**
 * Obtain a list of classes for the current item's inner.
 *
 * @since  1.0.0
 *
 * @param  mixed|string|array $custom_class
 *
 * @return array
 */
function nice_vc_integration_get_posts_item_inner_class( $custom_class = null ) {
	$item      = nice_vc_integration_posts_current_item();
	$shortcode = $item->shortcode;

	$class = array(
		'item-inner',
	);

	// Add class to specify if we have a caption here.
	if ( isset( $item->layout['media'] ) ) {
		array_push( $class, 'has-caption' );
	} else {
		array_push( $class, 'no-caption' );
	}

	// Add class for background color only when not using overlay.
	if ( ( $background_color = $shortcode->attr( 'single_back_color' ) ) && ( 'overlay' !== $shortcode->attr( 'single_text' ) ) ) {
		array_push( $class, nice_theme_color_background_class( $background_color ) );
	}

	// Add classes from function argument.
	if ( ! empty( $custom_class ) ) {
		if ( ! is_array( $custom_class ) ) {
			$custom_class = preg_split( '#\s+#', $custom_class );
		}

		$class = array_merge( $class, $custom_class );
	}

	$class = array_map( 'esc_attr', $class );

	return apply_filters( 'nice_vc_integration_posts_item_inner_class', $class );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_overlay_class' ) ) :
/**
 * Print classes for the current item's overlay.
 *
 * @since 1.0.0
 *
 * @param mixed|string|array
 */
function nice_vc_integration_posts_item_overlay_class( $class = null ) {
	nice_css_classes( nice_vc_integration_get_posts_item_overlay_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_item_overlay_class' ) ) :
/**
 * Obtain a list of classes for the current item's overlay.
 *
 * @since  1.0.0
 *
 * @param  mixed|string|array $custom_class
 *
 * @return array
 */
function nice_vc_integration_get_posts_item_overlay_class( $custom_class = null ) {
	$item      = nice_vc_integration_posts_current_item();
	$shortcode = $item->shortcode;
	$colors    = nice_theme_colors();

	$class = array(
		'item-caption-overlay',
	);

	// Add class for background color.
	if ( $background_color = $shortcode->attr( 'single_overlay_color', $colors['nice_accent_color']['css_id'] ) ) {
		array_push( $class, nice_theme_color_background_class( $background_color ) );
	}

	// Add class for overlay visibility.
	if ( 'yes' === $shortcode->attr( 'single_overlay_visible' ) ) {
		array_push( $class, 'visible' );
	}

	// Add class for visible animation.
	if ( 'yes' === $shortcode->attr( 'single_overlay_anim', 'yes' ) ) {
		array_push( $class, 'animated' );
	}

	// Add class for overlay coloration.
	if ( $overlay_coloration = $shortcode->attr( 'single_overlay_coloration' ) ) {
		array_push( $class, $overlay_coloration );
	}

	// Add classes from function argument.
	if ( ! empty( $custom_class ) ) {
		if ( ! is_array( $custom_class ) ) {
			$custom_class = preg_split( '#\s+#', $custom_class );
		}

		$class = array_merge( $class, $custom_class );
	}

	$class = array_map( 'esc_attr', $class );

	return apply_filters( 'nice_vc_integration_posts_item_overlay_class', $class );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_overlay_data' ) ) :
/**
 * Print HTML data for the post item overlay.
 *
 * @since  1.0.0
 *
 * @param  array $custom_data
 */
function nice_vc_integration_posts_item_overlay_data( array $custom_data = null ) {
	nice_parse_data_attributes( nice_vc_integration_get_posts_item_overlay_data( $custom_data ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_item_overlay_data' ) ) :
/**
 * Obtain a list of key/value pairs as HTML data for the posts container.
 *
 * @since  1.0.0
 *
 * @param  array $custom_data
 *
 * @return array
 */
function nice_vc_integration_get_posts_item_overlay_data( array $custom_data = null ) {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	$data = array();

	// Add data for opacity.
	if ( $opacity = $shortcode->attr( 'single_overlay_opacity', 50 ) ) {
		$data['opacity'] = esc_attr( $opacity );
	}

	if ( ! empty( $custom_data ) ) {
		foreach ( $custom_data as $data_item ) {
			array_push( $data, $data_item );
		}
	}

	return $data;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_container_data' ) ) :
/**
 * Print HTML data for the posts container.
 *
 * @since  1.0.0
 *
 * @param  array $custom_data
 */
function nice_vc_integration_posts_container_data( array $custom_data = null ) {
	nice_parse_data_attributes( nice_vc_integration_get_posts_container_data( $custom_data ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_container_data' ) ) :
/**
 * Obtain a list of key/value pairs as HTML data for the posts container.
 *
 * @since  1.0.0
 *
 * @param  array $custom_data
 *
 * @return array
 */
function nice_vc_integration_get_posts_container_data( array $custom_data = null ) {
	$shortcode = nice_vc_integration_posts_current_shortcode();
	$loop_args = $shortcode->get_loop_args();

	$data = array(
		'columns'  => $shortcode->attr( 'columns', 1 ),
		'animated' => 'false',
	);

	if ( 'rand' !== $loop_args['orderby'] ) {
		$data['pagination'] = $shortcode->attr( 'pagination_mode' );

		if ( 'disabled' !== $shortcode->attr( 'pagination_mode' ) ) {
			$data['max-pages'] = $shortcode->get_max_num_pages();
		}
	}

	// Disable infinite scroll in front-end editor.
	if ( vc_is_page_editable() && 'infinite-scroll' === $shortcode->attr( 'pagination_mode' ) ) {
		unset( $data['pagination'] );
	}

	// Add data for element animation.
	if ( $shortcode->attr( 'single_css_animation' ) ) {
		$data['animated'] = 'true';

		if ( $shortcode->attr( 'single_cascading' ) ) {
			$data['cascade'] = 'true';
			$data['cascade-delay'] = $shortcode->attr( 'single_cascading_delay' );
		}
	}

	// Add Isotope mode data.
	if ( $mode = $shortcode->attr( 'isotope_mode' ) ) {
		$data = array_merge( $data, array( 'layout-mode' => $mode ) );
	}

	if ( ! empty( $custom_data ) ) {
		foreach ( $custom_data as $data_item ) {
			array_push( $data, $data_item );
		}
	}

	return $data;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_data' ) ) :
/**
 * Print HTML data for the posts item.
 *
 * @since 1.0.0
 *
 * @param array $custom_data
 */
function nice_vc_integration_posts_item_data( array $custom_data = null ) {
	nice_parse_data_attributes( nice_vc_integration_get_posts_item_data( $custom_data ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_item_data' ) ) :
/**
 * Obtain a list of key/value pairs as HTML data for the posts item.
 *
 * @since  1.0.0
 *
 * @param  array $custom_data
 *
 * @return array
 */
function nice_vc_integration_get_posts_item_data( array $custom_data = null ) {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	$data = array();

	// Add animation data.
	if ( $animation = $shortcode->attr( 'single_css_animation' ) ) {
		$data = array_merge( $data, array( 'animation' => $animation ) );
	}

	// Add delay data.
	if ( $delay = $shortcode->attr( 'single_css_animation_delay' ) ) {
		$data = array_merge( $data, array( 'delay' => $delay ) );
	}

	// Add speed data.
	if ( $speed = $shortcode->attr( 'single_css_animation_speed', 400 ) ) {
		$data = array_merge( $data, array( 'speed' => $speed ) );
	}

	if ( ! empty( $custom_data ) ) {
		foreach ( $custom_data as $data_item ) {
			array_push( $data, $data_item );
		}
	}

	return $data;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_isotope_gutter_size' ) ) :
/**
 * Check the size of te gutter for the posts grid
 * return the css class.
 *
 * @since  1.0.0
 *
 * @param  int    $gutter_size
 *
 * @return string
 */
function nice_vc_integration_posts_isotope_gutter_size( $gutter_size ) {
	switch ( $gutter_size ) {
		case 0:
			$gutter_size = 'no-gap';
			break;
		case 1:
			$gutter_size = 'px-gutter';
			break;
		case 2:
			$gutter_size = 'half-gutter';
			break;
		case 3:
		default:
			$gutter_size = 'single-gutter';
			break;
		case 4:
			$gutter_size = 'double-gutter';
			break;
	}

	return $gutter_size;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_filter_container_class' ) ) :
/**
 * Print classes for the posts filter wrapper.
 *
 * @since 1.0.0
 *
 * @param mixed|string|array $class
 */
function nice_vc_integration_posts_filter_container_class( $class = null ) {
	nice_css_classes( nice_vc_integration_get_posts_filter_container_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_filter_container_class' ) ) :
/**
 * Obtain classes for the posts filter wrapper.
 *
 * @since  1.0.0
 *
 * @param  mixed|string|array $class
 *
 * @return array
 */
function nice_vc_integration_get_posts_filter_container_class( $class = null ) {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	$classes = array(
		'nice-vc-posts-element-filter',
		'filter',
	);

	// Add class for gutter size.
	if ( $shortcode->attr( 'style_preset' ) ) {
		array_push( $classes, 'filter-' . nice_vc_integration_posts_isotope_gutter_size( $shortcode->attr( 'gutter_size', 0 ) ) );
	} else {
		array_push( $classes, 'filter-' . nice_vc_integration_posts_isotope_gutter_size( $shortcode->attr( 'gutter_size_h', 0 ) ) );
	}

	if ( $skin = $shortcode->attr( 'filter_skin', 'light' ) ) {
		array_push( $classes, 'menu-' . $skin );
	}

	if ( $back_color = $shortcode->attr( 'filter_back_color', 'default' ) ) {
		if ( 'default' !== $back_color ) {
			array_push( $classes, nice_theme_color_background_class( $back_color ) );
		}

		array_push( $classes, 'has-bg' );
	}

	if ( 'yes' === $shortcode->attr( 'filter_mobile_hidden' ) ) {
		array_push( $classes, 'filter-mobile-hidden' );
	}

	if ( 'yes' === $shortcode->attr( 'inner_padding' ) ) {
		array_push( $classes, 'filter-inner-padding' );
	}

	if ( $vertical_padding = $shortcode->attr( 'filter_padding_v' ) ) {
		array_push( $classes, 'filter-padding-v-' . intval( $vertical_padding ) . 'x' );
	}

	if ( 'yes' === $shortcode->attr( 'filter_remove_gap' ) ) {
		array_push( $classes, 'filter-remove-gap' );
	}

	if ( $transform = $shortcode->attr( 'filtering_text_transform' ) ) {
		array_push( $classes, 'text-' . $transform );
	}

	// Add classes from function argument.
	if ( ! empty( $class ) ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}

		$classes = array_merge( $classes, $class );
	}

	$classes = array_map( 'esc_attr', $classes );

	return apply_filters( 'nice_vc_integration_posts_filter_container_class', $classes );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_filter_class' ) ) :
/**
 * Print classes for the posts filter wrapper.
 *
 * @since 1.0.0
 *
 * @param null|array $class
 */
function nice_vc_integration_posts_filter_class( $class = null ) {
	nice_css_classes( nice_vc_integration_get_posts_filter_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_filter_class' ) ) :
/**
 * Obtain classes for the posts filter wrapper.
 *
 * @since  1.0.0
 *
 * @param  mixed|string|array $class
 *
 * @return array
 */
function nice_vc_integration_get_posts_filter_class( $class = null ) {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	$classes = array(
		'isotope-filter',
		'filter-inner',
	);

	if ( $skin = esc_attr( $shortcode->attr( 'filter_skin' ) ) ) {
		array_push( $classes, 'filter-' . $skin );
	}

	if ( $position = esc_attr( $shortcode->attr( 'filtering_position' ) ) ) {
		array_push( $classes, 'filter-text-' . $position );
	}

	array_push( $classes, ( 'yes' === $shortcode->attr( 'filtering_full_width' ) ) ? 'filter-full-width' : 'filter-default-width' );

	// Add classes from function argument.
	if ( ! empty( $class ) ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}

		$classes = array_merge( $classes, $class );
	}

	$classes = array_map( 'esc_attr', $classes );

	return apply_filters( 'nice_vc_integration_posts_filter_class', $classes );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_filter_data' ) ) :
/**
 * Print HTML data for the posts filter.
 *
 * @since 1.0.0
 *
 * @param array $custom_data
 */
function nice_vc_integration_posts_filter_data( array $custom_data = null ) {
	nice_parse_data_attributes( nice_vc_integration_get_posts_filter_data( $custom_data ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_posts_filter_data' ) ) :
/**
 * Obtain a list of key/value pairs as HTML data for the posts filter.
 *
 * @since  1.0.0
 *
 * @param  array $custom_data
 *
 * @return array
 */
function nice_vc_integration_get_posts_filter_data( array $custom_data = null ) {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	$data = array(
		'scroll'     => nice_bool( 'yes' === $shortcode->attr( 'filter_scroll' ) ) ? 'true' : 'false',
		'pagination' => nice_bool( nice_vc_integration_posts_query_has_pagination() ) ? 'true' : 'false',
	);

	if ( ! empty( $custom_data ) ) {
		foreach ( $custom_data as $data_item ) {
			array_push( $data, $data_item );
		}
	}

	return $data;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_query_has_pagination' ) ) :
/**
 * Check if the current query needs to show any kind of pagination.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_query_has_pagination() {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	// Return false if there's no pagination mode set.
	if ( ! $shortcode->attr( 'pagination_mode' ) ) {
		return false;
	}

	// Return false if pagination is disabled.
	if ( 'disabled' === $shortcode->attr( 'pagination_mode' ) ) {
		return false;
	}

	$loop_args = $shortcode->get_loop_args();

	// Return false if the query results are ordered randomly.
	if ( 'rand' === $loop_args['orderby'] ) {
		return false;
	}

	// Return true if the current query has more than one page.
	if ( $shortcode->get_max_num_pages() > 1 ) {
		return true;
	}

	// Return false as fallback.
	return false;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_flat_array' ) ) :
/**
 * Flatten a given array.
 *
 * @since  1.0.0
 *
 * @param  array $array
 *
 * @return array
 */
function nice_vc_integration_posts_flat_array( array $array = array() ) {
	$flat_array = array();

	if ( ! empty( $array ) ) {
		foreach ( $array as $key => $value) {
			$flat_array[ $value[0] ] = $value[1];
		}
	}

	return $flat_array;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_shortcode_atts' ) ) :
/**
 * Obtain shortcode attributes from given array.
 *
 * @since  1.0.0
 *
 * @param  array $atts
 *
 * @return array
 */
function nice_vc_integration_posts_shortcode_atts( array $atts = array() ) {
	$options = nice_vc_integration_posts_options();

	$default_atts = array();

	if ( ! empty( $options['params'] ) ) {
		foreach ( $options['params'] as $param ) {
			if ( ! isset( $param['param_name'] )) {
				continue;
			}

			$value = isset( $param['value'] ) ? $param['value'] : '';

			if ( is_array( $value ) ) {
				$value = '';
			}

			if ( '' === $value && isset( $param['std'] ) ) {
				$value = $param['std'];
			}

			$default_atts[ $param['param_name'] ] = $value;
		}
	}

	$atts = shortcode_atts( $default_atts, $atts );

	return $atts;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_current_item' ) ) :
/**
 * Set and obtain the current post item being processed by the shortcode.
 *
 * @since  1.0.0
 *
 * @param  Nice_VCIntegration_Post_Item $post_item
 *
 * @return Nice_VCIntegration_Post_Item
 */
function nice_vc_integration_posts_current_item( Nice_VCIntegration_Post_Item $post_item = null ) {
	static $current_item = null;

	if ( ! is_null( $post_item ) ) {
		$current_item = $post_item;
	}

	return $current_item;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_default_caption_url' ) ) :
/**
 * Print URL of the default caption placeholder.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_default_caption_url() {
	$image_option = nice_get_option( 'nice_image_not_available' );
	$image_url    = $image_option ? $image_option : nice_get_file_uri( 'images/image-not-available.png' );

	/**
	 * @hook nice_vc_integration_posts_default_caption_url
	 *
	 * Hook here to modify the URL of the default caption placeholder.
	 *
	 * @since 1.0.0
	 */
	echo esc_url( apply_filters( 'nice_vc_integration_posts_default_caption_url', $image_url ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_single_item_image' ) ) :
/**
 * Print image for current item.
 *
 * @since 1.0.0
 */
function nice_vc_integration_single_item_image() {
	$item      = nice_vc_integration_posts_current_item();
	$icon_type = isset( $item->layout['icon'] ) ? esc_attr( $item->shortcode->attr( 'icon_type', 'fontawesome' ) ) : '';
	$icon      = ( 'overlay' === $item->shortcode->attr( 'single_text' ) ) ? '' : $item->shortcode->attr( 'icon_' . $icon_type );
	$post_type = get_post_type_object( $item->post_type );

	if ( $post_type->publicly_queryable && $post_type->public ) :	?>
		<a class="item-caption-permalink" href="<?php echo esc_url( $item->permalink ); ?>">
	<?php endif;

		if ( $item->thumbnail_id ) :
			/**
			 * @hook nice_vc_integration_single_item_image_before
			 *
			 * Allow printing HTML before the post's image.
			 *
			 * @since 1.0.0
			 */
			do_action( 'nice_vc_integration_single_item_image_before' );

			/**
			 * Print out post's image.
			 *
			 * @since 1.0.0
			 */
			$args = apply_filters( 'nice_vc_integration_single_item_image_args', array(
					'id'    => $item->post_id,
					'class' => 'item-caption-thumbnail',
					'size'  => nice_vc_integration_posts_image_size(),
					'echo'  => true,
				)
			);
			nice_image( $args );

			/**
			 * @hook nice_vc_integration_single_item_image_after
			 *
			 * Allow printing HTML after the post's image.
			 *
			 * @since 1.0.0
			 */
			do_action( 'nice_vc_integration_single_item_image_after' );

		else : ?>
			<img src="<?php nice_vc_integration_posts_default_caption_url(); ?>" class="item-caption-thumbnail" />
		<?php endif; ?>

		<div <?php nice_vc_integration_posts_item_overlay_class(); ?> <?php nice_vc_integration_posts_item_overlay_data(); ?>>
			<?php if ( $icon ) : ?>
				<i class="item-caption-overlay-icon <?php echo esc_attr( $icon ); ?>"></i>
			<?php endif; ?>
		</div>
	<?php if ( $post_type->public ) : ?>
		</a>
	<?php endif;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_image_size' ) ) :
/**
 * Obtain image size for VC Posts based on the number of grid columns.
 *
 * @since 1.0.0
 *
 * @return string
 */
function nice_vc_integration_posts_image_size() {
	if ( ! isset( $image_size ) ) {
		$item    = nice_vc_integration_posts_current_item();
		$columns = $item->shortcode->attr( 'columns' );
		$fluid   = ( 'yes' !== $item->shortcode->attr( 'disable_fluid_grid', 'yes' ) );

		$intervals = array(
			1  => array(
				'fluid'     => 'full',
				'not_fluid' => 'full',
			),
			2  => array(
				'fluid'     => 'large',
				'not_fluid' => 'full',
			),
			3  => array(
				'fluid'     => 'large',
				'not_fluid' => 'large',
			),
			4  => array(
				'fluid'     => 'medium',
				'not_fluid' => 'large',
			),
			6  => array(
				'fluid'     => 'medium',
				'not_fluid' => 'medium',
			),
		);

		for ( $i = 1; $i < 12; $i++ ) {
			if ( ! isset( $last_key ) ) {
				$last_key = $i;
			}
			$map[ $i ] = isset( $intervals[ $i ] ) ? $intervals[ $i ] : $intervals[ $last_key ];
			$last_key  = isset( $intervals[ $i ] ) ? $i : $last_key;
		}

		$image_size = $fluid ? $map[ $columns ]['fluid'] : $map[ $columns ]['not_fluid'];
	}

	return $image_size;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_display_options' ) ) :
/**
 * Return display options for VC Posts items.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_display_options() {
	return array(
		array(
			'block',
			esc_html__( 'Block', 'smart' ),
		),
		array(
			'inline',
			esc_html__( 'Inline', 'smart' ),
		),
		array(
			'inline-block',
			esc_html__( 'Inline Block', 'smart' ),
		),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_text_style_options' ) ) :
/**
 * Return icon options for VC Posts items.
 *
 * @since  1.0.0
 *
 * @param  array $exclude
 *
 * @return array
 */
function nice_vc_integration_posts_text_style_options( $exclude = array() ) {
	$options = array();

	$items = array(
		'text-icon' => esc_html__( 'Text and Icon', 'smart' ),
		'text'      => esc_html__( 'Text Only', 'smart' ),
		'icon'      => esc_html__( 'Icon Only', 'smart' ),
		'pills'     => esc_html__( 'Pills', 'smart' ),
	);

	foreach ( $items as $key => $value ) {
		if ( ! in_array( $key, $exclude, true ) ) {
			$options[] = array( $key, $value );
		}
	}

	return $options;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_meta_color_options' ) ) :
/**
 * Return options for meta data color in VC Posts items.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_meta_color_options() {
	$options = array(
		array(
			'inherit-skin',
			esc_html__( 'Inherit skin color', 'smart' ),
		),
		array(
			'contrast-skin',
			esc_html__( 'Use contrast color (doesn\'t work for pills)', 'smart' ),
		),
	);

	return $options;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_meta_position_options' ) ) :
/**
 * Obtain options for meta data position in VC Posts items.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_meta_position_options() {
	$options = array(
		array(
			'default',
			esc_html__( 'Default position', 'smart' ),
		),
		array(
			'top-left',
			esc_html__( 'Top Left', 'smart' ),
		),
		array(
			'top-right',
			esc_html__( 'Top Right', 'smart' ),
		),
		array(
			'bottom-left',
			esc_html__( 'Bottom Left', 'smart' ),
		),
		array(
			'bottom-right',
			esc_html__( 'Bottom Right', 'smart' ),
		),
	);

	return $options;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_alignment_options' ) ) :
/**
 * Return options for meta data alignment in VC Posts items.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_alignment_options() {
	$options = array(
		array(
			'',
			esc_html__( 'Default alignment (inherit from block settings)', 'smart' ),
		),
		array(
			'left',
			esc_html__( 'Left align', 'smart' ),
		),
		array(
			'right',
			esc_html__( 'Right align', 'smart' ),
		),
	);

	return $options;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_post_item_options' ) ) :
/**
 * Return list of display options for post items.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_post_item_options() {
	$options = array(
		nice_vc_integration_posts_item_media_options(),
		nice_vc_integration_posts_item_title_options(),
		nice_vc_integration_posts_item_type_options(),
		nice_vc_integration_posts_item_author_options(),
		nice_vc_integration_posts_item_date_options(),
		nice_vc_integration_posts_item_category_options(),
		nice_vc_integration_posts_item_comments_options(),
		nice_vc_integration_posts_item_text_options(),
		nice_vc_integration_posts_item_link_options(),
		nice_vc_integration_posts_item_icon_options(),
		nice_vc_integration_posts_item_separator_options(),
	);

	/**
	 * @hook nice_vc_integration_posts_post_item_options
	 *
	 * Add or remove options by hooking in here.
	 *
	 * @since 1.0.0
	 */
	return apply_filters( 'nice_vc_integration_posts_post_item_options', $options );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_page_item_options' ) ) :
/**
 * Return list of display options for post items.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_page_item_options() {
	$options = array(
		nice_vc_integration_posts_item_media_options(),
		nice_vc_integration_posts_item_title_options(),
		nice_vc_integration_posts_item_type_options(),
		nice_vc_integration_posts_item_text_options(),
		nice_vc_integration_posts_item_link_options(),
		nice_vc_integration_posts_item_icon_options(),
		nice_vc_integration_posts_item_separator_options(),
	);

	/**
	 * @hook nice_vc_integration_posts_post_item_options
	 *
	 * Add or remove options by hooking in here.
	 *
	 * @since 1.0.0
	 */
	return apply_filters( 'nice_vc_integration_posts_page_item_options', $options );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_media_options' ) ) :
/**
 * Obtain options for post media.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_media_options() {
	return array(
		'media',
		esc_html__( 'Media', 'smart' ),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_title_options' ) ) :
/**
 * Obtain options for post title.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_title_options() {
	return array(
		'title',
		esc_html__( 'Title', 'smart' ),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_type_options' ) ) :
/**
 * Obtain options for post type.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_type_options() {
	return array(
		'type',
		esc_html__( 'Post type', 'smart' ),
		nice_vc_integration_posts_display_options(),
		nice_vc_integration_posts_text_style_options( array( 'pills' ) ),
		nice_vc_integration_posts_meta_color_options(),
		nice_vc_integration_posts_alignment_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_author_options' ) ) :
/**
 * Obtain options for post author.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_author_options() {
	return array(
		'author',
		esc_html__( 'Author', 'smart' ),
		nice_vc_integration_posts_display_options(),
		nice_vc_integration_posts_meta_color_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_date_options' ) ) :
/**
 * Obtain options for post date.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_date_options() {
	return array(
		'date',
		esc_html__( 'Date', 'smart' ),
		nice_vc_integration_posts_display_options(),
		nice_vc_integration_posts_text_style_options( array( 'icon', 'pills' ) ),
		nice_vc_integration_posts_meta_color_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_category_options' ) ) :
/**
 * Obtain options for post category.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_category_options() {
	return array(
		'category',
		esc_html__( 'Category', 'smart' ),
		nice_vc_integration_posts_display_options(),
		nice_vc_integration_posts_text_style_options( array( 'icon' ) ),
		nice_vc_integration_posts_meta_color_options(),
		nice_vc_integration_posts_meta_position_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_text_options' ) ) :
/**
 * Obtain options for post text.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_text_options() {
	return array(
		'text',
		esc_html__( 'Text', 'smart' ),
		array(
			array(
				'excerpt',
				esc_html__( 'Excerpt', 'smart' ),
			),
			array(
				'full',
				esc_html__( 'Full content', 'smart' ),
			),
		),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_comments_options' ) ) :
/**
 * Obtain options for post comments.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_comments_options() {
	return array(
		'comments',
		esc_html__( 'Comments', 'smart' ),
		nice_vc_integration_posts_display_options(),
		nice_vc_integration_posts_text_style_options(),
		nice_vc_integration_posts_meta_color_options(),
		nice_vc_integration_posts_alignment_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_link_options' ) ) :
/**
 * Obtain options for post link.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_link_options() {
	return array(
		'link',
		esc_html__( 'Read more link', 'smart' ),
		array(
			array(
				'default',
				esc_html__( 'Default shape', 'smart' ),
			),
			array(
				'round',
				esc_html__( 'Round', 'smart' ),
			),
			array(
				'circle',
				esc_html__( 'Circle', 'smart' ),
			),
			array(
				'square',
				esc_html__( 'Square', 'smart' ),
			),
			array(
				'link',
				esc_html__( 'Standard link', 'smart' ),
			),
		),
		array(
			array(
				'text-no-transform',
				esc_html__( 'Default text style', 'smart' ),
			),
			array(
				'uppercase',
				esc_html__( 'Uppercase', 'smart' ),
			),
			array(
				'lowercase',
				esc_html__( 'Lowercase', 'smart' ),
			),
			array(
				'Capitalize',
				esc_html__( 'Capitalize', 'smart' ),
			),
		),
		array(
			array(
				'default-width',
				esc_html__( 'Default width', 'smart' ),
			),
			array(
				'full-width',
				esc_html__( 'Full width', 'smart' ),
			),
		),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_icon_options' ) ) :
/**
 * Obtain options for post icon.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_icon_options() {
	return array(
		'icon',
		esc_html__( 'Icon', 'smart' ),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_item_separator_options' ) ) :
/**
 * Obtain options for post separator.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_posts_item_separator_options() {
	return array(
		'separator',
		esc_html__( 'Separator', 'smart' ),
		array(
			array(
				'full',
				esc_html__( 'Full width', 'smart' ),
			),
			array(
				'reduced',
				esc_html__( 'Reduced width', 'smart' ),
			),
		),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_pagination' ) ) :
/**
 * Print pagination for the current VC-generated WP_Query.
 *
 * @since 1.0.0
 *
 * @param int $total
 * @param int $current
 * @param int $show
 */
function nice_vc_integration_posts_pagination( $total = 1, $current = 1, $show = 5 ) {
	$breakpoint   = $total / 2;
	$is_lower_set = ( $current <= $breakpoint );
	$current      = intval( $current );

	if ( $total < $show ) {
		$show = $total;
	}
	$total = intval( $total );

	if ( $is_lower_set ) {
		$eval = ( $current >= $show );

		$page_set = array(
			'first' => intval( $eval ? ( $current - $show ) + 2 : 1 ),
			'last'  => intval( $eval ? ( $current + 1 ) : $show ),
		);
	} else {
		$eval = ( $current <= ( $total - $show ) + 1 );

		$page_set = array(
			'first' => intval( $eval ? $current - 1 : ( $total - $show ) + 1 ),
			'last'  => intval( $eval ? ( $current + $show ) - 2 : $total ),
		);
	}

	$previous = $current - 1;
	$next     = $current + 1;
	$first    = 1;
	$last     = $total;

	$first_link_visible = ( $first === $page_set['first'] );
	$last_link_visible  = ( $last === $page_set['last'] );

	if ( $total > 1 ) : $i = intval( $page_set['first'] ); ?>
		<div class="pagination">

			<?php if ( $current > $first ) : ?>
				<?php if ( ! $first_link_visible ) : ?>
					<a href="javascript:void(0);" class="page first" data-page="1"><?php esc_html_e( 'First', 'smart' ); ?></a>
				<?php endif; ?>

				<?php if ( $previous > $first ) : ?>
					<a href="javascript:void(0);" class="page previous" data-page="<?php echo esc_attr( $previous ); ?>"><?php esc_html_e( 'Previous', 'smart' ); ?></a>
				<?php endif; ?>
			<?php endif; ?>

			<?php while ( $i <= $page_set['last'] ) : ?>
				<a href="javascript:void(0);" class="page page-<?php echo esc_attr( $i ); ?><?php echo esc_attr( ( $i === $current ) ? ' active' : '' ); ?>" data-page="<?php echo esc_attr( $i ); ?>"><?php echo esc_attr( $i ); ?></a>
				<?php $i++; ?>
			<?php endwhile; ?>

			<?php if ( $current < $last ) : ?>
				<?php if ( $next < $last ) : ?>
					<a href="javascript:void(0);" class="page next" data-page="<?php echo esc_attr( $next ); ?>"><?php esc_html_e( 'Next', 'smart' ); ?></a>
				<?php endif; ?>

				<?php if ( ! $last_link_visible ) : ?>
					<a href="javascript:void(0);" class="page last" data-page="<?php echo esc_attr( $total ); ?>"><?php esc_html_e( 'Last', 'smart' ); ?></a>
				<?php endif; ?>

			<?php endif; ?>

		</div>

	<?php endif;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_shortcode_ajax_content' ) ) :
/**
 * Process content of a VC Posts shortcode inside an AJAX request.
 *
 * @since 1.0.0
 *
 * @param Nice_VCIntegration_Posts_Shortcode $shortcode
 */
function nice_vc_integration_posts_shortcode_ajax_content( Nice_VCIntegration_Posts_Shortcode $shortcode ) {
	if ( ! nice_doing_ajax() ) {
		return;
	}

	// Return early if we don't have posts for this shortcode.
	if ( ! $shortcode->have_posts() ) {
		return;
	}

	while ( $shortcode->have_posts() ) : $shortcode->the_post();

		/**
		 * @hook nice_vc_integration_posts_single_item
		 *
		 * The markup for every single item in the current query is printed here.
		 * Hook in to add or remove processes before of after the HTML is processed.
		 *
		 * @since 1.0.0
		 *
		 * Hooked here:
		 * @see nice_vc_integration_posts_single_item() - 10
		 */
		do_action( 'nice_vc_integration_posts_single_item' );

	endwhile;

	wp_reset_postdata();
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_load_icon_font' ) ) :
add_action( 'nice_vc_integration_before_posts', 'nice_vc_integration_posts_load_icon_font' );
/**
 * Load required icon fonts for the current shortcode.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_load_icon_font() {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	// Load icon font if needed.
	if ( $icon_type = $shortcode->attr( 'icon_type' ) ) {
		vc_icon_element_fonts_enqueue( $icon_type );
	}
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts' ) ) :
add_action( 'nice_vc_integration_posts_loop', 'nice_vc_integration_posts', 20 );
/**
 * Process the loop of posts inside a VC Posts shortcode call.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts() {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	// Return early if we don't have posts for this shortcode.
	if ( ! $shortcode->have_posts() ) {
		return;
	}

?>
	<div <?php nice_vc_integration_posts_container_class(); ?>>
		<div <?php nice_vc_integration_posts_grid_class(); ?> <?php nice_vc_integration_posts_container_data(); ?>>

			<?php while ( $shortcode->have_posts() ) : $shortcode->the_post(); ?>

				<?php
					/**
					 * @hook nice_vc_integration_posts_single_item
					 *
					 * The markup for every single item in the current query is printed here.
					 * Hook in to add or remove processes before of after the HTML is processed.
					 *
					 * @since 1.0.0
					 *
					 * Hooked here:
					 * @see nice_vc_integration_posts_single_item() - 10
					 */
					do_action( 'nice_vc_integration_posts_single_item' );
				?>

			<?php endwhile; ?>

		</div>
	</div>
<?php
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_shortcode_collection_add' ) ) :
add_action( 'nice_vc_integration_posts_loop', 'nice_vc_integration_posts_shortcode_collection_add', 10 );
/**
 * Add shortcode to collection.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_shortcode_collection_add() {
	nice_vc_integration_posts_shortcode_collection( nice_vc_integration_posts_current_shortcode() );
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_title' ) ) :
add_action( 'nice_vc_integration_before_posts', 'nice_vc_integration_posts_title', 20 );
/**
 * Print title of current VC Posts widget.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_title() {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	if ( $title = $shortcode->attr( 'title' ) ) :
		$title_alignment = $shortcode->attr( 'title_alignment', is_rtl() ? 'right' : 'left' );
	?>

		<section class="nice-vc-posts-element-title text-<?php echo esc_attr( $title_alignment ); ?>">
			<h2 class="title"><?php echo esc_html( $title ); ?></h2>
		</section>

	<?php

	endif;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_filter' ) ) :
add_action( 'nice_vc_integration_before_posts', 'nice_vc_integration_posts_filter', 30 );
/**
 * Create the HTML for the posts isotope filter
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_filter() {
	$shortcode = nice_vc_integration_posts_current_shortcode();

	// Return early if the current shortcode is not filterable.
	if ( 'yes' !== $shortcode->attr( 'filtering' ) ) {
		return;
	}

	$categories       = $shortcode->get_categories();
	$loop_args        = $shortcode->get_loop_args();
	$queried_terms    = isset( $loop_args['tax_query'][0]['terms'] ) ? $loop_args['tax_query'][0]['terms'] : array();

	if ( ! empty( $categories ) && count( $categories ) > 1 ) : ?>

	<div <?php nice_vc_integration_posts_filter_container_class(); ?>>
		<div <?php nice_vc_integration_posts_filter_class(); ?> <?php nice_vc_integration_posts_filter_data(); ?>>
			<div class="select-term">
				<a href="javascript:void(0);" class="select"><?php esc_html_e( 'Choose a category', 'smart' ) ?></a>
			</div>

			<ul class="terms mobile-hidden">
				<?php if ( 'yes' === $shortcode->attr( 'filter_all_opposite' ) ) : ?>
					<li class="show-all">
						<a href="javascript:void(0);" class="filter category active" data-term="<?php echo esc_attr( join( ',', $queried_terms ) ); ?>"><?php esc_html_e( 'Show all', 'smart' ) ?></a>
					</li>
				<?php endif; ?>
				<?php foreach ( $categories as $category ) : ?>
					<li>
						<a href="javascript:void(0);" class="filter category" data-class=".term-<?php echo esc_attr( $category->term_id ); ?>" data-term="<?php echo esc_attr( $category->term_id ); ?>"><?php echo esc_attr( $category->name ) ?></a>
					</li>
				<?php endforeach; ?>
			</ul>
		</div>
	</div>

	<?php endif;
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_single_item' ) ) :
add_action( 'nice_vc_integration_posts_single_item', 'nice_vc_integration_posts_single_item' );
/**
 * Print current looped item.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_single_item() {
?>
	<div <?php nice_vc_integration_posts_item_class(); ?> <?php nice_vc_integration_posts_item_data(); ?>>
		<div <?php nice_vc_integration_posts_item_inner_class(); ?>>
			<?php
				/**
				 * @hook nice_vc_integration_posts_single_item_content
				 *
				 * Single post items are processed here. Hook into this action
				 * to add or remove elements.
				 *
				 * @since 1.0.0
				 *
				 * Hooked here:
				 * @see nice_vc_integration_posts_single_item_permalink() - 10
				 * @see nice_vc_integration_posts_single_item_caption() - 20
				 * @see nice_vc_integration_posts_single_item_content() - 30
				 */
				do_action( 'nice_vc_integration_posts_single_item_content' );
			?>
		</div>
	</div>
<?php
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_single_item_permalink' ) ) :
add_action( 'nice_vc_integration_posts_single_item_content', 'nice_vc_integration_posts_single_item_permalink', 10 );
/**
 * Print permalink for current item.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_single_item_permalink() {
	/**
	 * @hook nice_vc_integration_posts_single_item_permalink
	 *
	 * Allow by-passing item permalink. All replacement HTML should be both
	 * printed and returned inside the hooked function.
	 *
	 * @since 1.0.0
	 */
	if ( ! is_null( apply_filters( 'nice_vc_integration_posts_single_item_permalink', null ) ) ) {
		return;
	}

	$item = nice_vc_integration_posts_current_item();
	$post_type = get_post_type_object( $item->post_type );

	// Return early if we're not allowed to display a link.
	if ( ! $post_type->public || ! $post_type->publicly_queryable ) {
		return;
	}

	?>
		<a class="item-permalink" href="<?php echo esc_url( $item->permalink ); ?>"></a>
	<?php
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_single_item_caption' ) ) :
add_action( 'nice_vc_integration_posts_single_item_content', 'nice_vc_integration_posts_single_item_caption', 20 );
/**
 * Print caption for current item.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_single_item_caption() {
	$item = nice_vc_integration_posts_current_item();

	if ( 'overlay' !== $item->shortcode->attr( 'single_text' ) && ! isset( $item->layout['media'] ) ) {
		return;
	}

	?>

		<div class="item-caption">
			<div class="item-caption-inner">
				<?php nice_vc_integration_single_item_image(); ?>
			</div>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_single_item_content' ) ) :
add_action( 'nice_vc_integration_posts_single_item_content', 'nice_vc_integration_posts_single_item_content', 30 );
/**
 * Print contents of the current item.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_single_item_content() {
	$item   = nice_vc_integration_posts_current_item();
	$layout = $item->layout;

	if ( empty( $layout ) ) {
		return;
	}

	?>
		<div class="item-content">
			<?php $item->process_categories(); ?>
			<div class="item-content-inner">
				<?php $item->process_layout(); ?>
			</div>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'nice_vc_integration_get_post_categories' ) ) :
add_filter( 'nice_vc_integration_posts_categories', 'nice_vc_integration_get_post_categories', 10, 2 );
/**
 * Obtain post categories for current query.
 *
 * @since 1.0.0
 *
 * @param array   $categories
 * @param WP_Post $post
 *
 * @return array
 */
function nice_vc_integration_get_post_categories( array $categories = array(), WP_Post $post ) {
	if ( 'post' === $post->post_type ) {
		$post_categories = get_the_terms( $post, 'category' );

		if ( is_array( $post_categories ) && ! empty( $post_categories ) ) {
			$categories = array_merge( $categories, $post_categories );
		}
	}

	return $categories;
}
endif;

if ( ! function_exists( 'nice_vc_integration_ajax_posts_loader' ) ) :
add_action( 'nice_vc_integration_after_posts', 'nice_vc_integration_ajax_posts_loader' );
/**
 * Print loader for AJAX posts.
 *
 * @since 1.0.0
 */
function nice_vc_integration_ajax_posts_loader() {
	$shortcode = nice_vc_integration_posts_current_shortcode();
	$loop_args = $shortcode->get_loop_args();

	// Return early if using random order.
	if ( 'rand' === $loop_args['orderby'] ) {
		return;
	}

	$pagination_mode = $shortcode->attr( 'pagination_mode' );
	$pagination_classes = array(
		'padding-top-' . intval( $shortcode->attr( 'pagination_padding_top' ) ) . 'x',
		'padding-bottom-' . intval( $shortcode->attr( 'pagination_padding_bottom' ) ) . 'x',
	);

	switch ( $pagination_mode ) {
		case 'infinite-scroll' :
			// Infinite scroll should be disabled in front-end editor.
			if ( ! vc_is_page_editable() ) {
				$pagination_loader = $shortcode->attr( 'pagination_loader', 'beat' );

				?>
				<div class="grid-pagination">
					<div class="posts-loader-container">
						<div class="posts-loader infinite-scroll <?php echo esc_attr( join( ' ', $pagination_classes ) ); ?>">
							<?php if ( 'beat' === $pagination_loader ) : ?>
								<div class="loader"></div>
							<?php elseif ( 'spin' === $pagination_loader ) : ?>
								<i class="fa fa-refresh fa-spin"></i>
							<?php endif; ?>
						</div>
					</div>
				</div>
				<?php
			} else {
				?>
				<div class="nice-vc-message nice-vc-message-infinite-scroll-not-available">
					<?php esc_html_e( 'Infinite Scroll is not visible while editing a page.', 'smart' ); ?>
				</div>
				<?php
			}

			break;

		case 'click-to-load' :
			$button_classes = array(
				'load',
				'btn',
				'btn-default',
			);

			// Add class for button color.
			if ( $color = $shortcode->attr( 'click_to_load_background_color' ) ) {
				array_push( $button_classes, nice_theme_color_button_class( $color ) );
			}

			// Add class for button shape.
			if ( $shape = $shortcode->attr( 'click_to_load_button_shape' ) ) {
				array_push( $button_classes, nice_theme_shape_button_class( $shape ) );
			}

			// Add class for button shape.
			if ( 'yes' === $shortcode->attr( 'click_to_load_button_outlined' ) ) {
				array_push( $button_classes, nice_theme_style_button_class( 'outline' ) );
			}

			$button_text = $shortcode->attr( 'click_to_load_button_text' ) ? $shortcode->attr( 'click_to_load_button_text' ) : esc_html__( 'Load more', 'smart' );
			?>

			<div class="grid-pagination">
				<div class="posts-loader-container">
					<div class="posts-loader click-to-load <?php echo esc_attr( join( ' ', $pagination_classes ) ); ?>">
						<a href="javascript:void(0);" class="<?php echo esc_attr( join( ' ', $button_classes ) ); ?>"><?php echo esc_html( $button_text ); ?></a>
					</div>
				</div>
			</div>

			<?php break;

		case 'standard':
			// Break early if we only have one page.
			if ( ( $total = $shortcode->get_max_num_pages() ) <= 1 ) {
				break;
			}

			$pagination_loader = $shortcode->attr( 'pagination_loader', 'beat' );
			?>

			<div class="grid-pagination">
				<div class="posts-loader-container <?php echo esc_attr( join( ' ', $pagination_classes ) ); ?>">
					<div class="posts-loader-container-inner">
						<div class="posts-loader standard-pagination">
							<?php nice_vc_integration_posts_pagination( $total ); ?>
						</div>

						<div class="posts-loading-spinner">
							<?php if ( 'beat' === $pagination_loader ) : ?>
								<div class="loader"></div>
							<?php elseif ( 'spin' === $pagination_loader ) : ?>
								<i class="fa fa-refresh fa-spin"></i>
							<?php endif; ?>
						</div>
					</div>
				</div>
			</div>

			<?php break;
		default:
			break;
	}
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_shortcodes_json' ) ) :
add_action( 'wp_footer', 'nice_vc_integration_posts_shortcodes_json' );
/**
 * Print JSON code to allow firing VC Posts shortcodes via AJAX.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_shortcodes_json() {
	$shortcodes = nice_vc_integration_posts_shortcode_collection();

	if ( empty( $shortcodes ) ) {
		return;
	}
?>
	<script type="text/javascript">
		//<![CDATA[
		var NiceVCShortcodeCollection = <?php echo wp_json_encode( $shortcodes ); ?>;
		//]]>
	</script>
<?php
}
endif;

if ( ! function_exists( 'nice_vc_integration_posts_shortcode_ajax' ) ) :
add_action( 'wp_ajax_nopriv_nice_vc_integration_posts_shortcode_ajax', 'nice_vc_integration_posts_shortcode_ajax' );
add_action( 'wp_ajax_nice_vc_integration_posts_shortcode_ajax', 'nice_vc_integration_posts_shortcode_ajax' );
/**
 * Perform AJAX process for VC Posts.
 *
 * @since 1.0.0
 */
function nice_vc_integration_posts_shortcode_ajax() {
	// Return early if not in AJAX context.
	if ( ! nice_doing_ajax() ) {
		return;
	}

	check_ajax_referer( 'play-nice', 'nonce' );

	// Return early if we don't have the required data.
	if ( ! isset( $_POST['shortcode_atts'] ) || ! isset( $_POST['shortcode_page'] ) ) {
		return;
	}

	// Create new shortcode instance.
	$shortcode = new Nice_VCIntegration_Posts_Shortcode();

	$category = isset( $_POST['shortcode_category'] ) ? sanitize_text_field( wp_unslash( $_POST['shortcode_category'] ) ) : 0;

	// Process AJAX request.
	$shortcode->process_ajax(
		array_map( 'esc_attr', (array) wp_unslash( $_POST['shortcode_atts'] ) ),
		intval( $_POST['shortcode_page'] ),
		$category
	);

	// Initialize response.
	$response = array();

	/*
	 * Add contents of current page to response.
	 */
	ob_start();
	nice_vc_integration_posts_shortcode_ajax_content( $shortcode );
	$response['content'] = ob_get_contents();
	ob_end_clean();

	/*
	 * Add maximum number of pages to response.
	 */
	$response['max_pages'] = $shortcode->get_max_num_pages();

	/*
	 * Add current pagination to response if needed.
	 */
	if ( isset( $_POST['shortcode_pagination'] ) && 'standard' === $_POST['shortcode_pagination'] ) {
		ob_start();
		nice_vc_integration_posts_pagination( $shortcode->get_max_num_pages(), intval( $_POST['shortcode_page'] ) );
		$response['pagination'] = ob_get_contents();
		ob_end_clean();
	}

	// Print out response.
	echo wp_json_encode( $response );

	// Finish current request.
	die();
}
endif;

