<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage scripts for Visual Composer.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://www.nicethemes.com/theme-page
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_async_scripts' ) ) :
add_filter( 'nice_async_scripts', 'nice_vc_integration_async_scripts' );
/**
 * Add elements to the list of scripts that can be loaded asynchronously.
 *
 * @see   nice_theme_async_scripts()
 *
 * @since 1.0.0
 *
 * @param array $scripts
 */
function nice_vc_integration_async_scripts( $scripts = array() ) {
	if ( nice_vc_is_used() && nice_use_minified_files() ) {
		$scripts =  array_merge( $scripts, array(
				'nice-vc-scripts',
			)
		);
	}

	return $scripts;
}
endif;

if ( ! function_exists( 'nice_vc_integration_on_demand_scripts' ) ) :
add_filter( 'nice_on_demand_scripts', 'nice_vc_integration_on_demand_scripts' );
/**
 * Add elements to the list of scripts that can be loaded on demand.
 *
 * @since 1.0.0
 *
 * @param array $scripts
 *
 * @return array
 */
function nice_vc_integration_on_demand_scripts( $scripts = array() ) {
	$scripts = nice_vc_is_used() ? array_merge( $scripts, array(
			'nice-vc-posts-pagination' => 'postsPagination',
			'nice-vc-counterup-source' => 'counterup',
			'nice-vc-countdown-source' => 'countdown',
			'nice-vc-vivus-source'     => 'vivus',
		)
	) : $scripts;

	return $scripts;
}
endif;

if ( ! function_exists( 'nice_vc_integration_scripts' ) ) :
add_action( 'nice_register_scripts', 'nice_vc_integration_scripts', 0 );
/**
 * Load scripts for shopping cart.
 *
 * @since 1.0.0
 */
function nice_vc_integration_scripts() {
	if ( ! nice_vc_is_used() ) {
		return;
	}

	$js_folder = 'includes/plugin-integrations/visual-composer/assets/js';

	if ( nice_use_minified_files() ) {
		wp_register_script( 'nice-vc-scripts', nice_get_file_uri( $js_folder . '/min/nice-vc-scripts.min.js' ), array( 'nice-scripts' ), false, true );
		wp_enqueue_script( 'nice-vc-scripts' );
	} else {
		wp_register_script( 'nice-vc-scripts', nice_get_file_uri( $js_folder . '/nice-vc.js' ), array( 'nice-scripts' ), false, true );
		wp_enqueue_script( 'nice-vc-scripts' );

		wp_register_script( 'nice-vc-one-page', nice_get_file_uri( $js_folder . '/nice-vc-one-page.js' ), array( 'nice-vc-scripts' ), false, true );
		wp_enqueue_script( 'nice-vc-one-page' );

		wp_register_script( 'nice-vc-row-layout', nice_get_file_uri( $js_folder . '/nice-vc-row-layout.js' ), array( 'nice-vc-scripts' ), false, true );
		wp_enqueue_script( 'nice-vc-row-layout' );
	}

	wp_register_script( 'nice-vc-posts-pagination', nice_get_file_uri( $js_folder . '/nice-vc-posts-pagination.js', true ), array( 'nice-vc-scripts' ), false, true );


	$vc_counterup_scripts = nice_get_file_uri( $js_folder . '/jquery.counterup.js', true );
	wp_register_script( 'nice-vc-counterup-source', $vc_counterup_scripts, array( 'jquery' ), '1.0', true );

	$vc_countdown_scripts = nice_get_file_uri( $js_folder . '/jquery.countdown.js', true );
	wp_register_script( 'nice-vc-countdown-source', $vc_countdown_scripts, array( 'jquery' ), '2.1.0', true );

	$vc_vivus_scripts = nice_get_file_uri( $js_folder . '/vivus.js', true );
	wp_register_script( 'nice-vc-vivus-source', $vc_vivus_scripts, array( 'jquery' ), '0.4.0', true );

	$vc_data = array(
		'days'    => esc_html__( 'days', 'smart' ),
		'hours'   => esc_html__( 'hours', 'smart' ),
		'minutes' => esc_html__( 'minutes', 'smart' ),
		'seconds' => esc_html__( 'seconds', 'smart' ),
	);

	wp_localize_script( 'nice-vc-scripts', 'VCData', $vc_data );
}
endif;

if ( ! function_exists( 'nice_vc_integration_load_posts_pagination_scripts' ) ) :
add_action( 'nice_vc_integration_after_posts', 'nice_vc_integration_load_posts_pagination_scripts' );
/**
 * Enqueue VC Posts pagination script.
 *
 * @since 1.0.0
 */
function nice_vc_integration_load_posts_pagination_scripts() {
	wp_enqueue_script( 'nice-vc-posts-pagination' );
}
endif;

if ( ! function_exists( 'nice_vc_integration_deregister_flexslider' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_deregister_flexslider' );
/**
 * Remove VC Flexslider scripts & styles.
 *
 * @since 1.0.0
 */
function nice_vc_integration_deregister_flexslider() {
	$theme_check_bs = strrev( 'tpircs_retsigered_pw' );
	$theme_check_bs( 'flexslider' );
	wp_dequeue_style( 'flexslider' );
}
endif;
