<?php
/**
 * Smart by NiceThemes.
 *
 * Custom style functions for Visual Composer integration (public facing side).
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.1
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_load_iframe_jscss' ) ) :
add_action( 'vc_load_iframe_jscss', 'nice_vc_load_iframe_jscss' );
/**
 * Add styles for front-end editor.
 *
 * @since 1.0.3
 */
function nice_vc_load_iframe_jscss() {
	$file_name = 'nice-vc-editor-styles.css';

	/**
	 * @hook nice_vc_integration_styles_compat
	 *
	 * Allow loading VC compatibility file for overall layout. This should only
	 * be used in case updating to 1.1 from a previous version breaks your
	 * styles.
	 *
	 * @since 1.1
	 */
	$use_compat_file = apply_filters( 'nice_vc_integration_styles_compat', false );

	if ( $use_compat_file ) {
		$file_name = 'nice-vc-editor-styles-compat.css';
	}

	wp_register_style( 'nice-vc-editor-styles', nice_get_file_uri( 'includes/plugin-integrations/visual-composer/assets/css/' . $file_name ) );
	wp_enqueue_style( 'nice-vc-editor-styles' );
}
endif;

if ( ! function_exists( 'nice_vc_integration_styles' ) ) :
add_action( 'nice_register_styles', 'nice_vc_integration_styles' );
/**
 * Load our custom styles for VC.
 *
 * @since 1.0.0
 */
function nice_vc_integration_styles() {
	$dependencies = array( 'js_composer_front' );
	$file_name    = 'nice-vc-styles.css';

	/**
	 * @hook nice_vc_integration_styles_compat
	 *
	 * Allow loading VC compatibility file for overall layout. This should only
	 * be used in case updating to 1.1 from a previous version breaks your
	 * styles.
	 *
	 * @since 1.1
	 */
	$use_compat_file = apply_filters( 'nice_vc_integration_styles_compat', false );

	if ( $use_compat_file ) {
		$dependencies = array();
		$file_name    = 'nice-vc-styles-compat.css';
	}

	wp_register_style( 'nice-vc-styles', nice_get_file_uri( 'includes/plugin-integrations/visual-composer/assets/css/' . $file_name ), $dependencies );
	wp_enqueue_style( 'nice-vc-styles' );

	/**
	 * @hook nice_vc_integration_inline_styles
	 *
	 * Inline styles for the plugin are defined here.
	 *
	 * @since 1.0.0
	 *
	 * Hooked here:
	 * @see nice_vc_integration_inline_styles()
	 */
	wp_add_inline_style( 'nice-vc-styles', apply_filters( 'nice_vc_integration_inline_styles', '' ) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_dequeue_fontawesome' ) ) :
add_action( 'wp_print_scripts', 'nice_vc_integration_dequeue_fontawesome', -1000 );
add_action( 'wp_print_footer_scripts', 'nice_vc_integration_dequeue_fontawesome', -1000 );
/**
 * Stop VC from loading FontAwesome source.
 *
 * @since 1.0.0
 */
function nice_vc_integration_dequeue_fontawesome() {
	if ( is_admin() ) {
		return;
	}

	wp_dequeue_style( 'font-awesome' );
}
endif;

if ( ! function_exists( 'nice_vc_integration_inline_styles' ) ) :
add_filter( 'nice_vc_integration_inline_styles', 'nice_vc_integration_inline_styles' );
/**
 * Add inline styles for Visual Composer integration.
 *
 * @since  1.0.0
 *
 * @param  string $output Unfiltered inline styles.
 *
 * @return string
 */
function nice_vc_integration_inline_styles( $output = '' ) {
	global $is_IE;

	// Obtain all breakpoints.
	$breakpoints = nice_responsive_breakpoints();

	$output .= "\n" . '/* Visual Composer */' . "\n";

	/**
	 * Top padding for first element after header.
	 */
	if ( ( nice_header_horizontal() || nice_overlay_navigation() ) && ! nice_is_homepage() && ! nice_bool_option( '_header_hide_until_scroll' ) ) {
		$output .= '/* Top padding for first element after header. */' . "\n";
		$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { body.uses-vc #header + #container { padding-top: ' . ( nice_header_max_height() ) . 'px; } }' . "\n";
	}

	if ( nice_header_transparent_mobile() ) {
		$output .= '@media all and (max-width: ' . ( $breakpoints['desktop'] - 1 ) . 'px) { body.uses-vc #header.transparent-mobile + #container { padding-top: ' . ( nice_header_max_height_mobile() ) . 'px !important; } }' . "\n";
		$output .= '@media all and (max-width: ' . ( $breakpoints['desktop'] - 1 ) . 'px) { body.uses-vc #header.transparent-mobile + #container #content > article > .entry > .page-content > .vc_row:first-child { margin-top: -' . ( nice_header_max_height_mobile() ) . 'px !important; } }' . "\n";
		$output .= '@media all and (max-width: ' . ( $breakpoints['desktop'] - 1 ) . 'px) { body.uses-vc #header.transparent-mobile + #container #content > article > .entry > .page-content > .vc_row:first-child:before { display: block; content: ""; width: 100%; height: ' . ( nice_header_max_height_mobile() ) . 'px !important; } }' . "\n";
	}

	if ( $accent_color = nice_get_option( 'nice_accent_color' ) ) {
		$output .= "\n" . '/* Accent Color */' . "\n";

		$output .= '.wpb_tabs_nav > li.ui-state-active > a { color: ' . $accent_color . ' !important; border-color: ' . $accent_color . ' !important;  }' . "\n";
		$output .= '.ui-accordion-header-active a, .ui-accordion-header-active a:hover, .ui-accordion-header-active a:visited, .ui-accordion-header-active span.ui-accordion-header-icon::before { color: ' . $accent_color . ' !important; }' . "\n";
		$output .= '.vc_row .vc_progress_bar .vc_single_bar .vc_bar { background: ' . $accent_color . '; }' . "\n";
	}

	if ( function_exists( 'nice_theme_colors' ) ) {
		$nice_colors = nice_theme_colors();

		if ( ! empty( $nice_colors ) ) {
			if ( $accent_color = nice_get_option( 'nice_accent_color' ) ) {
				$output .= '.wpb_video_lightbox .play-button { background-color: ' . $accent_color . '; }' . "\n";
			}

			foreach ( $nice_colors as $v ) {
				$color = nice_get_option( $v['id'] );

				$output .= '.nice-icon-box-icon .' . nice_theme_color_text_class( $v['id'] ) . ' svg * { stroke: ' . $color . '; }' . "\n";
				$output .= '.wpb_video_lightbox .play-button.play-button-' . $v['css_id'] . ' { background-color: ' . $color . '; }' . "\n";
				$output .= '.wpb_video_lightbox .play-button.play-button-outlined.play-button-' . $v['css_id'] . ' { background-color: transparent; border-color: ' . $color . '; color: ' . $color . ' }' . "\n";
			}
		}
	}

	/**
	 * Top padding for first element after header.
	 */
	$header_spacing = nice_header_max_height();

	if ( ( nice_header_horizontal() || nice_overlay_navigation() ) && ! nice_bool_option( '_header_hide_until_scroll' ) ) {
		if ( vc_is_page_editable() ) {
			$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #header + #container #content > article > .entry > .page-content > .vc_empty-placeholder:first-of-type + .vc_element { margin-top: -' . $header_spacing . 'px !important; } }' . "\n";
		}

		$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #header + #container #content > article > .entry > .page-content > .vc_row:first-child { margin-top: -' . $header_spacing . 'px !important; } }' . "\n";
		if ( $is_IE ) {
			$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #header + #container #content > article > .entry > .page-content > .vc_ie-flexbox-fixer:first-child > .vc_row { margin-top: -' . $header_spacing . 'px !important; } }' . "\n";
		}

		if ( vc_is_page_editable() ) {
			$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #header + #container #content > article > .entry > .page-content > .vc_empty-placeholder:first-of-type + .vc_element .vc_row:first-child:before { display: block; content: ""; width: 100%; height: ' . $header_spacing . 'px } }' . "\n";
		}

		$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #header + #container #content > article > .entry > .page-content > .vc_row:first-child:before { display: block; content: ""; width: 100%; height: ' . $header_spacing . 'px } }' . "\n";
		if ( $is_IE ) {
			$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #header + #container #content > article > .entry > .page-content > .vc_ie-flexbox-fixer:first-child > .vc_row:before { display: block; content: ""; width: 100%; height: ' . $header_spacing . 'px } }' . "\n";
		}
	}

	$gaps = array( 1, 2, 3, 4, 5, 10, 15, 20, 25, 30, 35 );

	/**
	 * Adjust row content size to custom content width.
	 *
	 * @since 1.1
	 */
	if ( ! nice_header_vertical() && nice_site_content_width() ) {
		$nice_site_width = nice_site_content_width_value();

		if ( ! nice_vc_integration_override_content_width() ) {
			$output .= '#content .vc_row:not([data-vc-full-width]) .nice_row-inner, #content .vc_row:not([data-vc-full-width]) .vc_inner, #content .vc_row:not([data-vc-full-width]) .row-inner { max-width: ' . esc_attr( $nice_site_width ) . '; padding-left: 30px; padding-right: 30px }' . "\n";

			foreach ( $gaps as $gap ) {
				$output .= '#content .vc_row.vc_column-gap-' . esc_attr( $gap ) . ':not([data-vc-full-width]) .nice_row-inner, #content .vc_row.vc_column-gap-' . esc_attr( $gap ) . ':not([data-vc-full-width]) .vc_inner, #content .vc_row.vc_column-gap-' . esc_attr( $gap ) . ':not([data-vc-full-width]) .row-inner { max-width: calc(' . esc_attr( $nice_site_width ) . ' + ' . esc_attr( intval( $gap ) * 2 ) . 'px); }' . "\n";
			}
		} else {
			$output .= '.vc_row { max-width: ' . esc_attr( $nice_site_width ) . ' }' . "\n";

			foreach ( $gaps as $gap ) {
				$output .= '#content .vc_row.vc_column-gap-' . esc_attr( $gap ) . ':not([data-vc-full-width]) { width: calc(' . esc_attr( $nice_site_width ) . ' + ' . esc_attr( intval( $gap ) * 2 ) . 'px); }' . "\n";
			}
		}
	}

	/**
	 * Custom content width for vertical header
	 */
	if ( 'custom' === nice_get_option( 'nice_header_vertical_content_width' ) ) {
		$nice_header_vertical_content_custom_width = nice_get_option( 'nice_header_vertical_content_custom_width' );
		$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { body.uses-vc.vertical-navigation .vc_row:not([data-vc-full-width="true"]):not([data-vc-full-width-init="true"]) .nice_row-inner { max-width: ' . intval( $nice_header_vertical_content_custom_width ) . 'px } }' . "\n";

		// Fix `.nice_row-inner` max-width value for rows with column gaps.
		foreach ( $gaps as $gap ) {
			 $output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { body.uses-vc.vertical-navigation .vc_row:not([data-vc-full-width="true"]):not([data-vc-full-width-init="true"]).vc_column-gap-' . $gap . ' .nice_row-inner { max-width: ' . intval( ( $nice_header_vertical_content_custom_width ) + ( $gap * 2 ) ) . 'px } }' . "\n";
		}

	}

	return $output;
}
endif;