<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage responsive options.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_vc_integration_add_responsive_desktop' ) ) :
/**
 * Return array with options to enable desktop view.
 *
 * @since  1.0.0
 *
 * @param  array $args
 *
 * @return array
 */
function nice_vc_integration_add_responsive_desktop( array $args = array() ) {
	$desktop = array(
		'type'        => 'checkbox',
		'heading'     => esc_html__( 'Display in Desktop', 'smart' ),
		'param_name'  => 'desktop_visibility',
		'std'         => 'yes',
		'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
		'description' => esc_html__( 'Choose the visibiliy of the element in desktop layout mode (960px >).', 'smart' ),
		'group'       => esc_html__( 'Responsive', 'smart' ),
	);

	return array_merge( $desktop, $args );
}
endif;

if ( ! function_exists( 'nice_vc_integration_add_responsive_tablet' ) ) :
/**
 * Return array with options to tablet view
 *
 * @since  1.0.0
 *
 * @param  array $args
 *
 * @return array
 */
function nice_vc_integration_add_responsive_tablet( array $args = array() ) {
	$tablet = array(
		'type'        => 'checkbox',
		'heading'     => esc_html__( 'Display in Tablet', 'smart' ),
		'param_name'  => 'tablet_visibility',
		'std'         => 'yes',
		'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
		'description' => esc_html__( 'Choose the visibiliy of the element in tablet layout mode (570px > < 960px).', 'smart' ),
		'group'       => esc_html__( 'Responsive', 'smart' ),
	);

	return array_merge( $tablet, $args );

}
endif;

if ( ! function_exists( 'nice_vc_integration_add_responsive_mobile' ) ) :
/**
 * Return array with options to enable mobile view
 *
 * @since  1.0.0
 *
 * @param  array $args
 *
 * @return array
 */
function nice_vc_integration_add_responsive_mobile( array $args = array() ) {
	$mobile = array(
		'type'        => 'checkbox',
		'heading'     => esc_html__( 'Display in Mobile', 'smart' ),
		'param_name'  => 'mobile_visibility',
		'std'         => 'yes',
		'value'       => array( esc_html__( 'Yes', 'smart' ) => 'yes' ),
		'description' => esc_html__( 'Choose the visibiliy of the element in mobile layout mode (< 570px).', 'smart' ),
		'group'       => esc_html__( 'Responsive', 'smart' ),
	);

	$args = array_merge( $mobile, $args );

	return $args;
}
endif;
