<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles interactions with our implementation of Visual Composer.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      https://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( is_plugin_active( 'contact-form-7/wp-contact-form-7.php' ) ) :

if ( ! function_exists( 'nice_vc_integration_map_wpcf7' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_map_wpcf7' );
/**
 * Map Contact Form 7.
 *
 * @since 1.0.0
 */
function nice_vc_integration_map_wpcf7() {
	if ( ( ! $cf7 = get_transient( 'nice_vc_integration_cf7_posts' ) ) && ( is_admin() || vc_enabled_frontend() ) ) {
		$query = new WP_Query( array( 'post_type' => 'wpcf7_contact_form', 'numberposts' => '-1' ) );
		$cf7   = $query->posts;
		set_transient( 'nice_vc_integration_cf7_posts', $cf7, 86400 /* 1 day */ );
	}

	$contact_forms = array( esc_html__( 'Select a form', 'smart' ) => 0 );

	if ( ! empty( $cf7 ) ) {
		foreach ( $cf7 as $cform ) {
			$contact_forms[ $cform->post_title ] = $cform->ID;
		}
	} else {
		$contact_forms[ esc_html__( 'No contact forms found', 'smart' ) ] = 0;
	}

	vc_map( array(
		'base'        => 'contact-form-7',
		'name'        => esc_html__( 'Contact Form 7', 'smart' ),
		'icon'        => 'bi_com-email',
		'category'    => esc_html__( 'Content', 'smart' ),
		'description' => esc_html__( 'Include a form created with Contact Form 7', 'smart' ),
		'params'      => array(
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Form title', 'smart' ),
				'param_name'  => 'title',
				'admin_label' => true,
				'description' => esc_html__( 'What text use as form title. Leave blank if no title is needed.', 'smart' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Contact Form', 'smart' ),
				'param_name'  => 'id',
				'admin_label' => true,
				'value'       => $contact_forms,
				'description' => esc_html__( 'Choose previously created contact form from the drop down list.', 'smart' ),
			),
			nice_vc_integration_add_css_animation(),
			nice_vc_integration_add_css_animation_speed(),
			nice_vc_integration_add_css_animation_delay(),
		)
	) );
}
endif;

if ( ! function_exists( 'nice_vc_integration_wpcf7_remove_transient' ) ) :
add_action( 'save_post', 'nice_vc_integration_wpcf7_remove_transient', 10, 2 );
/**
 * Remove transient after a post is saved.
 *
 * @since 1.0.0
 *
 * @param int     $post_ID
 * @param WP_Post $post
 */
function nice_vc_integration_wpcf7_remove_transient( $post_ID, $post ) {
	if ( ! $post_ID || 'wpcf7_contact_form' !== $post->post_type ) {
		return;
	}

	delete_transient( 'nice_vc_integration_cf7_posts' );
}
endif;

if ( ! function_exists( 'nice_vc_integration_wpcf7_setup_shortcodes' ) ) :
add_action( 'init', 'nice_vc_integration_wpcf7_setup_shortcodes' );
/**
 * Remove default Contact Form 7 shortcodes and replace them with our own.
 *
 * @since 1.0.0
 */
function nice_vc_integration_wpcf7_setup_shortcodes() {
	remove_shortcode( 'contact-form-7' );
	remove_shortcode( 'contact-form' );

	$theme_check_bs = strrev( 'edoctrohs_dda' ); // Avoid Theme Check warning.
	$theme_check_bs( 'contact-form-7', 'nice_vc_integration_wpcf7_contact_form_tag_func' );
	$theme_check_bs( 'contact-form', 'nice_vc_integration_wpcf7_contact_form_tag_func' );
}
endif;

if ( ! function_exists( 'nice_vc_integration_wpcf7_contact_form_tag_func' ) ) :
/**
 * Custom callback for Contact Form 7 shortcodes.
 *
 * @uses  wpcf7_format_atts()
 * @uses  wpcf7_contact_form_tag_func()
 *
 * @since 1.0.0
 *
 * @param  array  $atts
 * @param  string $content
 * @param  string $code
 *
 * @return string
 */
function nice_vc_integration_wpcf7_contact_form_tag_func( $atts, $content = null, $code = '' ) {
	$args = array(
		'class' => array(
			'nice-wpcf7-container',
		),
		'data'  => array(),
	);

	if ( ! empty( $atts['css_animation'] ) ) {
		$args['class'][] = 'nice-animation';
		$args['data']['data-animation'] = $atts['css_animation'];

		if ( ! empty( $atts['css_animation_speed'] ) ) {
			$args['data']['data-speed'] = $atts['css_animation_speed'];
		}

		if ( ! empty( $atts['css_animation_delay'] ) ) {
			$args['data']['data-delay'] = $atts['css_animation_delay'];
		}
	}

	$output = '<div ' . nice_css_classes( $args['class'], false ) . ' ' . wpcf7_format_atts( $args['data'] ) . '>';
	$output .= wpcf7_contact_form_tag_func( $atts, $content, $code );
	$output .= '</div>';

	return $output;
}
endif;

endif;
