<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles interactions with our implementation of Visual Composer.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      https://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( is_plugin_active( 'gravityforms/gravityforms.php' ) ) :

	$gravity_forms_array[ esc_html__( 'No Gravity forms found.', 'smart' ) ] = '';

	if ( class_exists( 'RGFormsModel' ) ) {
		$gravity_forms = RGFormsModel::get_forms( 1, 'title' );
		if ( $gravity_forms ) {
			$gravity_forms_array = array(
				esc_html__( 'Specify a form to display.', 'smart' ) => ''
			);

			foreach ( $gravity_forms as $gravity_form ) {
				$gravity_forms_array[$gravity_form->title] = $gravity_form->id;
			}
		}
	}

	vc_map( array(
		'name'        => esc_html__( 'Gravity Form', 'smart' ) ,
		'base'        => 'gravityform',
		'icon'        => 'icon-wpb-vc_gravityform',
		'category'    => esc_html__( 'Content', 'smart' ) ,
		'description' => esc_html__( 'Place Gravity form', 'smart' ) ,
		'params'      => array(
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Form', 'smart' ) ,
				'param_name'  => 'id',
				'value'       => $gravity_forms_array,
				'description' => esc_html__( 'Specify a form to add it to your post or page.', 'smart' ) ,
				'admin_label' => true
			) ,
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Display Form Title', 'smart' ) ,
				'param_name'  => 'title',
				'value'       => array(
					esc_html__( 'No', 'smart' ) => 'false',
					esc_html__( 'Yes', 'smart' ) => 'true'
				) ,
				'description' => esc_html__( 'Would you like to display the forms title?', 'smart' ) ,
				'dependency' => array(
					'element'   => 'id',
					'not_empty' => true
				)
			) ,
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Display Form Description', 'smart' ) ,
				'param_name'  => 'description',
				'value'       => array(
					esc_html__( 'No', 'smart' )  => 'false',
					esc_html__( 'Yes', 'smart' ) => 'true'
				) ,
				'description' => esc_html__( 'Would you like to display the forms description?', 'smart' ) ,
				'dependency' => array(
					'element' => 'id',
					'not_empty' => true
				)
			) ,
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Enable AJAX?', 'smart' ) ,
				'param_name'  => 'ajax',
				'value'       => array(
					esc_html__( 'No', 'smart' )  => 'false',
					esc_html__( 'Yes', 'smart' ) => 'true'
				) ,
				'description' => esc_html__( 'Enable AJAX submission?', 'smart' ) ,
				'dependency' => array(
					'element' => 'id',
					'not_empty' => true
				)
			) ,
			array(
				'type'        => 'textfield',
				'heading'     => esc_html__( 'Tab Index', 'smart' ) ,
				'param_name'  => 'tabindex',
				'description' => esc_html__( '(Optional) Specify the starting tab index for the fields of this form. Leave blank if you\'re not sure what this is.', 'smart' ) ,
				'dependency' => array(
					'element' => 'id',
					'not_empty' => true
				)
			)
		)
	));

endif;
