<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles interactions with our implementation of Visual Composer.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      https://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( class_exists( 'Nice_Portfolio_Plugin' ) ) :

if ( ! function_exists( 'nice_vc_integration_portfolio_post_types' ) ) :
add_filter( 'nice_vc_post_types', 'nice_vc_integration_portfolio_post_types', 20 );
/**
 * Add project post type to list of available post types.
 *
 * @since  1.0.0
 *
 * @param  array $post_types
 *
 * @return array
 */
function nice_vc_integration_portfolio_post_types( array $post_types = array() ) {
	$post_types[] = 'portfolio_project';

	return $post_types;
}
endif;

if ( ! function_exists( 'nice_vc_integration_portfolio_posts_layout_key_map' ) ) :
add_filter( 'nice_vc_integration_posts_layout_key_map', 'nice_vc_integration_portfolio_posts_layout_key_map' );
/**
 * Add portfolio items to VC post item layout.
 *
 * @since 1.0.0
 *
 * @param array $key_map
 *
 * @return array
 */
function nice_vc_integration_portfolio_posts_layout_key_map( array $key_map = array() ) {
	$key_map[ nice_portfolio_post_type_name() ] = 'portfolio_items';

	return $key_map;
}
endif;

if ( ! function_exists( 'nice_vc_integration_portfolio_posts_categories' ) ) :
add_filter( 'nice_vc_integration_posts_categories', 'nice_vc_integration_portfolio_posts_categories', 10, 2 );
add_filter( 'nice_vc_integration_posts_item_categories', 'nice_vc_integration_portfolio_posts_categories', 10, 2 );
/**
 * Add project categories to category filter.
 *
 * @since  1.0.0
 *
 * @param  array   $categories
 * @param  WP_Post $post
 *
 * @return array
 */
function nice_vc_integration_portfolio_posts_categories( array $categories = array(), WP_Post $post ) {
	if ( nice_portfolio_post_type_name() === $post->post_type ) {
		$terms = get_the_terms( $post, nice_portfolio_category_name() );

		if ( is_array( $terms ) && ! empty( $terms ) ) {
			$categories = array_merge( $categories, $terms );
		}
	}

	return $categories;
}
endif;

if ( ! function_exists( 'nice_vc_integration_portfolio_posts_options' ) ) :
add_filter( 'nice_vc_integration_posts_options', 'nice_vc_integration_portfolio_posts_options', 30 );
/**
 * Add options for portfolio items to VC Posts component.
 *
 * @since 1.0.0
 *
 * @param  array $options
 *
 * @return array
 */
function nice_vc_integration_portfolio_posts_options( array $options = array() ) {
	$portfolio_options = array(
		array(
			'type'        => 'sorted_list',
			'heading'     => esc_html__( 'Portfolio Projects', 'smart' ),
			'param_name'  => 'portfolio_items',
			'id'          => 'portfolio_items',
			'description' => esc_html__( 'Control teasers look. Enable blocks and place them in desired order.', 'smart' ),
			'value'       => 'media,category|block|text|contrast-skin,title,text|contrast-skin,text,link|default,separator|full,author|inline-block|contrast-skin,comments|inline-block|icon-text|contrast-skin',
			'group'       => esc_html__( 'Module', 'smart' ),
			'options'     => nice_vc_integration_portfolio_posts_item_options(),
		),
	);

	$options['params'] = nice_options_enqueue( $options['params'], $portfolio_options, 'page_items' );

	return $options;
}
endif;

if ( ! function_exists( 'nice_vc_integration_portfolio_posts_item_options' ) ) :
/**
 * Return list of display options for post items.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_portfolio_posts_item_options() {
	$options = array(
		nice_vc_integration_posts_item_media_options(),
		nice_vc_integration_posts_item_title_options(),
		nice_vc_integration_posts_item_type_options(),
		nice_vc_integration_posts_item_author_options(),
		nice_vc_integration_posts_item_category_options(),
		nice_vc_integration_posts_item_comments_options(),
		nice_vc_integration_posts_item_text_options(),
		nice_vc_integration_posts_item_link_options(),
		nice_vc_integration_posts_item_icon_options(),
		nice_vc_integration_posts_item_separator_options(),
	);

	/**
	 * @hook nice_vc_integration_posts_post_item_options
	 *
	 * Add or remove options by hooking in here.
	 *
	 * @since 1.0.0
	 */
	return apply_filters( 'nice_vc_integration_portfolio_posts_item_options', $options );
}
endif;

if ( ! function_exists( 'nice_vc_integration_portfolio_posts_item_type_icon_class' ) ) :
add_filter( 'nice_vc_integration_posts_item_type_icon_class', 'nice_vc_integration_portfolio_posts_item_type_icon_class' );
/**
 * Obtain the HTML class for a portfolio project's icon.
 *
 * @since  1.0.0
 *
 * @param  string $icon_class
 *
 * @return string
 */
function nice_vc_integration_portfolio_posts_item_type_icon_class( $icon_class = '' ) {
	$item = nice_vc_integration_posts_current_item();

	if ( nice_portfolio_post_type_name() === $item->post_type ) {
		$icon_class = 'fa fa-paint-brush';
	}

	return $icon_class;
}
endif;

endif;
