<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles interactions with our implementation of Visual Composer.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      https://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( class_exists( 'Nice_Team_Plugin' ) ) :

if ( ! function_exists( 'nice_vc_integration_team_posts_layout_key_map' ) ) :
add_filter( 'nice_vc_integration_posts_layout_key_map', 'nice_vc_integration_team_posts_layout_key_map' );
/**
 * Add team items to VC post item layout.
 *
 * @since 1.0.0
 *
 * @param array $key_map
 *
 * @return array
 */
function nice_vc_integration_team_posts_layout_key_map( array $key_map = array() ) {
	$key_map[ nice_team_post_type_name() ] = 'team_member';

	return $key_map;
}
endif;

if ( ! function_exists( 'nice_vc_integration_team_posts_categories' ) ) :
add_filter( 'nice_vc_integration_posts_categories', 'nice_vc_integration_team_posts_categories', 10, 2 );
add_filter( 'nice_vc_integration_posts_item_categories', 'nice_vc_integration_team_posts_categories', 10, 2 );
/**
 * Add teams to a loop of posts processed with VC Posts shortcode.
 *
 * @since  1.0.0
 *
 * @param  array   $categories
 * @param  WP_Post $post
 *
 * @return array
 */
function nice_vc_integration_team_posts_categories( array $categories = array(), WP_Post $post ) {
	if ( nice_team_post_type_name() === $post->post_type ) {
		$terms = get_the_terms( $post, nice_team_category_name() );

		if ( is_array( $terms ) && ! empty( $terms ) ) {
			$categories = array_merge( $categories, $terms );
		}
	}

	return $categories;
}
endif;

if ( ! function_exists( 'nice_vc_integration_team_posts_options' ) ) :
add_filter( 'nice_vc_integration_posts_options', 'nice_vc_integration_team_posts_options', 20 );
/**
 * Add options for portfolio items to VC Posts component.
 *
 * @since 1.0.0
 *
 * @param  array $options
 *
 * @return array
 */
function nice_vc_integration_team_posts_options( array $options = array() ) {
	$team_options = array(
		array(
			'type'        => 'sorted_list',
			'heading'     => esc_html__( 'Team Members', 'smart' ),
			'param_name'  => 'team_member',
			'id'          => 'team_member',
			'description' => esc_html__( 'Control teasers look. Enable blocks and place them in desired order.', 'smart' ),
			'value'       => 'media,position|block|contrast-skin,title,category|block|text|contrast-skin,text|contrast-skin,text,link|default,separator|full,contact|contrast-skin',
			'group'       => esc_html__( 'Module', 'smart' ),
			'options'     => nice_vc_integration_team_posts_item_options(),
		),
	);

	$options['params'] = nice_options_enqueue( $options['params'], $team_options, 'page_items' );

	return $options;
}
endif;

if ( ! function_exists( 'nice_vc_integration_team_posts_item_options' ) ) :
/**
 * Return list of display options for post items.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_team_posts_item_options() {
	$options = array(
		nice_vc_integration_posts_item_media_options(),
		nice_vc_integration_team_posts_item_position_options(),
		nice_vc_integration_posts_item_title_options(),
		nice_vc_integration_posts_item_type_options(),
		nice_vc_integration_team_posts_item_category_options(),
		nice_vc_integration_posts_item_text_options(),
		nice_vc_integration_posts_item_link_options(),
		nice_vc_integration_posts_item_icon_options(),
		nice_vc_integration_posts_item_separator_options(),
		nice_vc_integration_team_posts_item_contact_options(),
	);

	/**
	 * @hook nice_vc_integration_posts_post_item_options
	 *
	 * Add or remove options by hooking in here.
	 *
	 * @since 1.0.0
	 */
	return apply_filters( 'nice_vc_integration_posts_page_item_options', $options );
}
endif;

if ( ! function_exists( 'nice_vc_integration_team_posts_item_position_options' ) ) :
/**
 * Obtain option for team member's position.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_team_posts_item_position_options() {
	return array(
		'position',
		esc_html__( 'Position', 'smart' ),
		nice_vc_integration_posts_display_options(),
		nice_vc_integration_posts_meta_color_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_team_posts_item_category_options' ) ) :
/**
 * Obtain options for member's teams.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_team_posts_item_category_options() {
	return array(
		'category',
		esc_html__( 'Teams', 'smart' ),
		nice_vc_integration_posts_display_options(),
		nice_vc_integration_posts_text_style_options( array( 'icon' ) ),
		nice_vc_integration_posts_meta_color_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_team_posts_item_contact_options' ) ) :
/**
 * Obtain option for team member's contact data.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_team_posts_item_contact_options() {
	return array(
		'contact',
		esc_html__( 'Contact Data', 'smart' ),
		nice_vc_integration_posts_meta_color_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_team_posts_item_position_html' ) ) :
add_filter( 'nice_vc_integration_posts_html_position', 'nice_vc_integration_team_posts_item_position_html', 10, 2 );
/**
 * Construct HTML for member's position.
 *
 * @since  1.0.0
 *
 * @param  string $html
 * @param  array $args
 *
 * @return string
 */
function nice_vc_integration_team_posts_item_position_html( $html = '', array $args = array() ) {
	$item = nice_vc_integration_posts_current_item();

	if ( nice_team_post_type_name() !== $item->post_type ) {
		return '';
	}

	$position = get_post_meta( $item->post_id, '_team_member_position', true );

	if ( $position ) {
		$display_type = empty( $args[0] ) ? 'block' : $args[0];
		$skin_class   = empty( $args[1] ) ? 'inherit-skin' : $args[1];

		$html .= '<section class="entry-position entry-meta ' . esc_attr( $display_type ) . ' ' . esc_attr( $skin_class ) . '">';
		$html .= '<span>' . esc_attr( $position ) . '</span>';
		$html .= '</section>';
	}

	return $html;
}
endif;

if ( ! function_exists( 'nice_vc_integration_team_posts_item_category_icon_class' ) ) :
add_filter( 'nice_vc_integration_posts_item_category_icon_class', 'nice_vc_integration_team_posts_item_category_icon_class' );
/**
 * Modify the icon for the list of team member's categories.
 *
 * @since  1.0.0
 *
 * @param  string $icon_class
 *
 * @return string
 */
function nice_vc_integration_team_posts_item_category_icon_class( $icon_class = '' ) {
	$item = nice_vc_integration_posts_current_item();

	if ( nice_team_post_type_name() === $item->post_type ) {
		$icon_class .= 'fa fa-group';
	}

	return $icon_class;
}
endif;

if ( ! function_exists( 'nice_vc_integration_team_posts_item_contact_html' ) ) :
add_filter( 'nice_vc_integration_posts_html_contact', 'nice_vc_integration_team_posts_item_contact_html', 10, 2 );
/**
 * Construct HTML for member's contact data.
 *
 * @since  1.0.0
 *
 * @param  string $html
 * @param  array  $args
 *
 * @return string
 */
function nice_vc_integration_team_posts_item_contact_html( $html = '', array $args = array() ) {
	$item = nice_vc_integration_posts_current_item();

	if ( nice_team_post_type_name() !== $item->post_type ) {
		return '';
	}

	$inner_html = '';

	$member_data = array(
		'url' => array(
			'title'      => esc_html__( 'Website', 'smart' ),
			'item_class' => 'member-url',
			'target'     => '_blank',
			'icon_class' => 'fa fa-lg fa-external-link',
			'item_prop'  => 'url',
		),
		'email' => array(
			'title'      => esc_html__( 'Email', 'smart' ),
			'item_class' => 'member-email',
			'target'     => '_self',
			'icon_class' => 'fa fa-lg fa-envelope-o',
			'item_prop'  => 'email',
			'before_contact' => 'mailto:',
		),
		'twitter' => array(
			'title'      => esc_html__( 'Twitter', 'smart' ),
			'item_class' => 'member-twitter',
			'target'     => '_self',
			'icon_class' => 'fa fa-lg fa-twitter',
			'item_prop'  => '',
			'before_contact' => 'https://twitter.com/',
		),
		'facebook' => array(
			'title'      => esc_html__( 'Twitter', 'smart' ),
			'item_class' => 'member-facebook',
			'target'     => '_self',
			'icon_class' => 'fa fa-lg fa-facebook',
			'item_prop'  => '',
		),
		'linkedin' => array(
			'title'      => esc_html__( 'LinkedIn', 'smart' ),
			'item_class' => 'member-linkedin',
			'target'     => '_self',
			'icon_class' => 'fa fa-lg fa-linkedin',
			'item_prop'  => '',
		),
	);

	foreach ( $member_data as $key => $data ) {
		$contact = get_post_meta( $item->post_id, '_team_member_' . $key, true );

		if ( $contact ) {
			$url = isset( $data['before_contact'] ) ? $data['before_contact'] . $contact : $contact;

			$inner_html .= '<span class="' . esc_attr( $data['item_class'] ) . '">';
			$inner_html .= '<a href="' . esc_url( $url ) . '" target="' . esc_attr( $data['target'] ) . '" title="' . esc_attr( $data['title'] ) . '" itemprop="' . esc_attr( $data['item_prop'] ) . '">';
			$inner_html .= '<i class="' . esc_attr( $data['icon_class'] ) . '"></i>';
			$inner_html .= '</a>';
			$inner_html .= '</span>';
		}
	}

	if ( $inner_html ) {
		$skin_class = empty( $args[0] ) ? 'inherit-skin' : $args[0];

		$html .= '<section class="entry-contact entry-meta block ' . esc_attr( $skin_class ) . '">';
		$html .= $inner_html;
		$html .= '</section>';
	}

	return $html;
}
endif;

endif;
