<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles interactions with our implementation of Visual Composer.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      https://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( is_plugin_active( 'revslider/revslider.php' ) ) :

if ( ! function_exists( 'nice_vc_integration_revslider_admin_icons' ) ) :
add_action( 'vc_after_init', 'nice_vc_integration_revslider_admin_icons', 20 );
/**
 * Modify the icons for revolution slider
 *
 * @since 1.0
 */
function nice_vc_integration_revslider_admin_icons() {
	vc_map_update( 'rev_slider_vc', 'icon', 'bi_music-repeat' );
}
endif;

if ( ! function_exists( 'nice_vc_integration_revslider_remove_component' ) ) :
// Hook for admin editor.
add_action( 'vc_build_admin_page', 'nice_vc_integration_revslider_remove_component' );
/**
 * Remove default components we don't want.
 *
 * @since 1.0.0
 */
function nice_vc_integration_revslider_remove_component() {

	vc_remove_element( 'rev_slider' );

}

endif;

if ( ! function_exists( 'nice_vc_integration_revslider_in_first_row' ) ) :
/**
 * Check if we have Revolution slider in the first row of the content
 *
 * @since 1.0.0
 */
function nice_vc_integration_revslider_in_first_row() {


	if ( is_singular( $post_types = nice_vc_get_post_types() ) ) {
		global $post;

		if ( has_shortcode( $post->post_content, 'rev_slider_vc' ) && has_shortcode( $post->post_content, 'vc_row' ) ) {
			// Parse current post content into a shortcode tree.
			$content = nice_shortcode_tree( $post->post_content );
			$root    = $content->getRoot();

			// Find the first row.
			$rows      = $root->findAll( 'vc_row' );
			$first_row = empty( $rows ) ? false : reset( $rows );

			// Find sliders in the first row.
			$first_row_sliders = $first_row->findAll( 'rev_slider_vc' );

			if ( ! empty( $first_row_sliders ) ) {
				return true;
			}
		}
	}

	return false;

}

endif;


if ( ! function_exists( 'nice_vc_integration_revslider_inline_styles' ) ) :
add_filter( 'nice_inline_styles', 'nice_vc_integration_revslider_inline_styles' );
/**
 * Add inline styles for Visual Composer integration.
 *
 * @since  1.0.0
 *
 * @param  string $output Unfiltered inline styles.
 *
 * @return string
 */
function nice_vc_integration_revslider_inline_styles( $output = '' ) {
	// Obtain all breakpoints.
	$breakpoints = nice_responsive_breakpoints();

	if ( nice_vc_integration_revslider_in_first_row() && ( nice_header_transparent() || nice_bool_option( '_header_hide_until_scroll' )) ) {
		$header_spacing = nice_header_max_height();

		$output .= '/* VC & RevSlider Compatibility */';
		$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { body.uses-vc #header + #container #content > article > .entry > .page-content > .vc_row:first-child { margin-top: -' . $header_spacing . 'px !important; } }' . "\n";
		$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { body.uses-vc #header + #container #content > article > .entry > .page-content > .vc_row:first-child:before { display: block; content: ""; width: 100%; height: 0 !important } }' . "\n";

		$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { body.uses-vc #header + #container #content > article > .entry > .page-content > .vc_row:first-child .rev_slider_wrapper .rev_slider:before { content: ""; display: block; height: ' . $header_spacing . 'px; } }';
	}

	if ( nice_header_transparent_mobile() ) {
		$header_spacing_mobile = nice_header_max_height_mobile();

		$output .= '@media all and (max-width: ' . ( $breakpoints['desktop'] - 1 ) . 'px) { body.uses-vc #header + #container #content > article > .entry > .page-content > .vc_row:first-child .rev_slider_wrapper .rev_slider { margin-top: -' . $header_spacing_mobile . 'px !important; } }';
		$output .= '@media all and (max-width: ' . ( $breakpoints['desktop'] - 1 ) . 'px) { body.uses-vc #header + #container #content > article > .entry > .page-content > .vc_row:first-child .wpb_revslider_element { margin-top: -' . $header_spacing_mobile . 'px !important; padding-top: ' . $header_spacing_mobile . 'px !important; } }';
	}

	return $output;
}
endif;

endif;
