<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles interactions with our implementation of Visual Composer.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      https://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( class_exists( 'WooCommerce' ) ) :

if ( ! function_exists( 'nice_vc_integration_woocommerce_post_types' ) ) :
add_filter( 'nice_vc_post_types', 'nice_vc_integration_woocommerce_post_types', 10 );
/**
 * Add product post type to list of available post types.
 *
 * @since  1.0.0
 *
 * @param  array $post_types
 *
 * @return array
 */
function nice_vc_integration_woocommerce_post_types( array $post_types = array() ) {
	$post_types[] = 'product';

	return $post_types;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_layout_key_map' ) ) :
add_filter( 'nice_vc_integration_posts_layout_key_map', 'nice_vc_integration_woocommerce_posts_layout_key_map' );
/**
 * Add woocommerce items to VC post item layout.
 *
 * @since 1.0.0
 *
 * @param array $key_map
 *
 * @return array
 */
function nice_vc_integration_woocommerce_posts_layout_key_map( array $key_map = array() ) {
	$key_map['product'] = 'product_items';

	return $key_map;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_categories' ) ) :
add_filter( 'nice_vc_integration_posts_categories', 'nice_vc_integration_woocommerce_posts_categories', 10, 2 );
add_filter( 'nice_vc_integration_posts_item_categories', 'nice_vc_integration_woocommerce_posts_categories', 10, 2 );
/**
 * Add product categories to category filter.
 *
 * @since  1.0.0
 *
 * @param  array   $categories
 * @param  WP_Post $post
 *
 * @return array
 */
function nice_vc_integration_woocommerce_posts_categories( array $categories = array(), WP_Post $post ) {
	if ( 'product' === $post->post_type ) {
		$terms = get_the_terms( $post, 'product_cat' );

		if ( is_array( $terms ) && ! empty( $terms ) ) {
			$categories = array_merge( $categories, $terms );
		}
	}

	return $categories;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_options' ) ) :
add_filter( 'nice_vc_integration_posts_options', 'nice_vc_integration_woocommerce_posts_options', 10 );
/**
 * Add options for woocommerce items to VC Posts component.
 *
 * @since 1.0.0
 *
 * @param  array $options
 *
 * @return array
 */
function nice_vc_integration_woocommerce_posts_options( array $options = array() ) {
	$woocommerce_options = array(
		array(
			'type'        => 'sorted_list',
			'heading'     => esc_html__( 'Products', 'smart' ),
			'param_name'  => 'product_items',
			'id'          => 'product_items',
			'description' => esc_html__( 'Control teasers look. Enable blocks and place them in desired order.', 'smart' ),
			'value'       => 'media,sale|top-right,rating|top-left,category|block|text|contrast-skin,title,text,price,add_to_cart|default,separator|full',
			'group'       => esc_html__( 'Module', 'smart' ),
			'options'     => array(
				nice_vc_integration_woocommerce_posts_item_media_options(),
				nice_vc_integration_posts_item_title_options(),
				nice_vc_integration_posts_item_type_options(),
				nice_vc_integration_posts_item_category_options(),
				nice_vc_integration_woocommerce_posts_item_rating_options(),
				nice_vc_integration_posts_item_text_options(),
				nice_vc_integration_woocommerce_posts_item_price_options(),
				nice_vc_integration_woocommerce_posts_item_sale_options(),
				nice_vc_integration_woocommerce_posts_item_add_to_cart_options(),
				nice_vc_integration_posts_item_link_options(),
				nice_vc_integration_posts_item_icon_options(),
				nice_vc_integration_posts_item_separator_options(),
				nice_vc_integration_woocommerce_posts_item_quick_view_options(),
			),
		),
	);

	/**
	 * @hook nice_vc_integration_woocommerce_options
	 *
	 * Modify post options here.
	 *
	 * @since 1.0.0
	 */
	$woocommerce_options = apply_filters( 'nice_vc_integration_woocommerce_options', $woocommerce_options );

	$options['params'] = nice_options_enqueue( $options['params'], $woocommerce_options, 'page_items' );

	return $options;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_media_options' ) ) :
/**
 * Obtain options for product media.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_woocommerce_posts_item_media_options() {
	return array_merge(
		nice_vc_integration_posts_item_media_options(),
		array(
			array(
				array(
					'',
					esc_html__( 'Single Image', 'smart' ),
				),
				array(
					'flip',
					esc_html__( 'Flip Image', 'smart' ),
				),
			)
		)
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_price_options' ) ) :
/**
 * Obtain options for product's price.
 *
 * @since  1.0.0
 * @return array
 */
function nice_vc_integration_woocommerce_posts_item_price_options() {
	return array(
		'price',
		esc_html__( 'Price', 'smart' ),
		nice_vc_integration_posts_meta_color_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_rating_options' ) ) :
/**
 * Obtain options for product's rating.
 *
 * @since  1.0.0
 * @return array
 */
function nice_vc_integration_woocommerce_posts_item_rating_options() {
	return array(
		'rating',
		esc_html__( 'Rating', 'smart' ),
		array(
			array(
				'top-left',
				esc_html__( 'Top Left', 'smart' ),
			),
			array(
				'top-right',
				esc_html__( 'Top Right', 'smart' ),
			),
		),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_sale_options' ) ) :
/**
 * Obtain options for product's sale badge.
 *
 * @since  1.0.0
 * @return array
 */
function nice_vc_integration_woocommerce_posts_item_sale_options() {
	return array(
		'sale',
		esc_html__( 'Sale Badge', 'smart' ),
		array(
			array(
				'top-right',
				esc_html__( 'Top Right', 'smart' ),
			),
			array(
				'top-left',
				esc_html__( 'Top Left', 'smart' ),
			),
		),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_add_to_cart_options' ) ) :
/**
 * Obtain options for product's "add to cart" button.
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_vc_integration_woocommerce_posts_item_add_to_cart_options() {
	return array(
		'add_to_cart',
		esc_html__( 'Add To Cart Button', 'smart' ),
		array(
			array(
				'default',
				esc_html__( 'Default Position', 'smart' ),
			),
			array(
				'overlay',
				esc_html__( 'Overlay (invalidates shape and width settings)', 'smart' ),
			),
			array(
				'text-based',
				esc_html__( 'Text Based (appears over price on hover and invalidates all other button settings)', 'smart' ),
			),
		),
		array(
			array(
				'default',
				esc_html__( 'Default shape', 'smart' ),
			),
			array(
				'round',
				esc_html__( 'Round', 'smart' ),
			),
			array(
				'circle',
				esc_html__( 'Circle', 'smart' ),
			),
			array(
				'square',
				esc_html__( 'Square', 'smart' ),
			),
		),
		array(
			array(
				'text-no-transform',
				esc_html__( 'Default text style', 'smart' ),
			),
			array(
				'uppercase',
				esc_html__( 'Uppercase', 'smart' ),
			),
			array(
				'lowercase',
				esc_html__( 'Lowercase', 'smart' ),
			),
			array(
				'Capitalize',
				esc_html__( 'Capitalize', 'smart' ),
			),
		),
		array(
			array(
				'default-width',
				esc_html__( 'Default width', 'smart' ),
			),
			array(
				'full-width',
				esc_html__( 'Full width', 'smart' ),
			),
		),
		array(
			array(
				'inherit-skin',
				esc_html__( 'Inherit skin', 'smart' ),
			),
			array(
				'light',
				esc_html__( 'Light', 'smart' ),
			),
			array(
				'dark',
				esc_html__( 'Dark', 'smart' ),
			),
		),
		array(
			array(
				'default-behavior',
				esc_html__( 'Default Behavior', 'smart' ),
			),
			array(
				'quick-view',
				esc_html__( 'Open Quick View', 'smart' ),
			),
		),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_quick_view_options' ) ) :
/**
 * Obtain options for quick view link.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_vc_integration_woocommerce_posts_item_quick_view_options() {
	$display_options = array_merge(
		array(
			array(
				'top-left',
				esc_html__( 'Top Left', 'smart' ),
			),
			array(
				'top-right',
				esc_html__( 'Top Right', 'smart' ),
			),
		),
		nice_vc_integration_posts_display_options()
	);

	return array(
		'quick_view',
		esc_html__( 'Quick View', 'smart' ),
		$display_options,
		nice_vc_integration_posts_meta_color_options(),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_class' ) ) :
add_filter( 'nice_vc_integration_posts_item_class', 'nice_vc_integration_woocommerce_posts_item_class' );
/**
 * Add extra classes for product items inside a loop of VC Posts.
 *
 * @since 1.0.0
 *
 * @param array $class
 *
 * @return array
 */
function nice_vc_integration_woocommerce_posts_item_class( array $class = array() ) {
	$item = nice_vc_integration_posts_current_item();

	if ( isset( $item->layout['add_to_cart'] ) && 'text-based' === $item->layout['add_to_cart'][0] ) {
		$class[] = 'has-add-to-cart-link';
	}

	return $class;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_price_html' ) ) :
add_filter( 'nice_vc_integration_posts_html_price', 'nice_vc_integration_woocommerce_posts_item_price_html', 10, 2 );
/**
 * Construct HTML for product's price.
 *
 * @since  1.0.0
 *
 * @param  string $html
 * @param  array  $args
 *
 * @return string
 */
function nice_vc_integration_woocommerce_posts_item_price_html( $html = '', array $args = array() ) {
	$item = nice_vc_integration_posts_current_item();

	if ( 'product' !== $item->post_type ) {
		return $html;
	}

	$skin_class = empty( $args[0] ) ? 'inherit-skin' : $args[0];

	$product = wc_get_product( $item->post_id );

	$html  = '<section class="entry-price entry-meta ' . esc_attr( $skin_class ) . '">';
	$html .= $product->get_price_html();

	if ( isset( $item->layout['add_to_cart'] ) && 'text-based' === $item->layout['add_to_cart'][0] ) {
		$product_type = method_exists( $product, 'get_type' ) ? $product->get_type() : $product->product_type;

		$class = array(
			'product_type_' . $product_type,
		);

		$link_text = esc_html( $product->add_to_cart_text() );
		$link_href = esc_url( $product->add_to_cart_url() );

		/**
		 * Support quick view if enabled.
		 */
		if ( isset( $item->layout['add_to_cart'][5] ) && ( 'quick-view' === $item->layout['add_to_cart'][5] ) ) {
			$class[] = 'modal-open';
			$class[] = 'modal-open-quick-view-product';

			$link_text = esc_html__( 'Quick view', 'smart' );
			$link_href = 'javascript:void(0);';

			if ( ! nice_woocommerce_integration_modal_display() ) {
				add_filter( 'nice_woocommerce_integration_modal_display', '__return_true' );
			}
		} else {
			$class[] = $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '';
			$class[] = $product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '';
		}

		$html .= '<span class="permalink"><a class="' . esc_attr( join( ' ', $class ) ) . '" href="' . $link_href . '" data-product_id="' . esc_attr( get_the_ID() ) . '">' . $link_text . '</a></span>';
	}

	$html .= '</section>';

	return $html;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_quick_view_html' ) ) :
add_filter( 'nice_vc_integration_posts_html_quick_view', 'nice_vc_integration_woocommerce_posts_item_quick_view_html', 10, 2 );
/**
 * Display link to open product quick view.
 *
 * @since  1.0.0
 *
 * @param  string $html
 * @param  array  $args
 *
 * @return string
 */
function nice_vc_integration_woocommerce_posts_item_quick_view_html( $html = '', array $args = array() ) {
	if ( ! nice_woocommerce_integration_modal_display() ) {
		add_filter( 'nice_woocommerce_integration_modal_display', '__return_true' );
	}

	$item = nice_vc_integration_posts_current_item();

	if ( 'product' !== $item->post_type ) {
		return $html;
	}

	$display_type = empty( $args[0] ) ? 'block' : $args[0];
	$skin_class   = empty( $args[1] ) ? 'inherit-skin' : $args[1];

	// Define quick view class.
	$quick_view_class    = 'item-quick-view';
	$quick_view_has_icon = ( 'top-left' === $display_type || 'top-right' === $display_type );

	if ( $quick_view_has_icon ) {
		$quick_view_class .= '-icon entry-meta-button';

		if ( 'top-left' === $display_type ) {
			$quick_view_class .= ' left';
		} else {
			$quick_view_class .= ' right';
		}
	}

	$quick_view = '<section class="' . esc_attr( $quick_view_class ) . ' entry-meta ' . esc_attr( $display_type ) . ' ' . esc_attr( $skin_class ) . '">';
	$quick_view .= '<a href="javascript:void(0);" class="modal-open modal-open-quick-view-product" data-product_id="' . $item->post_id . '">';

	if ( $quick_view_has_icon ) {
		$quick_view .= '<i class="fa fa-eye"></i>';
	} else {
		$quick_view .= esc_html__( 'Quick View', 'smart' );
	}

	$quick_view .= '</a>';

	if ( $quick_view_has_icon ) {
		$quick_view .= '<div class="tooltip">' . esc_html__( 'Quick View', 'smart' ) . '</div>';
	}

	$quick_view .= '</section>';

	return $quick_view;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_single_item_inner_class' ) ) :
add_filter( 'nice_vc_integration_posts_item_inner_class', 'nice_vc_integration_woocommerce_posts_single_item_inner_class' );
/**
 * Add classes to caption element.
 *
 * @since  1.0.0
 *
 * @param  array $classes
 *
 * @return array
 */
function nice_vc_integration_woocommerce_posts_single_item_inner_class( array $classes = array() ) {
	$item = nice_vc_integration_posts_current_item();

	if ( isset( $item->layout['quick_view'][0] ) && ( 'top-left' === $item->layout['quick_view'][0] || 'top-right' === $item->layout['quick_view'][0] ) ) {
		$alignment = str_replace( 'top-', '', $item->layout['quick_view'][0] );
		$classes[] = 'has-quick-view-icon-' . $alignment;
	}

	return $classes;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_rating_html' ) ) :
add_filter( 'nice_vc_integration_posts_html_rating', 'nice_vc_integration_woocommerce_posts_item_rating_html', 10, 2 );
/**
 * Construct HTML for product's rating.
 *
 * @since  1.0.0
 *
 * @param  string $html
 * @param  array  $args
 *
 * @return string
 */
function nice_vc_integration_woocommerce_posts_item_rating_html( $html = '', array $args = array() ) {
	$item = nice_vc_integration_posts_current_item();

	if ( 'product' !== $item->post_type ) {
		return $html;
	}

	ob_start();

	// Print loop rating.
	woocommerce_template_loop_rating();

	$rating_html = ob_get_contents();
	ob_end_clean();

	if ( $rating_html ) {
		$position_style = isset( $args[0] ) ? 'position-' . $args[0] : 'position-top-left';

		$html = '<section class="entry-rating ' . esc_attr( $position_style ) . '">' . $rating_html . '</section>';
	}

	return $html;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_sale_html' ) ) :
add_filter( 'nice_vc_integration_posts_html_sale', 'nice_vc_integration_woocommerce_posts_item_sale_html', 10, 2 );
/**
 * Construct HTML for product's sale badge.
 *
 * @since  1.0.0
 *
 * @param  string $html
 * @param  array  $args
 *
 * @return string
 */
function nice_vc_integration_woocommerce_posts_item_sale_html( $html = '', array $args = array() ) {
	$item = nice_vc_integration_posts_current_item();

	if ( 'product' !== $item->post_type ) {
		return $html;
	}

	remove_filter( 'woocommerce_sale_flash', 'nice_woocommerce_integration_loop_sale_flash_wrapper', 99 );

	ob_start();

	// Print loop sale.
	woocommerce_show_product_loop_sale_flash();

	$sale_html = ob_get_contents();
	ob_end_clean();

	if ( $sale_html ) {
		$position_style = isset( $args[0] ) ? 'position-' . $args[0] : 'position-top-right';

		$html = '<section class="entry-sale ' . esc_attr( $position_style ) . '">' . $sale_html . '</section>';
	}

	return $html;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_single_item_add_to_cart' ) ) :
add_filter( 'nice_vc_integration_posts_html_add_to_cart', 'nice_vc_integration_woocommerce_posts_single_item_add_to_cart', 35, 2 );
/**
 * Print "Add to cart" button for the current item.
 *
 * @since  1.0.0
 *
 * @param  string $html
 * @param  array $args
 *
 * @return string
 */
function nice_vc_integration_woocommerce_posts_single_item_add_to_cart( $html = '', array $args = array() ) {
	$item = nice_vc_integration_posts_current_item();

	if ( 'product' !== $item->post_type ) {
		return $html;
	}

	$style = isset( $args[0] ) ? $args[0] : 'default';

	if ( 'default' !== $style ) {
		return $html;
	}

	$button_class = array(
		'btn',
		'btn-default',
		'btn-disable-hover',
		'allow-pointer-events',
	);

	/**
	 * Support quick view if enabled.
	 */
	if ( isset( $args[5] ) && ( 'quick-view' === $args[5] ) ) {
		$button_class[] = 'modal-open';
		$button_class[] = 'modal-open-quick-view-product';

		if ( ! nice_woocommerce_integration_modal_display() ) {
			add_filter( 'nice_woocommerce_integration_modal_display', '__return_true' );

			add_filter( 'woocommerce_product_add_to_cart_text', function() {
				return esc_html__( 'Quick view', 'smart' );
			} );
		}
	}

	$shape = isset( $args[1] ) ? $args[1] : 'default';
	$button_shape = '';

	if ( 'default' !== $shape ) {
		$button_shape = nice_theme_shape_button_class( $shape );
	}

	if ( $button_shape ) {
		array_push( $button_class, $button_shape );
	}

	$text_transform = isset( $args[2] ) ? $args[2] : 'text-no-transform';
	array_push( $button_class, $text_transform );

	$button_width = isset( $args[3] ) ? $args[3] : 'default-width';
	array_push( $button_class, $button_width );

	$button_skin = isset( $args[4] ) ? $args[4] : 'inherit-skin';
	array_push( $button_class, $button_skin );

	ob_start();

	woocommerce_template_loop_add_to_cart( array( 'quantity' => 1 ) );

	$link_html = ob_get_contents();
	ob_end_clean();

	if ( $link_html ) {
		$link_html = str_replace( 'class="button', 'class="button ' . esc_attr( join( ' ', $button_class ) ), $link_html );

		$html = '<section class="entry-add-to-cart">' . $link_html . '</section>';
	}

	return $html;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_single_item_overlay' ) ) :
add_filter( 'nice_vc_integration_posts_single_item_permalink', 'nice_vc_integration_woocommerce_posts_single_item_overlay', 40 );
/**
 * Print overlay elements if needed.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_vc_integration_woocommerce_posts_single_item_overlay() {
	$item = nice_vc_integration_posts_current_item();

	if ( 'product' !== $item->post_type ) {
		return null;
	}

	if ( ! isset( $item->layout['add_to_cart'] ) ) {
		return '';
	}

	if ( 'overlay' !== $item->shortcode->attr( 'single_text' ) && ! isset( $item->layout['media'] ) ) {
		return '';
	}

	$args = $item->layout['add_to_cart'];

	$overlay_button = isset( $args[0] ) && 'overlay' === $args[0];

	if ( ! $overlay_button ) {
		return '';
	}

	$html = '';

	$button_class = array(
		'btn',
		'btn-default',
		'btn-square',
		'btn-disable-hover',
		'allow-pointer-events',
		'full-width',
	);

	/**
	 * Support quick view if enabled.
	 */
	if ( isset( $args[5] ) && ( 'quick-view' === $args[5] ) ) {
		$button_class[] = 'modal-open';
		$button_class[] = 'modal-open-quick-view-product';

		if ( ! nice_woocommerce_integration_modal_display() ) {
			add_filter( 'nice_woocommerce_integration_modal_display', '__return_true' );

			add_filter( 'woocommerce_product_add_to_cart_text', function() {
				return esc_html__( 'Quick view', 'smart' );
			} );
		}
	}

	$text_transform = isset( $args[2] ) ? $args[2] : 'text-no-transform';
	array_push( $button_class, $text_transform );

	$button_skin = isset( $args[4] ) ? $args[4] : 'inherit-skin';
	array_push( $button_class, $button_skin );

	ob_start();

	woocommerce_template_loop_add_to_cart( array( 'quantity' => 1 ) );

	$button_html = ob_get_contents();
	ob_end_clean();

	if ( $button_html ) {
		$button_html  = str_replace( 'class="button', 'class="button ' . esc_attr( join( ' ', $button_class ) ), $button_html );
		$link_html    = '<a class="permalink" href="' . esc_url( $item->permalink ) . '"></a>';

		$html = '<section class="item-permalink item-overlay-add-to-cart">' . $link_html . $button_html . '</section>';
	}

	echo $html;

	return $html;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_type_icon_class' ) ) :
add_filter( 'nice_vc_integration_posts_item_type_icon_class', 'nice_vc_integration_woocommerce_posts_item_type_icon_class' );
/**
 * Obtain the HTML class for a product's icon.
 *
 * @since  1.0.0
 *
 * @param  string $icon_class
 *
 * @return string
 */
function nice_vc_integration_woocommerce_posts_item_type_icon_class( $icon_class = '' ) {
	$item = nice_vc_integration_posts_current_item();

	if ( 'product' === $item->post_type ) {
		$icon_class = 'fa fa-shopping-bag';
	}

	return $icon_class;
}
endif;

if ( ! function_exists( 'nice_vc_integration_woocommerce_posts_item_image_args' ) ) :
add_filter( 'nice_vc_integration_single_item_image_args', 'nice_vc_integration_woocommerce_posts_item_image_args' );
/**
 * Set the image size for the single post item on `nice_posts`
 *
 * @since  1.0.0
 *
 * @param  array $args
 *
 * @return array
 */
function nice_vc_integration_woocommerce_posts_item_image_args( $args ) {
	$item = nice_vc_integration_posts_current_item();

	if ( 'product' === $item->post_type ) {

		$wc_size = get_option( 'shop_single_image_size' );

		if ( $wc_size && ( isset( $wc_size['width'] ) && isset( $wc_size['width'] ) ) ) {
			$args['width']  = $wc_size['width'];
			$args['height'] = $wc_size['height'];
		}
	}

	return $args;
}
endif;

if ( ! function_exists( 'nice_vc_woocommerce_integration_posts_single_item' ) ) :
add_action( 'nice_vc_integration_posts_single_item', 'nice_vc_woocommerce_integration_posts_single_item', 0 );
/**
 * Setup actions right before the item's HTML is printed.
 *
 * @since 1.0.0
 */
function nice_vc_woocommerce_integration_posts_single_item() {
	static $caption_removed = false;

	$item = nice_vc_integration_posts_current_item();

	// Avoid printing default caption markup if the current item is a product.
	if ( 'product' === $item->post_type ) {
		remove_action( 'nice_vc_integration_posts_single_item_content', 'nice_vc_integration_posts_single_item_caption', 20 );
		$caption_removed = true;

	} else if ( did_action( 'nice_vc_integration_posts_single_item_content' ) && $caption_removed ) {
		add_action( 'nice_vc_integration_posts_single_item_content', 'nice_vc_integration_posts_single_item_caption', 20 );
		$caption_removed = false;
	}
}
endif;

if ( ! function_exists( 'nice_vc_woocommerce_integration_posts_single_item_caption' ) ) :
add_action( 'nice_vc_integration_posts_single_item_content', 'nice_vc_woocommerce_integration_posts_single_item_caption', 20 );
/**
 * Print caption for current item.
 *
 * @since 1.0.0
 */
function nice_vc_woocommerce_integration_posts_single_item_caption() {
	$item = nice_vc_integration_posts_current_item();

	if ( 'product' !== $item->post_type ) {
		return;
	}

	if ( 'overlay' !== $item->shortcode->attr( 'single_text' ) && ! isset( $item->layout['media'] ) ) {
		return;
	}

	$image_flip = false;

	if ( isset( $item->layout['media'][0] ) && 'flip' === $item->layout['media'][0] ) {
		$image_flip = true;
	}

	$classes = array(
		'item-caption',
	);

	/**
	 * Generate markup and classes for Image Flip feature.
	 *
	 * @since 1.0.0
	 */
	if ( $image_flip ) {
		global $product;

		$attachment_ids = method_exists( $product, 'get_gallery_image_ids' ) ? $product->get_gallery_image_ids() : $product->get_gallery_attachment_ids();

		if ( count( $attachment_ids ) ) {
			$classes[] = 'item-caption-flip';
		}
	}

	/**
	 * @hook nice_vc_woocommerce_integration_posts_single_item_caption
	 *
	 * Modify caption classes.
	 *
	 * @since 1.0.0
	 */
	$classes = apply_filters( 'nice_vc_woocommerce_integration_posts_single_item_caption_class', $classes );

	?>
		<div <?php nice_css_classes( $classes ); ?>>
			<div class="item-caption-inner">
				<?php nice_vc_integration_single_item_image(); ?>
			</div>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'nice_vc_woocommerce_integration_posts_single_item_flip_image' ) ) :
add_action( 'nice_vc_integration_single_item_image_after', 'nice_vc_woocommerce_integration_posts_single_item_flip_image' );
/**
 * Print out Flip Image if needed.
 *
 * @since 1.0.0
 */
function nice_vc_woocommerce_integration_posts_single_item_flip_image() {
	$item = nice_vc_integration_posts_current_item();

	if ( 'product' !== $item->post_type ) {
		return;
	}

	if ( 'overlay' !== $item->shortcode->attr( 'single_text' ) && ! isset( $item->layout['media'] ) ) {
		return;
	}

	$image_flip = false;

	if ( isset( $item->layout['media'][0] ) && 'flip' === $item->layout['media'][0] ) {
		$image_flip = true;
	}

	if ( ! $image_flip ) {
		return;
	}

	/**
	 * Generate markup and classes for Image Flip feature.
	 *
	 * @since 1.0.0
	 */
	global $product;

	$attachment_ids = method_exists( $product, 'get_gallery_image_ids' ) ? $product->get_gallery_image_ids() : $product->get_gallery_attachment_ids();

	if ( ! empty( $attachment_ids ) ) {
		foreach ( $attachment_ids as $attachment_id ) {
			$thumbnail_size = apply_filters( 'single_product_shop_thumbnail_size', 'shop_catalog' );

			$secondary_image = nice_image( array(
					'id'    => $attachment_id,
					'class' => 'item-caption-thumbnail',
					'size'  => $thumbnail_size,
					'echo'  => false,
				)
			);

			break;
		}
	}

	if ( ! empty( $secondary_image ) ) {
		echo $secondary_image; // WPCS: XSS ok.
	}
}
endif;

endif;
