<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles interactions with our implementation of YITH Wishlist.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      https://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( class_exists( 'WooCommerce' ) && class_exists( 'YITH_WCWL' ) ) :

if ( ! function_exists( 'nice_vc_integration_yith_wcwl_options' ) ) :
add_filter( 'nice_vc_integration_woocommerce_options', 'nice_vc_integration_yith_wcwl_options' );
/**
 * Modify WooCommerce options to include wishlist settings.
 *
 * @since  1.0.0
 *
 * @param  array $options
 *
 * @return array
 */
function nice_vc_integration_yith_wcwl_options( array $options = array() ) {
	$options[0]['options'][] = nice_vc_integration_yith_wcwl_posts_item_wishlist_options();

	return $options;
}
endif;

if ( ! function_exists( 'nice_vc_integration_yith_wcwl_posts_item_wishlist_options' ) ) :
/**
 * Obtain options for add-to-wishlist link.
 *
 * @since 1.0.0
 */
function nice_vc_integration_yith_wcwl_posts_item_wishlist_options() {
	return array(
		'wishlist',
		esc_html__( 'Wishlist', 'smart' ),
		array(
			array(
				'top-left',
				esc_html__( 'Top Left', 'smart' ),
			),
			array(
				'top-right',
				esc_html__( 'Top Right', 'smart' ),
			),
		),
	);
}
endif;

if ( ! function_exists( 'nice_vc_integration_yith_wcwl_posts_item_wishlist_html' ) ) :
add_filter( 'nice_vc_integration_posts_html_wishlist', 'nice_vc_integration_yith_wcwl_posts_item_wishlist_html', 10, 2 );
/**
 * Construct HTML for product's add-to-wishlist link.
 *
 * @since  1.0.0
 *
 * @param  string $html
 * @param  array  $args
 *
 * @return null|string
 */
function nice_vc_integration_yith_wcwl_posts_item_wishlist_html( $html = '', array $args = array() ) {
	if ( 'yes' !== get_option( 'yith_wcwl_enabled' ) ) {
		return null;
	}

	$item = nice_vc_integration_posts_current_item();

	if ( 'product' !== $item->post_type ) {
		return $html;
	}

	$alignment = str_replace( 'top-', '', $args[0] );

	$html  = '<section class="entry-meta entry-meta-button item-wishlist-icon ' . esc_attr( $alignment ) . '">';
	$html .= YITH_WCWL_Shortcode::add_to_wishlist( nice_yith_wcwl_integration_shortcode_atts() );
	$html .= '</section>';

	return $html;
}
endif;

if ( ! function_exists( 'nice_vc_integration_yith_wcwl_posts_single_item_inner_class' ) ) :
add_filter( 'nice_vc_integration_posts_item_inner_class', 'nice_vc_integration_yith_wcwl_posts_single_item_inner_class' );
/**
 * Add classes to caption element.
 *
 * @since  1.0.0
 *
 * @param  array $classes
 *
 * @return array
 */
function nice_vc_integration_yith_wcwl_posts_single_item_inner_class( array $classes = array() ) {
	$item = nice_vc_integration_posts_current_item();

	if ( isset( $item->layout['wishlist'][0] ) ) {
		$alignment = str_replace( 'top-', '', $item->layout['wishlist'][0] );
		$classes[] = 'has-wishlist-icon-' . $alignment;
	}

	return $classes;
}
endif;

endif;
