<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains the nice_countdown template
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

$title = $el_class = $date = $font = $weight = $size = $separator = $transform = $text = $output = $css_animation = $css_animation_delay = $css_animation_speed = '';
extract( shortcode_atts( array(
	'title'                      => '',
	'el_class'                   => '',
	'date'                       => '',
	'weight'                     => '',
	'text_under_weight'          => '',
	'line_height'                => '',
	'text_under_line_height'     => '',
	'text_under_transform'       => '',
	'letter_spacing'             => '',
	'text_under_letter_spacing'  => '',
	'text_color'                 => '',
	'text_under_color'           => '',
	'use_theme_fonts'            => '',
	'text_under_use_theme_fonts' => '',
	'text_under_google_fonts'    => '',
	'google_fonts'               => '',
	'size'                       => 'h2',
	'text_under_size'            => '',
	'separator'                  => '',
	'transform'                  => '',
	'text'                       => '',
	'icon'                       => '',
	'css_animation'              => '',
	'css_animation_delay'        => '',
	'css_animation_speed'        => '',
) , $atts ) );

// Enqueue required libraries.
wp_enqueue_script( 'nice-vc-countdown-source' );

if ( ( empty( $text_under_use_theme_fonts ) || 'yes' !== $text_under_use_theme_fonts ) || ( empty( $use_theme_fonts ) ||  'yes' !== $use_theme_fonts ) ) {
	$settings = get_option( 'wpb_js_google_fonts_subsets' );

	if ( is_array( $settings ) && ! empty( $settings ) ) {
		$subsets = '&subset=' . implode( ',', $settings );
	} else {
		$subsets = '';
	}

	$google_fonts_obj = new Vc_Google_Fonts();

	if ( ! empty( $google_fonts ) ) {
		$google_fonts_data = $google_fonts_obj->_vc_google_fonts_parse_attributes( WPBMap::getParam( $this->shortcode, $google_fonts ), $google_fonts );
		$google_font = isset( $google_fonts_data['values']['font_family'] ) ? $google_fonts_data['values']['font_family'] : null;

		if ( $google_font && ! nice_web_font_is_registered( $google_font ) ) {
			nice_register_web_font( $google_font );
			wp_enqueue_style( 'vc_google_fonts_' . vc_build_safe_css_class( $google_font ), nice_web_font_uri( $google_font ) );
		}
	}

	if ( ! empty( $text_under_google_fonts ) ) {
		$text_under_google_fonts_data = $google_fonts_obj->_vc_google_fonts_parse_attributes( WPBMap::getParam( $this->shortcode, $text_under_google_fonts ), $text_under_google_fonts );

		$text_under_google_font = isset( $text_under_google_fonts_data['values']['font_family'] ) ? $text_under_google_fonts_data['values']['font_family'] : null;

		if ( $text_under_google_font && ! nice_web_font_is_registered( $text_under_google_font ) ) {
			nice_register_web_font( $text_under_google_font );
			wp_enqueue_style( 'vc_google_fonts_' . vc_build_safe_css_class( $text_under_google_font ), nice_web_font_uri( $text_under_google_font ) );
		}
	}
}

$css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, 'nice-countdown', $this->settings['base'], $atts );

$classes = array(
	'countdown',
);

if ( ! empty( $size ) ) {
	$classes[] = $size;
}
if ( ! empty( $weight ) ) {
	$classes[] = 'font-weight-' . $weight;
}
if ( ! empty( $letter_spacing ) ) {
	$classes[] = $letter_spacing;
}
if ( ! empty( $text_color ) ) {
	$classes[] = nice_theme_color_text_class( $text_color );
}
if ( ! empty( $transform ) ) {
	$classes[] = $transform;
}

$styles = array();

if ( ! empty( $line_height ) ) {
	$styles[] = 'line-height: ' . nice_css_unit( $line_height );
}

if ( ! empty( $google_fonts_data['values']['font_family'] ) ) {
	$font_family = explode( ':', $google_fonts_data['values']['font_family'] );
	$styles[] = 'font-family: \'' . $font_family[0] . '\'';
}

$div_data = array();

if ( ! empty( $css_animation ) ) {
	$css_class .= nice_vc_get_css_animation( $css_animation );

	$div_data['animation'] = ( ! empty( $css_animation ) ) ? $css_animation : '';
	$div_data['delay']     = ( ! empty( $css_animation_delay ) ) ? $css_animation_delay : '';
	$div_data['speed']     = ( ! empty( $css_animation_speed ) ) ? $css_animation_speed : '';
}

$output .= '<div class="' . esc_attr( $css_class ) . '" ' . nice_data_attributes( $div_data, false ) . '>';
$output .= '<p>';
$output .= '<span ' . nice_css_classes( $classes, false ) . ' style="' . esc_attr( join( '; ', $styles ) ) . '" data-countdown="' . esc_attr( $date ) . '">000 ' . esc_html__( 'days', 'smart' ).' 00 ' . esc_html__( 'hours', 'smart' ) . ' 00 ' . esc_html__( 'minutes', 'smart' ) . ' 00 ' . esc_html__( 'seconds', 'smart' ) . '</span>';
$output .= '</p>';

if ( 'yes' === $separator ) {
	$output .= '<hr class="nice-separator nice-separator-accent-color" />';
}

if ( ! empty( $text ) ) {
	$text_class = array(
		'counter-text',
	);
	$text_style = array();

	if ( ! empty( $text_under_transform ) ) {
		$text_class[] = $text_under_transform;
	}

	if ( ! empty( $text_under_size ) ) {
		$text_class[] = $text_under_size;
	}
	if ( ! empty( $text_under_weight ) ) {
		$text_class[] = 'font-weight-' . $text_under_weight;
	}
	if ( ! empty( $text_under_letter_spacing ) ) {
		$text_class[] = $text_under_letter_spacing;
	}
	if ( ! empty( $text_under_color ) ) {
		$text_class[] = nice_theme_color_text_class( $text_under_color );
	}

	if ( ! empty( $text_under_google_fonts_data['values']['font_family'] ) ) {
		$font_family = explode( ':', $text_under_google_fonts_data['values']['font_family'] );
		$text_style[] = 'font-family: \'' . $font_family[0] . '\'';
	}

	if ( ! empty( $text_under_line_height ) ) {
		$text_style[] = 'line-height: ' . nice_css_unit( $text_under_line_height );
	}

	$output .= '<div ' . nice_css_classes( $text_class, false ) . ' style="' . esc_attr( join( '; ', $text_style ) ) . '">' . wpautop( $text ) . '</div>';
}

$output .= '</div>';

echo wpb_js_remove_wpautop( $output );
