<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains the vc_button template
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

$url = $link = $target = $button_color = $size = $width = $outline = $wide = $icon = $icon_position = $icon_animation = $border_animation = $shape = $shadow = $italic = $display = $transform = $top_margin = $onclick = $rel = $media_lightbox = $css_animation = $animation_delay = $animation_speed = $el_class = '';
extract( shortcode_atts( array(
	'url'                 => '',
	'link'                => '',
	'target'              => 'self',
	'button_color'        => 'default',
	'size'                => '',
	'width'               => '',
	'outline'             => '',
	'wide'                => 'no',
	'icon'                => '',
	'type'                => '',
	'icon_position'       => '',
	'icon_animation'      => '',
	'shape'               => '',
	'shadow'              => '',
	'italic'              => '',
	'transform'           => '',
	'display'             => '',
	'top_margin'          => '',
	'onclick'             => '',
	'rel'                 => '',
	'media_lightbox'      => '',
	'css_animation'       => '',
	'css_animation_delay' => '',
	'css_animation_speed' => '',
	'el_class'            => '',
) , $atts ) );

$atts = vc_map_get_attributes( $this->getShortcode(), $atts );

extract( $atts );

// Enqueue needed icon font.
vc_icon_element_fonts_enqueue( $icon_type );

//parse link
$link     = ( '||' === $link ) ? '' : $link;
$link     = vc_build_link( $link );
$a_href   = $link['url'];
$a_title  = $link['title'];
$a_target = $link['target'];

// Prepare button classes
$wrapper_class = array( 'btn-container' );
$classes       = array( 'btn' );
$div_data      = array();

// Additional classes
if ( $el_class ) {
	$classes[] = $el_class;
}

// Size class
if ( $size ) {
	$classes[] = nice_theme_size_button_class( $size );
}

// Color class
if ( empty( $button_color ) ) {
	$button_color = 'default';
} else {
	$button_color = str_replace( '_', '-', str_replace( 'nice_', '', $button_color ) );
}

if ( 'link' !== $size ) {
	$classes[] = nice_theme_color_button_class( $button_color );
} else {
	$classes[] = nice_theme_color_text_class( $button_color . '-color' );
}

// Shape class
if ( $shape ) {
	$classes[] = nice_theme_shape_button_class( $shape );
}

// Outlined class
if ( 'yes' === $outline) {
	$classes[] = nice_theme_color_button_class( 'outline' );
}

// Shadow class
if ( 'yes' === $shadow ) {
	$classes[] = 'btn-shadow';
}

// Italic class
if ( 'yes' === $italic ) {
	$classes[] = 'btn-italic';
}

// Wide class
if ( 'yes' === $wide ) {
	$wrapper_class[] = 'btn-block';
	$classes[] = 'btn-block';
}

if ( 'inline' === $display ) {
	// Add margin class
	if ( 'yes' === $top_margin ) {
		$classes[] = 'btn-top-margin';
	}
	$wrapper_class[] = 'btn-inline';
}

// Prepare icon
if ( ! empty( $icon_type ) ) {

	$icon_class = isset( ${'icon_' . $icon_type} ) ? esc_attr( ${'icon_' . $icon_type} ) : '';

	if ( ! empty( $icon_class ) ) {
		$icon = '<i class="' . esc_attr( $icon_class ) . '"></i>';
		if ( 'yes' === $icon_animation ) {
			$classes[] = 'btn-icon-fx';
		}
	} else {
		$icon = '';
	}
}

if ( ! empty( $transform ) ) {
	$classes[] = $transform;
}

$content = trim( $content );

if ( $icon !== '' ) {
	if ( $icon_position === 'right' ) {
		$content = $content . $icon;
		$classes[] = 'btn-icon-right';
	} else {
		$content = $icon . $content;
		$classes[] = 'btn-icon-left';
	}
}

if ( ! empty( $border_animation ) ) {
	$classes[] = $border_animation;
	$classes[] = 'btn-border-animated';
}


$el_class = $this->getExtraClass( $el_class );
$css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, ' ' . implode( $classes, ' ' ) . $el_class, $this->settings['base'], $atts );

// Prepare onclick action
$onclick = ( ! empty( $onclick ) ) ? ' onClick="' . esc_js( $onclick ) . '"' : '';

// Prepare rel attribute
$rel = ( $rel) ? ' rel="' . esc_attr( $rel ) . '"' : '';

if ( ! empty( $css_animation ) ) {
	$wrapper_class[] = nice_vc_get_css_animation( $css_animation );

	$div_data['animation'] = ( ! empty( $css_animation ) ) ? $css_animation : '';
	$div_data['delay']     = ( ! empty( $css_animation_delay ) ) ? $css_animation_delay : '';
	$div_data['speed']     = ( ! empty( $css_animation_speed ) ) ? $css_animation_speed : '';
}

if ( ! empty( $width ) ) {
	$width = ' style="min-width:' . $width . 'px"';
}

$a_target = trim( $a_target );

$title  = ( ! empty( $a_title ) ) ? ' title="' . $a_title . '"' : '';
$target = ( ! empty( $a_target ) ) ? ' target="' . $a_target . '"' : '';

$output  = '<span class="' . esc_attr( trim( implode( $wrapper_class, ' ') ) ) . '" ' . nice_data_attributes( $div_data, false ) . '>';
$output .= '<a href="' . esc_url( $a_href) . '" class="custom-link ' . esc_attr( trim( implode( $classes, ' ' ) ) ) . '"' . $title . $target . $onclick . $rel  . $width . '>' . do_shortcode( $content ) . '</a></span>';

echo $output;
