<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains the vc_custom_heading template
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

$source = $text = $link = $google_fonts = $subheading_google_fonts = $font_container = $subheading_font_container = $el_class = $css =
$font_container_data = $subheading_font_container_data = $google_fonts_data = $subheading_google_fonts_data = $separator =
$text_color = $subheading_text_color = $letter_spacing = $subheading_letter_spacing = $separator_color = $separator_double = $subheading = $sub_reduced = $sub_class = $css_animation = $css_animation_speed = $css_animation_delay = $desktop_visibility = $tablet_visibility = $mobile_visibility = $use_theme_fonts = $subheading_use_theme_fonts = '';

// This is needed to extract $font_container_data and $google_fonts_data
extract( $this->getAttributes( $atts ) );
extract( nice_vc_integration_subheading_values( $this, $atts, array(
	'google_fonts' => $this->getParamData( 'subheading_google_fonts' ),
	'font_container' => $this->getParamData( 'subheading_font_container' ),
) ) );

$div_data = $heading_data = array();

// Validate CSS units where it's needed.
if ( '' !== trim( $font_container_data['values']['line_height'] ) ) {
	$font_container_data['values']['line_height'] = nice_css_unit( $font_container_data['values']['line_height'] );
	$heading_data['line-height'] = nice_css_unit( $font_container_data['values']['line_height'] );
}

// Validate CSS units where it's needed.
if ( '' !== trim( $subheading_font_container_data['values']['line_height'] ) ) {
	$subheading_font_container_data['values']['line_height'] = nice_css_unit( $subheading_font_container_data['values']['line_height'] );
}

if ( '' !== trim( $font_container_data['values']['font_size'] ) ) {
	$heading_data['font-size'] = $font_container_data['values']['font_size'];
}

$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
extract( $atts );

extract( $this->getStyles( $el_class, $css, $google_fonts_data, $font_container_data, $atts ) );

$heading_font = isset( $google_fonts_data['values']['font_family'] ) ? $google_fonts_data['values']['font_family'] : null;

if ( 'yes' !== $use_theme_fonts && $heading_font && ! nice_web_font_is_registered( $heading_font ) ) {
	nice_register_web_font( $heading_font );
	wp_enqueue_style( 'vc_google_fonts_' . vc_build_safe_css_class( $heading_font ), nice_web_font_uri( $heading_font ) );
}

$subheading_font = isset( $subheading_google_fonts_data['values']['font_family'] ) ? $subheading_google_fonts_data['values']['font_family'] : null;

if ( 'yes' !== $subheading_use_theme_fonts && $subheading_font && is_array( $subheading_google_fonts_data ) && ! nice_web_font_is_registered( $subheading_font ) ) {
	nice_register_web_font( $subheading_font );
	wp_enqueue_style( 'vc_google_fonts_' . vc_build_safe_css_class( $subheading_font ), nice_web_font_uri( $subheading_font ) );
}

if ( ! empty( $css_animation ) ) {
	$css_class .= nice_vc_get_css_animation( $css_animation );

	$div_data['animation'] = ( ! empty( $css_animation ) ) ? $css_animation : '';
	$div_data['delay']     = ( ! empty( $css_animation_delay ) ) ? $css_animation_delay : '';
	$div_data['speed']     = ( ! empty( $css_animation_speed ) ) ? $css_animation_speed : '';

}

if ( $desktop_visibility !== 'yes' ) {
	$css_class .= ' desktop-hidden';
}

if ( $tablet_visibility !== 'yes' ) {
	$css_class .= ' tablet-hidden';
}

if ( $mobile_visibility !== 'yes' ) {
	$css_classes .= ' mobile-hidden';
}

// Set the inline styles for the HX element. Remove the text alignment from the
// default `font_container` param type.
if ( ! empty( $styles ) ) {

	$style = 'style="';

	foreach ( $styles as $s ) {
		if ( false === strpos( $s, 'text-align' ) ) {
			$style .= esc_attr( $s ) . ';';
		}
	}

	$style .= '"';

} else {
	$style = '';
}

// Add text alignment to the entire heading/
if ( ! empty( $text_align ) ) {
	$css_class .= ' text-align-' . $text_align;
}

// Init the $classes array
$classes = array(
	'nice-heading-title',
);

// See if we need to add text transform class
if ( ! empty( $transform ) ) {
	$classes[] = $transform;
}

// See if we need to add letter spacing
if ( ! empty( $letter_spacing ) ) {
	$classes[] = $letter_spacing;
}

// See if we need to add text font-weight class
if ( ! empty( $weight ) ) {
	$classes[] = 'font-weight-' . $weight;
}

// See if we need to add a custom text color class
if ( ! empty( $text_color ) ) {
	$classes[] = nice_theme_color_text_class( $text_color );
}

// Get post title if selected
if ( 'post_title' === $source ) {
	$text = get_the_title( get_the_ID() );
}

// Process new lines in front-end editor.
if ( vc_is_page_editable() ) {
	$text = nl2br( $text );
}

// Prepare separator classes
if ( ! empty( $separator ) ) {
	$separator_classes[] = 'nice-separator';
	if ( 'yes' === $separator_color ) {
		$separator_classes[] = 'nice-separator-accent-color';
	}
	if ( 'yes' === $separator_double ) {
		$separator_classes[] = 'nice-separator-double-spacing';
	}
}

// Build link
if ( ! empty( $link ) ) {
	$link = vc_build_link( $link );
	$text = '<a href="' . esc_attr( $link['url'] ) . '"'
		. ( $link['target'] ? ' target="' . esc_attr( $link['target'] ) . '"' : '' )
		. ( $link['title'] ? ' title="' . esc_attr( $link['title'] ) . '"' : '' )
		. '>' . $text . '</a>';
}

$output = '';

$output .= '<div class="' . esc_attr( $css_class ) . '" ' . nice_data_attributes( $div_data, false ) . '>';

if ( 'over' === $separator ) {
	$output .= '<hr ' . nice_css_classes( $separator_classes, false ) . ' />';
}

$output .= '<' . $font_container_data['values']['tag'] . ' ' . nice_data_attributes( $heading_data, false ) . ' ' . nice_css_classes( $classes, false ) . ' ' . $style . '>';
$output .= $text;
$output .= '</' . $font_container_data['values']['tag'] . '>';

if ( 'yes' === $separator ) {
	$output .= '<hr ' . nice_css_classes( $separator_classes, false ) . ' />';
}

// Sub heading
if ( ! empty( $subheading ) ) {
	$inline = $this->getStyles( $el_class, $css, $subheading_google_fonts_data, $subheading_font_container_data, $atts );

	$sub_classes = array(
		'nice-subheading-text',
	);
	$sub_styles = $inline['styles'];

	foreach ( $sub_styles as $key => $value ) {
		if ( false !== strpos( $value, 'text-align' ) ) {
			unset( $sub_styles[ $key ] );
		}

		if ( false !== strpos( $value, 'font-weight' ) ) {
			$has_font_weight = true;
		}
	}

	if ( 'yes' === $sub_lead ) {
		$sub_classes[] = 'text-lead';
	}

	if ( 'yes' === $sub_reduced ) {
		$sub_classes[] = 'text-top-reduced';
	}

	if ( $subheading_letter_spacing ) {
		$sub_classes[] = $subheading_letter_spacing;
	}

	if ( ! empty( $subheading_text_align ) ) {
		$sub_classes[] = 'text-align-' . $subheading_text_align;
	}

	if ( ! empty( $subheading_text_color ) ) {
		$sub_classes[] = nice_theme_color_text_class( $subheading_text_color );
	}

	if ( ! empty( $subheading_weight ) && empty( $has_font_weight ) ) {
		$sub_styles[] = 'font-weight: ' . $subheading_weight;
	}

	if ( ! empty( $subheading_transform ) ) {
		$sub_styles[] = 'text-transform: ' . $subheading_transform;
	}

	$sub_class = '';
	if ( ! empty( $sub_classes ) ) {
		$sub_class .= ' class="' . esc_attr( join( ' ', $sub_classes ) ) . '"';
	}

	$sub_style = '';
	if ( ! empty( $sub_styles ) ) {
		$sub_style .= ' style="' . esc_attr( join( '; ', $sub_styles ) ) . ';"';
	}

	$output .= '<div' . $sub_class . $sub_style . '>' . wpb_js_remove_wpautop( $subheading, true ) . '</div>';
}

if ( 'under' === $separator ) {
	$output .= '<hr ' . nice_css_classes( $separator_classes, false ) . ' />';
}

$output .= '</div>' . "\n";

echo $output;
