<?php
/**
 * Smart by NiceThemes.
 *
 * Basic template for VC Gmaps shortcode.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

$output = $title = $latlon = $link = $size = $address = $zoom = $map_color = $ui_color = $map_saturation = $map_brightness = $type = $bubble = $mobile_no_drag = $el_class = $ui_color_map = '';
extract( shortcode_atts( array(
	'title'               => '',
	'latlon'              => '48.858518, 2.294503',
	'size'                => '',
	'address'             => '',
	'zoom'                => 10,
	'map_color'           => '',
	'ui_color'            => '',
	'map_saturation'      => 0,
	'map_brightness'      => 0,
	'mobile_no_drag'      => '',
	'el_class'            => '',
	'css_animation'       => '',
	'css_animation_delay' => '',
	'css_animation_speed' => '',
), $atts ) );

if ( $latlon === '' ) {
	return null;
}

$vc_gmaps_api_key = nice_get_option( 'nice_gmaps_api_key' );

if ( $vc_gmaps_api_key !== '' ) {
	$vc_gmaps_api_key = '?key=' . $vc_gmaps_api_key;
}

wp_enqueue_script( 'google-maps-api', '//maps.googleapis.com/maps/api/js' . $vc_gmaps_api_key, array(), false, true);

$vc_gmaps_script = nice_get_file_uri( 'includes/plugin-integrations/visual-composer/assets/js/nice-vc-google-maps.js', true );
wp_enqueue_script( 'nice-vc-google-maps', $vc_gmaps_script, array( 'google-maps-api' ), '1.0.0', true );

$latlon = explode( ',', $latlon );

global $front_background_colors;

if ( $map_color !== '' ) {
	$map_color = nice_get_option( $map_color );
}

if ( $ui_color !== '' ) {
	$ui_color_map = nice_get_option( $ui_color );
}

$map_saturation = ( $map_saturation !== '' && $map_color !== '' ) ? $map_saturation = $map_saturation : '';
$map_brightness = ( $map_brightness !== '' && $map_color !== '' ) ? $map_brightness = $map_brightness : '';
$ui_color       = ( isset( $ui_color ) && $ui_color !== '' ) ? $ui_color : '';

$el_id = 'gmap' . md5( time() );

if ( $address !== '' ) {
	$address = '<address class="style-' . ( ( $ui_color !== '' ) ? $ui_color : 'accent' ) . '-bg">' . $address . '</address>';
}

$size = str_replace( array( 'px',' ' ) , array( '','' ) , $size );

$el_class  = $this->getExtraClass( $el_class );
$el_class .= ( $size == '' ) ? ' nice-map-responsive' : '';

$div_data = array();

$div_data['draggable'] = ( $mobile_no_drag === 'yes' && wp_is_mobile() ) ? 'false' : 'true';
$div_data['zoom']      = $zoom;
$div_data['lat']       = trim( $latlon[0] );
$div_data['lon']       = trim( $latlon[1] );

if ( $map_color !== '' ) {
	$div_data['color'] = $map_color;
}

if ( $ui_color_map !== '' ) {
	$div_data['ui'] = $ui_color_map;
}

if ( $map_saturation !== '' ) {
	$div_data['saturation'] = $map_saturation;
}

if ( $map_brightness !== '' ) {
	$div_data['brightness'] = $map_brightness;
}

$css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, 'nice-vc-gmaps-widget ' . $el_class, $this->settings['base'], $atts);

if ( ! empty( $css_animation ) ) {
	$css_class .= nice_vc_get_css_animation( $css_animation );

	$div_data['animation'] = ( ! empty( $css_animation ) ) ? $css_animation : '';
	$div_data['delay']     = ( ! empty( $css_animation_delay ) ) ? $css_animation_delay : '';
	$div_data['speed']     = ( ! empty( $css_animation_speed ) ) ? $css_animation_speed : '';
}

?>

<div class="<?php echo esc_attr( $css_class ); ?>" <?php echo nice_data_attributes( $div_data, false ); ?>>

	<?php echo wpb_widget_title( array(
			'title'      => $title,
			'extraclass' => 'wpb_map_heading'
		));
	?>

	<div class="nice-wrapper">
		<div id="<?php echo esc_attr( $el_id ); ?>" class="nice-vc-gmaps-wrapper" <?php nice_data_attributes( $div_data ) ?> <?php if ( is_numeric( $size ) ) echo ' style="height: ' . esc_attr( $size ) . 'px"'; ?>>
		</div>
		<?php if ( $ui_color !== '' ) { ?>

			<?php $ui_bg_class = nice_theme_color_background_class( $ui_color ); ?>

			<div id="<?php echo esc_attr( $el_id ); ?>-zoom-in" class="gmap-buttons gmap-zoom-min btn <?php echo esc_attr( $ui_bg_class ); ?>"></div>
			<div id="<?php echo esc_attr( $el_id ); ?>-zoom-out" class="gmap-buttons gmap-zoom-out btn <?php echo esc_attr( $ui_bg_class ); ?>"></div>

		<?php } ?>

		<?php echo wpb_js_remove_wpautop( $address ); ?>

	</div>
</div>
