<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains the vc_row template
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	die();
}

/**
 * Shortcode attributes
 * @var $atts
 * @var $el_class
 * @var $full_width
 * @var $full_height
 * @var $equal_height
 * @var $columns_placement
 * @var $content_placement
 * @var $parallax
 * @var $background_image
 * @var $css
 * @var $el_id
 * @var $video_bg
 * @var $video_bg_url
 * @var $video_bg_parallax
 * @var $content - shortcode content
 * Shortcode class
 * @var $this WPBakeryShortCode_VC_Row
 */
$el_class = $full_height = $full_width = $equal_height = $flex_row = $columns_placement = $content_placement = $background_color = $parallax = $background_image = $background_position = $background_attachment = $background_repeat = $background_size = $css = $el_id = $video_bg = $video_bg_url = $video_bg_parallax = $padding_top = $padding_bottom = $padding_horizontal = $desktop_visibility = $tablet_visibility = $mobile_visibility = '';
$output = $after_output = $shift_y = $shift_y_fixed = '';
$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
extract( $atts );

wp_enqueue_script( 'wpb_composer_front_js' );

$el_class = $this->getExtraClass( $el_class );

$css_classes = array(
	'vc_row',
	'wpb_row', //deprecated
	'vc_row-fluid',
	$el_class,
	vc_shortcode_custom_css_class( $css ),
);

$row_inner_classes   = array();
$row_inner_classes[] = 'nice_row-inner';
$row_inner_classes[] = 'clearfix';

if ( vc_shortcode_custom_css_has_property( $css, array( 'border', 'background' ) ) || $video_bg || $parallax ) {
	$css_classes[] = 'vc_row-has-fill';
}

if ( ! empty( $atts['gap'] ) ) {
	$css_classes[] = 'vc_column-gap-' . $atts['gap'];
} else {
	$css_classes[] = 'vc_column-no-gap';
}

if ( ! empty( $atts['background_color'] ) ) {
	$css_classes[] = nice_theme_color_background_class( $atts['background_color'] );
}

if ( ! empty( $atts['padding_top'] ) ) {
	$css_classes[] = 'padding-top-' . $atts['padding_top'];
}

if ( ! empty( $atts['padding_bottom'] ) ) {
	$css_classes[] = 'padding-bottom-' . $atts['padding_bottom'];
}

if ( ! empty( $atts['padding_horizontal'] ) && $atts['padding_horizontal'] > 0 ) {
	$css_classes[] = 'padding-horizontal-' . $atts['padding_horizontal'] . 'x';
}

$wrapper_attributes = array();
$wrapper_id = '';

if ( ! empty( $el_id ) ) {
	$wrapper_id = 'id="' . sanitize_title( $el_id ). '"';
}

if ( ! empty( $full_width ) ) {
	$wrapper_attributes['vc-full-width'] = 'true';
	$wrapper_attributes['vc-full-width-init'] = 'false';

	if ( 'stretch_row' === $full_width ) {
		$wrapper_attributes['vc-stretch'] = 'true';
	} elseif ( 'stretch_row_content' === $full_width ) {
		$wrapper_attributes['vc-stretch-content'] = 'true';
	} elseif ( 'stretch_row_content_no_spaces' === $full_width ) {
		$wrapper_attributes['vc-stretch-content'] = 'true';
		$css_classes[] = 'vc_row-no-padding';
	}
	$after_output .= '<div class="vc_row-full-width"></div>';
}

if ( ! empty( $full_height ) ) {
	$css_classes[] = ' vc_row-o-full-height';
	if ( ! empty( $columns_placement ) ) {
		$flex_row = true;
		$css_classes[] = ' vc_row-o-columns-' . $columns_placement;
	}
}

if ( ! empty( $equal_height ) ) {
	$flex_row = true;
	$css_classes[] = ' vc_row-o-equal-height';
}

if ( ! empty( $content_placement ) ) {
	$flex_row = true;
	$css_classes[] = ' vc_row-o-content-' . $content_placement;
}

if ( ! empty( $flex_row ) ) {
	$css_classes[] = ' vc_row-flex';
}

$has_video_bg = ( ! empty( $video_bg ) && ! empty( $video_webm ) && ! empty( $video_mp4 ) );

if ( $has_video_bg ) {
	$parallax = $video_bg_parallax;
	$background_image = $video_bg_url;
	$css_classes[] = ' vc_video-bg-container';
	$poster = '';

	$video_bg = '
			<div class="nice-bg-video-container">
			<video class="nice-bg-video" ' . $poster . ' preload="auto" loop="loop" autoplay="autoplay">
				<source src="' . $video_webm . '" type="video/webm" />
				<source src="' . $video_mp4 . '" type="video/mp4" />
				<source src="' . $video_ogv . '" type="video/ogg" />
				' . esc_html__( 'Your browser does not support the video tag. We suggest you upgrade your browser.', 'smart' ) . '
			</video>
		</div>';

} else {
	$video_bg = '';
}

$overlay = '';

if ( ! empty( $overlay_color ) ) {

	$overlay_color = nice_get_option( $overlay_color );

	if ( ! empty( $overlay_opacity ) ) {
		$overlay_opacity = ( $overlay_opacity * 0.01 );
	}

	$overlay_style = 'background:' . nice_color_hex2rgba( $overlay_color, $overlay_opacity );

	$overlay = '<div class="overlay" style="' . $overlay_style . '"></div>';
}

if ( ! $parallax && $has_video_bg ) {
	$wrapper_attributes['vc-video-bg'] = esc_attr( $video_mp4 );
}

if ( ! empty( $parallax ) ) {
	wp_enqueue_script( 'vc_jquery_skrollr_js' );
	$wrapper_attributes['vc-parallax'] = '1.5'; // parallax speed
	$css_classes[] = 'vc_general vc_parallax vc_parallax-' . $parallax;
	if ( false !== strpos( $parallax, 'fade' ) ) {
		$css_classes[] = 'js-vc_parallax-o-fade';
		$wrapper_attributes['vc-parallax-o-fade'] = 'on';
	} elseif ( false !== strpos( $parallax, 'fixed' ) ) {
		$css_classes[] = 'js-vc_parallax-o-fixed';
	}
}

$background = '';

if ( ! empty( $parallax ) ) {
	if ( $has_video_bg ) {
		$background_image_src = $background_image;
	} else {
		$background_image_id = preg_replace( '/[^\d]/', '', $background_image );
		$background_image_src = wp_get_attachment_image_src( $background_image_id, 'full' );
		if ( ! empty( $background_image_src[0] ) ) {
			$background_image_src = $background_image_src[0];
		}
	}
	$wrapper_attributes['vc-parallax-image'] = esc_attr( $background_image_src );
} else {

	$background_image_id = preg_replace( '/[^\d]/', '', $background_image );
	$background_image_src = wp_get_attachment_image_src( $background_image_id, 'full' );
	if ( ! empty( $background_image_src[0] ) ) {
		$background_image_src = $background_image_src[0];
	}

	$background_repeat     = ( isset( $background_repeat ) && $background_repeat !== '' ) ? 'background-repeat: ' . $background_repeat . ';' : '';
	$background_position   = ( isset( $background_position ) && $background_position !== '' ) ? 'background-position: ' . $background_position . ';' : '';
	$background_attachment = ( isset( $background_attachment ) && $background_attachment !== '' ) ? 'background-attachment: ' . $background_attachment . ';' : '';
	$background_size       = ( isset( $background_size ) && $background_size !== '' ) ? 'background-size: ' . $background_size . ';' : '';

	$background  = '<div class="row-background background-element">';
	$background .= '<div class="background-wrapper">';
	$background .= '<div class="background-inner" style="background-image: url(' . esc_attr( $background_image_src ) . ');' . $background_repeat . $background_position . $background_attachment . $background_size . '"></div>';
	$background .= $overlay;
	$background .= '</div>';
	$background .= '</div>';

	$overlay = '';
}

if ( ! empty( $row_name ) ) {
	$wrapper_attributes['parent'] = 'true';
	$wrapper_attributes['label']  = esc_attr( $row_name );
	$wrapper_attributes['name']   = sanitize_title( $row_name );
	$css_classes[] = 'onepage-section';
}

if ( $shift_y != '0' && $shift_y != '' ) {
	switch ( $shift_y ) {
		case 1:
			$row_inner_classes[] = 'shift_y_1';
			break;
		case 2:
			$row_inner_classes[] = 'shift_y_2';
			break;
		case 3:
			$row_inner_classes[] = 'shift_y_3';
			break;
		case 4:
			$row_inner_classes[] = 'shift_y_4';
			break;
		case 5:
			$row_inner_classes[] = 'shift_y_5';
			break;
		case -1:
			$row_inner_classes[] = 'shift_y_neg_1';
			break;
		case -2:
			$row_inner_classes[] = 'shift_y_neg_2';
			break;
		case -3:
			$row_inner_classes[] = 'shift_y_neg_3';
		break;
		case -4:
			$row_inner_classes[] = 'shift_y_neg_4';
			break;
		case -5:
			$row_inner_classes[] = 'shift_y_neg_5';
			break;
	}
	if ( $shift_y_fixed === 'yes' ) {
		$row_inner_classes[] = 'shift_y_fixed';
	}
}

if ( $desktop_visibility !== 'yes' ) {
	$css_classes[] = 'desktop-hidden';
}

if ( $tablet_visibility !== 'yes' ) {
	$css_classes[] = 'tablet-hidden';
}

if ( $mobile_visibility !== 'yes' ) {
	$css_classes[] = 'mobile-hidden';
}

$css_class = preg_replace( '/\s+/', ' ', apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, implode( ' ', array_filter( $css_classes ) ), $this->settings['base'], $atts ) );

$output .= '<div ' . $wrapper_id . ' ' . nice_data_attributes( $wrapper_attributes, false ) . ' class="' . esc_attr( trim( $css_class ) ) . '">';
$output .= $background;
$output .= $overlay;
$output .= $video_bg;
$output .= '<div ' . nice_css_classes( $row_inner_classes, false ) . '>';
$output .= wpb_js_remove_wpautop( $content );
$output .= '</div>' . "\n";
$output .= '</div>' . "\n";
$output .= $after_output;

echo $output;
