<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains the vc_single_image template
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

$title = $source = $image = $custom_src = $onclick = $img_size = $external_img_size =
$caption = $img_link_large = $link = $img_link_target = $alignment = $el_class = $css_animation = $css_animation_speed = $css_animation_delay = $style = $external_style = $border_color = $padding_bottom = $css = '';
$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
extract( $atts );

$default_src = vc_asset_url( 'vc/no_image.png' );

// backward compatibility. since 4.6
if ( empty( $onclick ) && isset( $img_link_large ) && 'yes' === $img_link_large ) {
	$onclick = 'img_link_large';
} elseif ( empty( $atts['onclick'] ) && ( ! isset( $atts['img_link_large'] ) || 'yes' !== $atts['img_link_large'] ) ) {
	$onclick = 'custom_link';
}

if ( 'external_link' === $source ) {
	$style = $external_style;
	$border_color = $external_border_color;
}

$border_color = ( '' !== $border_color ) ? ' ' . nice_theme_color_border_class( $border_color ) : '';

$img = false;

switch ( $source ) {
	case 'media_library':
	case 'featured_image':

		if ( 'featured_image' === $source ) {
			$post_id = get_the_ID();
			if ( $post_id && has_post_thumbnail( $post_id ) ) {
				$img_id = get_post_thumbnail_id( $post_id );
			} else {
				$img_id = 0;
			}
		} else {
			$img_id = preg_replace( '/[^\d]/', '', $image );
		}

		// set rectangular
		if ( preg_match( '/_circle_2$/', $style ) ) {
			$style = preg_replace( '/_circle_2$/', '_circle', $style );
			$img_size = $this->getImageSquareSize( $img_id, $img_size );
		}

		if ( ! $img_size ) {
			$img_size = 'large';
		}

		if ( 'image/svg+xml' !== get_post_mime_type( $img_id ) ) {
			$img = wpb_getImageBySize( array(
				'attach_id' => $img_id,
				'thumb_size' => $img_size,
				'class' => 'vc_single_image-img',
			) );
		} else {
			$img_array = array();

			$img_width = 0;
			$img_height = 0;

			$img_sizes = nice_get_image_sizes();

			$p = stripos( strtolower( $img_size ), 'x' );

			if ( isset( $img_sizes[ $img_size ] ) ) {
				$img_width  = $img_sizes[ $img_size ]['width'];
				$img_height = $img_sizes[ $img_size ]['height'];
			} elseif ( stripos( strtolower( $img_size ), 'x' ) ) {
				$img_size_array = explode( 'x', strtolower( $img_size ) );

				if ( 2 === count( $img_size_array ) ) {
					$img_width  = trim( $img_size_array[0] );
					$img_height = trim( $img_size_array[1] );
				}
			}

			$image_path = get_nice_image_path( $img_id );

			$output = "\n\n" . nice_image_html_svg( $img_id );
			$output = preg_replace( '#\s(xmlns)="([^"]+)"#', '', $output );
			$output = preg_replace( '#\s(xmlns:svg)="([^"]+)"#', '', $output );
			$output = preg_replace( '#\s(xmlns:xlink)="([^"]+)"#', '', $output );
			$output = preg_replace( '#\s(id)="([^"]+)"#', ' $1="$2-' . rand() . '"', $output );

			$rand_id = 'svg-' . rand();

			$output = preg_replace( '/<svg/', '<svg id="' . $rand_id . '"', $output );

			if ( ! empty( $image_animated ) ) {
				$output = preg_replace( '/<svg/', '<svg class="svg-animated"', $output );

				if ( ! empty( $image_animation_delay ) ) {
					$output = preg_replace( '/<svg/', '<svg data-delay="' . esc_attr( $image_animation_delay ) . '"', $output );
				}

				if ( ! empty( $image_animation_speed ) ) {
					$output = preg_replace( '/<svg/', '<svg data-duration="' . esc_attr( $image_animation_speed ) . '"', $output );
				}
			}

			if ( ! empty( $image_color ) ) {
				$output = preg_replace( '/<svg/', '<svg style="color: ' . esc_attr( nice_get_option( $image_color ) ) . ';"', $output );
			}

			if ( $img_width ) {
				$output = preg_replace( '/<svg/', '<svg width="' . esc_attr( $img_width ) . '"', $output );
			}

			if ( $img_height ) {
				$output = preg_replace( '/<svg/', '<svg height="' . esc_attr( $img_height ) . '"', $output );
			}

			$img['thumbnail'] = $output;
		}


	// don't show placeholder in public version if post doesn't have featured image
		if ( 'featured_image' === $source ) {
			if ( ! $img && 'page' === vc_manager()->mode() ) {
				return;
			}
		}

		break;

	case 'external_link':
		$dimensions = vcExtractDimensions( $external_img_size );
		$hwstring = $dimensions ? image_hwstring( $dimensions[0], $dimensions[1] ) : '';

		$custom_src = $custom_src ? esc_attr( $custom_src ) : $default_src;

		$img['thumbnail'] = '<img class="vc_single_image-img" ' . $hwstring . ' src="' . $custom_src . '" />';

		break;

	default:
		$img = false;
}

if ( ! $img ) {
	$img['thumbnail'] = '<img class="vc_img-placeholder vc_single_image-img" src="' . $default_src . '" />';
}

// Allow filtering image tag output.
$img['thumbnail'] = apply_filters( 'nice_vc_integration_single_image_tag', $img['thumbnail'] );

$el_class = $this->getExtraClass( $el_class );

// backward compatibility
if ( vc_has_class( 'prettyphoto', $el_class ) ) {
	$onclick = 'link_image';
}

// backward compatibility. will be removed in 4.7+
if ( ! empty( $atts['img_link'] ) ) {
	$link = $atts['img_link'];
	if ( ! preg_match( '/^(https?\:\/\/|\/\/)/', $link ) ) {
		$link = 'http://' . $link;
	}
}

// backward compatibility
if ( in_array( $link, array( 'none', 'link_no' ), true ) ) {
	$link = '';
}

$a_attrs = array();

switch ( $onclick ) {
	case 'img_link_large':

		if ( 'external_link' === $source ) {
			$link = $custom_src;
		} else {
			$link = wp_get_attachment_image_src( $img_id, 'large' );
			$link = $link[0];
		}

		break;

	case 'link_image':
		wp_enqueue_script( 'prettyphoto' );
		wp_enqueue_style( 'prettyphoto' );

		$a_attrs['class'] = 'prettyphoto';
		$a_attrs['data-rel'] = 'prettyPhoto[rel-' . get_the_ID() . '-' . rand() . ']';

		// backward compatibility
		if ( ! vc_has_class( 'prettyphoto', $el_class ) && 'external_link' === $source ) {
			$link = $custom_src;
		} else {
			$link = wp_get_attachment_image_src( $img_id, 'large' );
			$link = $link[0];
		}

		break;

	case 'custom_link':
		// $link is already defined
		break;

	case 'zoom':
		wp_enqueue_script( 'vc_image_zoom' );

		if ( 'external_link' === $source ) {
			$large_img_src = $custom_src;
		} else {
			$large_img_src = wp_get_attachment_image_src( $img_id, 'large' );
			if ( $large_img_src ) {
				$large_img_src = $large_img_src[0];
			}
		}

		$img['thumbnail'] = str_replace( '<img ', '<img data-vc-zoom="' . $large_img_src . '" ', $img['thumbnail'] );

		break;
}

// backward compatibility
if ( vc_has_class( 'prettyphoto', $el_class ) ) {
	$el_class = vc_remove_class( 'prettyphoto', $el_class );
}

$wrapper_class = 'vc_single_image-wrapper ' . $style . ' ' . $border_color;

if ( $link ) {
	$a_attrs['href'] = $link;
	$a_attrs['target'] = $img_link_target;
	if ( ! empty( $a_attrs['class'] ) ) {
		$wrapper_class .= ' ' . $a_attrs['class'];
		unset( $a_attrs['class'] );
	}
	$html = '<a ' . vc_stringify_attributes( $a_attrs ) . ' class="' . $wrapper_class . '">' . $img['thumbnail'] . '</a>';
} else {
	$html = '<div class="' . $wrapper_class . '">' . $img['thumbnail'] . '</div>';
}

$div_data = array();

if ( ! empty( $css_animation ) ) {

	$div_data['animation'] = ( ! empty( $css_animation ) ) ? $css_animation : '';
	$div_data['delay']     = ( ! empty( $css_animation_delay ) ) ? $css_animation_delay : '';
	$div_data['speed']     = ( ! empty( $css_animation_speed ) ) ? $css_animation_speed : '';

	$css_animation = nice_vc_get_css_animation( $css_animation );

}

if ( ! empty( $padding_bottom ) && ( '' !== $padding_bottom ) ) {
	$padding_bottom = 'padding-bottom-' . $padding_bottom;
}

$class_to_filter = 'wpb_single_image wpb_content_element vc_align_' . $alignment . ' ' . $css_animation . ' ' . $padding_bottom;
$class_to_filter .= vc_shortcode_custom_css_class( $css, ' ' ) . $this->getExtraClass( $el_class );
$css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $class_to_filter, $this->settings['base'], $atts );

if ( in_array( $source, array( 'media_library', 'featured_image' ), true ) && 'yes' === $add_caption ) {
	$post    = get_post( $img_id );
	$caption = $post->post_excerpt;
} else {
	if ( 'external_link' === $source ) {
		$add_caption = 'yes';
	}
}

if ( 'yes' === $add_caption && '' !== $caption ) {
	$html .= '<figcaption class="vc_figure-caption">' . esc_html( $caption ) . '</figcaption>';
}

$output = '
	<div class="' . esc_attr( trim( $css_class ) ) . '" ' . nice_data_attributes( $div_data, false ) . '>
		' . wpb_widget_title( array( 'title' => $title, 'extraclass' => 'wpb_singleimage_heading' ) ) . '
		<figure class="wpb_wrapper vc_figure">
			' . $html . '
		</figure>
	</div>
';

echo $output; // WPCS: XSS ok.
