<?php
/**
 * Smart by NiceThemes.
 *
 * Manage WooCommerce custom fields.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_woocommerce_integration_custom_fields_page' ) ) :
add_filter( 'nice_custom_fields', 'nice_woocommerce_integration_custom_fields_page', 20, 2 );
/**
 * Add Woocommerce-related custom fields to pages.
 *
 * @since  1.0.0
 *
 * @param  array  $nice_fields
 * @param  string $post_type
 *
 * @return array
 */
function nice_woocommerce_integration_custom_fields_page( array $nice_fields = array(), $post_type ) {
	if ( 'page' === $post_type ) {

		$nice_woocommerce_header_custom_fields[] = array(
			'name'      => '_post_header_woocommerce_navigation',
			'std'       => '',
			'label'     => esc_html__( 'Display Shopping Cart', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Select whether or not to show a link to the shopping cart in the header for this page.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields = nice_custom_fields_enqueue( $nice_fields, $nice_woocommerce_header_custom_fields, '_post_header_display_search', false );
	}

	return $nice_fields;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_custom_fields_post' ) ) :
add_filter( 'nice_custom_fields', 'nice_woocommerce_integration_custom_fields_post', 20, 2 );
/**
 * Add Woocommerce-related custom fields to posts.
 *
 * @since  1.0.0
 *
 * @param  array  $nice_fields
 * @param  string $post_type
 *
 * @return array
 */
function nice_woocommerce_integration_custom_fields_post( array $nice_fields = array(), $post_type ) {
	if ( 'post' === $post_type ) {

		$nice_woocommerce_header_custom_fields[] = array(
			'name'      => '_post_header_woocommerce_navigation',
			'std'       => '',
			'label'     => esc_html__( 'Display Shopping Cart', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Select whether or not to show a link to the shopping cart in the header for this post.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields = nice_custom_fields_enqueue( $nice_fields, $nice_woocommerce_header_custom_fields, '_post_header_display_search', false );
	}

	return $nice_fields;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_custom_fields_product' ) ) :
add_filter( 'nice_custom_fields', 'nice_woocommerce_integration_custom_fields_product', 10, 2 );
/**
 * Load array with custom fields for pages.
 * then save the array into WP options.
 *
 * @since  1.0.0
 *
 * @param  array  $nice_fields
 * @param  string $post_type
 *
 * @return array
 */
function nice_woocommerce_integration_custom_fields_product( array $nice_fields = array(), $post_type ) {
	if ( 'product' === $post_type ) {
		$up_to = function( $limit ) {
			$arr = array();
			$i = 1;
			while ( $i <= $limit ) {
				$arr[ $i ] = $i;
				$i++;
			}
			return $arr;
		};

		/**
		 * Header
		 */
		$nice_fields[] = array(
			'name'  => 'portfolio-header',
			'label' => esc_html__( 'Header', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_layout-header"></i>',
		);

		$nice_fields[] = array(
			'name'      => '_post_header',
			'std'       => '',
			'label'     => esc_html__( 'Display Header', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Show the header for this product.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_post_navigation_menu',
			'std'       => '',
			'label'     => esc_html__( 'Navigation Menu', 'smart' ),
			'type'      => 'select',
			'options'   => nice_get_navigation_menus(),
			'desc'      => esc_html__( 'Select the navigation menu to use for this product.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_navigation_style',
			'std'       => '',
			'label'     => esc_html__( 'Navigation Style', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''         => esc_html__( 'Inherit', 'smart' ),
				'default'  => esc_html__( 'Top', 'smart' ),
				'vertical' => esc_html__( 'Side', 'smart' ),
				'overlay'  => esc_html__( 'Overlay', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the navigation style to use for this product.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_background_transparent',
			'std'       => '',
			'label'     => esc_html__( 'Transparent Header', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Make the header transparent.', 'smart' ),
			'condition' => '_post_header:not(false),_post_navigation_style:not(vertical)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_background_transparent_mobile',
			'std'       => '',
			'label'     => esc_html__( 'Transparent Header (Mobile)', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Make the header transparent in smaller viewports. This option only works when the transparent header is enabled on desktop.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_skin',
			'std'       => '',
			'label'     => esc_html__( 'Header Content Skin', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'light' => esc_html__( 'Light', 'smart' ),
				'dark'  => esc_html__( 'Dark', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the header content skin to use for this product.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_background_color',
			'std'       => '',
			'label'     => esc_html__( 'Header Background Color', 'smart' ),
			'type'      => 'select_color',
			'options'   => nice_theme_colors_dropdown_values(),
			'desc'      => esc_html__( 'Choose a background color.', 'smart' ),
			'class'     => 'nice-select-color',
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_navigation_submenu_skin',
			'std'       => '',
			'label'     => esc_html__( 'Navigation Sub-Menu Content Skin', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'light' => esc_html__( 'Light', 'smart' ),
				'dark'  => esc_html__( 'Dark', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the navigation sub-menu content skin to use for this product.', 'smart' ),
			'condition' => '_post_header:not(false),_post_navigation_style:not(overlay)' . ( ( 'overlay' === nice_get_option( 'nice_header_navigation' ) ) ? ',_post_navigation_style:not()' : '' ),
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_width',
			'std'       => '',
			'label'     => esc_html__( 'Header Width', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'full'  => esc_html__( 'Full', 'smart' ),
				'limit' => esc_html__( 'Limit', 'smart' ),
			),
			'desc'      => esc_html__( 'Select whether or not to make the header contents take the full width for this product.', 'smart' ),
			'condition' => '_post_header:not(false),_post_navigation_style:not(vertical)' . ( ( 'vertical' === nice_get_option( 'nice_header_navigation' ) ) ? ',_post_navigation_style:not()' : '' ),
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_display_search',
			'std'       => '',
			'label'     => esc_html__( 'Display Search', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( "Select whether or not to show a link to the site's search in the header for this product.", 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_display_social',
			'std'       => '',
			'label'     => esc_html__( 'Display Social Icons', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Select whether or not to show a the social icons in the header for this product.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		/**
		 * Product Details
		 */
		$nice_fields[] = array(
			'name'  => 'product-details',
			'label' => esc_html__( 'Product Details', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_music-eq-a"></i>',
		);

		$nice_fields[] = array(
			'name'      => '_product_gallery_position',
			'std'       => '',
			'label'     => esc_html__( 'Gallery Position', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''                     => esc_html__( 'Default', 'smart' ),
				'left'   => esc_html__( 'Left', 'smart' ),
				'right'  => esc_html__( 'Right', 'smart' ),
			),
			'desc'      => esc_html__( 'Choose the position for this product\'s gallery.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_product_gallery_layout',
			'std'       => '',
			'label'     => esc_html__( 'Gallery Layout', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''                     => esc_html__( 'Default', 'smart' ),
				'slider-thumbs-bottom' => esc_html__( 'Image slider with thumbnails on bottom', 'smart' ),
				'slider-thumbs-left'   => esc_html__( 'Image slider with thumbnails on the left side', 'smart' ),
				'slider-thumbs-right'  => esc_html__( 'Image slider with thumbnails on the right side', 'smart' ),
				'slider-no-thumbs'     => esc_html__( 'Image slider without thumbnails', 'smart' ),
				'img-list'             => esc_html__( 'List of images', 'smart' ),
			),
			'desc'      => esc_html__( 'Choose the layout for this product\'s gallery.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_product_tabs_position',
			'std'       => '',
			'label'     => esc_html__( 'Tabs Position', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''     => esc_html__( 'Inherit', 'smart' ),
				'top'  => esc_html__( 'On Top', 'smart' ),
				'side' => esc_html__( 'Side', 'smart' ),
			),
			'desc'      => esc_html__( 'Choose the position of this product\'s tabs.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_product_tabs_position_top',
			'std'       => '',
			'label'     => esc_html__( 'Tabs Orientation (Top)', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''       => esc_html__( 'Inherit', 'smart' ),
				'left'   => esc_html__( 'Left', 'smart' ),
				'center' => esc_html__( 'Center', 'smart' ),
				'right'  => esc_html__( 'Right', 'smart' ),
			),
			'desc'      => esc_html__( 'Choose the alignment direction for this product\'s tabs.', 'smart' ),
			'condition' => '_product_tabs_position:not(side)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_product_tabs_position_side',
			'std'       => '',
			'label'     => esc_html__( 'Tabs Orientation (Side)', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'left'  => esc_html__( 'Left', 'smart' ),
				'right' => esc_html__( 'Right', 'smart' ),
			),
			'desc'      => esc_html__( 'Choose which side you want the tabs to display in.', 'smart' ),
			'condition' => '_product_tabs_position:not(top)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'    => '_product_reviews_display',
			'std'     => '',
			'label'   => esc_html__( 'Display Product Reviews', 'smart' ),
			'desc'    => esc_html__( 'Display reviews on this product\'s page.', 'smart' ),
			'type'    => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
		);

		/**
		 * Linked Products
		 */
		$nice_fields[] = array(
			'name'  => 'products-linked',
			'label' => esc_html__( 'Linked Products', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_ecommerce-shirt-a"></i>',
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_display_related',
			'std'       => '',
			'label'     => esc_html__( 'Display Related Products', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Default', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Display related products on this product\'s page.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_related_limit',
			'std'       => '',
			'label'     => esc_html__( 'Related Products limit', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''       => esc_html__( 'Default', 'smart' ),
				'custom' => esc_html__( 'Custom', 'smart' ),
			),
			'desc'      => esc_html__( 'Maximum number of related products to display.', 'smart' ),
			'condition' => '_product_linked_display_related:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_related_limit_custom',
			'std'       => nice_get_option( '_woocommerce_products_related_limit', 4 ),
			'label'     => esc_html__( 'Custom Related Products limit', 'smart' ),
			'type'      => 'select',
			'options'   => $up_to( 20 ),
			'desc'      => esc_html__( 'Set the number of related products to display.', 'smart' ),
			'condition' => '_product_linked_display_related:not(false),_product_linked_related_limit:is(custom)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_related_columns',
			'std'       => '',
			'label'     => esc_html__( 'Columns for Related Products', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''       => esc_html__( 'Default', 'smart' ),
				'custom' => esc_html__( 'Custom', 'smart' ),
			),
			'desc'      => esc_html__( 'Number of columns for related products to be displayed.', 'smart' ),
			'condition' => '_product_linked_display_related:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_related_columns_custom',
			'std'       => nice_get_option( '_woocommerce_products_related_limit', 4 ),
			'label'     => esc_html__( 'Custom number of columns for Related Products', 'smart' ),
			'type'      => 'select',
			'options'   => $up_to( 6 ),
			'desc'      => esc_html__( 'Choose the number of columns for related products to be displayed.', 'smart' ),
			'condition' => '_product_linked_display_related:not(false),_product_linked_related_columns:is(custom)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_display_upsells',
			'std'       => '',
			'label'     => esc_html__( 'Display Up-sells', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Default', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Display upsells on this product\'s page.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_upsells_limit',
			'std'       => '',
			'label'     => esc_html__( 'Up-sells limit', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''       => esc_html__( 'Default', 'smart' ),
				'custom' => esc_html__( 'Custom', 'smart' ),
			),
			'desc'      => esc_html__( 'Maximum number of up-sells to display.', 'smart' ),
			'condition' => '_product_linked_display_upsells:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_upsells_limit_custom',
			'std'       => nice_get_option( '_woocommerce_products_upsells_limit', 4 ),
			'label'     => esc_html__( 'Custom Up-sells limit', 'smart' ),
			'type'      => 'select',
			'options'   => $up_to( 20 ),
			'desc'      => esc_html__( 'Set the number of up-sells to display.', 'smart' ),
			'condition' => '_product_linked_display_upsells:not(false),_product_linked_upsells_limit:is(custom)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_upsells_columns',
			'std'       => '',
			'label'     => esc_html__( 'Columns for Up-sells', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''       => esc_html__( 'Default', 'smart' ),
				'custom' => esc_html__( 'Custom', 'smart' ),
			),
			'desc'      => esc_html__( 'Number of columns for up-sells to be displayed.', 'smart' ),
			'condition' => '_product_linked_display_upsells:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_product_linked_upsells_columns_custom',
			'std'       => nice_get_option( '_woocommerce_products_upsells_columns', 4 ),
			'label'     => esc_html__( 'Custom number of columns for Up-sells', 'smart' ),
			'type'      => 'select',
			'options'   => $up_to( 6 ),
			'desc'      => esc_html__( 'Choose the number of columns for up-sells to be displayed.', 'smart' ),
			'condition' => '_product_linked_display_related:not(false),_product_linked_upsells_columns:is(custom)',
			'operator'  => 'and',
		);

		/**
		 * Footer
		 */

		$nice_fields[] = array(
			'name'  => 'portfolio-footer',
			'label' => esc_html__( 'Footer', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_layout-footer"></i>',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer',
			'std'       => '',
			'label'     => esc_html__( 'Display Footer', 'smart' ),
			'type'      => 'select',
			'desc'      => esc_html__( 'Show the footer for this product.', 'smart' ),
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
		);

		$nice_fields[] = array(
			'name'    => '_post_footer_skin',
			'std'     => '',
			'label'   => esc_html__( 'Footer Skin', 'smart' ),
			'type'    => 'select',
			'options' => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'dark'  => esc_html__( 'Dark', 'smart' ),
				'light' => esc_html__( 'Light', 'smart' ),
			),
			'desc'    => esc_html__( 'Select the footer skin for this product.', 'smart' ),
			'condition' => '_post_footer:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer_widgets',
			'std'       => '',
			'label'     => esc_html__( 'Display Footer Widgets Area', 'smart' ),
			'type'      => 'select',
			'desc'      => esc_html__( 'Show the footer widgets area for this product.', 'smart' ),
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'condition' => '_post_footer:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer_extended',
			'std'       => '',
			'label'     => esc_html__( 'Display Copyright Area', 'smart' ),
			'type'      => 'select',
			'desc'      => esc_html__( 'Show the footer copyright area for this product.', 'smart' ),
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'condition' => '_post_footer:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer_display_social',
			'std'       => '',
			'label'     => esc_html__( 'Display Social Icons', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Select whether or not to show a the social icons in the footer for this product.', 'smart' ),
			'condition' => '_post_footer_extended:not(false),_post_footer_extended:not(false)',
			'operator'  => 'or',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer_width',
			'std'       => '',
			'label'     => esc_html__( 'Footer Width', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'full'  => esc_html__( 'Full', 'smart' ),
				'limit' => esc_html__( 'Limit', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the width of the footer contents for this product.', 'smart' ),
			'condition' => '_post_footer:not(false)',
			'operator'  => 'and',
		);
	}

	return $nice_fields;
}
endif;
