<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the default theme settings.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.1
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_woocommerce_integration_default_settings' ) ) :
add_filter( 'nice_default_settings', 'nice_woocommerce_integration_default_settings' );
/**
 * Define and return default values for theme settings.
 *
 * @param  array $settings
 *
 * @return array
 */
function nice_woocommerce_integration_default_settings( $settings = array() ) {
	$theme_settings = array(
		'woocommerce_navigation'                       => false,
		'woocommerce_header_cart_type'                 => 'icon',
		'woocommerce_columns'                          => array(
			'range' => 'min',
			'value' => '4',
			'min'   => '1',
			'max'   => '8'
		),
		'woocommerce_products_per_page'                => array(
			'range' => 'min',
			'value' => '12',
			'min'   => '1',
			'max'   => '40'
		),
		'woocommerce_sale_flash_text'                  => esc_attr__( 'Sale', 'smart' ),
		'woocommerce_sale_flash_text_position'         => 'right',
		'woocommerce_myaccount_navigation_position'    => '',
		'woocommerce_archives_sidebar'                 => false,
		'woocommerce_archives_breadcrumb'              => false,
		'woocommerce_shop_layout'                      => 'grid',
		'woocommerce_allow_shop_layout_switch'         => true,
		'woocommerce_add_to_cart_text'                 => false,
		'woocommerce_archives_rating'                  => false,
		'woocommerce_image_flip'                       => false,
		'woocommerce_quick_view'                       => false,
		'woocommerce_quick_view_style'                 => 'default',
		'woocommerce_quick_view_link_position'         => 'left',
		'woocommerce_quick_view_gallery_position'      => 'right',
		'woocommerce_quick_view_overlay_color'         => '',
		'woocommerce_quick_view_overlay_opacity'       => array(
			'range' => 'min',
			'value' => '60',
			'min'   => '0',
			'max'   => '100',
			'unit'  => '%',
		),
		'product_header'                               => true,
		'product_navigation_menu'                      => '',
		'product_navigation_style'                     => '',
		'product_header_background_transparent'        => '',
		'product_header_background_transparent_mobile' => '',
		'product_header_skin'                          => '',
		'product_header_background_color'              => '',
		'product_navigation_submenu_skin'              => '',
		'product_header_width'                         => '',
		'product_header_display_search'                => '',
		'product_header_display_social'                => '',
		'woocommerce_gallery_position'                 => '',
		'woocommerce_gallery_layout'                   => 'slider-thumbs-bottom',
		'product_tabs_position'                        => '',
		'product_tabs_position_top'                    => '',
		'product_tabs_position_side'                   => '',
		'product_reviews_display'                      => '',
		'woocommerce_products_sidebar'                 => false,
		'woocommerce_products_breadcrumb'              => false,
		'woocommerce_products_related'                 => true,
		'woocommerce_products_related_title'           => esc_attr__( 'Related products', 'woocommerce' ),
		'woocommerce_products_related_limit'           => array(
			'range' => 'min',
			'value' => '4',
			'min'   => '1',
			'max'   => '20',
		),
		'woocommerce_products_related_columns'         => array(
			'range' => 'min',
			'value' => '4',
			'min'   => '1',
			'max'   => '6',
		),
		'woocommerce_products_upsells'                 => true,
		'woocommerce_products_upsells_title'           => esc_attr__( 'You may also like&hellip;', 'woocommerce' ),
		'woocommerce_products_upsells_limit'           => array(
			'range' => 'min',
			'value' => '4',
			'min'   => '1',
			'max'   => '20',
		),
		'woocommerce_products_upsells_columns'         => array(
			'range' => 'min',
			'value' => '4',
			'min'   => '1',
			'max'   => '6',
		),
		'product_footer'                               => true,
		'product_footer_skin'                          => '',
		'product_footer_widgets'                       => true,
		'product_footer_extended'                      => true,
		'product_footer_display_social'                => '',
		'product_footer_width'                         => '',
	);

	return array_merge( $settings, $theme_settings );
}
endif;