<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles interactions with our implementation of YITH Order Tracking.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      https://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( class_exists( 'Yith_WooCommerce_Order_Tracking' ) ) :

if ( ! function_exists( 'nice_integration_yith_wcot_remove_default_icons' ) ) :
add_action( 'init', 'nice_integration_yith_wcot_remove_default_icons' );
/**
 * Remove default plugin icons.
 *
 * @since 1.0.0
 */
function nice_integration_yith_wcot_remove_default_icons() {
	global $YWOT_Instance;

	// Return early if the plugin's main instance has been modified.
	if ( ! $YWOT_Instance instanceof Yith_WooCommerce_Order_Tracking ) {
		return;
	}

	remove_action( 'woocommerce_my_account_my_orders_actions', array( $YWOT_Instance, 'show_picked_up_icon_on_orders' ), 99 );
}
endif;

if ( ! function_exists( 'nice_integration_yith_wcot_show_picked_up_icon_on_orders' ) ) :
add_action( 'woocommerce_my_account_my_orders_actions', 'nice_integration_yith_wcot_show_picked_up_icon_on_orders', 99, 2 );
/**
 * Show on my orders page, a link image stating the order has been picked
 *
 * @since  1.0.0
 *
 * @param  array    $actions
 * @param  WC_Order $order
 *
 * @return array
 */
function nice_integration_yith_wcot_show_picked_up_icon_on_orders( $actions, $order ) {
	global $YWOT_Instance;

	// Return early if the plugin's main instance has been modified.
	if ( ! $YWOT_Instance instanceof Yith_WooCommerce_Order_Tracking ) {
		return null;
	}

	$id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->{'id'};
	$data = get_post_custom( $id );

	if ( $YWOT_Instance->is_order_picked_up( $data ) ) {
		nice_integration_yith_wcot_show_picked_up_icon( $data, 'button' );
	}

	return $actions;
}
endif;

if ( ! function_exists( 'nice_integration_yith_wcot_show_picked_up_icon' ) ) :
/**
 * Show an image stating the order has been picked up.
 *
 * @param array  $data      Post meta related to current order.
 * @param string $css_class
 *
 * @since  1.0.0
 */
function nice_integration_yith_wcot_show_picked_up_icon( $data, $css_class = '' ) {
	global $YWOT_Instance;

	// Return early if the plugin's main instance has been modified.
	if ( ! $YWOT_Instance instanceof Yith_WooCommerce_Order_Tracking ) {
		return;
	}

	if ( ! $YWOT_Instance->is_order_picked_up( $data ) ) {
		return;
	}

	$message = $YWOT_Instance->get_picked_up_message( $data );

	echo '<a class="track-button ' . esc_attr( $css_class ) . ' " href="javascript:void(0);" data-title="' . esc_attr( $message ) . '"><i class="fa fa-truck" data-title="' . esc_attr( $message ) . '" /></i></a>';
}
endif;

if ( ! function_exists( 'nice_integration_yith_wcot_custom_styles' ) ) :
add_action( 'nice_register_styles', 'nice_integration_yith_wcot_custom_styles' );
/**
 * Add custom styles for plugin integration.
 *
 * @since 1.0.0
 *
 * @param string $template_directory_uri
 */
function nice_integration_yith_wcot_custom_styles( $template_directory_uri = '' ) {
	wp_register_style( 'nice-yith-wcot-styles', $template_directory_uri . '/includes/plugin-integrations/woocommerce/css/nice-woocommerce-yith-wcot-styles.css' );
	wp_enqueue_style( 'nice-yith-wcot-styles' );
}
endif;

if ( ! function_exists( 'nice_integration_yith_wcot_remove_styles' ) ) :
add_action( 'wp_print_styles', 'nice_integration_yith_wcot_remove_styles' );
/**
 * Remove default plugin styles.
 *
 * @since 1.0.0
 */
function nice_integration_yith_wcot_remove_styles() {
	wp_dequeue_style( 'ywot_style' ); // This plugin does some weird shit with its preffixes.
}
endif;

endif;