<?php
/**
 * Smart by NiceThemes.
 *
 * This file handles interactions with our implementation of YITH Wishlist.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      https://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( class_exists( 'YITH_WCWL' ) ) :

if ( ! function_exists( 'nice_yith_wcwl_styles' ) ) :
add_action( 'nice_register_styles', 'nice_yith_wcwl_styles' );
/**
 * Remove default plugin styles.
 *
 * @since 1.0.0
 *
 * @param  string $template_directory_uri
 */
function nice_yith_wcwl_styles( $template_directory_uri = '' ) {
	wp_register_style( 'nice-yith-wcwl-styles', $template_directory_uri . '/includes/plugin-integrations/woocommerce/css/nice-woocommerce-yith-wcwl-styles.css' );
	wp_enqueue_style( 'nice-yith-wcwl-styles' );
	wp_dequeue_style( 'yith-wcwl-main' );
	wp_dequeue_style( 'yith-wcwl-font-awesome' );
}
endif;

if ( ! function_exists( 'nice_yith_wcwl_integration_options' ) ) :
add_filter( 'nice_options', 'nice_yith_wcwl_integration_options', 20 );
/**
 * Add wishlist specific options to theme options.
 *
 * @since  1.0.0
 *
 * @param  array $nice_options
 * @return array
 */
function nice_yith_wcwl_integration_options( $nice_options ) {
	// Obtain the prefix for the option fields.
	$prefix = NICE_PREFIX;

	$nice_yith_wcwl_shop_options[] = array(
		'name' => esc_html__( 'Display Wishlist Icon on Shop pages', 'smart' ),
		'desc' => sprintf( esc_html__( 'Show wishlist icon on shop and archive pages.', 'smart' ), '<em>', '</em>' ),
		'id'   => $prefix . '_yith_wcwl_shop_link',
		'std'  => nice_default_setting( 'yith_wcwl_shop_link' ),
		'type' => 'checkbox',
	);

	$nice_yith_wcwl_shop_options[] = array(
		'name'      => esc_html__( 'Wishlist Icon position', 'smart' ),
		'desc'      => esc_html__( 'Choose the position of the wishlist icon.', 'smart' ),
		'id'        => $prefix . '_yith_wcwl_shop_link_position',
		'type'      => 'select',
		'std'       => nice_default_setting( 'yith_wcwl_shop_link_position' ),
		'tip'       => '',
		'options'   => array(
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
		'condition' => $prefix . '_yith_wcwl_shop_link:is(true)',
		'operator'  => 'and',
	);

	$nice_yith_wcwl_single_options[] = array(
		'name' => esc_html__( 'Display Wishlist Icon on Product pages', 'smart' ),
		'desc' => sprintf( esc_html__( 'Show wishlist icon on %1$sall%2$s product pages. Make sure to set "Position" to "Use shortcode" in your wishlist settings to make this option work fine.', 'smart' ), '<em>', '</em>' ),
		'id'   => $prefix . '_yith_wcwl_single_link',
		'std'  => nice_default_setting( 'yith_wcwl_single_link' ),
		'type' => 'checkbox',
	);

	$nice_yith_wcwl_single_options[] = array(
		'name'      => esc_html__( 'Wishlist Icon position', 'smart' ),
		'desc'      => esc_html__( 'Choose the position of the wishlist icon.', 'smart' ),
		'id'        => $prefix . '_yith_wcwl_single_link_position',
		'type'      => 'select',
		'std'       => nice_default_setting( 'yith_wcwl_single_link_position' ),
		'tip'       => '',
		'options'   => array(
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
		'condition' => $prefix . '_yith_wcwl_single_link:is(true)',
		'operator'  => 'and',
	);

	$nice_options = nice_options_enqueue( $nice_options, $nice_yith_wcwl_shop_options, $prefix . '_woocommerce_quick_view_overlay_opacity', false );
	$nice_options = nice_options_enqueue( $nice_options, $nice_yith_wcwl_single_options, $prefix . '_woocommerce_products_breadcrumb', false );

	return $nice_options;
}
endif;

if ( ! function_exists( 'nice_yith_wcwl_integration_positions' ) ) :
add_filter( 'yith_wcwl_positions', 'nice_yith_wcwl_integration_positions' );
/**
 * Modify default positions of add-to-wishlist button.
 *
 * @since 1.0.0
 *
 * @param  array $positions
 *
 * @return array
 */
function nice_yith_wcwl_integration_positions( array $positions = array() ) {
	$positions['add-to-cart'] = array( 'hook' => 'woocommerce_after_add_to_cart_button', 'priority' => 31 );

	return $positions;
}
endif;

if ( ! function_exists( 'nice_yith_wcwl_integration_wishlist' ) ) :
add_action( 'nice_woocommerce_integration_loop_item_content', 'nice_yith_wcwl_integration_wishlist', 30 );
/**
 * Display default link to add product to wishlist.
 *
 * @since 1.0.0
 */
function nice_yith_wcwl_integration_wishlist() {
	if ( ! nice_bool_option( '_yith_wcwl_shop_link' ) ) {
		return;
	}

	wc_get_template( 'wishlist/icon.php' );
}
endif;

if ( ! function_exists( 'nice_yith_wcwl_integration_shortcode_atts' ) ) :
/**
 * Custom array of attributes for wishlist shortcode.
 *
 * @since 1.0.0
 */
function nice_yith_wcwl_integration_shortcode_atts() {
	$label         = get_option( 'yith_wcwl_add_to_wishlist_text' ) ? : esc_html__( 'Add to Wishlist', 'smart' );
	$wishlist_text = get_option( 'yith_wcwl_browse_wishlist_text' ) ? : esc_html__( 'View Wishlist', 'smart' );

	$atts = array(
		'icon'                      => 'fa-heart',
		'label'                     => '<label class="tooltip">' . $label . '</label>',
		'browse_wishlist_text'      => '<i class="fa fa-heart text-accent-color"></i><label class="tooltip">' . $wishlist_text . '</label>',
		'already_in_wishslist_text' => '', // "wishslist" is not a typo.
		'product_added_text'        => '',
		'link_classes'              => 'add_to_wishlist',
	);

	if ( $page_id = get_option( 'yith_wcwl_wishlist_page_id' ) ) {
		$atts['wishlist_url'] = get_permalink( $page_id );
	}

	return $atts;
}
endif;

if ( ! function_exists( 'nice_integration_yith_wcwl_add_to_wishlist_params' ) ) :
add_filter( 'yith_wcwl_add_to_wishlist_params', 'nice_integration_yith_wcwl_add_to_wishlist_params' );
/**
 * Override default whishlist parameters.
 *
 * @since 1.0.0
 *
 * @param array $params
 *
 * @return array
 */
function nice_integration_yith_wcwl_add_to_wishlist_params( array $params = array() ) {
	if ( $page_id = get_option( 'yith_wcwl_wishlist_page_id' ) ) {
		$params['wishlist_url'] = get_permalink( $page_id );
	}

	return $params;
}
endif;

if ( ! function_exists( 'nice_yith_wcwl_integration_single_wishlist' ) ) :
add_action( 'nice_woocommerce_integration_before_single_product_gallery', 'nice_yith_wcwl_integration_single_wishlist' );
/**
 * Print add-to-wishlist link before the single product gallery.
 *
 * @since 1.0.0
 */
function nice_yith_wcwl_integration_single_wishlist() {
	if ( nice_doing_ajax() ) {
		return;
	}

	if ( 'shortcode' !== get_option( 'yith_wcwl_button_position' ) || ! nice_bool_option( '_yith_wcwl_single_link' ) ) {
		return;
	}

	wc_get_template( 'wishlist/single-icon.php' );
}
endif;

if ( ! function_exists( 'nice_integration_yith_wcwl_locate_template' ) ) :
add_filter( 'yith_wcwl_locate_template', 'nice_integration_yith_wcwl_locate_template', 10, 2 );
/**
 * Locate plugin template.
 *
 * @since 1.0.0
 *
 * @param string $plugin_path
 * @param string $path
 *
 * @return string
 */
function nice_integration_yith_wcwl_locate_template( $plugin_path = '', $path = '' ) {
	if ( file_exists( $plugin_path ) ) {
		$located = wc_locate_template( 'wishlist/' . $path );

		if ( file_exists( $located ) ) {
			$plugin_path = $located;
		}
	}

	return $plugin_path;
}
endif;

if ( ! function_exists( 'nice_integration_yith_wcwl_before_wishlist_form' ) ) :
add_action( 'yith_wcwl_before_wishlist_form', 'nice_integration_yith_wcwl_before_wishlist_form' );
/**
 * Add or remove hooks before the wishlist form is printed.
 *
 * @since 1.0.0
 */
function nice_integration_yith_wcwl_before_wishlist_form() {
	remove_filter( 'woocommerce_loop_add_to_cart_args', 'nice_woocommerce_integration_loop_add_to_cart_args' );
}
endif;

if ( ! function_exists( 'nice_yith_wcwl_integration_top_bar_shortcodes' ) ) :
add_filter( 'nice_top_bar_shortcodes', 'nice_yith_wcwl_integration_top_bar_shortcodes' );
/**
 * Add top bar shortcodes for wishlist.
 *
 * @since 1.0.0
 *
 * @param array $shortcodes
 *
 * @return array
 */
function nice_yith_wcwl_integration_top_bar_shortcodes( array $shortcodes = array() ) {
	$shortcodes['wishlist'] = 'nice_yith_wcwl_integration_wishlist_shortcode';

	return $shortcodes;
}
endif;

if ( ! function_exists( 'nice_yith_wcwl_integration_wishlist_shortcode' ) ) :
/**
 * Print link to wishlist, including number of items.
 *
 * @since 1.0.0
 *
 * @param array $atts
 *
 * @return string
 */
function nice_yith_wcwl_integration_wishlist_shortcode( array $atts = array() ) {
	$text       = empty( $atts['label'] ) ? esc_html__( 'Wishlist', 'smart' ) : $atts['label'];
	$icon_class = empty( $atts['icon_class'] ) ? 'fa-heart' : $atts['icon_class'];

	$wishlist_url = '';
	if ( $page_id = get_option( 'yith_wcwl_wishlist_page_id' ) ) {
		$wishlist_url = get_permalink( $page_id );
	}

	/**
	 * Obtain wishlist count.
	 *
	 * @since 1.0.0
	 */
	$count = 0;
	if ( is_user_logged_in() ) {
		$wishlists = YITH_WCWL()->get_wishlists( array( 'user_id' => get_current_user_id(), 'is_default' => 1 ) );
		$count = YITH_WCWL()->count_products( $wishlists[0]['wishlist_token'] );
	}

	ob_start();
	?>
	<div id="top-bar-wishlist" class="top-bar-link">
		<a href="<?php echo esc_url( $wishlist_url ); ?>" title="<?php echo esc_attr( $text ); ?>">
			<?php if ( isset( $atts['icon'] ) && nice_bool( $atts['icon'] ) ) : ?>
				<i class="fa <?php echo esc_attr( $icon_class ); ?>"></i>
			<?php endif; ?>
			<?php echo esc_html( $text ); ?>
			<span id="top-bar-wishlist-count" class="<?php nice_theme_color_background_class( 'accent-color', true ); ?>" data-count="<?php echo esc_attr( (int) $count ); ?>"><?php echo esc_html( $count ); ?></span>
		</a>
	</div>
	<?php

	$content = ob_get_contents();
	ob_end_clean();

	return $content;
}
endif;

endif;
