/**
 * Smart by NiceThemes.
 *
 * Manage Flexslider implementation for WooCommerce.
 *
 * @since   1.0.0
 * @package Smart
 */
var NiceWooCommerceFlexslider = ( function( $ ) {
	// Tell browsers we're not doing anything silly.
	'use strict';

	/**
	 * Load Flexslider.
	 *
	 * @since 1.0.0
	 */
	var load = function() {
		var url = $.NiceLazyScript( 'flexslider' );

		$( 'document' ).ready( function() {
			if ( typeof $.fn.flexslider !== 'function' && url ) {
				$.getScript( url, setup );
			} else if ( typeof $.fn.flexslider === 'function' ) {
				setup();
			} else {
				$.NiceDev.log( 'Warning: FlexSlider is not initialized.' );
			}
		} );
	},

	/**
	 * Setup Flexslider.
	 *
	 * @since 1.0.0
	 */
	setup = function() {
		// The slider being synced must be initialized first.
		loadCarousel( '.fs-slider' );
		loadSlider( '.fs-carousel' );

		// Notify about DOM changes.
		$( document ).trigger( 'NiceDOMChanged' );
	},

	/**
	 * Load carousel.
	 *
	 * @param {string} asNavFor
	 *
	 * @since 1.0.0
	 */
	loadCarousel = function( asNavFor ) {
		$( '.fs-carousel' ).flexslider( {
			animation: 'slide',
			controlNav: false,
			animationLoop: false,
			slideshow: false,
			itemWidth: 110,
			itemMargin: 5,
			asNavFor: asNavFor
		} );
	},

	/**
	 * Load slider.
	 *
	 * @param {string} sync
	 *
	 * @since 1.0.0
	 */
	loadSlider = function( sync ) {
		$( '.fs-slider' ).flexslider( {
			animation: 'fade',
			controlNav: false,
			animationLoop: false,
			slideshow: false,
			sync: sync
		} );
	},

	/**
	 * Fire events on document ready, and bind other events.
	 *
	 * @since 1.0.0
	 */
	ready = function() {
		load();
	};

	// Expose the ready function to the world.
	return {
		ready: ready,
		loadCarousel: function( asNavFor ) {
			loadCarousel( asNavFor );
		},
		loadSlider: function( sync ) {
			loadSlider( sync );
		}
	};

} )( jQuery );

// jQuery( NiceWooCommerceFlexslider.ready );
