/**
 * Smart by NiceThemes.
 *
 * Manage jQuery Zoom implementation for WooCommerce.
 *
 * @since   1.0.1
 * @package Smart
 */
var NiceWooCommerceZoom = ( function( $ ) {
	'use strict';

	/**
	 * HTML object that contains all images to be zoomed.
	 *
	 * @since 1.0.1
	 */
	var $gallery,

	/**
	 * Load jQuery Zoom implementation.
	 *
	 * @since 1.0.1
	 */
	load = function() {
		if ( 'undefined' !== typeof NiceWooCommerceOwlCarousel && NiceWooCommerceOwlCarousel.fired() ) {
			initGallery( $( '#product-gallery-container' ).find( 'ul' ) );
			return;
		}

		$( document ).on( 'NiceSingleProductGalleryLoaded', function( event, $gal ) {
			initGallery( $gal );
		} );
	},

	/**
	 * Initialize jQuery Zoom implementation.
	 *
	 * @since 1.0.1
	 */
	init = function() {
		var $imgs = $gallery.find( 'img' );

		if ( $imgs.length ) {
			$imgs.each( function() {
				$( this ).parent().zoom( { url: $( this ).attr( 'src' ) } );
			} );
		}
	},

	initGallery = function( $gal ) {
		var url = $.NiceLazyScript( 'zoom' );

		$gallery = $gal;

		if ( 'function' !== typeof $.fn.zoom && url ) {
			$.getScript( url, init );
		} else if ( 'function' === typeof $.fn.zoom ) {
			init();
		} else {
			$.NiceDev.log( 'Warning: Zoom is not initialized.' );
		}
	},

	ready = function() {
		load();
	};

	return {
		ready: ready
	};
} )( jQuery );

jQuery( NiceWooCommerceZoom.ready );