<?php
/**
 * Smart by NiceThemes.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://www.nicethemes.com/theme-page
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_woocommerce_integration_options' ) ) :
add_filter( 'nice_options', 'nice_woocommerce_integration_options' );
/**
 * Add WooCommerce specific options to theme options.
 *
 * @since  1.0.0
 *
 * @param  array $nice_options
 * @return array
 */
function nice_woocommerce_integration_options( $nice_options ) {
	// Obtain the prefix for the option fields.
	$prefix = NICE_PREFIX;

	$nice_woocommerce_header_extra_options[] = array(
		'name' => esc_html__( 'Display Shopping Cart', 'smart' ),
		'desc' => esc_html__( 'Show a link to the shopping cart in the header.', 'smart' ),
		'id'   => $prefix . '_woocommerce_navigation',
		'std'  => nice_default_setting( 'woocommerce_navigation' ),
		'options' => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	$nice_woocommerce_header_extra_options[] = array(
		'name'      => esc_html__( 'Shopping Cart Type', 'smart' ),
		'desc'      => esc_html__( 'Choose the type of cart you would like to display in the header. Icon or text.', 'smart' ),
		'id'        => $prefix . '_woocommerce_header_cart_type',
		'type'      => 'select',
		'std'       => nice_default_setting( 'woocommerce_header_cart_type' ),
		'tip'       => '',
		'options'   => array(
			'icon'  => esc_html__( 'Icon', 'smart' ),
			'text'  => esc_html__( 'Text', 'smart' ),
		),
		'condition' => $prefix . '_woocommerce_navigation:is(true)',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'WooCommerce', 'smart' ),
		'id'   => $prefix . '_woocommerce_integration_section',
		'type' => 'heading',
		'icon' => '<i class="bi_ecommerce-shopcart"></i>',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'General', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_music-eq-a"></i>',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Columns', 'smart' ),
		'desc' => esc_html__( 'Select the number of columns for your shop.', 'smart' ),
		'id'   => $prefix . '_woocommerce_columns',
		'std'  => nice_default_setting( 'woocommerce_columns' ),
		'type' => 'slider',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Products per Page', 'smart' ),
		'desc' => esc_html__( 'Select the number of products per page for your shop.', 'smart' ),
		'id'   => $prefix . '_woocommerce_products_per_page',
		'std'  => nice_default_setting( 'woocommerce_products_per_page' ),
		'type' => 'slider',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( '"On Sale" Text', 'smart' ),
		'desc' => sprintf( esc_html__( 'Change the &1$s"Sale!"%2$s text.', 'smart' ), '<em>', '</em>' ),
		'id'   => $prefix . '_woocommerce_sale_flash_text',
		'std'  => nice_default_setting( 'woocommerce_sale_flash_text' ),
		'type' => 'text',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'    => esc_html__( '"On Sale" Text Position', 'smart' ),
		'desc'    => esc_html__( 'Select the default position for the "on sale" text.', 'smart' ),
		'id'      => $prefix . '_woocommerce_sale_flash_text_position',
		'std'     => nice_default_setting( 'woocommerce_sale_flash_text_position' ),
		'options' => array(
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
		'type'    => 'select',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'    => esc_html__( '"My Account" Navigation Position', 'smart' ),
		'desc'    => esc_html__( 'Select position for "My Account" navigation area.', 'smart' ),
		'id'      => $prefix . '_woocommerce_myaccount_navigation_position',
		'std'     => nice_default_setting( 'woocommerce_myaccount_navigation_position' ),
		'options' => array(
			''      => esc_html__( 'Default', 'smart' ),
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
		'type'    => 'select',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Shop & Archives', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_ecommerce-market"></i>',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Display Sidebar on Shop Archives Pages', 'smart' ),
		'desc' => esc_html__( 'Show the sidebar on shop archive pages.', 'smart' ),
		'id'   => $prefix . '_woocommerce_archives_sidebar',
		'std'  => nice_default_setting( 'woocommerce_archives_sidebar' ),
		'type' => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Display Breadcrumbs on Shop Pages', 'smart' ),
		'desc' => esc_html__( 'Show breadcrumbs on shop pages.', 'smart' ),
		'id'   => $prefix . '_woocommerce_archives_breadcrumb',
		'std'  => nice_default_setting( 'woocommerce_archives_breadcrumb' ),
		'type' => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'    => esc_html__( 'Default Shop Layout', 'smart' ),
		'desc'    => esc_html__( 'Choose the default layout of your shop.', 'smart' ),
		'id'      => $prefix . '_woocommerce_shop_layout',
		'type'    => 'select',
		'std'     => nice_default_setting( 'woocommerce_shop_layout' ),
		'tip'     => '',
		'options' => array(
			'grid' => esc_html__( 'Grid', 'smart' ),
			'list' => esc_html__( 'List', 'smart' ),
		),
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Switch Shop Layout', 'smart' ),
		'desc' => esc_html__( 'Allow visitors to switch the shop layout.', 'smart' ),
		'id'   => $prefix . '_woocommerce_allow_shop_layout_switch',
		'std'  => nice_default_setting( 'woocommerce_allow_shop_layout_switch' ),
		'type' => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Use Text Based "Add to cart"/"Show more" Option', 'smart' ),
		'desc'      => esc_html__( 'Show an "Add to cart"/"Show more" link when hovering the product\'s price instead of a button.', 'smart' ),
		'id'        => $prefix . '_woocommerce_add_to_cart_text',
		'std'       => nice_default_setting( 'woocommerce_add_to_cart_text' ),
		'type'      => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Display Rating Stars on Shop Pages', 'smart' ),
		'desc' => esc_html__( 'Show rating stars on shop pages', 'smart' ),
		'id'   => $prefix . '_woocommerce_archives_rating',
		'std'  => nice_default_setting( 'woocommerce_archives_rating' ),
		'type' => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Image Flip', 'smart' ),
		'desc'      => esc_html__( 'Show a secondary image when hovering a product.', 'smart' ),
		'id'        => $prefix . '_woocommerce_image_flip',
		'std'       => nice_default_setting( 'woocommerce_image_flip' ),
		'type'      => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Display "Quick View" link in shop archive pages.', 'smart' ),
		'desc' => esc_html__( 'Display a link to show a quick view of the product.', 'smart' ),
		'id'   => $prefix . '_woocommerce_quick_view',
		'std'  => nice_default_setting( 'woocommerce_quick_view' ),
		'type' => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Quick View Style', 'smart' ),
		'desc'      => esc_html__( 'Choose a style for the "Quick View" link.', 'smart' ),
		'id'        => $prefix . '_woocommerce_quick_view_style',
		'type'      => 'select',
		'std'       => nice_default_setting( 'woocommerce_quick_view_style' ),
		'tip'       => '',
		'options'   => array(
			'default' => esc_html__( 'Default', 'smart' ),
			'text'    => esc_html__( 'Text Link', 'smart' ),
			'btn'     => esc_html__( 'Button', 'smart' ),
		),
		'condition' => $prefix . '_woocommerce_quick_view:is(true)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Quick View Link Position', 'smart' ),
		'desc'      => esc_html__( 'Choose the position of the quick view link.', 'smart' ),
		'id'        => $prefix . '_woocommerce_quick_view_link_position',
		'type'      => 'select',
		'std'       => nice_default_setting( 'woocommerce_quick_view_link_position' ),
		'tip'       => '',
		'options'   => array(
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Quick View Gallery Position', 'smart' ),
		'desc'      => esc_html__( 'Choose the position of the product gallery inside quick view.', 'smart' ),
		'id'        => $prefix . '_woocommerce_quick_view_gallery_position',
		'type'      => 'select',
		'std'       => nice_default_setting( 'woocommerce_quick_view_gallery_position' ),
		'tip'       => '',
		'options'   => array(
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Quick View Overlay Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a background color for the Quick View overlay.', 'smart' ),
		'id'        => $prefix . '_woocommerce_quick_view_overlay_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'woocommerce_quick_view_overlay_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Quick View Overlay Opacity', 'smart' ),
		'desc' => esc_html__( 'Choose the opacity for the quick view overlay.', 'smart' ),
		'id'   => $prefix . '_woocommerce_quick_view_overlay_opacity',
		'std' => nice_default_setting( 'woocommerce_quick_view_overlay_opacity' ),
		'type' => 'slider',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Product Page', 'smart' ),
		'id'   => $prefix . '_woocommerce_product_section',
		'type' => 'heading',
		'icon' => '<i class="bi_ecommerce-shirt-a"></i>',
		'parent' => $prefix . '_woocommerce_integration_section',
	);

	/**
	 * WooCoomerce > Product > Header
	 */

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Header', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-header"></i>',
		'id'   => $prefix . '_layout_product_header',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Display Header', 'smart' ),
		'desc'      => esc_html__( 'Show the header for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_product_header',
		'std'       => nice_default_setting( 'product_header' ),
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'type'    => 'radio_on_off',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Navigation Menu', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation menu to use for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_product_navigation_menu',
		'std'       => nice_default_setting( 'product_navigation_menu' ),
		'type'      => 'select',
		'options'   => nice_get_navigation_menus(),
		'condition' => $prefix . '_product_header:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Navigation Style', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation style to use for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_product_navigation_style',
		'std'       => nice_default_setting( 'product_navigation_style' ),
		'type'      => 'select',
		'options'   => array(
			''         => esc_html__( 'Inherit', 'smart' ),
			'default'  => esc_html__( 'Top', 'smart' ),
			'vertical' => esc_html__( 'Side', 'smart' ),
			'overlay'  => esc_html__( 'Overlay', 'smart' ),
		),
		'condition' => $prefix . '_product_header:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Transparent Header', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent.', 'smart' ),
		'id'        => $prefix . '_product_header_background_transparent',
		'std'       => nice_default_setting( 'product_header_background_transparent' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_product_header:not(false),' . $prefix . '_product_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Transparent Header (Mobile)', 'smart' ),
		'desc'      => esc_html__( 'Make the header transparent in smaller viewports. This option only works when the transparent header is enabled on desktop.', 'smart' ),
		'id'        => $prefix . '_product_header_background_transparent_mobile',
		'std'       => nice_default_setting( 'product_header_background_transparent_mobile' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_product_header:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Header Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the header content skin to use for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_product_header_skin',
		'std'       => nice_default_setting( 'product_header_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_product_header:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Header Background Color', 'smart' ),
		'desc'      => esc_html__( 'Choose a background color.', 'smart' ),
		'id'        => $prefix . '_product_header_background_color',
		'std'       => nice_default_setting( 'product_header_background_color' ),
		'type'      => 'select_color',
		'options'   => nice_theme_colors_dropdown_values(),
		'class'     => 'nice-select-color',
		'condition' => $prefix . '_product_header:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Navigation Sub-Menu Content Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the navigation sub-menu content skin to use for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_product_navigation_submenu_skin',
		'std'       => nice_default_setting( 'product_navigation_submenu_skin' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
		),
		'condition' => $prefix . '_product_header:not(false),' . $prefix . '_product_navigation_style:not(overlay)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Header Width', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to make the header contents take the full width for portfolio projects.', 'smart' ),
		'id'        => $prefix . '_product_header_width',
		'std'       => nice_default_setting( 'product_header_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_product_header:not(false),' . $prefix . '_product_navigation_style:not(vertical)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Display Search', 'smart' ),
		'desc'      => esc_html__( "Select whether or not to show a link to the site's search in the header for portfolio projects.", 'smart' ),
		'id'        => $prefix . '_product_header_display_search',
		'std'       => nice_default_setting( 'product_header_display_search' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_product_header:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'      => esc_html__( "Select whether or not to show a the social icons in the header for portfolio projects.", 'smart' ),
		'id'        => $prefix . '_product_header_display_social',
		'std'       => nice_default_setting( 'product_header_display_social' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_product_header:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Product Details', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_music-eq-a"></i>',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Product Gallery Position', 'smart' ),
		'desc'      => esc_html__( 'Choose a position for your product gallery on product pages.', 'smart' ),
		'id'        => $prefix . '_woocommerce_gallery_position',
		'type'      => 'select',
		'std'       => nice_default_setting( 'woocommerce_gallery_position' ),
		'tip'       => '',
		'options'   => array(
			''      => esc_html__( 'Default', 'smart' ),
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Product Gallery Layout', 'smart' ),
		'desc'      => esc_html__( 'Choose a layout for your product gallery on product pages.', 'smart' ),
		'id'        => $prefix . '_woocommerce_gallery_layout',
		'type'      => 'select',
		'std'       => nice_default_setting( 'woocommerce_gallery_layout' ),
		'tip'       => '',
		'options'   => array(
			'slider-thumbs-bottom' => esc_html__( 'Image slider with thumbnails on bottom', 'smart' ),
			'slider-thumbs-left'   => esc_html__( 'Image slider with thumbnails on the left side', 'smart' ),
			'slider-thumbs-right'  => esc_html__( 'Image slider with thumbnails on the right side', 'smart' ),
			'slider-no-thumbs'     => esc_html__( 'Image slider without thumbnails', 'smart' ),
			'img-list'             => esc_html__( 'List of images', 'smart' ),
		),
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Tabs Position', 'smart' ),
		'desc'      => esc_html__( 'Choose the position of this product\'s tabs.', 'smart' ),
		'id'        => $prefix . '_product_tabs_position',
		'std'       => nice_default_setting( 'product_tabs_position' ),
		'type'      => 'select',
		'options'   => array(
			'top'  => esc_html__( 'On Top', 'smart' ),
			'side' => esc_html__( 'Side', 'smart' ),
		),

	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Tabs Orientation (Top)', 'smart' ),
		'desc'      => esc_html__( 'Choose the alignment direction for this product\'s tabs.', 'smart' ),
		'id'        => $prefix . '_product_tabs_position_top',
		'std'       => nice_default_setting( 'product_tabs_position_top' ),
		'type'      => 'select',
		'options'   => array(
			'left'   => esc_html__( 'Left', 'smart' ),
			'center' => esc_html__( 'Center', 'smart' ),
			'right'  => esc_html__( 'Right', 'smart' ),
		),

		'condition' => $prefix . '_product_tabs_position:is(top)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Tabs Orientation (Side)', 'smart' ),
		'desc'      => esc_html__( 'Choose which side you want the tabs to display in.', 'smart' ),
		'id'        => $prefix . '_product_tabs_position_side',
		'std'       => nice_default_setting( 'product_tabs_position_side' ),
		'type'      => 'select',
		'options'   => array(
			'left'  => esc_html__( 'Left', 'smart' ),
			'right' => esc_html__( 'Right', 'smart' ),
		),
		'condition' => $prefix . '_product_tabs_position:is(side)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Display Product Reviews', 'smart' ),
		'desc'      => esc_html__( 'Display reviews on this product\'s page.', 'smart' ),
		'id'        => $prefix . '_product_reviews_display',
		'std'       => nice_default_setting( 'product_reviews_display' ),
		'type'      => 'radio_on_off',
		'options'  => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Layout', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-sidebar-l-half-a"></i>',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Display Sidebar on Product Pages', 'smart' ),
		'desc' => sprintf( esc_html__( 'Show the sidebar on %1$sall%2$s product pages.', 'smart' ), '<em>', '</em>' ),
		'id'   => $prefix . '_woocommerce_products_sidebar',
		'std'  => nice_default_setting( 'woocommerce_products_sidebar' ),
		'type' => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Display Breadcrumbs on Product pages', 'smart' ),
		'desc' => sprintf( esc_html__( 'Show breadcrumbs on %1$sall%2$s product pages.', 'smart' ), '<em>', '</em>' ),
		'id'   => $prefix . '_woocommerce_products_breadcrumb',
		'std'  => nice_default_setting( 'woocommerce_products_breadcrumb' ),
		'type' => 'checkbox',
	);


	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Related Products & Up-sells', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_ecommerce-tshirt"></i>',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Display Related Products on Product pages', 'smart' ),
		'desc' => sprintf( esc_html__( 'Show related products on %1$sall%2$s product pages.', 'smart' ), '<em>', '</em>' ),
		'id'   => $prefix . '_woocommerce_products_related',
		'std'  => nice_default_setting( 'woocommerce_products_related' ),
		'type' => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Related Products title', 'smart' ),
		'desc'      => sprintf( esc_html__( 'Title for Related Products in product pages.', 'smart' ), '<em>', '</em>' ),
		'id'        => $prefix . '_woocommerce_products_related_title',
		'std'       => nice_default_setting( 'woocommerce_products_related_title' ),
		'type'      => 'text',
		'condition' => $prefix . '_woocommerce_products_related:is(true)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Related Products Limit', 'smart' ),
		'desc'      => esc_html__( 'Choose the maximum number of related products to display.', 'smart' ),
		'id'        => $prefix . '_woocommerce_products_related_limit',
		'std'       => nice_default_setting( 'woocommerce_products_related_limit' ),
		'type'      => 'slider',
		'condition' => $prefix . '_woocommerce_products_related:is(true)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Columns for Related Products', 'smart' ),
		'desc'      => esc_html__( 'Choose the number of columns for related products to be displayed.', 'smart' ),
		'id'        => $prefix . '_woocommerce_products_related_columns',
		'std'       => nice_default_setting( 'woocommerce_products_related_columns' ),
		'type'      => 'slider',
		'condition' => $prefix . '_woocommerce_products_related:is(true)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Display Up-sells on Product pages', 'smart' ),
		'desc' => sprintf( esc_html__( 'Show up-sells on %1$sall%2$s product pages.', 'smart' ), '<em>', '</em>' ),
		'id'   => $prefix . '_woocommerce_products_upsells',
		'std'  => nice_default_setting( 'woocommerce_products_upsells' ),
		'type' => 'checkbox',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Up-sells title', 'smart' ),
		'desc'      => sprintf( esc_html__( 'Title for Up-sells in product pages.', 'smart' ), '<em>', '</em>' ),
		'id'        => $prefix . '_woocommerce_products_upsells_title',
		'std'       => nice_default_setting( 'woocommerce_products_upsells_title' ),
		'type'      => 'text',
		'condition' => $prefix . '_woocommerce_products_related:is(true)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Up-sells Limit', 'smart' ),
		'desc'      => esc_html__( 'Choose the maximum number of up-sells to display.', 'smart' ),
		'id'        => $prefix . '_woocommerce_products_upsells_limit',
		'std'       => nice_default_setting( 'woocommerce_products_upsells_limit' ),
		'type'      => 'slider',
		'condition' => $prefix . '_woocommerce_products_upsells:is(true)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Columns for Up-sells', 'smart' ),
		'desc'      => esc_html__( 'Choose the number of columns for up-sells to be displayed.', 'smart' ),
		'id'        => $prefix . '_woocommerce_products_upsells_columns',
		'std'       => nice_default_setting( 'woocommerce_products_upsells_columns' ),
		'type'      => 'slider',
		'condition' => $prefix . '_woocommerce_products_upsells:is(true)',
		'operator'  => 'and',
	);

	/**
	 * WooCommerce > Product > Footer
	 */

	$nice_woocommerce_integration_options[] = array(
		'name' => esc_html__( 'Footer', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_layout-footer"></i>',
		'id'   => $prefix . '_layout_product_footer',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Display Footer', 'smart' ),
		'desc'      => esc_html__( 'Show the footer for products.', 'smart' ),
		'id'        => $prefix . '_product_footer',
		'std'       => nice_default_setting( 'product_footer' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Footer Skin', 'smart' ),
		'desc'      => esc_html__( 'Select the footer skin for products.', 'smart' ),
		'id'        => $prefix . '_product_footer_skin',
		'std'       => nice_default_setting( 'product_footer_skin' ),
		'type'      => 'select',
		'options' => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'dark'  => esc_html__( 'Dark', 'smart' ),
			'light' => esc_html__( 'Light', 'smart' ),
		),
		'condition' => $prefix . '_product_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Display Footer Widgets Area', 'smart' ),
		'desc'      => esc_html__( 'Show the footer widgets area for products.', 'smart' ),
		'id'        => $prefix . '_product_footer_widgets',
		'std'       => nice_default_setting( 'product_footer_widgets' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_product_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Display Copyright Area', 'smart' ),
		'desc'      => esc_html__( 'Show the footer copyright area for products.', 'smart' ),
		'id'        => $prefix . '_product_footer_extended',
		'std'       => nice_default_setting( 'product_footer_extended' ),
		'type'      => 'radio_on_off',
		'options'   => array(
			true  => array( 'label' => esc_html__( 'On', 'smart' ) ),
			false => array( 'label' => esc_html__( 'Off', 'smart' ) ),
		),
		'condition' => $prefix . '_product_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Display Social Icons', 'smart' ),
		'desc'      => esc_html__( 'Select whether or not to show a the social icons in the footer for products.', 'smart' ),
		'id'        => $prefix . '_product_footer_display_social',
		'std'       => nice_default_setting( 'product_footer_display_social' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			true  => esc_html__( 'Yes', 'smart' ),
			false => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_product_footer:not(false),' . $prefix . '_product_footer_extended:not(false)',
		'operator'  => 'and',
	);

	$nice_woocommerce_integration_options[] = array(
		'name'      => esc_html__( 'Footer Width', 'smart' ),
		'desc'      => esc_html__( 'Select the width of the footer contents for products.', 'smart' ),
		'id'        => $prefix . '_product_footer_width',
		'std'       => nice_default_setting( 'product_footer_width' ),
		'type'      => 'select',
		'options'   => array(
			''      => esc_html__( 'Inherit', 'smart' ),
			'full'  => esc_html__( 'Full', 'smart' ),
			'limit' => esc_html__( 'Limit', 'smart' ),
		),
		'condition' => $prefix . '_product_footer:not(false)',
		'operator'  => 'and',
	);

	$nice_options = nice_options_enqueue( $nice_options, $nice_woocommerce_header_extra_options, $prefix . '_header_display_search', false );
	$nice_options = nice_options_enqueue( $nice_options, $nice_woocommerce_integration_options, $prefix . '_custom_typography_section', true );

	return $nice_options;
}
endif;
