<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage WooCommerce cart.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_woocommerce_integration_navigation_extras_cart_class' ) ) :
add_filter( 'nice_navigation_menu_extras_class', 'nice_woocommerce_integration_navigation_extras_cart_class' );
/**
 * Apply HTML class to #navigation-extras when displaying the shopping cart form.
 *
 * @since 1.0.0
 *
 * @param string $class
 *
 * @return string
 */
function nice_woocommerce_integration_navigation_extras_cart_class( $class = '' ) {
	if ( nice_woocommerce_integration_header_display_navigation() ) {
		if ( false !== ( $key = array_search( 'no-extras', $class ) ) ) {
			unset( $class[ $key ] );
		}

		if ( 'text' === nice_woocommerce_integration_header_cart_type() ) {
			$class[] = 'cart-text';
		}

		$class[] = 'has-shopping-cart';
	}

	return $class;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_header_cart' ) ) :
add_action( 'nice_navigation_menu', 'nice_woocommerce_integration_header_cart', 30 );
/**
 * Print shopping cart in the header of the theme.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_woocommerce_integration_header_cart() {
	if ( ! nice_woocommerce_integration_header_display_navigation() ) {
		return;
	}

	$cart_url = function_exists( 'wc_get_cart_url' ) ? wc_get_cart_url() : WC()->cart->get_cart_url();
	$cart_contents_count = WC()->cart->get_cart_contents_count();
?>
	<div id="header-shopping-cart-wrapper">
		<a id="header-shopping-cart" href="<?php echo esc_url( $cart_url ); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'smart' ); ?>">
			<div class="woo-cart-items">
				<?php echo nice_woocommerce_integration_header_cart_icon(); ?>
			</div>

			<?php if ( $cart_contents_count > 0 ) : ?>
				<div class="woo-cart-details">
					<?php echo intval( $cart_contents_count ); ?>
				</div>
			<?php endif; ?>

		</a>
		<?php nice_woocommerce_integration_get_header_cart(); ?>
	</div>
<?php
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_header_add_to_cart_fragment' ) ) :
add_filter( 'woocommerce_add_to_cart_fragments', 'nice_woocommerce_integration_header_add_to_cart_fragment' );
/**
 * Ensure cart contents update when products are added to the cart via AJAX.
 *
 * @since  1.0.0
 *
 * @param  array $fragments Current fragments.
 * @return array            Filtered fragments.
 */
function nice_woocommerce_integration_header_add_to_cart_fragment( $fragments ) {
	$cart = WC()->cart;
	$cart_url = function_exists( 'wc_get_cart_url' )  ? wc_get_cart_url() : $cart->get_cart_url();

	ob_start();

?>
	<div id="header-shopping-cart-wrapper">
		<a id="header-shopping-cart" href="<?php echo esc_url( $cart_url ); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'smart' ); ?>">
			<div class="woo-cart-items">
				<?php echo nice_woocommerce_integration_header_cart_icon(); ?>
			</div>

			<?php if ( $cart->cart_contents_count > 0 ) : ?>
				<div class="woo-cart-details">
					<?php echo intval( $cart->cart_contents_count ); ?>
				</div>
			<?php endif; ?>

		</a>
		<?php nice_woocommerce_integration_get_header_cart(); ?>
	</div>
<?php

	$fragments['#header-shopping-cart-wrapper'] = ob_get_clean();
	$fragments = apply_filters( 'nice_woocommerce_integration_header_add_to_cart_fragment', $fragments );

	return $fragments;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_header_cart_icon' ) ) :
/**
 * Return HTML for cart icon in header.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_header_cart_icon() {
	$cart_icon = '<span class="woo-cart-text">' . esc_html__( 'Cart', 'smart' ) . '</span>';

	if ( nice_woocommerce_integration_header_cart_type() === 'icon' ) {
		require_once( ABSPATH . 'wp-admin/includes/file.php' );

		/**
		 * Initialize WordPress' file system handler.
		 *
		 * @var WP_Filesystem_Base $wp_filesystem
		 */
		WP_Filesystem();
		global $wp_filesystem;

		$cart_icon = $wp_filesystem->get_contents( nice_get_file_path( '/includes/plugin-integrations/woocommerce/images/shopping-bag.svg' ) );
	}

	return apply_filters( 'nice_woocommerce_integration_header_cart_icon', $cart_icon );
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_header_cart_type' ) ) :
/**
 * Return the header cart type.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_header_cart_type() {

	$option_value = nice_get_option( 'nice_woocommerce_header_cart_type' );

	$cart_type = ( $option_value ) ? $option_value : 'icon';

	return apply_filters( 'nice_woocommerce_header_cart_type', $cart_type );
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_get_header_cart' ) ) :
/**
 * Print HTML for cart in header.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_get_header_cart() {
	if ( nice_header_vertical() ) {
		return;
	}

	$cart          = WC()->cart;
	$cart_contents = $cart->cart_contents;
	$cart_url      = function_exists( 'wc_get_cart_url' ) ? wc_get_cart_url() : $cart->get_cart_url();
	$checkout_url  = function_exists( 'wc_get_checkout_url' ) ? wc_get_checkout_url() : $cart->get_checkout_url();

	$classes = array();

	if ( nice_bool_option( '_header_menu_remove_border' ) ) {
		$classes[] = 'no-border';
	} else {
		$classes[] = 'has-border';
	}

?>
	<div id="nice-mini-cart" <?php nice_css_classes( $classes ); ?>>
		<ul id="cart-list">
			<?php if ( count( $cart_contents ) ) : ?>

				<?php foreach ( $cart_contents as $cart_item_key => $cart_item ) : $product = $cart_item['data']; ?>

					<?php if ( $product instanceof WC_Product and $product->exists() and $cart_item['quantity'] ) : ?>
						<?php
							$nice_product_title       = $product->get_title();
							$nice_short_product_title = ( strlen( $nice_product_title ) > 28 ) ? substr( $nice_product_title, 0, 25 ) . '...' : $nice_product_title;
						?>
						<li class="cart-list-product">
							<a class="cart-list-product-img" href="<?php echo esc_url( get_permalink( $cart_item['product_id'] ) ); ?>"><?php echo $product->get_image( array( 50, 50 ) ); ?></a>

							<div class="cart-list-product-title">
								<a href="<?php echo esc_url( get_permalink( $cart_item['product_id'] ) ); ?>"><?php echo esc_html( apply_filters( 'woocommerce_cart_widget_product_title', $nice_short_product_title, $product ) ); ?></a>

								<div class="cart-list-product-quantity"><?php echo intval( $cart_item['quantity'] ); ?> x </div>

								<div class="cart-list-product-price"> <?php echo wc_price( $product->get_price() ); ?></div>
							</div>

							<?php echo sprintf( '<a href="%s" class="remove" title="%s">&times;</a>', esc_url( $cart->get_remove_url( $cart_item_key ) ), esc_html__( 'Remove this item', 'smart' ) ); ?>
						</li>

					<?php endif; ?>

				<?php endforeach; ?>

			<?php else : ?>
				<li class="empty"><?php esc_html_e( 'No products in the cart.', 'smart' ); ?></li>
			<?php endif; ?>
		</ul>

		<?php if ( count( $cart_contents ) ) : ?>
			<ul id="cart-actions">
				<li class="cart-list-subtotal">
					<div class="minicart-total-checkout">
						<?php esc_html_e( 'Subtotal', 'smart' ); ?>
						<span class="<?php echo ( is_rtl() ? 'alignleft' : 'alignright' ); ?>"><?php echo $cart->get_cart_total(); ?></span>
					</div>
				</li>

				<li class="cart-list-view">
					<a href="<?php echo esc_url( $cart_url ); ?>" class="nice-minicart-cart-button"><?php esc_html_e( 'View cart', 'smart' ); ?>
						<span class="<?php echo ( is_rtl() ? 'alignleft' : 'alignright' ); ?>"><?php echo intval( $cart->cart_contents_count ); ?></span></a>
				</li>

				<li class="cart-list-checkout">
					<a href="<?php echo esc_url( $checkout_url ); ?>" class="nice-minicart-checkout-button"><?php esc_html_e( 'Checkout', 'smart' ); ?>
						<span class="<?php echo ( is_rtl() ? 'alignleft' : 'alignright' ); ?>"><i class="fa fa-angle-<?php echo ( is_rtl() ? 'left' : 'right' ); ?>"></i></span></a>
				</li>
			</ul>
		<?php endif; ?>

	</div>
<?php
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_before_cart' ) ) :
add_action( 'woocommerce_before_cart', 'nice_woocommerce_integration_before_cart' );
/**
 * Print HTML before shopping cart.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_before_cart() {
	$cart = WC()->cart;
?>
	<p class="items-found-cart">
		<?php echo esc_html( sprintf( _n( '%d item', '%d items', $cart->cart_contents_count, 'smart' ), $cart->cart_contents_count ) ); ?> <?php esc_html_e( 'found', 'smart' ); ?>
	</p>
<?php
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_set_total' ) ) :
add_action( 'woocommerce_cart_contents', 'nice_woocommerce_integration_set_total' );
/**
 * Print HTML to display the cart total.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_set_total() {
?>
	<tr>
		<td colspan="6" class="actions">
			<strong><?php echo WC()->cart->get_total(); ?></strong>
		</td>
	</tr>
<?php
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_cart_item_empty' ) ) :
add_action( 'woocommerce_init', 'nice_woocommerce_integration_cart_item_empty' );
/**
 * Clear output for some filters.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_cart_item_empty() {
	add_filter( 'woocommerce_cart_item_remove_link',       '__return_empty_string' );
	add_filter( 'woocommerce_cart_item_thumbnail',         '__return_empty_string' );
	add_filter( 'woocommerce_checkout_cart_item_quantity', '__return_empty_string' );
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_cart_item' ) ) :
add_filter( 'woocommerce_cart_item_name', 'nice_woocommerce_integration_cart_item', 20, 3 );
/**
 * Obtain HTML for cart item.
 *
 * @since  1.0.0
 *
 * @param  string            $title
 * @param  array             $cart_item
 * @param  int               $cart_item_key
 * @return mixed|void|string
 */
function nice_woocommerce_integration_cart_item( $title, $cart_item, $cart_item_key ) {
	global $woocommerce;

	$_product = $cart_item['data'];

	// Return early if we don't have a real product.
	if ( ! $_product instanceof WC_Product ) {
		return null;
	}

	$thumbnail = $_product->get_image();

	if ( $_product->is_visible() ) {
		$remove_link = sprintf( '<a href="%s" class="remove" title="%s">&times;</a>', esc_url( $woocommerce->cart->get_remove_url( $cart_item_key ) ), esc_attr__( 'Remove this item', 'smart' ) );
		$thumbnail = '<figure>' . sprintf( '<a href="%s">%s</a>', $_product->get_permalink(), $thumbnail ) . $remove_link . '</figure>';
	}

	$product_desc = '';

	if ( is_checkout() ) {
		$product_desc = sprintf( ' &times;%s', $cart_item['quantity'] );
	}

	$output = $thumbnail . '<div class="cart-item">' . $title . $product_desc . '</div>';
	$output = apply_filters( 'nice_woocommerce_integration_cart_item', $output );

	return $output;
}
endif;

/**
 * Re-position the cart cross sells.
 *
 * @since 1.0.0
 */
remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
add_action( 'woocommerce_after_cart', 'woocommerce_cross_sell_display' );
