<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage scripts for WooCommerce.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://www.nicethemes.com/theme-page
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_woocommerce_integration_on_demand_scripts' ) ) :
add_filter( 'nice_on_demand_scripts', 'nice_woocommerce_integration_on_demand_scripts' );
/**
 * Setup on-demand scripts for WooCommerce integration.
 *
 * @since 1.0.2
 *
 * @param array $scripts
 *
 * @return array
 */
function nice_woocommerce_integration_on_demand_scripts( $scripts = array() ) {
	if ( is_product() ) {
		$scripts = array_merge( $scripts, array(
				'nice-owl-carousel-source' => 'owlCarousel',
				'zoom'                     => 'zoom',
			)
		);
	}

	return $scripts;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_cart_scripts' ) ) :
add_action( 'nice_register_scripts', 'nice_woocommerce_integration_cart_scripts', 0 );
/**
 * Load scripts for shopping cart.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_cart_scripts() {
	$owl_src = nice_get_file_uri( 'includes/assets/js/owl.carousel.js', true );
	wp_register_script( 'nice-owl-carousel-source', $owl_src, array( 'jquery' ), false, true );
	wp_enqueue_script( 'nice-owl-carousel-source' );

	if ( nice_use_minified_files() ) {
		/**
		 * If we're using minified assets, load all theme JS
		 * implementation from a single minified file.
		 *
		 * @since 1.0.0
		 */
		$src = nice_get_file_uri( 'includes/plugin-integrations/woocommerce/js/min/nice-woocommerce-scripts.min.js' );
		wp_register_script( 'nice-woocommerce-scripts', $src, array( 'nice-scripts' ), false, true );
		wp_enqueue_script( 'nice-woocommerce-scripts' );
	} else {
		/**
		 * If we're not using minified assets, load all theme
		 * JS implementation from separated files.
		 *
		 * @since 1.0.0
		 */
		$src = nice_get_file_uri( 'includes/plugin-integrations/woocommerce/js/nice-woocommerce-cart.js', true );
		wp_register_script( 'nice-woocommerce-scripts', $src, array( 'nice-scripts' ), false, true );
		wp_enqueue_script( 'nice-woocommerce-scripts' );

		$src = nice_get_file_uri( 'includes/plugin-integrations/woocommerce/js/nice-woocommerce-flexslider.js', true );
		wp_register_script( 'nice-woocommerce-flexslider-scripts', $src, array( 'nice-flexslider' ), false, true );
		wp_enqueue_script( 'nice-woocommerce-flexslider-scripts' );

		$src = nice_get_file_uri( 'includes/plugin-integrations/woocommerce/js/nice-woocommerce-owl-carousel.js', true );
		wp_register_script( 'nice-woocommerce-owl-carousel-scripts', $src, array( 'nice-owl-carousel-source' ), false, true );
		wp_enqueue_script( 'nice-woocommerce-owl-carousel-scripts' );

		if ( is_product() ) {
			$src = nice_get_file_uri( 'includes/plugin-integrations/woocommerce/js/nice-woocommerce-zoom.js', true );
			wp_register_script( 'nice-woocommerce-zoom-scripts', $src, array( 'zoom' ), false, true );
			wp_enqueue_script( 'nice-woocommerce-zoom-scripts' );
		}
	}

	// Disable cart fragments when using vertical header.
	if ( nice_header_vertical() ) {
		wp_dequeue_script( 'wc-cart-fragments' );
	}

	wp_localize_script( 'nice-woocommerce-scripts', 'NiceWooCommerceData', array(
			'prev' => esc_html__( 'Previous', 'smart' ),
			'next' => esc_html__( 'Next', 'smart' ),
		)
	);
}
endif;

