<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage styles for WooCommerce.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://www.nicethemes.com/theme-page
 * @copyright 2017 NiceThemes
 * @since     1.1
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_woocommerce_integration_styles' ) ) :
add_action( 'nice_register_styles', 'nice_woocommerce_integration_styles' );
/**
 * Load our custom styles for WooCommerce.
 *
 * @since 1.0.0
 *
 * @param string $template_directory_uri
 */
function nice_woocommerce_integration_styles( $template_directory_uri ) {
	wp_register_style( 'nice-woocommerce-styles', $template_directory_uri . '/includes/plugin-integrations/woocommerce/css/nice-woocommerce.css' );
	wp_enqueue_style( 'nice-woocommerce-styles' );

	/**
	 * @hook nice_woocommerce_integration_inline_styles
	 *
	 * Inline styles for WC are set here.
	 *
	 * Hooked here:
	 * @see nice_woocommerce_integration_inline_styles()
	 */
	wp_add_inline_style( 'nice-woocommerce-styles', apply_filters( 'nice_woocommerce_integration_inline_styles', '' ) );
}
endif;


if ( ! function_exists( 'nice_woocommerce_integration_rtl_styles' ) ) :
add_action( 'nice_register_styles', 'nice_woocommerce_integration_rtl_styles' );
/**
 * Load RTL styles for WooCommerce.
 *
 * @link  http://codex.wordpress.org/Right-to-Left_Language_Support
 *
 * @since 1.0.0
 *
 * @param string $template_directory_uri
 */
function nice_woocommerce_integration_rtl_styles( $template_directory_uri ) {
	if ( is_rtl() ) {
		wp_register_style( 'nice-woocommerce-rtl-styles', $template_directory_uri . '/includes/plugin-integrations/woocommerce/css/nice-woocommerce-rtl.css' );
		wp_enqueue_style( 'nice-woocommerce-rtl-styles' );
	}
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_inline_styles' ) ) :
add_filter( 'nice_woocommerce_integration_inline_styles', 'nice_woocommerce_integration_inline_styles' );
/**
 * Add inline styles for WooCommerce integration.
 *
 * @since  1.0.0
 *
 * @param  string $output Unfiltered inline styles.
 *
 * @return string
 */
function nice_woocommerce_integration_inline_styles( $output = '' ) {
	// Obtain all breakpoints.
	$breakpoints = nice_responsive_breakpoints();

	if ( $accent_color = nice_get_option( 'nice_accent_color' ) ) {
		$output .= '/* Accent Color */' . "\n";
		if ( 'side' === nice_woocommerce_integration_product_tabs_position() ) {
			$output .= '.woocommerce.single-product .woocommerce-tabs.woocommerce-tabs-side.woocommerce-tabs-left .active[role="tab"]:before, .woocommerce.single-product .woocommerce-tabs.woocommerce-tabs-side.woocommerce-tabs-right .active[role="tab"]:before { background-color: ' . $accent_color . ' }' . "\n";
		} else {
			$output .= '.woocommerce.single-product .woocommerce-tabs ul.tabs li.active a, .woocommerce.single-product .woocommerce-tabs ul.tabs li.ui-state-active a, .woocommerce.single-product .woocommerce-tabs .ui-tabs ul.tabs li.active a, .woocommerce.single-product .woocommerce-tabs .ui-tabs ul.tabs li.ui-state-active a, .woocommerce.single-product .woocommerce-tabs .ui.tabs .ui-tabs-nav li.active a, .woocommerce.single-product .woocommerce-tabs .ui.tabs .ui-tabs-nav li.ui-state-active a { border-top-color: ' . $accent_color . ' }' . "\n";
		}
		$output .= nice_header_vertical() ? '' : '#nice-mini-cart { border-color: ' . $accent_color . ' }' . "\n";
		$output .= '#cart-actions li.cart-list-view:hover, #cart-actions li.cart-list-checkout:hover, #navigation-extras:not(.cart-text) .woo-cart-details { background-color: ' . $accent_color . ' }' . "\n";
		$output .= '#header-shopping-cart:hover i, .star-rating span, #cart-list .cart-list-product .remove:hover { color: ' . $accent_color . ' }' . "\n";
		$output .= '.woocommerce.single-product .woocommerce-tabs ul.tabs li a:hover, .woocommerce.single-product .woocommerce-tabs .ui-tabs ul.tabs li a:hover, .woocommerce.single-product .woocommerce-tabs .ui.tabs .ui-tabs-nav li a:hover { color: ' . $accent_color . ' }' . "\n";
		$output .= 'p.stars a.star-1:hover:after, p.stars a.star-1.active:after, p.stars a.star-2:hover:after, p.stars a.star-2.active:after, p.stars a.star-3:hover:after, p.stars a.star-3.active:after, p.stars a.star-4:hover:after, p.stars a.star-4.active:after, p.stars a.star-5:hover:after, p.stars a.star-5.active:after, .cart-text .woo-cart-details { color: ' . $accent_color . ' }' . "\n";
		$output .= '.onsale, table.shop_table tr td a.remove:hover { background-color: ' . $accent_color . ' }' . "\n";
		$output .= '.nice-cart-notification.added:before { background-color: ' . $accent_color . '; }';
		$output .= 'table.shop_table td.product-name figure a.remove:hover { background-color: ' . $accent_color . '; color: ' . nice_contrast_color( $accent_color ) . '; }';
		$output .= 'body.woocommerce-page .select2-container--default .select2-results__option--highlighted[aria-selected] { background-color: ' . $accent_color . ' }' . "\n";
	}

	if ( nice_bool( nice_get_option( 'nice_custom_typography' ) ) ) {
		if ( $font_menu = nice_get_option( 'nice_font_menu' ) ) {
			$output .= '#header #header-shopping-cart { ' . nice_custom_font_css( $font_menu ) . '; }' . "\n";

			if ( nice_header_vertical() || nice_development_mode() ) {
				$output .= '#header.vertical #header-shopping-cart > span { ' . nice_custom_font_css( $font_menu ) . '; }' . "\n";
			}
		}

		if ( $font_submenu = nice_get_option( 'nice_font_submenu' ) ) {
			$output .= '#header #nice-mini-cart { ' . nice_custom_font_css( $font_submenu, array( 'exclude' => array( 'letter-spacing' ) ) ) . ' }' . "\n";
		}

		if ( $font_buttons = nice_get_option( 'nice_font_buttons' ) ) {
			$output .= '.onsale { ' . nice_custom_font_css( $font_buttons ) . '; }' . "\n";
		}
	}

	if ( nice_bool( nice_get_option( 'nice_header_submenu_uppercase' ) ) ) {
		$output .= '#nice-mini-cart { text-transform: uppercase; }' . "\n";
	}

	if ( nice_header_transparent() ) {
		$transparent_header_text_color = nice_get_option( 'nice_header_background_transparent_text_color' );
		$transparent_header_text_color = $transparent_header_text_color ? $transparent_header_text_color : '#fff';

		$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #header.transparent:not(.scrolled) #header-shopping-cart *:not(.woo-cart-details), #header.transparent:not(.scrolled) #header-shopping-cart:hover .cart-icon .bag { color: ' . $transparent_header_text_color . '; border-color: ' . $transparent_header_text_color . '; } }' . "\n";
	}

	if ( nice_bool_option( '_woocommerce_quick_view' ) ) {
		if ( $quick_view_overlay_color = nice_get_option( '_woocommerce_quick_view_overlay_color' ) ) {
			$quick_view_overlay_color = nice_get_option( $quick_view_overlay_color );

			if ( false === stripos( $quick_view_overlay_color, 'rgba' ) ) {
				$quick_view_overlay = nice_get_option( '_woocommerce_quick_view_overlay_opacity' );
				$quick_view_overlay_color = nice_color_hex2rgba( $quick_view_overlay_color, ( $quick_view_overlay / 100 ) );
			}

			$output .= '#modal { background-color: ' . $quick_view_overlay_color . ' }' . "\n";
		}
	}

	/*
		Light Skin
	*/

	if ( $light_skin_subnav_text_color = nice_get_option( '_light_skin_subnav_text_color' ) ) {
		$output .= '#header.submenu-light #header-inner #nice-mini-cart, #header.submenu-light #header-inner #nice-mini-cart a { color: ' . nice_theme_color_value( $light_skin_subnav_text_color ) . ' !important; }' . "\n";
	}

	if ( $light_skin_subnav_background_color = nice_get_option( '_light_skin_subnav_background_color' ) ) {
		$output .= '#header.submenu-light #header-inner #nice-mini-cart { background-color: ' . nice_theme_color_value( $light_skin_subnav_background_color ) . ' !important; }' . "\n";
		$output .= '#header.submenu-light #cart-actions li.cart-list-view:hover, #header.submenu-light #cart-actions li.cart-list-checkout:hover { background-color: ' . nice_color_darken( nice_theme_color_value( $light_skin_subnav_background_color ), .15 ) . ' }' . "\n";
	}

	/*
		Dark Skin
	*/

	if ( $dark_skin_subnav_text_color = nice_get_option( '_dark_skin_subnav_text_color' ) ) {
		$output .= '#header.submenu-dark #header-inner #nice-mini-cart, #header.submenu-dark #header-inner #nice-mini-cart a { color: ' . nice_theme_color_value( $dark_skin_subnav_text_color ) . ' !important; }' . "\n";
	}

	if ( $dark_skin_subnav_background_color = nice_get_option( '_dark_skin_subnav_background_color' ) ) {
		$output .= '#header.submenu-dark #header-inner #nice-mini-cart { background-color: ' . nice_theme_color_value( $dark_skin_subnav_background_color ) . ' !important; }' . "\n";
		$output .= '#header.submenu-dark #cart-actions li.cart-list-view:hover, #header.submenu-dark #cart-actions li.cart-list-checkout:hover { background-color: ' . nice_color_darken( nice_theme_color_value( $dark_skin_subnav_background_color ), .05 ) . ' }' . "\n";
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_disable_default_styles' ) ) :
add_action( 'wp_enqueue_scripts', 'nice_woocommerce_integration_disable_default_styles', 0 );
/**
 * Disable WooCommerce default styles.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_disable_default_styles() {
	global $woocommerce;

	if ( version_compare( $woocommerce->version, '2.1', '<' ) ) {
		/**
		 * Disable CSS for old versions of WC.
		 */
		define( 'WOOCOMMERCE_USE_CSS', false );
	} else {
		add_filter( 'woocommerce_enqueue_styles', '__return_false' );
	}
}
endif;