<?php
/**
 * Smart by NiceThemes.
 *
 * This file includes functions to interact with WooCommerce that print HTML directly.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_woocommerce_integration_featured_products' ) ) :
/**
 * Display featured products.
 *
 * @since 1.0.0
 *
 * @param array $args
 */
function nice_woocommerce_integration_featured_products( $args = array() ) {
	$defaults = apply_filters( 'nice_woocommerce_integration_featured_products_default_args', array(
			'post_status'         => 'publish',
			'post_type'           => 'product',
			'ignore_sticky_posts' => 1,
			'meta_key'            => '_featured',
			'meta_value'          => 'yes',
			'posts_per_page'      => get_option( 'posts_per_page' ),
			'orderby'             => 'ID',
			'order'               => 'DESC',
		)
	);

	$args = wp_parse_args( $args, $defaults );
	$args = apply_filters( 'nice_woocommerce_integration_featured_products_args', $args );

	$products = new WP_Query( $args );

	if ( $products->have_posts() ) :
		while ( $products->have_posts() ) : $products->the_post();
			wc_get_template_part( 'content', 'product' );
		endwhile; // end of the loop.
	endif;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_on_sale_products' ) ) :
/**
 * Display on-sale priced products.
 *
 * @since 1.0.0
 *
 * @param array $args
 */
function nice_woocommerce_integration_on_sale_products( $args = array() ) {
	$defaults = apply_filters( 'nice_woocommerce_integration_on_sale_products_default_args', array(
			'post_type'           => 'product',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => 1,
			'posts_per_page'      => get_option( 'posts_per_page' ),
			'orderby'             => 'ID',
			'order'               => 'DESC',
			'meta_query'          => array(
				array(
					'key'     => '_visibility',
					'value'   => array( 'catalog', 'visible' ),
					'compare' => 'IN',
				),
				array(
					'key'     => '_sale_price',
					'value'   => 0,
					'compare' => '>',
					'type'    => 'NUMERIC',
				),
			)
		)
	);

	$args = wp_parse_args( $args, $defaults );
	$args = apply_filters( 'nice_woocommerce_integration_on_sale_products_args', $args );

	$products = new WP_Query( $args );

	if ( $products->have_posts() ) :
		while ( $products->have_posts() ) : $products->the_post();
			wc_get_template_part( 'content', 'product' );
		endwhile; // end of the loop.
	endif;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_latest_products' ) ) :
/**
 * Display the latest published products.
 *
 * @since 1.0.0
 *
 * @param array $args
 */
function nice_woocommerce_integration_latest_products( $args = array() ) {
	$defaults = apply_filters( 'nice_woocommerce_integration_latest_products_default_args', array(
			'post_type'           => 'product',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => 1,
			'posts_per_page'      => get_option( 'posts_per_page' ),
		)
	);

	$args = wp_parse_args( $args, $defaults );
	$args = apply_filters( 'nice_woocommerce_integration_latest_products_args', $args );

	$products = new WP_Query( $args );

	if ( $products->have_posts() ) :
		while ( $products->have_posts() ) : $products->the_post();
			wc_get_template_part( 'content', 'product' );
		endwhile; // end of the loop.
	endif;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_best_sellers' ) ) :
/**
 * Display the best sold products.
 *
 * @since 1.0.0
 *
 * @param array $args
 */
function nice_woocommerce_integration_best_sellers( $args = array() ) {
	$defaults = apply_filters( 'nice_woocommerce_integration_best_sellers_default_args', array(
		'post_type'           => 'product',
		'post_status'         => 'publish',
		'ignore_sticky_posts' => 1,
		'posts_per_page'      => get_option( 'posts_per_page' ),
		'meta_key'            => 'total_sales',
		'orderby'             => 'meta_value',
	) );

	$args = wp_parse_args( $args, $defaults );
	$args = apply_filters( 'nice_woocommerce_integration_best_sellers_args', $args );

	$products = new WP_Query( $args );

	if ( $products->have_posts() ) :
		while ( $products->have_posts() ) : $products->the_post();
			wc_get_template_part( 'content', 'product' );
		endwhile; // end of the loop.
	endif;
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_products_loop_container_class' ) ) :
/**
 * Display classes for products container.
 *
 * @since 1.0.0
 *
 * @param mixed|array|string
 */
function nice_woocommerce_integration_products_loop_container_class( $class = null ) {
	nice_css_classes( nice_woocommerce_integration_products_loop_container_get_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_products_loop_container_data' ) ) :
/**
 * Display data for products container.
 *
 * @since 1.0.0
 *
 * @param mixed|array|string
 */
function nice_woocommerce_integration_products_loop_container_data( $data = null ) {
	nice_data_attributes( nice_woocommerce_integration_products_loop_container_get_data( $data ) );
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_single_product_categories' ) ) :
/**
 * Print out HTML for the current product categories.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_single_product_categories() {
	global $post;

	$cat_count = sizeof( get_the_terms( $post->ID, 'product_cat' ) );

	$separator   = ', ';
	$before_list = '<span class="posted_in"><span class="meta-label">' . _n( 'Category', 'Categories', $cat_count, 'smart' ) . '</span> ';
	$after_list  = '</span>';

	if ( function_exists( 'wc_get_product_category_list' ) ) {
		echo wc_get_product_category_list( $post->ID, $separator, $before_list, $after_list );

		return;
	}

	global $product;

	echo $product->get_categories( $separator, $before_list, $after_list );
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_single_product_tags' ) ) :
/**
 * Print out HTML for the current product categories.
 *
 * @since 1.0.0
 */
function nice_woocommerce_integration_single_product_tags() {
	global $post;

	$tag_count = sizeof( get_the_terms( $post->ID, 'product_tag' ) );

	$separator   = ', ';
	$before_list = '<span class="tagged_as"><span class="meta-label">' . _n( 'Tag', 'Tags', $tag_count, 'smart' ) . '</span> ';
	$after_list  = '</span>';

	if ( function_exists( 'wc_get_product_tag_list' ) ) {
		echo wc_get_product_tag_list( $post->ID, $separator, $before_list, $after_list );

		return;
	}

	global $product;

	echo $product->get_tags( $separator, $before_list, $after_list );
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_single_product_related_title' ) ) :
/**
 * Print out the title for related products.
 *
 * @since 1.0.2
 */
function nice_woocommerce_integration_single_product_related_title() {
	echo esc_html( nice_get_option( '_woocommerce_products_related_title' ) );
}
endif;

if ( ! function_exists( 'nice_woocommerce_integration_single_product_upsells_title' ) ) :
/**
 * Print out the title for up-sells.
 *
 * @since 1.0.2
 */
function nice_woocommerce_integration_single_product_upsells_title() {
	echo esc_html( nice_get_option( '_woocommerce_products_upsells_title' ) );
}
endif;
