<?php
/**
 * Single Product tabs
 *
 * Override this template from a child theme by copying it to any of these locations:
 * `your-child-theme/includes/plugin-integrations/woocommerce/single-product/tabs/tabs.php`.
 * `your-child-theme/woocommerce/single-product/tabs/tabs.php`.
 *
 * @package Smart
 * @since   1.0.2
 *
 * WooCommerce Data:
 * @version 2.4.0
 * @see 	https://docs.woocommerce.com/document/template-structure/
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Filter tabs and allow third parties to add their own.
 *
 * Each tab is an array containing title, callback and priority.
 * @see woocommerce_default_product_tabs()
 */
$tabs = apply_filters( 'woocommerce_product_tabs', array() );

if ( ! empty( $tabs ) ) :
	$side      = nice_woocommerce_integration_product_tabs_position();
	$direction = nice_woocommerce_integration_product_tabs_direction();
	?>

	<div class="woocommerce-tabs woocommerce-tabs-<?php echo esc_attr( $side ); ?> woocommerce-tabs-<?php echo esc_attr( $direction ); ?> wc-tabs-wrapper">
		<ul class="tabs wc-tabs" role="tablist">
			<?php foreach ( $tabs as $key => $tab ) : ?>
				<li class="<?php echo esc_attr( $key ); ?>_tab" id="tab-title-<?php echo esc_attr( $key ); ?>" role="tab" aria-controls="tab-<?php echo esc_attr( $key ); ?>">
					<a href="#tab-<?php echo esc_attr( $key ); ?>"><?php echo apply_filters( 'woocommerce_product_' . $key . '_tab_title', esc_html( $tab['title'] ), $key ); ?></a>
				</li>
			<?php endforeach; ?>
		</ul>
		<?php foreach ( $tabs as $key => $tab ) : ?>
			<div class="woocommerce-Tabs-panel woocommerce-Tabs-panel--<?php echo esc_attr( $key ); ?> panel entry-content wc-tab" id="tab-<?php echo esc_attr( $key ); ?>" role="tabpanel" aria-labelledby="tab-title-<?php echo esc_attr( $key ); ?>">
				<?php call_user_func( $tab['callback'], $key, $tab ); ?>
			</div>
		<?php endforeach; ?>
	</div>

<?php endif; ?>
