<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions that handle gallery post format presentation.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_post_footer_meta_author_gallery' ) ) :
add_filter( 'nice_post_footer_meta_author', 'nice_post_footer_meta_author_gallery' );
/**
 * Modify author text for meta data section in gallery posts.
 *
 * @since  1.0.0
 *
 * @param  string $post_author Current HTML for post author.
 *
 * @return string
 */
function nice_post_footer_meta_author_gallery( $post_author = '' ) {
	// Allow bypass.
	if ( $output = apply_filters( 'nice_post_footer_meta_author_gallery', '' ) ) {
		return $output;
	}

	if ( has_post_format( 'gallery' ) ) {
		$post_author = '<section class="author"><i class="icon-picture"></i> ' . sprintf( esc_html__( 'Gallery shared by %s', 'smart' ), '<a href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ) . '">' . get_the_author_meta( 'display_name' ) . '</a>' ) . '</section>';
	}

	return $post_author;

}
endif;

if ( ! function_exists( 'nice_gallery_format_default_args' ) ) :
add_filter( 'nice_gallery_default_args', 'nice_gallery_format_default_args' );
/**
 * Modify default arguments when constructing a gallery in a post with "gallery" post format.
 *
 * @since  1.0.0
 *
 * @param  array $args Original arguments.
 *
 * @return array
 */
function nice_gallery_format_default_args( array $args = array() ) {
	if ( has_post_format( 'gallery', get_the_ID() ) ) {
		// Obtain the ID of the featured image for the current post.
		$featured_image_id = get_post_thumbnail_id();

		// Add featured image ID to list of image IDs.
		$ids  = $featured_image_id ? $featured_image_id . ',' : '';

		// Add image IDs from post gallery.
		$ids .= implode( ',', array_keys( nice_attachments_from_gallery() ) );

		// Remove additional commas.
		$ids = trim( $ids, ',' );

		$args = array_merge( $args, array(
				'before'        => '<div class="flexslider slider"><ul class="slides">',
				'after'         => '</ul></div>',
				'item_template' => '<li class="slide"><div class="%%CLASS%% slide-image">%%IMAGE%%</div></li>',
				'columns'       => 0,
				'ids'           => $ids,
				'width'         => nice_content_width(),
			)
		);
	}

	return $args;
}
endif;
