<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions that handle the presentation of link post format.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_get_post_link' ) ) :
/**
 * Obtain post link.
 *
 * @since  1.0.0
 *
 * @param  int    $post_id
 * @return string
 */
function nice_get_post_link( $post_id = null ) {
	if ( ! $post_id ) {
		$post_id = get_the_ID();
	}

	// Allow bypass.
	if ( $post_link = apply_filters( 'nice_post_link', '', $post_id ) ) {
		return $post_link;
	}

	$post_link = esc_url( get_post_meta( $post_id, 'link', true ) );

	if ( ! $post_link ) {
		$post_link = get_the_permalink( $post_id );
	}

	return $post_link;
}
endif;

if ( ! function_exists( 'nice_post_footer_meta_author_link' ) ) :
add_filter( 'nice_post_footer_meta_author', 'nice_post_footer_meta_author_link' );
/**
 * Modify author text for meta data section in link posts.
 *
 * @since  1.0.0
 *
 * @param  string $post_author Current HTML for post author.
 *
 * @return string
 */
function nice_post_footer_meta_author_link( $post_author = '' ) {
	// Allow bypass.
	if ( $output = apply_filters( 'nice_post_footer_meta_author_link', '' ) ) {
		return $output;
	}

	if ( has_post_format( 'link' ) ) {
		$post_author = '<section class="author"><i class="icon-link"></i> ' . sprintf( esc_html__( 'Link shared by %s', 'smart' ), '<a href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ) . '">' . get_the_author_meta( 'display_name' ) . '</a>' ) . '</section>';
	}

	return $post_author;

}
endif;
