<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions that handle the presentation of quote post format.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_get_post_quote' ) ) :
/**
 * Obtain post quote.
 *
 * @since  1.0.0
 *
 * @param  int    $post_id
 * @return string
 */
function nice_get_post_quote( $post_id = null ) {
	if ( ! $post_id ) {
		$post_id = get_the_ID();
	}

	// Allow bypass.
	if ( $post_quote = apply_filters( 'nice_post_quote', '', $post_id ) ) {
		return $post_quote;
	}

	$post_quote = get_post_meta( $post_id, 'quote', true );

	return $post_quote;
}
endif;

if ( ! function_exists( 'nice_get_post_quote_author' ) ) :
/**
 * Obtain post quote author.
 *
 * @since  1.0.0
 *
 * @param  int    $post_id
 * @return string
 */
function nice_get_post_quote_author( $post_id = null ) {
	if ( ! $post_id ) {
		$post_id = get_the_ID();
	}

	// Allow bypass.
	if ( $post_quote_author = apply_filters( 'nice_post_quote_author', '', $post_id ) ) {
		return $post_quote_author;
	}

	$post_quote_author = get_post_meta( $post_id, 'quote-author', true );

	return $post_quote_author;
}
endif;

if ( ! function_exists( 'nice_post_footer_meta_author_quote' ) ) :
add_filter( 'nice_post_footer_meta_author', 'nice_post_footer_meta_author_quote' );
/**
 * Modify author text for meta data section in quote posts.
 *
 * @since  1.0.0
 *
 * @param  string $post_author Current HTML for post author.
 *
 * @return string
 */
function nice_post_footer_meta_author_quote( $post_author = '' ) {
	// Allow bypass.
	if ( $output = apply_filters( 'nice_post_footer_meta_author_quote', '' ) ) {
		return $output;
	}

	if ( has_post_format( 'quote' ) ) {
		$post_author = '<section class="author"><i class="icon-quote-right"></i> ' . sprintf( esc_html__( 'Quote shared by %s', 'smart' ), '<a href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ) . '">' . get_the_author_meta( 'display_name' ) . '</a>' ) . '</section>';
	}

	return $post_author;

}
endif;
