<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains the function to hook custom fields for posts.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_custom_fields_post' ) ) :
add_filter( 'nice_custom_fields', 'nice_custom_fields_post', 10, 2 );
/**
 * Load array with custom fields for posts.
 * then save the array into WP options.
 *
 * @since 1.0.0
 *
 * @param $nice_fields
 * @param $post_type
 *
 * @return array
 */
function nice_custom_fields_post( array $nice_fields = array(), $post_type ) {
	if ( 'post' === $post_type ) {
		/**
		 * Header
		 */

		$nice_fields[] = array(
			'name'  => 'page-header',
			'label' => esc_html__( 'Header', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_layout-header"></i>',
		);

		$nice_fields[] = array(
			'name'      => '_post_header',
			'std'       => '',
			'label'     => esc_html__( 'Display Header', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Show the header for this post.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_post_navigation_menu',
			'std'       => '',
			'label'     => esc_html__( 'Navigation Menu', 'smart' ),
			'type'      => 'select',
			'options'   => nice_get_navigation_menus(),
			'desc'      => esc_html__( 'Select the navigation menu to use for this post.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_navigation_style',
			'std'       => '',
			'label'     => esc_html__( 'Navigation Style', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''         => esc_html__( 'Inherit', 'smart' ),
				'default'  => esc_html__( 'Top', 'smart' ),
				'vertical' => esc_html__( 'Side', 'smart' ),
				'overlay'  => esc_html__( 'Overlay', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the navigation style to use for this post.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_background_transparent',
			'std'       => '',
			'label'     => esc_html__( 'Transparent Header', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Make the header transparent.', 'smart' ),
			'condition' => '_post_header:not(false),_post_navigation_style:not(vertical)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_background_transparent_mobile',
			'std'       => '',
			'label'     => esc_html__( 'Transparent Header (Mobile)', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Make the header transparent in smaller viewports. This option only works when the transparent header is enabled on desktop.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_skin',
			'std'       => '',
			'label'     => esc_html__( 'Header Content Skin', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'light' => esc_html__( 'Light', 'smart' ),
				'dark'  => esc_html__( 'Dark', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the header content skin to use for this post.', 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_background_color',
			'std'       => '',
			'label'     => esc_html__( 'Header Background Color', 'smart' ),
			'type'      => 'select_color',
			'options'   => nice_theme_colors_dropdown_values(),
			'desc'      => esc_html__( 'Choose a background color.', 'smart' ),
			'class'     => 'nice-select-color',
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_navigation_submenu_skin',
			'std'       => '',
			'label'     => esc_html__( 'Navigation Sub-Menu Content Skin', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'light' => esc_html__( 'Light', 'smart' ),
				'dark'  => esc_html__( 'Dark', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the navigation sub-menu content skin to use for this post.', 'smart' ),
			'condition' => '_post_header:not(false),_post_navigation_style:not(overlay)' . ( ( 'overlay' === nice_get_option( 'nice_header_navigation' ) ) ? ',_post_navigation_style:not()' : '' ),
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_width',
			'std'       => '',
			'label'     => esc_html__( 'Header Width', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'full'  => esc_html__( 'Full', 'smart' ),
				'limit' => esc_html__( 'Limit', 'smart' ),
			),
			'desc'      => esc_html__( 'Select whether or not to make the header contents take the full width for this post.', 'smart' ),
			'condition' => '_post_header:not(false),_post_navigation_style:not(vertical)' . ( ( 'vertical' === nice_get_option( 'nice_header_navigation' ) ) ? ',_post_navigation_style:not()' : '' ),
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_width_value',
			'std'       => '',
			'label'     => esc_html__( 'Custom Width', 'smart' ),
			'type'      => 'measurement',
			'desc'      => esc_html__( 'Define the custom width for the header area (in px or in %).', 'smart' ),
			'condition' => '_post_header_width:is(limit)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_display_search',
			'std'       => '',
			'label'     => esc_html__( 'Display Search', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__("Select whether or not to show a link to the site's search in the header for this post.", 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_header_display_social',
			'std'       => '',
			'label'     => esc_html__( 'Display Social Icons', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__("Select whether or not to show a the social icons in the header for this post.", 'smart' ),
			'condition' => '_post_header:not(false)',
			'operator'  => 'and',
		);

		/**
		 * Title Bar
		 */

		$nice_fields[] = array(
			'name'  => 'page-title',
			'label' => esc_html__( 'Title Bar', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_layout-third-h"></i>',
		);

		$nice_fields[] = array(
			'name'    => '_post_heading',
			'std'     => '',
			'label'   => esc_html__( 'Display Title Bar', 'smart' ),
			'type'    => 'select',
			'desc'    => esc_html__( 'Show the title bar section for this post.', 'smart' ),
			'options' => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
		);

		$nice_fields[] = array(
			'name'      => '_post_title_heading',
			'std'       => '',
			'label'     => esc_html__( 'Display Post Title in the Title Bar', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Show the post title in the title bar.', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_categories_heading',
			'std'       => '',
			'label'     => esc_html__( 'Display Post Categories in the Title Bar', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Show the post categories in the title bar (they go above the title).', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_categories_heading_color',
			'std'       => '',
			'label'     => esc_html__( 'Post Categories Color', 'smart' ),
			'type'      => 'select_color',
			'options'   => nice_theme_colors_dropdown_values(),
			'desc'      => esc_html__( 'Choose a color.', 'smart' ),
			'class'     => 'nice-select-color',
			'condition' => '_post_heading:not(false),_post_categories_heading:is(true)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_categories_heading_shape',
			'label'     => esc_html__( 'Post Categories Shape', 'smart' ),
			'type'      => 'select',
			'std'       => '',
			'tip'       => '',
			'options'   => array(
				''       => esc_html__( 'Default', 'smart' ),
				'round'  => esc_html__( 'Round', 'smart' ),
				'circle' => esc_html__( 'Circle', 'smart' ),
				'square' => esc_html__( 'Square', 'smart' ),
			),
			'condition' => '_post_heading:not(false),_post_categories_heading:is(true)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_categories_heading_style',
			'label'     => esc_html__( 'Post Categories Style', 'smart' ),
			'type'      => 'select',
			'std'       => '',
			'tip'       => '',
			'options'   => array(
				''        => esc_html__( 'Default', 'smart' ),
				'outline' => esc_html__( 'Outlined', 'smart' ),
				'solid'   => esc_html__( 'Solid Background', 'smart' ),
			),
			'condition' => '_post_heading:not(false),_post_categories_heading:is(true)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_title_alignment',
			'std'       => '',
			'label'     => esc_html__( 'Title Horizontal Alignment', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''       => esc_html__( 'Inherit', 'smart' ),
				'left'   => esc_html__( 'Left', 'smart' ),
				'center' => esc_html__( 'Center', 'smart' ),
				'right'  => esc_html__( 'Right', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the horizontal alignment you would like for your title and subtitle.', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_title_alignment_v',
			'std'       => '',
			'label'     => esc_html__( 'Title Vertical Alignment', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''       => esc_html__( 'Inherit', 'smart' ),
				'top'    => esc_html__( 'Top', 'smart' ),
				'middle' => esc_html__( 'Middle', 'smart' ),
				'bottom' => esc_html__( 'Bottom', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the vertical alignment you would like for your title and subtitle (warning: bottom alignment may overlap with scroll down arrow).', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_title_width',
			'std'       => '',
			'label'     => esc_html__( 'Title Width', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'full'  => esc_html__( 'Full', 'smart' ),
				'limit' => esc_html__( 'Limit', 'smart' ),
			),
			'desc'      => esc_html__( 'Select whether or not to make the title bar contents take the full width for this post.', 'smart' ),
			'condition' => '_post_navigation_style:not(vertical)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_title_width_value',
			'std'       => '',
			'label'     => esc_html__( 'Custom Width', 'smart' ),
			'type'      => 'measurement',
			'desc'      => esc_html__( 'Define the custom width for the title area (in px or in %).', 'smart' ),
			'condition' => '_post_navigation_style:not(vertical),_post_title_width:is(limit)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_title_height',
			'std'       => '',
			'label'     => esc_html__( 'Height', 'smart' ),
			'type'      => 'measurement',
			'desc'      => esc_html__( 'Define the custom height for the title area in px or in %. Leave blank to use default theme settings.', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_title_height_min',
			'std'       => '',
			'label'     => esc_html__( 'Minimum height', 'smart' ),
			'type'      => 'text',
			'desc'      => esc_html__( 'Enter a minimum height for the header (in pixels). Leave blank to use default theme settings.', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_title_text_transform',
			'std'       => '',
			'label'     => esc_html__( 'Title Text Transform', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''           => esc_html__( 'Inherit', 'smart' ),
				'default'    => esc_html__( 'Default CSS', 'smart' ),
				'uppercase'  => esc_html__( 'Uppercase', 'smart' ),
				'lowercase'  => esc_html__( 'Lowercase', 'smart' ),
				'capitalize' => esc_html__( 'Capitalize', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the title text transformation.', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_title_font_weight',
			'std'       => '',
			'label'     => esc_html__( 'Title Font Weight', 'smart' ),
			'type'      => 'select',
			'options'   => nice_font_weight(),
			'desc'      => esc_html__( 'Select the title font weight.', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_title_font_size',
			'std'       => '',
			'label'     => esc_html__( 'Title Font Size', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''             => esc_html__( 'Inherit', 'smart' ),
				'h1'           => esc_html__( 'h1', 'smart' ),
				'h2'           => esc_html__( 'h2', 'smart' ),
				'h3'           => esc_html__( 'h3', 'smart' ),
				'h4'           => esc_html__( 'h4', 'smart' ),
				'h5'           => esc_html__( 'h5', 'smart' ),
				'h6'           => esc_html__( 'h6', 'smart' ),
				'fontsize-12'  => esc_html__( 'Size 12px', 'smart' ),
				'fontsize-40'  => esc_html__( 'Size 40px', 'smart' ),
				'fontsize-50'  => esc_html__( 'Size 50px', 'smart' ),
				'fontsize-75'  => esc_html__( 'Size 75px', 'smart' ),
				'fontsize-100' => esc_html__( 'Size 100px', 'smart' ),
				'fontsize-125' => esc_html__( 'Size 125px', 'smart' ),
				'fontsize-150' => esc_html__( 'Size 150px', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the title font size.', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_heading_skin',
			'std'       => '',
			'label'     => esc_html__( 'Post Title Skin', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'light' => esc_html__( 'Light', 'smart' ),
				'dark'  => esc_html__( 'Dark', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the heading skin. "Light" equals light background with dark color contents, and "Dark" equals dark background with light color contents.', 'smart' ),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_background_image',
			'std'       => '',
			'label'     => esc_html__( 'Post Title Background Image', 'smart' ),
			'type'      => 'upload',
			'desc'      => esc_html__( 'Upload/select a background image.', 'smart' ),
			'condition' => '_post_heading:not(false),_post_background_solid_color:not(true)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_background_image_parallax',
			'std'       => '',
			'label'     => esc_html__( 'Parallax for Background Image', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Add a parallax effect to the background image.', 'smart' ),
			'condition' => '_post_heading:not(false),_post_background_image:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_background_repeat',
			'std'       => '',
			'label'     => esc_html__( 'Background Image Repeat', 'smart' ),
			'type'      => 'select',
			'options' => array(
				''          => esc_html__( 'Inherit', 'smart' ),
				'no-repeat' => esc_html__( 'No Repeat', 'smart' ),
				'repeat'    => esc_html__( 'Repeat All', 'smart' ),
				'repeat-x'  => esc_html__( 'Repeat Horizontally', 'smart' ),
				'repeat-y'  => esc_html__( 'Repeat Vertically', 'smart' ),
			),
			'desc'      => esc_html__( 'Select how your background image should be repeated.', 'smart' ),
			'condition' => '_post_heading:not(false),_post_background_image:not(),_post_background_image_parallax:is(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_background_position',
			'std'       => '',
			'label'     => esc_html__( 'Background Image Position', 'smart' ),
			'type'      => 'select',
			'options' => array(
				''              => esc_html__( 'Inherit', 'smart' ),
				'left top'      => esc_html__( 'Left Top', 'smart' ),
				'left center'   => esc_html__( 'Left Center', 'smart' ),
				'left bottom'   => esc_html__( 'Left Bottom', 'smart' ),
				'center top'    => esc_html__( 'Center Top', 'smart' ),
				'center center' => esc_html__( 'Center Center', 'smart' ),
				'center bottom' => esc_html__( 'Center Bottom', 'smart' ),
				'right top'     => esc_html__( 'Right Top', 'smart' ),
				'right center'  => esc_html__( 'Right Center', 'smart' ),
				'right bottom'  => esc_html__( 'Right Bottom', 'smart' ),
			),
			'desc'      => esc_html__( 'Select where your background image should be positioned.', 'smart' ),
			'condition' => '_post_heading:not(false),_post_background_image:not(),_post_background_image_parallax:is(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_background_size',
			'std'       => '',
			'label'     => esc_html__( 'Background Image Size', 'smart' ),
			'type'      => 'select',
			'options' => array(
				''        => esc_html__( 'Inherit', 'smart' ),
				'auto'    => esc_html__( 'Auto', 'smart' ),
				'cover'   => esc_html__( 'Cover', 'smart' ),
				'contain' => esc_html__( 'Contain', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the size for you background image.', 'smart' ),
			'condition' => '_post_heading:not(false),_post_background_image:not(),_post_background_image_parallax:is(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_background_attachment',
			'std'       => '',
			'label'     => esc_html__( 'Background Image Attachment', 'smart' ),
			'type'      => 'select',
			'options' => array(
				''        => esc_html__( 'Inherit', 'smart' ),
				'scroll'  => esc_html__( 'Scroll', 'smart' ),
				'fixed'   => esc_html__( 'Fixed', 'smart' ),
			),
			'desc'      => esc_html__( 'Select how your background image should be attached to the post.', 'smart' ),
			'condition' => '_post_heading:not(false),_post_background_image:not(),_post_background_image_parallax:is(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_background_color',
			'std'       => '',
			'label'     => esc_html__( 'Post Title Bar Background Color', 'smart' ),
			'type'      => 'select_color',
			'options'   => nice_theme_colors_dropdown_values(),
			'desc'      => esc_html__( 'Choose a background color. If a background image is set from Theme Options, your selected color will show instead as a solid background.', 'smart' ),
			'class'     => 'nice-select-color',
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_scroll_down_arrow',
			'std'       => '',
			'label'     => esc_html__( 'Display Scroll Down Arrow Button', 'smart' ),
			'type'      => 'select',
			'desc'      => esc_html__( 'Show the scroll down arrow button.', 'smart' ),
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'condition' => '_post_heading:not(false)',
			'operator'  => 'and',
		);

		/**
		 * Content
		 */

		$nice_fields[] = array(
			'name'  => 'page-content',
			'label' => esc_html__( 'Content', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_doc-binder-three"></i>',
		);

		// Aside Post Format

		$nice_fields[] = array(
			'name'  => 'aside-info',
			'label' => esc_html__( 'Aside Post Format', 'smart' ),
			'type'  => 'info',
			'desc'  => esc_html__( 'This post should be kind of an informal note.', 'smart' ),
		);

		// Video Post Format

		$nice_fields[] = array(
			'name'  => 'video-info',
			'label' => esc_html__( 'Video Post Format', 'smart' ),
			'type'  => 'info',
			'desc'  => esc_html__("This post should contain a video. Don't forget to add your video embed code below.", 'smart' ),
		);

		$nice_fields[] = array(
			'name'  => 'embed',
			'std'   => '',
			'label' => esc_html__( 'Video Embed Code', 'smart' ),
			'type'  => 'textarea',
			'desc'  => esc_html__( 'Enter the video embed code for your video (YouTube, Vimeo, or similar).', 'smart' ),
		);

		// Link Post Format

		$nice_fields[] = array(
			'name'  => 'link-info',
			'label' => esc_html__( 'Link Post Format', 'smart' ),
			'type'  => 'info',
			'desc'  => esc_html__( "This post should contain a link to another website. Don't forget to add your link URL below.", 'smart' ),
		);

		$nice_fields[] = array(
			'name'  => 'link',
			'std'   => '',
			'label' => esc_html__( 'Link URL', 'smart' ),
			'type'  => 'text',
			'desc'  => sprintf( esc_html__( 'Enter your link URL (i.e. %s).', 'smart' ), 'http://nicethemes.com' ),
		);

		// Quote Post Format

		$nice_fields[] = array(
			'name'  => 'quote-info',
			'label' => esc_html__( 'Quote Post Format', 'smart' ),
			'type'  => 'info',
			'desc'  => esc_html__("This post should contain a quotation. Don't forget to add your quote and author below.", 'smart' ),
		);

		$nice_fields[] = array(
			'name'  => 'quote',
			'std'   => '',
			'label' => esc_html__( 'Quote', 'smart' ),
			'type'  => 'textarea',
			'desc'  => esc_html__( 'Enter your quote (i.e. "Design is not just what it looks like and feels like. Design is how it works.").', 'smart' ),
		);

		$nice_fields[] = array(
			'name'  => 'quote-author',
			'std'   => '',
			'label' => esc_html__( 'Quote Author', 'smart' ),
			'type'  => 'text',
			'desc'  => esc_html__( 'Enter the author of your quote (i.e. Steve Jobs).', 'smart' ),
		);

		// Image Post Format

		$nice_fields[] = array(
			'name'  => 'image-info',
			'label' => esc_html__( 'Image Post Format', 'smart' ),
			'type'  => 'info',
			'desc'  => esc_html__("This post should contain an image. Don't forget to add it as the featured image.", 'smart' ),
		);

		// Gallery Post Format

		$nice_fields[] = array(
			'name'  => 'gallery-info',
			'label' => esc_html__( 'Gallery Post Format', 'smart' ),
			'type'  => 'info',
			'desc'  => sprintf( esc_html__( 'This post should contain a gallery. Click the %1$s"Add Media"%2$s button below to start adding some images. Keep in mind that your featured image will appear before the images you add to your gallery.', 'smart' ), '<strong>', '</strong>' ) . '<br /><br /><a class="button insert-media add_media" title="' . __( 'Add Media', 'smart' ). '" data-editor="content" href="#"><span class="wp-media-buttons-icon"></span>' . __( 'Add Media', 'smart' ) . '</a>',
		);

		// Audio Post Format

		$nice_fields[] = array(
			'name'  => 'audio-info',
			'label' => esc_html__( 'Audio Post Format', 'smart' ),
			'type'  => 'info',
			'desc'  => esc_html__("This post should contain an audio. Don't forget to add it to your post content.", 'smart' ),
		);

		// Standard fields

		$nice_fields[] = array(
			'name'    => '_post_title_content',
			'std'     => '',
			'label'   => esc_html__( 'Display Post Title in Content', 'smart' ),
			'type'    => 'select',
			'options' => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'    => esc_html__( 'Show the post title in the content area.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'    => '_post_thumbnail_content',
			'std'     => '',
			'label'   => esc_html__( 'Display Post Featured Image in Content', 'smart' ),
			'type'    => 'select',
			'options' => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'    => esc_html__( 'Show the post featured image in the content area.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'    => '_post_content_skin',
			'std'     => '',
			'label'   => esc_html__( 'Content Skin', 'smart' ),
			'type'    => 'select',
			'options' => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'light' => esc_html__( 'Light', 'smart' ),
				'dark'  => esc_html__( 'Dark', 'smart' ),
			),
			'desc'    => esc_html__( 'Select the content skin for this post.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'    => '_post_content_width',
			'std'     => '',
			'label'   => esc_html__( 'Content Width', 'smart' ),
			'type'    => 'select',
			'options' => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'full'  => esc_html__( 'Full', 'smart' ),
				'limit' => esc_html__( 'Limit', 'smart' ),
			),
			'desc'      => esc_html__( 'Select whether or not to limit the content width for this post.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_post_content_width_value',
			'std'       => '',
			'label'     => esc_html__( 'Custom Width', 'smart' ),
			'type'      => 'measurement',
			'desc'      => esc_html__( 'Define the custom width for the content area (in px or in %).', 'smart' ),
			'condition' => '_post_content_width:is(limit)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'    => '_post_author_display',
			'std'     => get_post_meta( get_the_ID(), '_post_author_hide', true ) ? 'false' : '',
			'label'   => esc_html__( 'Display Post Author', 'smart' ),
			'type'    => 'select',
			'options' => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'    => sprintf( esc_html__( 'Display the post author for this post.', 'smart' ) ),
		);

		$nice_fields[] = array(
			'name'      => '_post_navigation_skin',
			'std'       => '',
			'label'     => esc_html__( 'Post Navigation Skin', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'light' => esc_html__( 'Light', 'smart' ),
				'dark'  => esc_html__( 'Dark', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the navigation skin to use for this post.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_post_navigation_background_color',
			'std'       => '',
			'label'     => esc_html__( 'Post Navigation Background Color', 'smart' ),
			'type'      => 'select_color',
			'options'   => nice_theme_colors_dropdown_values(),
			'desc'      => esc_html__( 'Choose a background color.', 'smart' ),
			'class'     => 'nice-select-color',
		);

		/**
		 * Sidebar
		 */

		$nice_fields[] = array(
			'name'  => 'page-sidebar',
			'label' => esc_html__( 'Sidebar', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_layout-sidebar-r-a"></i>',
		);

		$nice_fields[] = array(
			'name'      => '_post_sidebar',
			'std'       => '',
			'label'     => esc_html__( 'Display Sidebar', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Show a sidebar for this post.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_post_sidebar_id',
			'std'       => '',
			'label'     => esc_html__( 'Select Sidebar', 'smart' ),
			'type'      => 'select_sidebar',
			'desc'      => esc_html__( 'Select the sidebar for this post.', 'smart' ),
			'condition' => '_post_sidebar:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'label'     => esc_html__( 'Sidebar Position', 'smart' ),
			'desc'      => esc_html__( 'Set the position of the sidebar for this post.', 'smart' ),
			'name'      => '_post_sidebar_position',
			'type'      => 'select',
			'std'       => '',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'left'  => esc_html__( 'Left', 'smart' ),
				'right' => esc_html__( 'Right', 'smart' ),
			),
			'condition' => '_post_sidebar:not(false)',
			'operator'  => 'and',
		);

		/**
		 * Footer
		 */

		$nice_fields[] = array(
			'name'  => 'page-footer',
			'label' => esc_html__( 'Footer', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_layout-footer"></i>',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer',
			'std'       => '',
			'label'     => esc_html__( 'Display Footer', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Show the footer for this post.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'    => '_post_footer_skin',
			'std'     => '',
			'label'   => esc_html__( 'Footer Skin', 'smart' ),
			'type'    => 'select',
			'options' => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'dark'  => esc_html__( 'Dark', 'smart' ),
				'light' => esc_html__( 'Light', 'smart' ),
			),
			'desc'    => esc_html__( 'Select the footer skin for this post.', 'smart' ),
			'condition' => '_post_footer:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer_widgets',
			'std'       => '',
			'label'     => esc_html__( 'Display Footer Widgets Area', 'smart' ),
			'type'      => 'select',
			'desc'      => esc_html__( 'Show the footer widgets area for this post.', 'smart' ),
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'condition' => '_post_footer:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer_extended',
			'std'       => '',
			'label'     => esc_html__( 'Display Copyright Area', 'smart' ),
			'type'      => 'select',
			'desc'      => esc_html__( 'Show the footer copyright area for this post.', 'smart' ),
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'condition' => '_post_footer:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer_display_social',
			'std'       => '',
			'label'     => esc_html__( 'Display Social Icons', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'true'  => esc_html__( 'Yes', 'smart' ),
				'false' => esc_html__( 'No', 'smart' ),
			),
			'desc'      => esc_html__( 'Select whether or not to show a the social icons in the footer for this post.', 'smart' ),
			'condition' => '_post_footer:not(false),_post_footer_extended:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer_width',
			'std'       => '',
			'label'     => esc_html__( 'Footer Width', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''      => esc_html__( 'Inherit', 'smart' ),
				'full'  => esc_html__( 'Full', 'smart' ),
				'limit' => esc_html__( 'Limit', 'smart' ),
			),
			'desc'      => esc_html__( 'Select the width of the footer contents for this post.', 'smart' ),
			'condition' => '_post_footer:not(false)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_post_footer_width_value',
			'std'       => '',
			'label'     => esc_html__( 'Custom Width', 'smart' ),
			'type'      => 'measurement',
			'desc'      => esc_html__( 'Define the custom width for the footer area (in px or in %).', 'smart' ),
			'condition' => '_post_footer_width:is(limit)',
			'operator'  => 'and',
		);

	}

	return $nice_fields;
}
endif;
