<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains the function to hook custom fields for slides.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_custom_fields_slide' ) ) :
add_filter( 'nice_custom_fields', 'nice_custom_fields_slide', 10, 2 );
/**
 * Load array with custom fields for slides.
 * then save the array into WP options.
 *
 * @since 1.0.0
 *
 * @param array  $nice_fields
 * @param string $post_type
 *
 * @return array
 */
function nice_custom_fields_slide( $nice_fields, $post_type ) {
	if ( ! post_type_exists( 'slide' ) ) {
		return $nice_fields;
	}

	if ( 'slide' === $post_type || ! get_post_type() ) {

		$nice_fields[] = array(
			'name'  => 'slide-information',
			'label' => esc_html__( 'Content', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_doc-binder-three"></i>',
		);

		$nice_fields[] = array(
			'name'  => '_slide_info',
			'label' => esc_html__( 'Slide Image', 'smart' ),
			'type'  => 'info',
			'desc'  => esc_html__( "Slides use featured images as their slide images. Don't forget to add one to this slide.", 'smart' ),
		);

		$nice_fields[] = array(
			'label'   => esc_html__( 'Title Heading Tag', 'smart' ),
			'desc'    => esc_html__( 'Select the slide title heading tag.', 'smart' ),
			'name'    => '_slide_caption_heading_tag',
			'type'    => 'select',
			'std'     => '',
			'tip'     => '',
			'options' => nice_heading_tags_options(),
		);

		$nice_fields[] = array(
			'name'  => 'slide_description',
			'label' => esc_html__( 'Description', 'smart' ),
			'std'   => '',
			'type'  => 'textarea',
			'desc'  => esc_html__( 'Enter the slide description (optional).', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_slide_caption_background',
			'std'       => '',
			'label'     => esc_html__( 'Display Description Background', 'smart' ),
			'type'      => 'checkbox',
			'default'   => '',
			'desc'      => esc_html__( 'Add a semi-transparent background to the slide description.', 'smart' ),
			'condition' => 'slide_description:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'    => '_slide_skin',
			'std'     => 'light',
			'label'   => esc_html__( 'Content Skin', 'smart' ),
			'type'    => 'radio_image',
			'options' => array(
				'light' => array(
					'label' => esc_html__( 'Light', 'smart' ),
					'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-light.png' )
				),
				'dark'  => array(
					'label' => esc_html__( 'Dark', 'smart' ),
					'image' => nice_get_file_uri( 'engine/admin/assets/images/options/skin-dark.png' )
				),
			),
			'desc'    => esc_html__( 'Select the slide content skin, so your text is visible regardless of the background.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'    => '_slide_caption_position_x',
			'std'     => '',
			'label'   => esc_html__( 'Content Horizontal Position', 'smart' ),
			'type'    => 'select',
			'options' => array(
				'left'   => esc_html__( 'Left', 'smart' ),
				'center' => esc_html__( 'Center', 'smart' ),
				'right'  => esc_html__( 'Right', 'smart' )
			),
			'default' => '',
			'desc'    => esc_html__( 'Set the horizontal position for the slide content.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'    => '_slide_caption_position_y',
			'std'     => 'middle',
			'label'   => esc_html__( 'Content Vertical Position', 'smart' ),
			'type'    => 'select',
			'options' => array(
				'top'    => esc_html__( 'Top', 'smart' ),
				'middle' => esc_html__( 'Middle', 'smart' ),
				'bottom' => esc_html__( 'Bottom', 'smart' ),
			),
			'default' => '',
			'desc'    => esc_html__( 'Set the vertical position for the slide content.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'  => 'slide-buttons',
			'label' => esc_html__( 'Buttons', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_interface-left-t-k"></i>',
		);

		$nice_fields[] = array(
			'name'  => '_slide_info_button',
			'label' => esc_html__( 'Buttons', 'smart' ),
			'type'  => 'info',
			'desc'  => esc_html__( 'You can use (or not) buttons within your slides. That way you will be able to set particular links and call to actions.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'  => '_button_url',
			'std'   => '',
			'label' => esc_html__( 'Main Button Link URL', 'smart' ),
			'type'  => 'text',
			'desc'  => esc_html__( 'Enter the main button link URL (optional).', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_button_url_text',
			'std'       => '',
			'label'     => esc_html__( 'Main Button Label', 'smart' ),
			'type'      => 'text',
			'desc'      => esc_html__( 'Enter the anchor text you would like to use for the main button.', 'smart' ),
			'condition' => '_button_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_button_size',
			'std'       => '',
			'label'     => esc_html__( 'Main Button Size', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''   => esc_html__( 'Inherit', 'smart' ),
				'sm' => esc_html__( 'Small', 'smart' ),
				'md' => esc_html__( 'Medium', 'smart' ),
				'lg' => esc_html__( 'Large', 'smart' ),
				'xl' => esc_html__( 'Extra Large', 'smart' ),
			),
			'default'   => '',
			'desc'      => esc_html__( 'Set the main button size.', 'smart' ),
			'condition' => '_button_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_button_shape',
			'std'       => '',
			'label'     => esc_html__( 'Main Button Shape', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''       => esc_html__( 'Inherit', 'smart' ),
				'round'  => esc_html__( 'Round', 'smart' ),
				'circle' => esc_html__( 'Circle', 'smart' ),
				'square' => esc_html__( 'Square', 'smart' ),
			),
			'default'   => '',
			'desc'      => esc_html__( 'Set the main button shape.', 'smart' ),
			'condition' => '_button_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'  => '_button_text_transform',
			'std'   => '',
			'label' => esc_html__( 'Main Button Text Transform', 'smart' ),
			'type'  => 'select',
			'options' => nice_text_transform_options(),
			'default' => '',
			'desc'  => esc_html__( 'Set the text transformation for the main button.', 'smart' ),
			'condition' => '_button_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'    => '_button_outlined',
			'std'     => '',
			'label'   => esc_html__( 'Main Button Outlined', 'smart' ),
			'type'    => 'select',
			'desc'    => esc_html__( 'Make the main button have a border outline (instead of a full background color).', 'smart' ),
			'options' => array(
				''        => esc_html__( 'Default', 'smart' ),
				'outline' => esc_html__( 'Yes', 'smart' ),
				' '       => esc_html__( 'No', 'smart' ),
			),
			'condition' => '_button_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'    => '_button_color',
			'std'     => 'false',
			'label'   => esc_html__( 'Main Button Color', 'smart' ),
			'type'    => 'select_color',
			'class'   => 'nice-select-color',
			'options' => nice_theme_colors_dropdown_values(),
			'desc'    => esc_html__( 'Choose the color for the main button background.', 'smart' ),
			'condition' => '_button_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'  => '_slide_button_2',
			'std'   => 'false',
			'label' => esc_html__( 'Secondary Button', 'smart' ),
			'type'  => 'checkbox',
			'desc'  => esc_html__( 'Do you want to have a second button for this slide?', 'smart' ),
		);

		/* Secondary */

		$nice_fields[] = array(
			'name'      => '_button_2_url',
			'std'       => '',
			'label'     => esc_html__( 'Secondary Button Link URL', 'smart' ),
			'type'      => 'text',
			'desc'      => esc_html__( 'Enter the secondary button link URL.', 'smart' ),
			'condition' => '_slide_button_2:is(true)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_button_2_url_text',
			'std'       => '',
			'label'     => esc_html__( 'Secondary Button Label', 'smart' ),
			'type'      => 'text',
			'desc'      => esc_html__( 'Enter the anchor text you would like to use for the secondary button.', 'smart' ),
			'condition' => '_slide_button_2:is(true),_button_2_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_button_2_size',
			'std'       => '',
			'label'     => esc_html__( 'Secondary Button Size', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''   => esc_html__( 'Inherit', 'smart' ),
				'sm' => esc_html__( 'Small', 'smart' ),
				'md' => esc_html__( 'Medium', 'smart' ),
				'lg' => esc_html__( 'Large', 'smart' ),
				'xl' => esc_html__( 'Extra Large', 'smart' ),
			),
			'default'   => '',
			'desc'      => esc_html__( 'Set the secondary button size.', 'smart' ),
			'condition' => '_slide_button_2:is(true),_button_2_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_button_2_shape',
			'std'       => '',
			'label'     => esc_html__( 'Secondary Button Shape', 'smart' ),
			'type'      => 'select',
			'options'   => array(
				''       => esc_html__( 'Inherit', 'smart' ),
				'round'  => esc_html__( 'Round', 'smart' ),
				'circle' => esc_html__( 'Circle', 'smart' ),
				'square' => esc_html__( 'Square', 'smart' ),
			),
			'default'   => '',
			'desc'      => esc_html__( 'Set the secondary button shape.', 'smart' ),
			'condition' => '_slide_button_2:is(true),_button_2_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_button_2_text_transform',
			'std'       => '',
			'label'     => esc_html__( 'Secondary Button Text Transform', 'smart' ),
			'type'      => 'select',
			'options'   => nice_text_transform_options(),
			'default'   => '',
			'desc'      => esc_html__( 'Set the text transformation for the secondary button.', 'smart' ),
			'condition' => '_slide_button_2:is(true),_button_2_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_button_2_outlined',
			'std'       => 'false',
			'label'     => esc_html__( 'Secondary Button Outlined', 'smart' ),
			'type'      => 'select',
			'desc'      => esc_html__( 'Make the secondary button have a border outline (instead of a full background color).', 'smart' ),
			'options'   => array(
				''        => esc_html__( 'Default', 'smart' ),
				'outline' => esc_html__( 'Yes', 'smart' ),
				' '       => esc_html__( 'No', 'smart' ),
			),
			'condition' => '_slide_button_2:is(true),_button_2_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_button_2_color',
			'std'       => 'false',
			'label'     => esc_html__( 'Secondary Button Color', 'smart' ),
			'type'      => 'select_color',
			'class'     => 'nice-select-color',
			'options'   => nice_theme_colors_dropdown_values(),
			'desc'      => esc_html__( 'Choose the color for the secondary button background.', 'smart' ),
			'condition' => '_slide_button_2:is(true),_button_2_url:not()',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'  => 'slide-video',
			'label' => esc_html__( 'Video', 'smart' ),
			'type'  => 'section',
			'icon'  => '<i class="bi_media-video-a"></i>',
		);

		$nice_fields[] = array(
			'name'  => '_slide_info_video',
			'label' => esc_html__( 'Video Slide', 'smart' ),
			'type'  => 'info',
			'desc'  => sprintf( esc_html__( '%1$sYou can also use videos as the background of your slide. For self-hosted video backgrounds, we recommend a video loop with no sound. You must include %3$sMP4%4$s and %3$swebM%4$s formats to render your video with cross-browser compatibility. %3$sOGV is optional%4$s. The video must be in a 16:9 aspect ratio.%2$s%1$sYou can choose between self-hosted videos, and videos from third parties, like YouTube, Vimeo, or similar.%2$s', 'smart' ), '<p>', '</p>', '<strong>', '</strong>' ),
		);

		$nice_fields[] = array(
			'name'  => '_slide_video',
			'std'   => false,
			'label' => esc_html__( 'Video Background', 'smart' ),
			'type'  => 'checkbox',
			'desc'  => esc_html__( 'Use a video as the background for this slide.', 'smart' ),
		);

		$nice_fields[] = array(
			'name'      => '_slide_upload_mp4',
			'std'       => '',
			'label'     => esc_html__( 'Video MP4 Upload', 'smart' ),
			'type'      => 'upload',
			'desc'      => esc_html__( 'Upload your MP4 video file. This will be automatically played on load, so make sure to use this responsibly for enhancing your design, rather than annoying your user.', 'smart' ),
			'condition' => '_slide_video:is(true)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_slide_upload_webm',
			'std'       => '',
			'label'     => esc_html__( 'Video WebM Upload', 'smart' ),
			'type'      => 'upload',
			'desc'      => esc_html__( 'Upload your WebM video file.', 'smart' ),
			'condition' => '_slide_video:is(true)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => '_slide_upload_ogv',
			'std'       => '',
			'label'     => esc_html__( 'Video OGV Upload', 'smart' ),
			'type'      => 'upload',
			'desc'      => esc_html__( 'Upload your OGV video file (optional).', 'smart' ),
			'condition' => '_slide_video:is(true)',
			'operator'  => 'and',
		);

		$nice_fields[] = array(
			'name'      => 'embed',
			'std'       => '',
			'label'     => esc_html__( 'Video Embed Code', 'smart' ),
			'type'      => 'textarea',
			'desc'      => esc_html__( 'Enter the video embed code for your video (YouTube, Vimeo, or similar). Will show instead of the self-hosted video.', 'smart' ),
			'condition' => '_slide_video:is(true)',
			'operator'  => 'and',
		);
	}

	return $nice_fields;
}
endif;
