<?php
/**
 * Smart by NiceThemes.
 *
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_slider_options' ) ) :
add_filter( 'nice_options', 'nice_slider_options' );
/**
 * Add Slider specific options to theme options.
 *
 * @since  1.0.0
 *
 * @param  array $nice_options
 * @return array
 */
function nice_slider_options( $nice_options ) {
	// Obtain the prefix for the option fields.
	$prefix = NICE_PREFIX;

	if ( ! post_type_exists( 'slide' ) ) {
		return $nice_options;
	}

	/**
	 * Home > Slider
	 */

	$nice_slider_options[] = array(
		'name'   => esc_html__( 'Slider', 'smart' ),
		'type'   => 'heading',
		'icon'   => '<i class="bi_sport-cards"></i>',
		'parent' => $prefix . '_homepage',
	);

	/**
	 * Home > Slider > General
	 */

	$nice_slider_options[] = array(
		'name' => esc_html__( 'General', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_music-eq-a"></i>',
	);

	$nice_slider_options[] = array(
		'name' => esc_html__( 'Display Slider', 'smart' ),
		'desc' => esc_html__( 'Show the slider on the home page template.', 'smart' ),
		'id'   => $prefix . '_slider',
		'std'  => nice_default_setting( 'slider' ),
		'tip'  => '',
		'type' => 'checkbox',
	);

	$nice_slider_options[] = array(
		'name'    => esc_html__( 'Loader Icon', 'smart' ),
		'desc'    => esc_html__( 'Select the slider loader icon.', 'smart' ),
		'id'      => $prefix . '_slider_loader_icon',
		'type'    => 'select',
		'std'     => nice_default_setting( 'slider_loader_icon' ),
		'tip'     => '',
		'options' => array(
			'beat' => esc_html__( 'Beat', 'smart' ),
			'spin' => esc_html__( 'Spin', 'smart' ),
		),
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Entries Quantity', 'smart' ),
		'desc'      => esc_html__( 'Select the number of entries that should appear in the home page slider.', 'smart' ),
		'id'        => $prefix . '_slider_entries',
		'std'       => nice_default_setting( 'slider_entries' ),
		'type'      => 'slider',
		'tip'       => '',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Reverse Animation Direction', 'smart' ),
		'desc'      => esc_html__( 'Reverse the slider animation direction.', 'smart' ),
		'id'        => $prefix . '_slider_reverse',
		'std'       => nice_default_setting( 'slider_reverse' ),
		'tip'       => '',
		'type'      => 'checkbox',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Auto-Start', 'smart' ),
		'desc'      => esc_html__( 'Set the slider to start sliding automatically.', 'smart' ),
		'id'        => $prefix . '_slider_slideshow',
		'std'       => nice_default_setting( 'slider_slideshow' ),
		'tip'       => '',
		'type'      => 'checkbox',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Randomize Slides', 'smart' ),
		'desc'      => esc_html__( 'Select to randomly order the slides.', 'smart' ),
		'id'        => $prefix . '_slider_randomize',
		'std'       => nice_default_setting( 'slider_randomize' ),
		'tip'       => '',
		'type'      => 'checkbox',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	/**
	 * Home > Slider > Animation
	 */

	$nice_slider_options[] = array(
		'name' => esc_html__( 'Animation', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_tool-magic-wand"></i>',
	);

	$nice_slider_options[] = array(
		'name'    => esc_html__( 'Animation Effect', 'smart' ),
		'desc'    => esc_html__( 'Select the slider animation effect.', 'smart' ),
		'id'      => $prefix . '_slider_animation',
		'type'    => 'select',
		'std'     => nice_default_setting( 'slider_animation' ),
		'tip'     => '',
		'options' => array(
			'slide' => esc_html__( 'Slide', 'smart' ),
			'fade'  => esc_html__( 'Fade', 'smart' ),
		),
		'extra'   => array(
			'type' => 'radio-buttonset',
		),
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'    => esc_html__( 'Scroll Animation', 'smart' ),
		'desc'    => esc_html__( 'Select the slider scroll animation.', 'smart' ),
		'id'      => $prefix . '_slider_scroll',
		'type'    => 'select',
		'std'     => nice_default_setting( 'slider_scroll' ),
		'tip'     => '',
		'options' => array(
			'default'  => esc_html__( 'None', 'smart' ),
			'parallax' => esc_html__( 'Parallax', 'smart' ),
		),
		'extra'   => array(
			'type' => 'radio-buttonset',
		),
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Animation Loop', 'smart' ),
		'desc'      => esc_html__( 'Make the slider animation loop.', 'smart' ),
		'id'        => $prefix . '_slider_animation_loop',
		'std'       => false,
		'tip'       => '',
		'type'      => 'checkbox',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Animation Speed', 'smart' ),
		'desc'      => esc_html__( 'The time in milliseconds the animation between frames will take.', 'smart' ),
		'id'        => $prefix . '_slider_animation_speed',
		'std'       => nice_default_setting( 'slider_animation_speed' ),
		'tip'       => '',
		'type'      => 'slider',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Auto-Slide Interval', 'smart' ),
		'desc'      => esc_html__( 'The time in (in milliseconds) each slide pauses for, before sliding to the next.', 'smart' ),
		'id'        => $prefix . '_slider_slideshow_speed',
		'std'       => nice_default_setting( 'slider_slideshow_speed' ),
		'tip'       => '',
		'type'      => 'slider',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Pause on Hover', 'smart' ),
		'desc'      => esc_html__( 'Make the slider pause when hovering over it.', 'smart' ),
		'id'        => $prefix . '_slider_pause_on_hover',
		'std'       => nice_default_setting( 'slider_pause_on_hover' ),
		'tip'       => '',
		'type'      => 'checkbox',
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_slideshow:is(true)',
		'operator'  => 'and',
	);

	/**
	 * Home > Slider > Pagination
	 */

	$nice_slider_options[] = array(
		'name' => esc_html__( 'Pagination', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-documents"></i>',
	);

	$nice_slider_options[] = array(
		'name' => esc_html__( 'Pagination Bar', 'smart' ),
		'desc' => esc_html__( 'Show the slider pagination bar.', 'smart' ),
		'id'   => $prefix . '_slider_control_nav',
		'std'  => nice_default_setting( 'slider_control_nav' ),
		'tip'  => '',
		'type' => 'checkbox',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( '"Previous/Next" Navigation', 'smart' ),
		'desc'      => esc_html__( 'Show the slider "Previous/Next" navigation.', 'smart' ),
		'id'        => $prefix . '_slider_direction_nav',
		'std'       => nice_default_setting( 'slider_direction_nav' ),
		'tip'       => '',
		'type'      => 'checkbox',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( '"Previous/Next" Navigation Buttons Style', 'smart' ),
		'desc'      => esc_html__( 'Select the "Previous/Next" navigation buttons style.', 'smart' ),
		'id'        => $prefix . '_slider_direction_nav_style',
		'type'      => 'radio_image',
		'std'       => nice_default_setting( 'slider_direction_nav_style' ),
		'tip'       => '',
		'options'   => array(
			''            => array(
				'label' => esc_html__( 'Default', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-slider-nav-default.png' ),
			),
			'outline' => array(
				'label' => esc_html__( 'Outlined', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-slider-nav-outlined.png' ),
			),
			'solid'   => array(
				'label' => esc_html__( 'Solid Background', 'smart' ),
				'image' => nice_get_file_uri( 'engine/admin/assets/images/options/btn-slider-nav-solid.png' ),
			),
		),
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_direction_nav:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( '"Previous/Next" Navigation Buttons Shape', 'smart' ),
		'desc'      => esc_html__( 'Select the "Previous/Next" navigation buttons shape.', 'smart' ),
		'id'        => $prefix . '_slider_direction_nav_shape',
		'type'      => 'select',
		'std'       => nice_default_setting( 'slider_direction_nav_shape' ),
		'tip'       => '',
		'options'   => array(
			''       => esc_html__( 'Default', 'smart' ),
			'round'  => esc_html__( 'Round', 'smart' ),
			'circle' => esc_html__( 'Circle', 'smart' ),
			'square' => esc_html__( 'Square', 'smart' ),
		),
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_direction_nav:is(true),' . $prefix . '_slider_direction_nav_style:not()',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( '"Previous/Next" Navigation Buttons Background Color', 'smart' ),
		'desc'      => esc_html__( 'Select the "Previous/Next" buttons background color.', 'smart' ),
		'id'        => $prefix . '_slider_direction_nav_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'slider_direction_nav_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_direction_nav:is(true),' . $prefix . '_slider_direction_nav_style:not()',
		'operator'  => 'and',
	);

	/**
	 * Home > Slider > Content
	 */

	$nice_slider_options[] = array(
		'name' => esc_html__( 'Content', 'smart' ),
		'type' => 'group',
		'icon' => '<i class="bi_doc-binder-two"></i>',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Display Slide Content', 'smart' ),
		'desc'      => esc_html__( 'Show the title and description for each slide.', 'smart' ),
		'id'        => $prefix . '_slider_caption',
		'std'       => nice_default_setting( 'slider_caption' ),
		'tip'       => '',
		'type'      => 'checkbox',
		'condition' => $prefix . '_slider:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Title Heading Tag', 'smart' ),
		'desc'      => esc_html__( 'Select the default slide title heading tag.', 'smart' ),
		'id'        => $prefix . '_slider_caption_heading_tag',
		'type'      => 'select',
		'std'       => nice_default_setting( 'slider_caption_heading_tag' ),
		'tip'       => '',
		'options'   => nice_heading_tags_options(),
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_caption:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Slide Button Size', 'smart' ),
		'desc'      => esc_html__( 'Select the default slide button style.', 'smart' ),
		'id'        => $prefix . '_slider_caption_button_size',
		'type'      => 'select',
		'std'       => nice_default_setting( 'slider_caption_button_size' ),
		'tip'       => '',
		'options'   => array(
			''   => esc_html__( 'Default', 'smart' ),
			'sm' => esc_html__( 'Small', 'smart' ),
			'md' => esc_html__( 'Medium', 'smart' ),
			'lg' => esc_html__( 'Large', 'smart' ),
			'xl' => esc_html__( 'Extra-Large', 'smart' ),
		),
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_caption:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Slide Button Shape', 'smart' ),
		'desc'      => esc_html__( 'Select the default slide button shape.', 'smart' ),
		'id'        => $prefix . '_slider_caption_button_shape',
		'type'      => 'select',
		'std'       => nice_default_setting( 'slider_caption_button_shape' ),
		'tip'       => '',
		'options'   => array(
			''       => esc_html__( 'Default', 'smart' ),
			'round'  => esc_html__( 'Round', 'smart' ),
			'circle' => esc_html__( 'Circle', 'smart' ),
			'square' => esc_html__( 'Square', 'smart' ),
		),
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_caption:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Slide Button Text Transformation', 'smart' ),
		'desc'      => esc_html__( 'Select the default slide button text transformation.', 'smart' ),
		'id'        => $prefix . '_slider_caption_button_text_transform',
		'type'      => 'select',
		'std'       => nice_default_setting( 'slider_caption_button_text_transform' ),
		'tip'       => '',
		'options'   => nice_text_transform_options(),
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_caption:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Slide Button Outlined', 'smart' ),
		'desc'      => esc_html__( 'Make slide buttons outlined (with no full background color) by default.', 'smart' ),
		'id'        => $prefix . '_slider_caption_button_outlined',
		'type'      => 'select',
		'std'       => nice_default_setting( 'slider_caption_button_outlined' ),
		'tip'       => '',
		'options'   => array(
			''        => esc_html__( 'Default', 'smart' ),
			'outline' => esc_html__( 'Yes', 'smart' ),
			' '       => esc_html__( 'No', 'smart' ),
		),
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_caption:is(true)',
		'operator'  => 'and',
	);

	$nice_slider_options[] = array(
		'name'      => esc_html__( 'Slide Button Color', 'smart' ),
		'desc'      => esc_html__( 'Choose the slide button text color.', 'smart' ),
		'id'        => $prefix . '_slider_caption_button_color',
		'type'      => 'select_color',
		'std'       => nice_default_setting( 'slider_caption_button_color' ),
		'class'     => 'nice-select-color',
		'options'   => nice_theme_colors_dropdown_values(),
		'condition' => $prefix . '_slider:is(true),' . $prefix . '_slider_caption:is(true)',
		'operator'  => 'and',
	);


	$nice_options = nice_options_enqueue( $nice_options, $nice_slider_options, $prefix . '_homepage_content_background_color_opacity', false );

	return $nice_options;
}
endif;
