<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions that print HTML directly for "slider" post type.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_slider_data' ) ) :
/**
 * Add HTML5 data attributes to slider container.
 *
 * @since 1.0.0
 *
 * @param array $data
 */
function nice_slider_data( $data = array() ) {
	if ( nice_doing_homepage_slider() ) {
		$data['settings'] = 'flexsliderSettings';
	}

	/**
	 * @hook nice_slider_data
	 *
	 * Hook here to change the slider data attributes.
	 *
	 * @since 1.0.0
	 */
	echo apply_filters( 'nice_slider_data', nice_data_attributes( $data, false ) );
}
endif;

if ( ! function_exists( 'nice_slide_data' ) ) :
/**
 * Add HTML5 data attributes to slide.
 *
 * @since 1.0.0
 *
 * @param array $data
 */
function nice_slide_data( $data = array() ) {
	if ( nice_doing_homepage_slider() ) {
		$data = array_merge( $data, array(
				'color-scheme' => nice_slide_get_skin(),
				'x-pos'        => nice_slide_caption_get_position_x(),
				'y-pos'        => nice_slide_caption_get_position_y(),
			)
		);
	}

	/**
	 * @hook nice_slide_data
	 *
	 * Hook here to change the slide data attributes.
	 *
	 * @since 1.0.0
	 */
	echo apply_filters( 'nice_slide_data', nice_data_attributes( $data, false ) );
}
endif;

if ( ! function_exists( 'nice_slide_caption_data' ) ) :
/**
 * Add HTML5 data attributes to a slide's caption.
 *
 * @since 1.0.0
 *
 * @param array $data
 */
function nice_slide_caption_data( $data = array() ) {
	if ( nice_doing_homepage_slider() ) {
		$data = array_merge( $data, array(
				'color-scheme' => nice_slide_get_skin(),
			)
		);
	}

	/**
	 * @hook nice_slide_caption_data
	 *
	 * Hook here to change the slide caption data attributes.
	 *
	 * @since 1.0.0
	 */
	echo apply_filters( 'nice_slide_caption_data', nice_data_attributes( $data, false ) );
}
endif;

if ( ! function_exists( 'nice_slider_class' ) ) :
/**
 * Print HTML class(es) for the wrapper of a slider.
 *
 * @since 1.2.0
 *
 * @param string|array $class String or array containing custom classes.
 * @param int          $count Number of slides in query.
 */
function nice_slider_class( $class = '', $count = 0 ) {
	nice_css_classes( nice_get_slider_class( $class, $count ) );
}
endif;

if ( ! function_exists( 'nice_slide_caption_class' ) ) :
/**
 * Print HTML class(es) for a slide's caption.
 *
 * @since 1.2.0
 *
 * @param string|array $class String or array containing custom classes.
 */
function nice_slide_caption_class( $class = '' ) {
	nice_css_classes( nice_get_slide_caption_class( $class ) );
}
endif;

if ( ! function_exists( 'nice_slide_video' ) ) :
/**
 * Display video for a slide.
 *
 * @since  1.0.0
 *
 * @param  WP_Post $post     Post object to get caption from.
 *
 * @return mixed|void|string
 */
function nice_slide_video( WP_Post $post = null ) {
	if ( is_null( $post ) ) {
		$post = get_post();
	}

	$video_webm = get_post_meta( $post->ID, '_slide_upload_webm', true );
	$video_mp4  = get_post_meta( $post->ID, '_slide_upload_mp4', true );
	$video_ogv  = get_post_meta( $post->ID, '_slide_upload_ogv', true );

	if ( ! empty( $video_webm ) && ! empty( $video_mp4 ) ) {
		$poster = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'nice-slide' );

		if ( $poster ) { ?>
			<div class="slide-image">
				<?php nice_slide_image( $post, array( 'class' => 'nice-slide-video-image' ) ); ?>
			</div>
			<?php
			$poster = 'poster="' . $poster[0] . '"';
		}
		?>
		<div id="nice-slide-video-container-<?php echo esc_attr( $post->ID ); ?>" class="video nice-slide-video-container">
			<div class="video-overlay"></div>
			<video class="fill-width" <?php echo $poster; ?> preload="auto" loop="loop" autoplay="autoplay">
				<source src="<?php echo esc_url( $video_webm ); ?>" type="video/webm" />
				<source src="<?php echo esc_url( $video_mp4 ); ?>" type="video/mp4" />
				<source src="<?php echo esc_url( $video_ogv ); ?>" type="video/ogg" />
				<?php esc_html_e( 'Your browser does not support the video tag. We suggest you upgrade your browser.', 'smart' ); ?>
			</video>
		</div>
		<?php

	} elseif ( $embed_video = nice_slide_get_embed( $post ) ) {
		echo $embed_video;
	}
}
endif;

if ( ! function_exists( 'nice_slide_image' ) ) :
/**
 * Display image for a slide.
 *
 * @since 1.0.0
 *
 * @param WP_Post $post Post object to get image from.
 *
 * @param array   $args Arbitrary arguments to get the slide image.
 */
function nice_slide_image( WP_Post $post = null, $args = array() ) {
	echo nice_slide_get_image( $post, $args );
}
endif;

if ( ! function_exists( 'nice_slide_description' ) ) :
/**
 * Display the description of a slide.
 *
 * @since  1.0.0
 *
 * @param  WP_Post $post Post object to get description from.
 */
function nice_slide_description( WP_Post $post = null ) {
	echo nice_slide_get_description( $post );
}
endif;

if ( ! function_exists( 'nice_slide_buttons' ) ) :
/**
 * Display buttons of a slide element.
 *
 * @since  1.0.0
 *
 * @param  WP_Post $post Post object to get link from.
 */
function nice_slide_buttons( WP_Post $post = null ) {
	echo nice_slide_get_buttons( $post );
}
endif;

if ( ! function_exists( 'nice_slide_title' ) ) :
/**
 * Display title of a slide element.
 *
 * @since 1.0.0
 *
 * @param WP_Post $post Post object to get title from.
 */
function nice_slide_title( WP_Post $post = null ) {
	echo nice_slide_get_title( $post );
}
endif;

if ( ! function_exists( 'nice_slide_skin' ) ) :
/**
 * Display color scheme for a slide.
 *
 * @since  1.0.0
 *
 * @param  WP_Post $post     Post object to get caption from.
 *
 * @return mixed|void|string
 */
function nice_slide_skin( WP_Post $post = null ) {
	echo nice_slide_get_skin( $post );
}
endif;

if ( ! function_exists( 'nice_slide_caption_position_x' ) ) :
/**
 * Display horizontal position for a slide.
 *
 * @since  1.0.0
 *
 * @param  WP_Post $post     Post object to get caption from.
 *
 * @return mixed|void|string
 */
function nice_slide_caption_position_x( WP_Post $post = null ) {
	echo nice_slide_caption_get_position_x( $post );
}
endif;

if ( ! function_exists( 'nice_slide_caption_position_y' ) ) :
/**
 * Display vertical position for a slide.
 *
 * @since  1.0.0
 *
 * @param  WP_Post $post     Post object to get caption from.
 *
 * @return mixed|void|string
 */
function nice_slide_caption_position_y( WP_Post $post = null ) {
	echo nice_slide_caption_get_position_y( $post );
}
endif;

if ( ! function_exists( 'nice_slide_caption_background' ) ) :
/**
 * Get if a slide has background for its caption.
 *
 * @since  1.0.0
 *
 * @param  WP_Post $post     Post object to get caption from.
 *
 * @return mixed|void|string
 */
function nice_slide_caption_background( WP_Post $post = null ) {
	echo nice_slide_get_caption_background( $post );
}
endif;
