<?php
/**
 * Smart by NiceThemes.
 *
 * This file includes functions to manage scripts for the theme.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_theme_async_scripts' ) ) :
add_filter( 'nice_async_scripts', 'nice_theme_async_scripts' );
/**
 * List of scripts that can be loaded asynchronously.
 *
 * This list should be used for custom scripts, and only in cases where the
 * loading order isn't an issue. It is not recommended for the main JS file.
 *
 * @since 1.0.0
 *
 * @param array $scripts
 *
 * @return array
 */
function nice_theme_async_scripts( $scripts = array() ) {
	global $is_IE;

	$scripts = array_merge( $scripts, array(
			'nice-overlay-navigation',
			'nice-centered-inline-logo',
			'nice-full-page-overlay',
			'nice-heading-parallax',
			'nice-contact-map',
			'nice-woocommerce-scripts',
			'nice-posts-loader-scripts',
		)
	);

	if ( $is_IE ) {
		$scripts[] = 'nice-object-fit-image-scripts';
	}

	return $scripts;
}
endif;

if ( ! function_exists( 'nice_theme_on_demand_scripts' ) ) :
add_filter( 'nice_on_demand_scripts', 'nice_theme_on_demand_scripts' );
/**
 * List of scripts that can be loaded on demand.
 *
 * This list should be used for third-party libraries only. If a script listed
 * as asynchronous or deferred is also in this list, it will ne used only as an
 * on-demand script.
 *
 * @since  1.0.0
 *
 * @param  array $scripts List of registered scripts.
 *
 * @return array
 */
function nice_theme_on_demand_scripts( $scripts = array() ) {
	$scripts = array_merge( $scripts, array(
		'nice-waypoints-source'     => 'waypoints',
		'nice-fancybox-source'      => 'fancybox',
		'nice-superfish-source'     => 'superfish',
		'nice-isotope-source'       => 'isotope',
		'nice-vimeo-player-source'  => 'vimeoPlayer',
		'nice-flexslider-source'    => 'flexslider',
		'nice-scrollto-source'      => 'scrollTo',
	) );

	if ( nice_lazyload_images() ) {
		$scripts['nice-lazyload-source'] = 'lazyload';
	}

	return $scripts;
}
endif;

if ( ! function_exists( 'nice_scripts' ) ) :
add_action( 'nice_register_scripts', 'nice_scripts' );
/**
 * Register general scripts.
 *
 * @uses wp_register_script()
 * @uses wp_enqueue_script()
 *
 * @since 1.0.0
 */
function nice_scripts() {
	$on_demand_js = nice_on_demand_js();
	$js_folder = 'includes/assets/js';

	$nice_scripts_deps = array( 'jquery' );

	/**
	 * Register Pace scripts.
	 *
	 * @since 1.0.0
	 */
	wp_register_script( 'nice-pace-source', nice_get_file_uri( $js_folder . '/pace.js', true ), array(), '1.0.2' );
	$nice_scripts_deps[] = 'nice-pace-source';

	wp_register_script( 'nice-waypoints-source', nice_get_file_uri( $js_folder . '/jquery.waypoints.js', true ), array( 'jquery' ), '4.0.1', true );
	$nice_scripts_deps[] = 'nice-waypoints-source';

	/**
	 * Register Fancybox scripts.
	 *
	 * @since 1.0.0
	 */
	wp_register_script( 'nice-fancybox-source', nice_get_file_uri( $js_folder . '/jquery.fancybox.js', true ), array( 'jquery' ), '2.1.5', true );
	$nice_scripts_deps[] = 'nice-fancybox-source';

	/**
	 * Register Superfish scripts.
	 *
	 * @since 1.0.0
	 */
	wp_register_script( 'nice-superfish-source', nice_get_file_uri( $js_folder . '/superfish.js', true ), array( 'jquery', 'hoverIntent' ), '1.7.9', true );
	$nice_scripts_deps[] = 'nice-superfish-source';

	/**
	 * Load Isotope scripts.
	 *
	 * @since 1.0.0
	 */
	wp_register_script( 'nice-isotope-source', nice_get_file_uri( $js_folder . '/min/isotope.min.js' ), array( 'jquery' ), '2.2.2', true );
	wp_enqueue_script( 'nice-isotope-source' );
	$nice_scripts_deps[] = 'nice-isotope-source';

	/**
	 * Register Vimeo Player scripts.
	 *
	 * @since 1.0.0
	 */
	wp_register_script( 'nice-vimeo-player-source', nice_get_file_uri( $js_folder . '/player.js', true ), array(), '2.0.1', true );

	/**
	 * Register Flexslider scripts.
	 *
	 * @since 1.0.0
	 */
	wp_register_script( 'nice-flexslider-source', nice_get_file_uri( $js_folder . '/jquery.flexslider.js', true ), array( 'jquery', 'nice-vimeo-player-source' ), '2.6.3', true );
	$nice_scripts_deps[] = 'nice-flexslider-source';

	/**
	 * Load scripts for scroll.
	 *
	 * @since 1.0.0
	 */
	wp_register_script( 'nice-scrollto-source', nice_get_file_uri( $js_folder . '/jquery.scrollTo.js', true ), array( 'jquery' ), '2.1.2', true );
	$nice_scripts_deps[] = 'nice-scrollto-source';

	/**
	 * Load scripts for LazyLoad.
	 *
	 * @since 1.0.0
	 */
	if ( nice_lazyload_images() ) {
		wp_register_script( 'nice-lazyload-source', nice_get_file_uri( $js_folder . '/lazyload.js', true ), array(), '4.0.4', true );
		$nice_scripts_deps[] = 'nice-lazyload-source';
	}

	/**
	 * Register general scripts.
	 *
	 * @since 1.0.0
	 */
	if ( apply_filters( 'nice_scripts', true ) ) {
		$data = array(
			'homeURL'       => get_home_url(),
			'adminURL'      => admin_url(),
			'adminAjaxURL'  => admin_url() . 'admin-ajax.php',
			'playNiceNonce' => wp_create_nonce( 'play-nice' ),
			'headerFixed'   => nice_bool( nice_get_option( 'nice_header_fixed' ) ),
			'headerShrink'  => nice_bool( nice_get_option( 'nice_header_shrink' ) ),
			'AjaxCache'     => $on_demand_js,
		);

		/**
		 * @hook nice_flexslider_settings
		 *
		 * Flexslider settings are applied here.
		 *
		 * Hooked here:
		 * @see nice_homepage_slides_flexslider_settings()
		 */
		$flexslider_settings = apply_filters( 'nice_flexslider_settings', array() );

		if ( ! empty( $flexslider_settings ) ) {
			$data['flexsliderSettings'] = $flexslider_settings;
		}

		// Make sure this argument doesn't get printed if we're not in development mode.
		if ( nice_development_mode() ) {
			$data['devMode'] = true;
		}

		if ( nice_use_minified_files() ) {
			/**
			 * If we're using minified assets, load all theme JS
			 * implementation from a single minified file.
			 *
			 * @since 1.0.0
			 */
			wp_register_script( 'nice-scripts', nice_get_file_uri( $js_folder . '/min/nice-scripts.min.js' ), $nice_scripts_deps, false, true );
			wp_enqueue_script( 'nice-scripts' );
		} else {
			/**
			 * If we're not using minified assets, load all theme
			 * JS implementation from separated files.
			 *
			 * @since 1.0.0
			 */
			wp_register_script( 'nice-scripts', nice_get_file_uri( $js_folder . '/nice-general.js' ), $nice_scripts_deps, false, true );
			wp_enqueue_script( 'nice-scripts' );

			wp_register_script( 'nice-dev', nice_get_file_uri( $js_folder . '/nice-dev.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-dev' );

			wp_register_script( 'nice-lazy-scripts', nice_get_file_uri( $js_folder . '/nice-lazy-scripts.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-lazy-scripts' );

			wp_register_script( 'nice-animations', nice_get_file_uri( $js_folder . '/nice-animations.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-animations' );

			wp_register_script( 'nice-mobile', nice_get_file_uri( $js_folder . '/nice-mobile.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-mobile' );

			wp_register_script( 'nice-css-rules-handler', nice_get_file_uri( $js_folder . '/nice-css-rules-handler.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-css-rules-handler' );

			wp_register_script( 'nice-lazyload', nice_get_file_uri( $js_folder . '/nice-lazyload.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-lazyload' );

			wp_register_script( 'nice-throttle', nice_get_file_uri( $js_folder . '/nice-throttle.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-throttle' );

			// Load Fancybox implementation.
			wp_register_script( 'nice-fancybox', nice_get_file_uri( $js_folder . '/nice-fancybox.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-fancybox' );

			// Load Superfish implementation.
			wp_register_script( 'nice-superfish', nice_get_file_uri( $js_folder . '/nice-superfish.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-superfish' );

			// Load Flexslider implementation.
			wp_register_script( 'nice-flexslider', nice_get_file_uri( $js_folder . '/nice-flexslider.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-flexslider' );

			// Load custom Isotope implementation.
			wp_register_script( 'nice-isotope-scripts', nice_get_file_uri( $js_folder . '/nice-isotope.js' ), array( 'nice-scripts' ), false, true );
			wp_enqueue_script( 'nice-isotope-scripts' );
		}

		/**
		 * Register and enqueue script for heading parallax.
		 */
		wp_register_script( 'nice-heading-parallax', nice_get_file_uri( $js_folder . '/nice-heading-parallax.js', true ), array( 'nice-scripts' ), false, true );
		// Only enqueue the script if the current page needs a parallax effect in its heading.
		if ( nice_page_heading_has_parallax() ) {
			wp_enqueue_script( 'nice-heading-parallax' );
		}

		/**
		 * Register and enqueue script for full page loader.
		 */
		wp_register_script( 'nice-full-page-overlay', nice_get_file_uri( $js_folder . '/nice-full-page-overlay.js', true ), array( 'nice-scripts' ), false, true );
		// Only enqueue the script if the full page loader is enabled.
		if ( 'full_page' === nice_get_option('_page_loader') ) {
			wp_enqueue_script( 'nice-full-page-overlay' );
		}

		/**
		 * Register and enqueue overlay navigation script.
		 */
		wp_register_script( 'nice-overlay-navigation', nice_get_file_uri( $js_folder . '/nice-overlay-navigation.js', true ), array( 'nice-scripts' ), false, true );
		// Only enqueue the script when the navigation option is set to overlay.
		if ( nice_overlay_navigation() ) {
			wp_enqueue_script( 'nice-overlay-navigation' );
		}

		/**
		 * Register and enqueue script for centered inline logo.
		 */
		wp_register_script( 'nice-centered-inline-logo', nice_get_file_uri( $js_folder . '/nice-centered-inline-logo.js', true ), array( 'nice-scripts' ), false, true );
		// Only enqueue the script when the logo alignment is set to centered inline.
		if ( 'logo-centered-inline' === nice_get_option( '_header_top_navigation_alignment' ) ) {
			wp_enqueue_script( 'nice-centered-inline-logo' );
		}

		/**
		 * Register Contact Page Template script for Google Map.
		 */
		wp_register_script( 'nice-contact-map', nice_get_file_uri( $js_folder . '/nice-contact-map.js', true ), array( 'nice-scripts' ), false, true );
		// Only enqueue the script in Contact page templates.
		if ( is_page_template( 'page-templates/contact.php' ) && nice_get_option( '_gmaps_api_key' ) && nice_get_option( '_google_map' ) ) {
			wp_enqueue_script( 'nice-contact-map' );
		}

		if ( $on_demand_js ) {
			$data['lazyScripts'] = nice_on_demand_scripts();
		}

		wp_localize_script( 'nice-scripts', 'generalData', $data );
	}

	/**
	 * Load polyfill to support object-fit property in IE.
	 *
	 * @since 1.0.0
	 */
	global $is_IE;
	if ( $is_IE ) {
		wp_register_script( 'nice-object-fit-image-scripts', nice_get_file_uri( $js_folder . '/ofi.js', true ), array(), false, true );

		if ( apply_filters( 'nice_ie_object_fit_image_scripts', true ) && $is_IE ) {
			wp_enqueue_script( 'nice-object-fit-image-scripts' );
		}
	}

	/**
	 * Load JavaScript for "load more" functionality conditionally (disabled by default).
	 *
	 * @since 1.0.0
	 */
	wp_register_script( 'nice-posts-loader-scripts', nice_get_file_uri( $js_folder . '/nice-posts-loader.js', true ), array( 'jquery' ), false, true );

	if ( apply_filters( 'nice_load_more_posts_scripts', false ) ) {
		$on_scroll = ( 'on_scroll' === nice_get_option( 'nice_masonry_posts_load_method' ) );

		wp_enqueue_script( 'nice-posts-loader-scripts' );

		wp_localize_script( 'nice-posts-loader-scripts', 'postsLoader', array(
				'onScroll'     => $on_scroll,
				'isOriginLeft' => ! is_rtl(),
			)
		);

		wp_playlist_scripts( 'audio' );
		wp_playlist_scripts( 'video' );
	}
}
endif;
