<?php
/**
 * Smart by NiceThemes.
 *
 * This file includes functions to manage styles for the theme.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_theme_async_styles' ) ) :
add_filter( 'nice_async_styles', 'nice_theme_async_styles', 10, 2 );
/**
 * List of styles that can be loaded asynchronously.
 *
 * @since 1.0.0
 *
 * @param array $scripts
 * @param array $context
 *
 * @return array
 */
function nice_theme_async_styles( $scripts = array(), $context = array() ) {
	// Return early if asynchronous styles are not setup.
	if ( ! nice_load_async_styles() ) {
		return array();
	}

	$scripts = array_merge( $scripts, array(
			'nice-ie-styles',
			'nice-animate-css-styles',
			'nice-fancybox-styles',
			'nice-font-awesome-source',
		)
	);

	/**
	 * @hook nice_theme_async_styles
	 *
	 * Hook here to modify the list os asynchronous styles.
	 *
	 * @since 1.0.0
	 *
	 * Hooked here:
	 * @see nice_web_fonts_async_styles()
	 */
	return apply_filters( 'nice_theme_async_styles', $scripts, $context );
}
endif;

if ( ! function_exists( 'nice_styles' ) ) :
add_action( 'nice_register_styles', 'nice_styles', 0 ); // Use zero as priority to make sure these files are loaded first.
/**
 * Load CSS files.
 *
 * @uses wp_register_style()
 * @uses wp_enqueue_style()
 *
 * @since 1.0.0
 */
function nice_styles() {
	/**
	 * Load main styles.
	 *
	 * @since 1.0.0
	 */
	if ( apply_filters( 'nice_default_styles', true ) ) {
		wp_register_style( 'nice-styles', get_stylesheet_uri() );
		wp_enqueue_style( 'nice-styles' );
	}

	/**
	 * Load styles for Internet Explorer if necessary.
	 *
	 * @since 1.0.0
	 */
	global $is_IE;

	if ( apply_filters( 'nice_ie_styles', true ) && $is_IE ) {
		wp_register_style( 'nice-ie-styles', get_stylesheet_directory_uri() . '/ie.css' );
		wp_enqueue_style( 'nice-ie-styles' );
	}

	/**
	 * Load animate.css styles.
	 *
	 * @since 1.0.0
	 */
	if ( apply_filters( 'nice_animate_css_styles', true ) ) {
		wp_register_style( 'nice-animate-css-styles', nice_get_file_uri( 'includes/assets/css/animate.min.css' ), array(), '3.5.1' );
		wp_enqueue_style( 'nice-animate-css-styles' );
	}

	/**
	 * Load Fancybox styles.
	 *
	 * @since 1.0.0
	 */
	if ( apply_filters( 'nice_fancybox_styles', true ) ) {
		wp_register_style( 'nice-fancybox-styles', nice_get_file_uri( 'includes/assets/css/jquery.fancybox.css' ), array(), '2.1.5' );
		wp_enqueue_style( 'nice-fancybox-styles' );
	}

	/**
	 * Load FontAwesome.
	 *
	 * @since 1.0.0
	 */
	if ( apply_filters( 'nice_font_awesome_styles', true ) ) {
		wp_register_style( 'nice-font-awesome-source', nice_get_file_uri( 'includes/assets/css/font-awesome.min.css', array(), '4.7.0' ) );
		wp_enqueue_style( 'nice-font-awesome-source' );
	}
}
endif;

if ( ! function_exists( 'nice_multisite_signup_styles' ) ) :
add_action( 'before_signup_form', 'nice_multisite_signup_styles' );
/**
 * Adjust some styles for multisite signup form.
 *
 * @since 1.1
 */
function nice_multisite_signup_styles() {
	if ( !is_multisite() ) {
		return;
	}

	?>
	<style type="text/css">
		.mu_register {
			width: 100%;
		}
		.mu_register .mu_alert {
			padding: 15px;
			margin: 0 auto 1em;
		}
	</style>
	<?php
}
endif;
