<?php
/**
 * Smart by NiceThemes.
 *
 * Manage slides in home page template.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_doing_homepage_slider' ) ) :
/**
 * Check if we're running into the process that renders the homepage slider.
 *
 * @since  1.0.0
 *
 * @param  mixed|null|bool $new_status
 *
 * @return bool
 */
function nice_doing_homepage_slider( $new_status = null ) {
	static $status;

	if ( ! is_null( $new_status ) ) {
		$status = nice_bool( $new_status );
	}

	return $status;
}
endif;

if ( ! function_exists( 'nice_homepage_slides' ) ) :
/**
 * Add slides to home page.
 *
 * @since  1.0.0
 *
 * @param  bool              $echo Choose to display HTML or not.
 *
 * @return mixed|string|void
 */
function nice_homepage_slides( $echo = true ) {
	// Allow bypass.
	if ( $output = apply_filters( 'nice_homepage_slides', '' ) ) {
		return $output;
	}

	if ( ! $echo ) {
		ob_start();
	}

	if ( nice_bool( nice_get_option( 'nice_slider' ) ) ) {
		nice_doing_homepage_slider( true );

		get_template_part( 'template-parts/home/slider' );

		nice_doing_homepage_slider( false );
	}

	if ( ! $echo ) {
		$output = ob_get_contents();
		ob_end_clean();

		return $output;
	}

	return null;
}
endif;

if ( ! function_exists( 'nice_homepage_slides_flexslider_settings' ) ) :
add_filter( 'nice_flexslider_settings', 'nice_homepage_slides_flexslider_settings' );
/**
 * Set values for Flexslider implementation in homepage template.
 *
 * @since  1.0.0
 *
 * @param  array $settings Current Flexslider settings.
 *
 * @return array
 */
function nice_homepage_slides_flexslider_settings( array $settings = array() ) {
	if ( ! nice_is_homepage() ) {
		return $settings;
	}

	$settings = array_merge( $settings, array(
		'animation'      => nice_get_option( '_slider_animation', 'fade' ),
		'reverse'        => nice_bool_option( '_slider_reverse', false ),
		'randomize'      => nice_bool_option( '_slider_randomize', false ),
		'animationLoop'  => nice_bool_option( '_slider_animation_loop', false ),
		'animationSpeed' => nice_get_option( '_slider_animation_speed', 600 ),
		'slideshow'      => nice_bool_option( '_slider_slideshow', false ),
		'slideshowSpeed' => nice_get_option( '_slider_slideshow_speed', 7000 ),
		'pauseOnHover'   => nice_bool_option( '_slider_slideshow', false ) && nice_bool_option( '_slider_pause_on_hover', false ),
		'controlNav'     => nice_bool_option( '_slider_control_nav', true ),
		'directionNav'   => nice_bool_option( '_slider_direction_nav', true ),
		'smoothHeight'   => ( 'slide' === nice_get_option( '_slider_animation', 'fade' ) ),
	) );

	if ( $nav_style = nice_get_option( '_slider_direction_nav_style' ) ) {
		$settings['directionNavStyle'] = $nav_style;

		if ( $nav_shape = nice_get_option( '_slider_direction_nav_shape' ) ) {
			$settings['directionNavShape'] = $nav_shape;
		}

		if ( $nav_color = nice_get_option( '_slider_direction_nav_color' ) ) {
			$settings['directionNavColor'] = trim( nice_prefix_class( '', $nav_color ), '-' );
		}
	}

	return $settings;
}
endif;
