<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions that print out HTML.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_blog_post_content' ) ) :
add_action( 'nice_blog_post_content', 'nice_blog_post_content' );
/**
 * Print the content of the current post.
 *
 * @since 1.0.0
 */
function nice_blog_post_content() {
	if ( is_search() ) : ?>
		<div class="entry-summary">
			<?php the_excerpt(); ?>
		</div>

	<?php else : ?>
		<div class="post-content">
			<?php
				/**
				 * Display content or excerpt for the current post.
				 *
				 * Use add_filter( 'nice_blog_content', '__return_false' ) to show excerpt
				 * instead of post content.
				 *
				 * @since 1.0.0
				 */
				if ( apply_filters( 'nice_blog_content', true ) ) :
					the_content( esc_html__( 'Continue reading', 'smart' ) );
				else :
					nice_excerpt( 400 );
				endif;
			?>
		</div>
	<?php endif;
}
endif;

if ( ! function_exists( 'nice_pagenavi' ) ) :
/**
 * If `wp_pagenavi()` exists, it shows it. Else, it shows the < previous | next > links.
 *
 * @since 1.0.0
 */
function nice_pagenavi() {
	ob_start();

	if ( function_exists( 'wp_pagenavi' ) ) {
		wp_pagenavi();
	} else {
		// Define template and obtain default content.
		$pagenavi_tpl = '[next_posts] [prev_posts]';
		$navigation_content = $pagenavi_tpl;

		/**
		 * @hook nice_next_posts_text
		 *
		 * Hook in here to modify the default text for the "next" post link.
		 *
		 * @since 1.0.0
		 */
		$next_posts_text = apply_filters( 'nice_next_posts_text', esc_html__( 'Next', 'smart' ) );

		/**
		 * @hook nice_prev_posts_text
		 *
		 * Hook in here to modify the default text for the "previous" post link.
		 *
		 * @since 1.0.0
		 */
		$prev_posts_text = apply_filters( 'nice_prev_posts_text', esc_html__( 'Previous', 'smart' ) );

		// Obtain markup for next posts.
		$next_posts_content = '<div class="nav-next fl">' . get_next_posts_link( $next_posts_text ) . '</div>';

		/**
		 * @hook nice_next_posts_content
		 *
		 * Hook in here to modify the default content for the "next" post link.
		 *
		 * @since 1.0.0
		 */
		$next_posts_content = apply_filters( 'nice_next_posts_content', $next_posts_content );

		$navigation_content = str_replace( '[next_posts]', $next_posts_content, $navigation_content );

		// Obtain markup for previous posts.
		$prev_posts_content = '<div class="nav-prev fl">' . get_previous_posts_link( $prev_posts_text ) . '</div>';

		/**
		 * @hook nice_prev_posts_content
		 *
		 * Hook in here to modify the default content for the "previous" post link.
		 *
		 * @since 1.0.0
		 */
		$prev_posts_content = apply_filters( 'nice_prev_posts_content', $prev_posts_content );

		$navigation_content  = str_replace( '[prev_posts]', $prev_posts_content, $navigation_content );

		?>
		<?php if ( get_next_posts_link() || get_previous_posts_link() ) : ?>
			<nav class="nav-entries">
				<?php echo $navigation_content; // WPCS: XSS Ok. ?>
			</nav>
		<?php endif; ?>
	<?php }

	$output = ob_get_contents();
	ob_end_clean();

	/**
	 * @hook nice_pagenavi
	 *
	 * Hook in here to modify the markup for the blog navigation.
	 *
	 * @since 1.0.0
	 */
	$output = apply_filters( 'nice_pagenavi', $output );

	echo $output; // WPCS: XSS Ok.
}
endif;

if ( ! function_exists( 'nice_post_comments' ) ) :
/**
 * Post metadata, nicely displayed.
 *
 * @since 1.0.0
 *
 * @param array $args
 *
 * @return string
 */
function nice_post_comments( $args = array() ) {
	/**
	 * @hook nice_post_comments_default_args
	 *
	 * Hook here to change the default values to get the post comments.
	 *
	 * @since 1.2.0
	 */
	$defaults = apply_filters( 'nice_post_comments_default_args', array(
		'echo' => false,
		'link' => true,
		'text' => true,
		'icon' => '',
	) );

	// Process arguments.
	$args = wp_parse_args( $args, $defaults );

	/**
	 * @hook nice_post_comments_args
	 *
	 * Hook here to change the values to get the post comments.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_post_comments_args', $args );

	// Obtain comments number.
	$comments_number = get_comments_number(); // `get_comments_number()` returns only a numeric value

	// Initialize output.
	$post_comments = '';

	// Obtain output.
	if ( comments_open() ) {

		if ( $args['text'] ) {
			if ( ! $comments_number ) {
				$post_comments = esc_html__( 'No Comments', 'smart' );
			} else {

				$post_comments = sprintf(
					/* translators: 1: number of comments */
					_nx(
						'%1$s Comment',
						'%1$s Comments',
						$comments_number,
						'comments post meta',
						'smart'
					),
					number_format_i18n( $comments_number )
				);

			}
		} else {
			$post_comments = $comments_number;
		}

		if ( is_rtl() ) {
			$post_comments = $post_comments . $args['icon'];
		} else {
			$post_comments = $args['icon'] . $post_comments;
		}

		// Add link.
		if ( nice_bool( $args['link'] ) ) {
			$post_comments = '<a href="' . get_comments_link() . '">' . $post_comments . '</a>';
		}
	}

	/**
	 * @hook nice_post_comments_args
	 *
	 * Hook here to change the output of the post comments.
	 *
	 * @since 1.0.0
	 */
	$post_comments = apply_filters( 'nice_post_comments', $post_comments );

	if ( $args['echo'] ) {
		echo $post_comments; // WPCS: XSS Ok.
	}

	return $post_comments;
}
endif;

if ( ! function_exists( 'nice_post_meta' ) ) :
/**
 * Nicely display post meta data.
 *
 * The order of the post meta data elements can be changed by hooking into the `nice_post_meta_template`
 * filter. This filter, by default, returns `'[post_date] [post_author_posts_link] [post_categories] [post_edit]'`
 * which is the order of appearance of the post meta data elements, and can be modified to show
 * certain elements in different positions.
 *
 * @since  1.0.0
 *
 * @param  array  $args Arguments to display post meta data.
 * @return string
 */
function nice_post_meta( $args = array() ) {
	// Return early for page post type.
	if ( 'post' !== get_post_type( get_the_ID() ) ) {
		return null;
	}

	$post = get_post(); // Not a global, so WPCS: override ok.

	/**
	 * @hook nice_post_meta_default_args
	 *
	 * Hook here to modify the default arguments to get the post meta.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_post_meta_default_args', array(
		'echo'    => true,
		'before'  => '<section class="post-meta">',
		'after'   => '</section>',
		'context' => '',
	) );

	// Process arguments.
	$args = wp_parse_args( $args, $defaults );

	/**
	 * @hook nice_post_meta_args
	 *
	 * Hook here to modify the arguments to get the post meta.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_post_meta_args', $args );

	/**
	 * @hook nice_before_post_meta
	 *
	 * Let plugins and child themes hook in here right before the post meta displays.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_before_post_meta', $args );

	// Initialize output.
	$output = '';

	$output .= $args['before'] . "\n";

	// The template.
	$nice_post_meta_tpl = '[post_author_posts_link] [post_date] [post_categories] [post_comments] [post_edit]';

	/**
	 * @hook nice_post_meta_template
	 *
	 * Hook here to modify the template for the post meta.
	 *
	 * @since 1.0.0
	 */
	$nice_post_meta_tpl = apply_filters( 'nice_post_meta_template', $nice_post_meta_tpl, $args );

	$title = get_the_title();
	$date = get_the_time( get_option( 'date_format' ) );

	if ( ! $title && ! is_single() ) {
		$date = '<a href="' . get_the_permalink() . '">' . $date . '</a>';
	}

	// Obtain meta data.
	$post_date       = '<time class="entry-date time" datetime="%1$s">%2$s</time>';
	$post_date       = sprintf( $post_date, esc_attr( get_the_date( 'c' ) ) , $date );

	$post_author_id  = (int) $post->post_author;
	$post_author     = '<section class="author entry-author">' . sprintf( esc_html__( 'by %s', 'smart' ), '<a href="' . get_author_posts_url( $post_author_id ) . '">' . get_the_author_meta( 'display_name', $post_author_id ) . '</a>' ) . '</section>';
	$post_categories = '<section class="categories entry-categories">' . sprintf( esc_html__( 'Posted in %s', 'smart' ), nice_post_categories( $post, false ) ) . '</section>';
	$edit_post_link  = get_edit_post_link();
	$edit_post_link  = $edit_post_link ? '<section class="edit"><a class="post-edit-link" title="' . esc_attr__( 'Edit', 'smart' ) . '" href="' . $edit_post_link . '"><i class="fa fa-pencil" aria-hidden="true"></i></a></section>' : '';
	$post_comments   = nice_post_comments( array( 'echo' => false ) );
	$post_comments   = $post_comments ?  '<section class="comments entry-comments">' . $post_comments . '</section>' : '';

	/**
	 * @hook nice_post_meta_date
	 *
	 * Hook here to modify the date in post meta.
	 *
	 * @since 1.0.0
	 */
	$post_date = apply_filters( 'nice_post_meta_date', $post_date, $args['context'] );

	/**
	 * @hook nice_post_meta_author
	 *
	 * Hook here to modify the author in post meta.
	 *
	 * @since 1.0.0
	 */
	$post_author = apply_filters( 'nice_post_meta_author', $post_author, $args['context'] );

	/**
	 * @hook nice_post_meta_categories
	 *
	 * Hook here to modify the categories in post meta.
	 *
	 * @since 1.0.0
	 */
	$post_categories = apply_filters( 'nice_post_meta_categories', $post_categories, $args['context'] );

	/**
	 * @hook nice_post_meta_comments
	 *
	 * Hook here to modify the comments in post meta.
	 *
	 * @since 1.0.0
	 */
	$post_comments = apply_filters( 'nice_post_meta_comments', $post_comments, $args['context'] );

	/**
	 * @hook nice_post_meta_edit
	 *
	 * Hook here to modify the "edit post" link in post meta.
	 *
	 * @since 1.0.0
	 */
	$post_edit = apply_filters( 'nice_post_meta_edit', $edit_post_link, $args['context'] );

	// Process replacements.
	$nice_post_meta_tpl = str_replace( '[post_date]', $post_date, $nice_post_meta_tpl );
	$nice_post_meta_tpl = str_replace( '[post_author_posts_link]', $post_author, $nice_post_meta_tpl );
	$nice_post_meta_tpl = str_replace( '[post_categories]', $post_categories, $nice_post_meta_tpl );
	$nice_post_meta_tpl = str_replace( '[post_comments]', $post_comments, $nice_post_meta_tpl );
	$nice_post_meta_tpl = str_replace( '[post_edit]', $post_edit, $nice_post_meta_tpl );

	$output .= $nice_post_meta_tpl;

	$output .= $args['after'] . "\n";

	/**
	 * @hook nice_post_meta
	 *
	 * Hook here to modify the HTML of the post meta.
	 *
	 * @since 1.0.0
	 */
	$output = apply_filters( 'nice_post_meta', $output, $args );

	// Print output if required.
	if ( $args['echo'] ) {
		echo $output; // WPCS: XSS Ok.
	}

	/**
	 * @hook nice_post_meta_after
	 *
	 * Let plugins and child themes hook in here right after the post meta displays.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_after_post_meta', $args );

	return $output;
}
endif;


if ( ! function_exists( 'nice_post_format_icon_class' ) ) :
/**
 * Display an HTML class to show an icon depending on the current post format.
 *
 * @note  This function doesn't work outside The Loop.
 *
 * @since 1.0.0
 */
function nice_post_format_icon_class() {
	echo nice_get_post_format_icon_class(); // WPCS: XSS Ok.
}
endif;

if ( ! function_exists( 'nice_get_post_format_icon_class' ) ) :
/**
 * Obtain an HTML class to show an icon depending on the current post format.
 *
 * @note   This function doesn't work outside The Loop.
 *
 * @since  1.0.0
 *
 * @return string
 */
function nice_get_post_format_icon_class() {
	// Allow by-passing.
	/**
	 * @hook nice_post_format_icon_class_before
	 *
	 * Hook in here to by-pass the output of the `nice_get_post_format_icon_class()`
	 * function.
	 *
	 * @see nice_get_post_format_icon_class()
	 *
	 * @since 1.0.0
	 */
	if ( $icon_class = apply_filters( 'nice_post_format_icon_class_before', '' ) ) {
		return $icon_class;
	}

	$post_format = get_post_format();

	switch ( $post_format ) {
		case 'video':
			$icon_class = 'icon-video fa fa-film';
			break;

		case 'gallery':
			$icon_class = 'icon-gallery fa fa-image';
			break;

		case 'image':
			$icon_class = 'icon-image fa fa-image';
			break;

		case 'audio':
			$icon_class = 'icon-volume fa fa-volume-up';
			break;

		case 'link':
			$icon_class = 'icon-link fa fa-link';
			break;

		case 'quote':
			$icon_class = 'icon-quote fa fa-quote-right';
			break;

		default:
			$icon_class = 'icon-standard fa fa-file-o';
			break;
	}

	/**
	 * @hook nice_get_post_format_icon_class
	 *
	 * Hook in here to modify the output of the post format icon class.
	 *
	 * @since 1.0.0
	 */
	$icon_class = apply_filters( 'nice_get_post_format_icon_class', $icon_class );

	return $icon_class;
}
endif;


if ( ! function_exists( 'nice_post_footer_meta' ) ) :
/**
 * Nicely display post meta data in the footer.
 *
 * The order of the post meta data elements can be changed by hooking into the `nice_post_footer_meta_template`
 * filter. This filter, by default, returns `'[post_author_posts_link] [post_date] [post_comments] [post_tags]'`
 * which is the order of appearance of the post meta data elements, and can be modified to show
 * certain elements in different positions.
 *
 * @since  1.0.0
 *
 * @param  array  $args Arguments to display post meta data.
 * @return string
 */
function nice_post_footer_meta( $args = array() ) {
	// Get default values.
	/**
	 * @hook nice_post_footer_meta_default_args
	 *
	 * Hook in here to modify the default arguments for the post footer meta.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_post_footer_meta_default_args', array(
		'echo'    => true,
		'before'  => '<footer class="entry-footer">',
		'after'   => '</footer>',
		'context' => '',
	) );

	// Process arguments.
	$args = wp_parse_args( $args, $defaults );

	/**
	 * @hook nice_post_footer_meta_args
	 *
	 * Hook in here to modify the arguments for the post footer meta.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_post_footer_meta_args', $args );

	/**
	 * @hook nice_post_footer_meta_before
	 *
	 * Do something right before the post meta displays.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_post_footer_meta_before', $args );

	// Initialize output.
	$output = '';

	// The template.
	$nice_post_footer_meta_tpl = '[post_format] [post_author_posts_link] [post_date] [post_comments] [post_tags]';

	/**
	 * @hook nice_post_footer_meta_template
	 *
	 * Modify the template for post footer meta.
	 *
	 * @since 1.0.0
	 */
	$nice_post_footer_meta_tpl = apply_filters( 'nice_post_footer_meta_template', $nice_post_footer_meta_tpl, $args );

	// Obtain format output.
	$post_format               = '<section class="post-format-wrapper"><i class="post-format ' . nice_get_post_format_icon_class() . '"></i></section>';

	/**
	 * @hook nice_post_footer_meta_post_format
	 *
	 * Modify the post footer meta for a given post format.
	 *
	 * @since 1.0.0
	 */
	$post_format = apply_filters( 'nice_post_footer_meta_post_format', $post_format );

	$nice_post_footer_meta_tpl = str_replace( '[post_format]', $post_format, $nice_post_footer_meta_tpl );

	// Author.
	$post_author               = '<section class="author"><i class="icon-author fa fa-file-o"></i> ' . sprintf( esc_html__( 'Words by %s', 'smart' ), '<a href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ) . '">' . get_the_author_meta( 'display_name' ) . '</a>' ) . '</section>';

	/**
	 * @hook nice_post_footer_meta_author
	 *
	 * Modify the author information in post footer meta.
	 *
	 * @since 1.0.0
	 */
	$post_author = apply_filters( 'nice_post_footer_meta_author', $post_author );

	$nice_post_footer_meta_tpl = str_replace( '[post_author_posts_link]', $post_author, $nice_post_footer_meta_tpl );

	// Date.
	$post_date = '<section class="time"><i class="icon-time fa fa-clock-o"></i> ' . get_the_time( get_option( 'date_format' ) ) . '</section>';

	/**
	 * @hook nice_post_footer_meta_date
	 *
	 * Modify the date information in post footer meta.
	 *
	 * @since 1.0.0
	 */
	$post_date = apply_filters( 'nice_post_footer_meta_date', $post_date );

	$nice_post_footer_meta_tpl = str_replace( '[post_date]', $post_date, $nice_post_footer_meta_tpl );

	// Comments.
	$post_comments = ( is_page() && ! comments_open() ) ? '' : nice_comments_link_section( get_the_ID(), array( 'text' => get_comments_number_text( '0', '1', '%' ) ) );

	/**
	 * @hook nice_post_footer_meta_comments
	 *
	 * Modify the comments information in post footer meta.
	 *
	 * @since 1.0.0
	 */
	$post_comments = apply_filters( 'nice_post_footer_meta_comments', $post_comments );

	$nice_post_footer_meta_tpl = str_replace( '[post_comments]', $post_comments, $nice_post_footer_meta_tpl );

	// Tags
	$post_tags = '<section class="tags"><i class="icon-tags fa fa-tag"></i>' . nice_post_tags( get_post() ) . '</section>';

	/**
	 * @hook nice_post_footer_meta_tags
	 *
	 * Modify the list of tags in post footer meta.
	 *
	 * @since 1.0.0
	 */
	$post_tags = apply_filters( 'nice_post_footer_meta_tags', $post_tags );

	$nice_post_footer_meta_tpl = str_replace( '[post_tags]', $post_tags, $nice_post_footer_meta_tpl );

	/**
	 * @hook nice_post_footer_meta
	 *
	 * Modify the output of post footer meta before wrapping it inside a
	 * container.
	 *
	 * @since 1.0.0
	 */
	$output .= apply_filters( 'nice_post_footer_meta', $nice_post_footer_meta_tpl );

	if ( $output ) {
		$output = $args['before'] . "\n" . $output . $args['after'] . "\n";
	}

	/**
	 * @hook nice_post_footer_meta_html
	 *
	 * Modify the full output of post footer meta.
	 *
	 * @since 1.0.0
	 */
	$output = apply_filters( 'nice_post_footer_meta_html', $output, $args );

	// Print output if required.
	if ( $args['echo'] ) {
		echo $output; // WPCS: XSS Ok.
	}

	/**
	 * @hook nice_post_footer_meta_after
	 *
	 * Do something right after printing the output of post footer meta.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_post_footer_meta_after', $args );

	return $output;
}
endif;


if ( ! function_exists( 'nice_post_meta_masonry' ) ) :
/**
 * Post metadata for the masonry template, nicely displayed.
 *
 * @since 1.0.0
 */
function nice_post_meta_masonry() {
	ob_start();

	?>
	<p class="post-meta">
		<span class="post-author"><i class="fa fa-user"></i> <?php the_author_posts_link(); ?></span>
		<span class="post-date"><i class="fa fa-clock-o"></i><?php the_time( 'M j, Y' ); ?></span>
		<span class="post-comments"><i class="fa fa-comment-o"></i> <?php comments_popup_link( '0', '1', '%' ); ?></span>
		<?php edit_post_link( esc_html__( 'Edit', 'smart' ), '<span class="edit"><i class="fa fa-pencil"></i>', '</span>' ); ?>
	</p>
	<?php
	$output = ob_get_contents();
	ob_end_clean();

	/**
	 * @hook nice_post_meta_masonry
	 *
	 * Modify the post meta in Masonry Blog view.
	 *
	 * @since 1.0.0
	 */
	$output = apply_filters( 'nice_post_meta_masonry', $output );

	return $output;
}
endif;

if ( ! function_exists( 'nice_post_author' ) ) :
add_action( 'nice_post_author', 'nice_post_author', 10 );
/**
 * Post author info, nicely displayed.
 *
 * @since 1.0.0
 *
 * @param array $args Arguments to display post author.
 */
function nice_post_author( $args = array() ) {
	// Return early in non-post views.
	if ( ! is_single() ) {
		return;
	}

	$display = nice_bool( nice_get_option( 'nice_post_author' ) );

	// Return early if the post doesn't have to be displayed.
	/**
	 * @hook nice_post_author_display
	 *
	 * Set to false if you don't want the post author to be displayed.
	 *
	 * @since 1.0.0
	 */
	if ( ! apply_filters( 'nice_post_author_display', $display ) ) {
		return;
	}

	// Return early if we don't have an author's description.
	if ( ! $description = get_the_author_meta( 'description' ) ) {
		return;
	}

	$author = get_the_author();

	if ( is_rtl() ) {
		$link = '<span class="meta-nav">&larr;</span> ' . sprintf( esc_html__( 'View all posts by %s', 'smart' ), $author );
	} else {
		$link = sprintf( esc_html__( 'View all posts by %s', 'smart' ), $author . ' <span class="meta-nav">&rarr;</span>' );
	}

	/**
	 * @hook nice_post_author_default_args
	 *
	 * Modify default arguments to obtain the post author's data.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_post_author_default_args', array(
		'size'  => 65,
		'title' => sprintf( esc_attr__( 'About %s', 'smart' ), $author ),
		'link'  => $link,
	) );

	// Process arguments.
	$args = wp_parse_args( $args, $defaults );

	/**
	 * @hook nice_post_author_args
	 *
	 * Modify arguments to obtain the post author's data.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_post_author_args', $args );
	?>
		<!-- BEGIN .post-author -->
		<div id="post-author" class="clearfix">

			<div class="profile-image thumb">
				<?php echo get_avatar( get_the_author_meta( 'ID' ), $args['size'] ); ?>
			</div>

			<!-- BEGIN .profile-content -->
			<div class="profile-content">

				<h4 class="title"><?php echo esc_attr( $args['title'] ); ?></h4>

				<?php echo $description; // WPCS: XSS ok. ?>

				<div class="profile-link">
					<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo $args['link']; // WPCS: XSS Ok. ?></a>
				</div>

			</div><!-- END .profile-content -->

		</div><!-- END #post-author -->
	<?php
}
endif;

if ( ! function_exists( 'nice_post_thumbnail' ) ) :
/**
 * Nicely display the post thumbnail.
 *
 * The image is obtained by default using the `$content_width` size.
 *
 * @since 1.0.0
 *
 * @param array $args Arguments to display the thumbnail.
 */
function nice_post_thumbnail( $args = array() ) {
	// Return early if we don't need the thumbnail here.
	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
		return;
	}

	/**
	 * @hook nice_post_thumbnail_display
	 *
	 * Set to false if you don't want to display the post thumbnail.
	 *
	 * @since 1.0.0
	 */
	if ( ! apply_filters( 'nice_post_thumbnail_display', true, $args ) ) {
		return;
	}

	/**
	 * @hook nice_post_thumbnail_default_args
	 *
	 * Hook in here to modify the default values for the post thumbnail.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_post_thumbnail_default_args', array(
		'size'    => nice_has_sidebar() ? 'large' : 'nice-extra-large',
		'class'   => 'wp-post-image',
		'before'  => '<figure class="featured-image">',
		'after'   => '</figure>',
		'link'    => '',
		'overlay' => true,
	) );

	// Process arguments.
	$args = wp_parse_args( $args, $defaults );
	/**
	 * @hook nice_post_thumbnail_args
	 *
	 * Hook in here to modify the arguments to generate the post thumbnail.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_post_thumbnail_args', $args );

	// Process link.
	$link = ! empty( $args['link'] ) ? $args['link'] : get_the_permalink();

	/**
	 * @hook nice_post_thumbnail_before
	 *
	 * Do something before the post thumbnail gets printed.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_post_thumbnail_before', $args );

	$image_wrapper_start = '';
	$image_wrapper_end   = '';

	if ( ! is_singular() || ! empty( $args['link'] ) ) {
		$image_wrapper_start = '<a class="item-caption-permalink" href="' . esc_url( $link ) . '"';

		if ( empty( $args['link'] ) ) {
			$image_wrapper_start .= ' title="' . sprintf( esc_attr__( 'Permanent Link to %s', 'smart' ), esc_attr( get_the_title() ) ) . '"';
		} else {
			$image_wrapper_start .= ' target="_blank"';
		}

		$image_wrapper_start .= '>';

		$image_wrapper_end = '</a>';
	}

	ob_start();

	echo $args['before'], $image_wrapper_start; // WPCS: XSS ok.

	if ( is_singular() ) :
		nice_image( $args );
	else : ?>
		<?php if ( ! empty( $args['overlay'] ) ) : ?>
			<div class="overlay"></div>
		<?php endif; ?>

		<?php nice_image( $args ); ?>
	<?php
	endif;

	echo $image_wrapper_end, $args['after']; // WPCS: XSS ok.

	$output = ob_get_contents();
	ob_end_clean();

	/**
	 * @hook nice_post_thumbnail
	 *
	 * Modify the full output of a post thumbnail.
	 *
	 * @since 1.0.0
	 */
	$output = apply_filters( 'nice_post_thumbnail', $output );

	echo $output; // WPCS: XSS ok.

	/**
	 * @hook nice_post_thumbnail_after
	 *
	 * Do something after the post thumbnail gets printed.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_post_thumbnail_after', $args );
}
endif;

if ( ! function_exists( 'nice_archive_title' ) ) :
/**
 * Print the title of an archive page.
 *
 * @since 1.0.0
 */
function nice_archive_title() {
	echo nice_get_archive_title(); // WPCS: XSS ok.
}
endif;

if ( ! function_exists( 'nice_heading_class' ) ) :
/**
 * Print a conditional heading block.
 *
 * @since  1.0.0
 *
 * @param  bool $echo Whether or not to print the obtained HTML.
 *
 * @return string
 */
function nice_heading_class( $echo = true ) {
	$output = '';

	/**
	 * @hook nice_heading_class
	 *
	 * Hook in here to modify the classes that are passed to the post heading.
	 *
	 * @since 1.0.0
	 */
	if ( $classes = apply_filters( 'nice_heading_class', array() ) ) {
		$output = 'class="' . join( ' ', $classes ) . '"';
	}

	if ( $echo ) {
		echo $output; // WPCS: XSS ok.
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_wp_title' ) ) :
add_filter( 'wp_title', 'nice_wp_title' );
/**
 * Customize the page title.
 *
 * Hook origin:
 * @see wp_title()
 *
 * @since  1.0.0
 *
 * @param string $title Page title.
 *
 * @return string
 */
function nice_wp_title( $title ) {
	return $title . get_bloginfo( 'name' );
}
endif;

if ( ! function_exists( 'nice_page_title' ) ) :
add_action( 'nice_heading_title', 'nice_page_title' );
/**
 * Obtain page title for heading.
 *
 * @since  1.0.0
 *
 * @param  array $args
 *
 * @return string
 */
function nice_page_title( $args = array() ) {
	/**
	 * @hook nice_page_title_default_args
	 *
	 * Hook in here to modify the default arguments to generate the post title.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_page_title_default_args', array(
			'echo'   => true,
			'before' => '<h1 class="page-title">',
			'after'  => '</h1>',
			'title'  => get_the_title(),
		)
	);

	$args = wp_parse_args( $args, $defaults );

	/**
	 * @hook nice_page_title_args
	 *
	 * Hook in here to modify the arguments to generate the post title.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_page_title_args', $args );

	$title = $args['before'] . $args['title'] . $args['after'];

	/**
	 * @hook nice_page_title
	 *
	 * Modify the full output of a page title.
	 *
	 * @since 1.0.0
	 */
	$output = apply_filters( 'nice_page_title', $title, $args );

	if ( $args['echo'] ) {
		echo $output; // WPCS: XSS Ok.
	}

	return $output;

}
endif;

if ( ! function_exists( 'nice_comments_link_section' ) ) :
/**
 * Display the number of comments for a given post besides a comments icon.
 *
 * If FontAwesome is not active, then the icon won't be displayed.
 *
 * @since  1.0.0
 *
 * @param  int    $post_id ID of the post.
 * @param  array  $args    Arguments to construct the link.
 * @return string
 */
function nice_comments_link_section( $post_id = 0, $args = array() ) {
	if ( ! $post_id ) {
		global $post;

		$post_id = $post->ID;
	}

	/**
	 * @hook nice_comments_link_icon_default_args
	 *
	 * Hook in here to modify the default arguments to print the "comments"
	 * section of a post.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_comments_link_icon_default_args', array(
			'echo'       => false,
			'before'     => '<section class="comment-count">',
			'after'      => '</section>',
			'text'       => get_comments_number_text( '0 Comments', '1 Comment', '% Comments' ),
			'icon_class' => 'icon-comment fa fa-comment-o',
		)
	);

	$args = wp_parse_args( $args, $defaults );

	/**
	 * @hook nice_comments_link_icon_default_args
	 *
	 * Hook in here to modify the arguments to print the "comments"section of a
	 * post.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_comments_link_icon_args', $args );

	$output = $args['before'] . '<a href="' . get_comments_link( $post_id ) . '"><i class="' . esc_attr( $args['icon_class'] ) . '"></i> <span>' . $args['text'] . '</span></a>' . $args['after'];

	if ( $args['echo'] ) {
		echo $output; // WPCS: XSS Ok.
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_video' ) ) :
/**
 * Wrapper for `nice_embed()`.
 *
 * @since  1.0.0
 *
 * @param  array $args Arguments to construct the output.
 *
 * @return string
 */
function nice_video( array $args = array() ) {
	/**
	 * @hook nice_video
	 *
	 * By-pass the output of the `nice_video()` function.
	 *
	 * @see nice_video()
	 *
	 * @since 1.0.0
	 */
	if ( $output = apply_filters( 'nice_video', '' ) ) {
		return $output;
	}

	/**
	 * @hook nice_video_default_args
	 *
	 * Modify the default arguments to generate the output of a post's video.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_video_default_args', array(
			'echo'  => true,
			'class' => 'featured-video',
		)
	);
	$args = wp_parse_args( $args, $defaults );

	/**
	 * @hook nice_video_args
	 *
	 * Modify the arguments to generate the output of a post's video.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_video_args', $args );

	// Obtain embedded code.
	$output = nice_embed( wp_parse_args( array( 'echo' => false ), $args ) );

	if ( $args['echo'] ) {
		echo $output; // WPCS: XSS Ok.
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_playlist' ) ) :
/**
 * Print a playlist for a post.
 *
 * @since  1.0.0
 *
 * @uses   wp_playlist_shortcode()
 * @uses   nice_get_post_playlist()
 *
 * @param  array $args Arguments to construct output.
 *
 * @return string
 */
function nice_playlist( array $args = array() ) {
	/**
	 * @hook nice_playlist
	 *
	 * By-pass the output of the `nice_playlist()` function.
	 *
	 * @see nice_playlist()
	 *
	 * @since 1.0.0
	 */
	if ( $output = apply_filters( 'nice_playlist', '' ) ) {
		return $output;
	}

	$media = nice_get_post_playlist( get_post(), false );

	$args = array_merge( $args, $media );

	/**
	 * @hook nice_playlist_default_args
	 *
	 * Modify the default arguments to generate the output of a post's playlist.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_playlist_default_args', array(
			'echo'   => true,
			'before' => '<div class="featured-audio">',
			'after'  => '</div>',
		)
	);

	$args = wp_parse_args( $args, $defaults );

	/**
	 * @hook nice_playlist_args
	 *
	 * Modify the arguments to generate the output of a post's playlist.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_playlist_args', $args );

	if ( ! empty( $media ) ) {
		unset( $args['is_audio'] );

		if ( $media['is_audio'] ) {
			$output = wp_audio_shortcode( $args );
		} else {
			$output = wp_playlist_shortcode( $args );
		}
	}

	if ( $output ) {
		$output = $args['before'] . $output . $args['after'];
	}

	if ( $args['echo'] ) {
		echo $output; // WPCS: XSS Ok.
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_post_link' ) ) :
/**
 * Display post link.
 *
 * @since 1.0.0
 *
 * @uses  nice_get_post_link()
 *
 * @param int $post_id ID of the post to get link from.
 */
function nice_post_link( $post_id = null ) {
	echo nice_get_post_link( $post_id ); // WPCS: XSS Ok.
}
endif;

if ( ! function_exists( 'nice_link' ) ) :
/**
 * Print the formatted link for a post with the "link" post format.
 *
 * @since 1.0.0
 */
function nice_link() {
?>
	<section class="post-link">
		<p>
			<a target="_blank" href="<?php nice_post_link(); ?>"><?php esc_html_e( 'Visit Link', 'smart' ); ?></a>
		</p>
	</section>
<?php
}
endif;

if ( ! function_exists( 'nice_post_quote' ) ) :
/**
 * Display post quote.
 *
 * @since 1.0.0
 *
 * @uses  nice_get_post_quote()
 *
 * @param int $post_id ID of the post to get quote from.
 */
function nice_post_quote( $post_id = null ) {
	echo nice_get_post_quote( $post_id ); // WPCS: XSS Ok.
}
endif;

if ( ! function_exists( 'nice_quote' ) ) :
/**
 * Print the formatted quote for a post with "quote" post format.
 *
 * @since 1.0.0
 */
function nice_quote() {
?>
	<!-- BEGIN .entry-quote -->
	<section class="entry-quote">

		<blockquote class="quote">
			<?php nice_post_quote(); ?>

			<?php if ( nice_get_post_quote_author() ) : ?>
				<footer class="quote-author"><?php nice_post_quote_author(); ?></footer>
			<?php endif; ?>

		</blockquote>

	</section><!-- END .entry-quote -->
<?php
}
endif;

if ( ! function_exists( 'nice_post_quote_author' ) ) :
/**
 * Display post quote author.
 *
 * @since 1.0.0
 *
 * @uses  nice_get_post_quote_author()
 *
 * @param int $post_id ID of the post to get quote author from.
 */
function nice_post_quote_author( $post_id = null ) {
	echo nice_get_post_quote_author( $post_id ); // WPCS: XSS Ok.
}
endif;

if ( ! function_exists( 'nice_gallery' ) ) :
/**
 * Create a the gallery.
 *
 * @since  1.0.0
 *
 * @param  array $args
 * @return string
 */
function nice_gallery( $args = array() ) {
	/**
	 * @hook nice_gallery_default_args
	 *
	 * Modify the default arguments to obtain the output of a post gallery.
	 *
	 * @since 1.0.0
	 */
	$defaults = apply_filters( 'nice_gallery_default_args',
		array(
			'ids'           => null,
			'columns'       => 4,
			'rows'          => false,
			'numberposts'   => -1,
			'orderby'       => 'menu_order',
			'echo'          => true,
			'order'         => 'ASC',
			'size'          => 'medium_large',
			'width'         => 480,
			'height'        => 480,
			'before'        => '<div class="nice-gallery grid">' . "\n",
			'after'         => '</div>',
			'item_template' => '<div class="%%CLASS%%"><figure class="thumb">%%IMAGE%%</figure></div>',
		)
	);

	// Process gallery arguments.
	$args = wp_parse_args( $args, $defaults );

	/**
	 * @hook nice_gallery_args
	 *
	 * Modify the arguments to obtain the output of a post gallery.
	 *
	 * @since 1.0.0
	 */
	$args = apply_filters( 'nice_gallery_args', $args );

	/**
	 * @hook nice_gallery_before
	 *
	 * Do something right before the post gallery is printed.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_gallery_before', $args );

	// Initialize HTML output.
	$output = '';

	if ( ! empty( $args['ids'] ) ) {
		// Get the ids parameter containing the list of images and set the list in an array.
		$ids            = array();
		$attachment_ids = explode( ',', $args['ids'] );
		$ids            = array_merge( $ids, $attachment_ids );
		$attachments    = array_flip( $ids );
	} else {
		// Get the images from the media uploaded to the page/post/CPT.
		$attachments = get_children(
			array(
				'post_parent'    => get_the_ID(),
				'post_type'      => 'attachment',
				'post_mime_type' => 'image',
				'order'          => $args['order'],
				'numberposts'    => $args['numberposts'],
				'orderby'        => $args['orderby'],
			)
		);

		if ( empty( $attachments ) ) {
			// If the gallery shortcode is used, we get the images from there.
			$attachments = nice_attachments_from_gallery();
		}
	}

	if ( ! empty( $attachments ) && ( count( $attachments ) > 1 ) ) {
		// Begin parsing the images, creating the gallery.
		$output .= $args['before'] . "\n";

		// The template for each gallery item.
		$gallery_item_template = $args['item_template'];

		/**
		 * @hook nice_gallery_item_template
		 *
		 * Modify the template for gallery items.
		 *
		 * @since 1.0.0
		 */
		$gallery_item_template = apply_filters( 'nice_gallery_item_template', $gallery_item_template, $args );

		// Initialize loop counter.
		$loop = 0;

		foreach ( $attachments as $att_id => $attachment ) {
			$loop ++;

			$template = $gallery_item_template;

			$class = 'item';

			if ( $args['columns'] ) {
				$class = ' columns-' . esc_attr( intval( $args['columns'] ) );
			}

			if ( $args['columns'] && ( 0 === ($loop % $args['columns'] ) ) ) {
				$class .= ' last';
			}

			if ( $args['columns'] && ( 0 === ( ( $loop - 1 ) % $args['columns'] ) ) ) {
				$class .= ' first';

				if ( $args['rows'] ) {
					$output .= '<div class="row">' . "\n";
				}
			}

			$template = str_replace( '%%CLASS%%', $class, $template );

			$image = '<a rel="group" data-fancybox="group" href="' . wp_get_attachment_url( $att_id ) . '" title="' . get_the_title( $att_id ) . '" data-caption="' . get_the_title( $att_id ) . '">';

			/**
			 * Support native image sizes, if any was specified.
			 */
			$image_size = 'medium';

			if ( $args['size'] ) {
				$image_size = esc_attr( $args['size'] );
			}

			/**
			 * @hook nice_gallery_image_size
			 *
			 * Modify the image size of gallery items.
			 *
			 * @since 1.0.0
			 */
			$image_size = apply_filters( 'nice_gallery_image_size', $image_size );

			if ( function_exists( 'nice_image' ) ) {
				$image .= nice_image( array(
						'size' => $image_size,
						'id'   => $att_id,
						'echo' => false,
					)
				);
			} else {
				$image .= get_the_post_thumbnail( $att_id, $image_size );
			}

			$image .= '</a>';

			$template = str_replace( '%%IMAGE%%', $image, $template );

			/**
			 * @hook nice_gallery_template
			 *
			 * Modify the template of a post's gallery.
			 *
			 * @since 1.0.0
			 */
			$template = apply_filters( 'nice_gallery_template', $template );

			$output .= $template;

			if ( $args['columns'] && ( 0 === ( $loop % $args['columns'] ) ) && $args['rows'] ) {
				$output .= '</div>';
			}
		}

		if ( $args['columns'] && ( 0 !== ( $loop % $args['columns'] ) ) && $args['rows'] ) {
			$output .= '</div>';
		}

		$output .= $args['after'] . "\n";
	} else {
		$output .= '<div class="gallery-empty">' . esc_html__( 'There are no images for this gallery', 'smart' ) . '</div>';
	}

	/**
	 * @hook nice_gallery_html
	 *
	 * Modify the full output of a post's gallery.
	 *
	 * @since 1.0.0
	 */
	$output = apply_filters( 'nice_gallery_html', $output, $attachments, $args );

	if ( $args['echo'] ) {
		echo $output; // WPCS: XSS Ok.
	}

	/**
	 * @hook nice_gallery_after
	 *
	 * Do something right after the post gallery is printed.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_gallery_after', $args );

	return $output;
}
endif;

if ( ! function_exists( 'nice_header_properties' ) ) :
/**
 * Display additional properties for #header element.
 *
 * @since 1.0.0
 *
 * @param array $args List of properties and values for HTML tag.
 */
function nice_header_properties( array $args = array() ) {
	$output = '';

	$properties = array(
		'class' => nice_header_class( array(), false ),
		'data'  => nice_header_data( array(), false ),
	);

	if ( ! empty( $args ) ) {
		$properties = array_merge( $properties, $args );
	}

	/**
	 * @hook nice_header_properties
	 *
	 * Modify header properties by hooking in here.
	 *
	 * @since 1.0.0
	 */
	$properties = apply_filters( 'nice_header_properties', $properties );

	if ( is_array( $properties ) && ! empty( $properties ) ) {
		$output = join( ' ', $properties );
	}

	echo $output; // WPCS: XSS Ok.
}
endif;

if ( ! function_exists( 'nice_term_description' ) ) :
/**
 * Display an optional term description for categories and tags.
 *
 * @uses  term_description()
 *
 * @since 1.0.0
 */
function nice_term_description() {
	$term_description = term_description();

	if ( ! empty( $term_description ) ) {
		echo '<div class="taxonomy-description">' . $term_description . '</div>'; // WPCS: XSS Ok.
	}
}
endif;

if ( ! function_exists( 'nice_link_pages' ) ) :
/**
 * Display page links for paginated posts.
 *
 * @uses  wp_link_pages()
 *
 * @since 1.0.0
 */
function nice_link_pages() {
	global $page, $numpages;

	/**
	 * Initialize previous and next page links.
	 */
	$previous_link = '';
	$next_link     = '';

	/**
	 * Create link to next page.
	 */
	if ( $page > 1 ) {
		$previous_link = '<li class="prev">' . _wp_link_page( ( $page - 1 ) ) . '&larr;</a></li>';
	}

	/**
	 * Create link to previous page.
	 */
	if ( $page !== $numpages ) {
		$next_link = '<li class="next">' . _wp_link_page( ( $page + 1 ) ) . '&rarr;</a></li>';
	}

	/**
	 * Print pagination.
	 */
	wp_link_pages( array(
			'before'    => '<nav class="post-pagination paged-navigation"><ul class="page-numbers">' . $previous_link . '<li>',
			'after'     => '</li>' . $next_link . '</ul></nav>',
			'separator' => '</li><li>',
		)
	);
}
endif;
