<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to customize the blog and posts in a blog context.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_masonry_post_meta_template' ) ) :
add_filter( 'nice_post_meta_template', 'nice_masonry_post_meta_template', 10, 2 );
/**
 * Filter the default post meta template when viewing Masonry blog.
 *
 * @since 1.0.0
 *
 * @param  string $template Default template.
 * @param  array  $args     Arguments to build post meta block.
 *
 * @return string
 */
function nice_masonry_post_meta_template( $template = '', $args = array() ) {
	if ( ! empty( $args['context'] ) && 'masonry-blog' === $args['context'] ) {
		$template = '[post_date]';
	}

	return $template;
}
endif;

if ( ! function_exists( 'nice_masonry_post_footer_meta' ) ) :
add_action( 'nice_after_masonry_blog_post', 'nice_masonry_post_footer_meta' );
/**
 * Display the footer meta for a post in the blog masonry context.
 *
 * @since 1.0.0
 */
function nice_masonry_post_footer_meta() {
	$post_type = get_post_type_object( get_post_type() );

	/**
	 * @hook nice_masonry_post_footer_meta
	 *
	 * Post footer meta should be printed here.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_masonry_post_footer_meta', $post_type );
}
endif;

if ( ! function_exists( 'nice_masonry_post_footer_meta_post_type' ) ) :
add_action( 'nice_masonry_post_footer_meta', 'nice_masonry_post_footer_meta_post_type', 10 );
/**
 * Print post type inside footer meta.
 *
 * @since 1.0.0
 *
 * @param WP_Post_Type $post_type
 */
function nice_masonry_post_footer_meta_post_type( $post_type ) { ?>
	<section class="entry-type entry-meta inline-block contrast-skin alignleft">
		<i class="<?php echo nice_get_post_format_icon_class(); ?>" title="<?php echo esc_attr( $post_type->labels->singular_name ); ?>"></i>
	</section>
	<?php
}
endif;

if ( ! function_exists( 'nice_masonry_post_footer_meta_comments' ) ) :
add_action( 'nice_masonry_post_footer_meta', 'nice_masonry_post_footer_meta_comments', 20 );
/**
 * Print post comments inside footer meta.
 *
 * @since 1.0.0
 */
function nice_masonry_post_footer_meta_comments() {
	if ( ! comments_open() ) {
		return;
	}

	nice_comments_link_section( get_the_ID(),
		array(
			'text'       => get_comments_number_text( '0', '1', '%' ),
			'echo'       => true,
			'before'     => '<section class="entry-comments entry-meta inline-block contrast-skin alignright">',
			'after'      => '</section>',
			'icon_class' => 'fa fa-comment-o',
		)
	);
}
endif;

if ( ! function_exists( 'nice_masonry_post_footer_meta_template' ) ) :
add_filter( 'nice_post_footer_meta_template', 'nice_masonry_post_footer_meta_template', 10, 2 );
/**
 * Filter the default post footer meta template when viewing Masonry blog.
 *
 * @since 1.0.0
 *
 * @param  string $template Default template.
 * @param  array  $args     Arguments to build post meta block.
 *
 * @return string
 */
function nice_masonry_post_footer_meta_template( $template = '', $args = array() ) {
	if ( ! empty( $args['context'] ) && 'masonry-blog' === $args['context'] ) {
		$template = '[post_format] [post_comments]';
	}

	return $template;
}
endif;
