<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the footer layout and the different options.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_footer' ) ) :
add_action( 'nice_footer', 'nice_footer', 10 );
/**
 * Print the footer
 *
 * @since 1.0.0
 */
function nice_footer() {
	?>
		<!-- BEGIN #footer -->
		<footer id="footer" <?php nice_footer_class(); ?>>
			<?php
				/**
				 * @hook nice_footer_widgets
				 *
				 * Print widgets.
				 *
				 * @since 1.0.0
				 *
				 * Hooked here:
				 * @see nice_footer_widgets()
				 */
				do_action( 'nice_footer_widgets' );
			?>

			<?php
				/**
				 * @hook nice_footer_extended
				 *
				 * Print extended footer.
				 *
				 * @since 1.0.0
				 *
				 * Hooked here:
				 * @see nice_footer_extended()
				 */
				do_action( 'nice_footer_extended' );
			?>
		</footer><!-- END #footer -->
	<?php
}
endif;

if ( ! function_exists( 'nice_footer_widgets' ) ) :
add_action( 'nice_footer_widgets', 'nice_footer_widgets' );
/**
 * Print the footer widgets.
 *
 * @since 1.0.0
 *
 * @param  array $args
 * @return string
 */
function nice_footer_widgets( $args = array() ) {
	$class = 'col-full';

	if ( nice_footer_full_width() ) {
		$class = 'full-width';
	}

	$defaults = array(
		'echo'    => true,
		'columns' => '4',
		'before'  => '<!-- BEGIN #footer-widget --><div id="footer-widgets" class="' . $class . '">',
		'after'   => '</div><!-- /#footer-widgets -->',
	);

	$args = wp_parse_args( $args, $defaults );
	$args = apply_filters( 'nice_footer_widgets_args', $args );

	// Initialize output.
	ob_start();

	// Obtain number of columns.
	$footer_columns = nice_get_option( 'nice_footer_columns' );
	$footer_columns = intval( $footer_columns ? $footer_columns : $args['columns'] );

	// Obtain HTML class.
	$class = ' columns-' . esc_attr( $footer_columns );

	if (   is_active_sidebar( 'footer-1' )
	    || is_active_sidebar( 'footer-2' )
	    || is_active_sidebar( 'footer-3' )
	    || is_active_sidebar( 'footer-4' )
	) : ?>
		<?php echo $args['before']; ?>

		<div id="footer-grid" class="grid">
			<div class="widget-section first <?php echo esc_attr( $class ); ?>">
				<?php dynamic_sidebar( 'footer-1' ); ?>
			</div>
			<div class="widget-section even <?php echo esc_attr( $class ); ?>">
				<?php dynamic_sidebar( 'footer-2' ); ?>
			</div>
			<?php if ( 3 === $footer_columns or 4 === $footer_columns ) : ?>
				<?php if ( 3 === $footer_columns ) :
					$class .= ' last';
				endif; ?>
				<div class="widget-section odd <?php echo esc_attr( $class ); ?>">
					<?php dynamic_sidebar( 'footer-3' ); ?>
				</div>
			<?php endif; ?>
			<?php if ( 4 === $footer_columns ) : ?>
				<div class="widget-section odd <?php echo esc_attr( $class ); ?> last">
					<?php dynamic_sidebar( 'footer-4' ); ?>
				</div>
			<?php endif; ?>
		</div>

		<?php echo $args['after']; ?>
	<?php endif;

	$output = ob_get_contents();
	ob_end_clean();

	/**
	 * @hook nice_footer_widgets_html
	 *
	 * Hook here to change the HTML output of the footer widgets.
	 *
	 * @since 1.0.0
	 */
	$output = apply_filters( 'nice_footer_widgets_html', $output, $args );

	if ( $args['echo'] ) {
		echo $output;
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_footer_extended' ) ) :
add_action( 'nice_footer_extended', 'nice_footer_extended' );
/**
 * Print the extended footer
 *
 * @since 1.0.0
 */
function nice_footer_extended() {
	$class = 'col-full';

	if ( nice_footer_full_width() ) {
		$class = 'full-width';
	}

	?>

	<div id="extended-footer">
		<div id="extended-footer-content" class="<?php echo esc_attr( $class ); ?>">
			<div class="grid">
				<div class="columns-2">
					<?php
						/**
						 * @hook nice_copyright
						 *
						 * Print copyright-related HTML.
						 *
						 * @since 1.0.0
						 *
						 * Hooked here:
						 * @see nice_copyright_display()
						 */
						do_action( 'nice_copyright' );
					?>
				</div>
				<div class="columns-2">
					<?php
						/**
						 * @hook nice_footer_menu
						 *
						 * Print HTML related to a navigation menu.
						 *
						 * @since 1.0.0
						 *
						 * Hooked here:
						 * @see nice_footer_social_icons()
						 */
						do_action( 'nice_footer_menu' );
					?>
				</div>
			</div>
		</div>
	</div>
<?php
}
endif;

if ( ! function_exists( 'nice_copyright_display' ) ) :
add_action( 'nice_copyright', 'nice_copyright_display' );
/**
 * Display copyright text using framework functionality.
 *
 * @since 1.0.0
 */
function nice_copyright_display() {
	nice_copyright( array(
		'before' => '<div id="copyright">',
		'after'  => '</div>',
	) );
}
endif;

if ( ! function_exists( 'nice_footer_social_icons' ) ) :
add_action( 'nice_footer_menu', 'nice_footer_social_icons' );
/**
 * Display copyright text using framework functionality.
 *
 * @since 1.0.0
 */
function nice_footer_social_icons() {

	if ( ! nice_footer_display_social() ) {
		return;
	}
	?>

	<div id="footer-social">
		<?php nice_social_links( array( 'section' => 'footer', 'echo' => true ) ); ?>
	</div>
	<?php
}
endif;

if ( ! function_exists( 'nice_copyright_filter' ) ) :
add_filter( 'nice_copyright_default_args', 'nice_copyright_filter' );
/**
 * Set the copyright arguments for this the function nice_copyright()
 *
 * @since 1.0.0
 *
 * @see   nice_copyright()
 *
 * @param  array  $args
 *
 * @return array
 */
function nice_copyright_filter( $args ) {
	// Initialize text string.
	$text = '';

	$custom_copyright_enable = nice_get_option( 'nice_custom_copyright_enable' );

	if ( ! empty( $custom_copyright_enable ) && nice_bool( $custom_copyright_enable ) ) {
		$custom_copyright_text = nice_get_option( 'nice_custom_copyright_text' );

		if ( ! empty( $custom_copyright_text ) ) {
			$text .= $custom_copyright_text;
		}

	} else {
		$text = sprintf( '<a href="%1$s" target="_blank" title="%2$s">%3$s</a>', 'http://nicethemes.com/product/smart/', esc_attr__( 'Smart Multipurpose WordPress Theme', 'smart' ), esc_attr__( 'Smart', 'smart' ) ) . ' ' . sprintf( esc_attr__( 'by %s', 'smart' ), sprintf( '<a href="%1$s" title="%2$s">%3$s</a>', 'http://nicethemes.com', esc_attr__( 'WordPress NiceThemes', 'smart' ), esc_attr__( 'NiceThemes', 'smart' ) ) ) . ' &copy; ' . date( 'Y' ) . '. &mdash; ' . sprintf( esc_attr__( 'Powered by %s', 'smart' ), sprintf( '<a href="%1$s">%2$s</a>', 'http://wordpress.org', esc_attr__( 'WordPress', 'smart' ) ) ) . '.';
	}

	$args['text'] = $text;

	return $args;
}
endif;

if ( ! function_exists( 'nice_footer_display_html' ) ) :
add_filter( 'wp', 'nice_footer_display_html' );
/**
 * Check if the footer sections should be displayed
 *
 * @see    nice_footer_display()
 *
 * @since  1.1
 */
function nice_footer_display_html() {
	if ( ! is_page() && ! is_single() ) {
		return;
	}

	if ( ! $footer_display = nice_footer_display() ) {
		remove_action( 'nice_footer', 'nice_footer' );
		return;
	}

	if ( ! $footer_widgets = nice_footer_display_widgets() ) {
		remove_action( 'nice_footer_widgets', 'nice_footer_widgets' );
	}

	if ( ! $footer_extended = nice_footer_display_extended() ) {
		remove_action( 'nice_footer_extended', 'nice_footer_extended' );
	}

}
endif;

if ( ! function_exists( 'nice_footer_display' ) ) :
/**
 * Check if the footer sections should be displayed
 *
 * @see    nice_footer_display()
 *
 * @since  1.0.0
 */
function nice_footer_display() {
	if ( is_page() || is_single() ) {
		$footer = get_post_meta( get_the_ID(), '_post_footer', true );

		if ( $footer !== '' ) {
			if ( $footer && ( ! nice_bool( $footer ) ) ) {
				return false;
			}
		} else {
			$post_type = get_post_type();
			$footer    = nice_get_option( "_{$post_type}_footer" );

			if ( $footer && ! nice_bool( $footer ) ) {
				return false;
			}
		}
	}

	return true;
}
endif;

if ( ! function_exists( 'nice_footer_display_widgets' ) ) :
/**
 * Return whether to display or not the footer widgets
 *
 * @since 1.1
 *
 * @return bool
 */
function nice_footer_display_widgets() {

	if ( is_page() || is_single() ) {

		$footer_widgets = get_post_meta( get_the_ID(), '_post_footer_widgets', true );

		if ( $footer_widgets !== '' ) {
			if ( $footer_widgets && ! nice_bool( $footer_widgets ) ) {
				return false;
			}

		} else {
			$post_type      = get_post_type();
			$footer_widgets = nice_get_option( "_{$post_type}_footer_widgets" );

			if ( $footer_widgets && ! nice_bool( $footer_widgets ) ) {
				return false;
			}

		}


	}

	return true;

}
endif;

if ( ! function_exists( 'nice_footer_display_extended' ) ) :
/**
 * Return whether to display or not the extended footer
 *
 * @since 1.1
 *
 * @return bool
 */
function nice_footer_display_extended() {

	if ( is_page() || is_single() ) {

		$footer_extended = get_post_meta( get_the_ID(), '_post_footer_extended', true );

		if ( $footer_extended !== '' ) {
			if ( ! nice_bool( $footer_extended ) ) {
				return false;
			}
		} else {
			$post_type       = get_post_type();
			$footer_extended = nice_get_option( "_{$post_type}_footer_extended" );

			if ( $footer_extended && ( ! nice_bool( $footer_extended ) ) ) {
				return false;
			}

		}

	}

	return true;

}
endif;

if ( ! function_exists( 'nice_footer_display_social' ) ) :
/**
 * Return whether to display or not the social icons in the footer.
 *
 * @since 1.0.0
 *
 * @return string
 */
function nice_footer_display_social() {
	$nice_display_social = nice_get_option( 'nice_footer_display_social' );

	if ( is_page() || is_single() ) {
		$_post_display_social = get_post_meta( get_the_ID(), '_post_footer_display_social', true );

		if ( '' !== $_post_display_social ) {
			$nice_display_social = $_post_display_social;
		} else {
			$post_type            = get_post_type();
			$_post_display_social = nice_get_option( "_{$post_type}_footer_display_social" );

			if ( '' !== $_post_display_social ) {
				$nice_display_social = $_post_display_social;
			}
		}
	}

	/**
	 * @hook nice_footer_display_social
	 *
	 * Hook in here to modify the default output of the
	 * `nice_footer_display_social()` (bool) function.
	 *
	 * @see   nice_footer_display_social()
	 *
	 * @since 1.0.0
	 */
	return nice_bool( apply_filters( 'nice_footer_display_social', $nice_display_social ) );
}
endif;

if ( ! function_exists( 'nice_footer_width' ) ) :
/**
 * Return the current width type for the footer element.
 *
 * @since 1.1
 *
 * @return string
 */
function nice_footer_width() {
	static $footer_width = null;

	if ( is_null( $footer_width ) ) {
		$footer_width = '';

		// Try to obtain footer width for single post object.
		if ( is_page() || is_single() ) {
			$post_type    = get_post_type();
			$footer_width = get_post_meta( get_the_ID(), '_post_footer_width', true );

			// Try to obtain from theme settings for the current post type.
			if ( ! $footer_width ) {
				$footer_width = nice_get_option( $post_type . '_footer_width' );
			}
		}
	}

	/**
	 * @hook nice_footer_width
	 *
	 * Hook in here to modify the width type for the footer element.
	 *
	 * @since 1.1
	 */
	return apply_filters( 'nice_footer_width', $footer_width );
}
endif;

if ( ! function_exists( 'nice_footer_width_value' ) ) :
/**
 * Return the current width of the footer.
 *
 * @since 1.1
 *
 * @return string
 */
function nice_footer_width_value() {
	static $footer_width = null;

	// Try to obtain footer width for single post object.
	if ( is_null( $footer_width ) && ( is_page() || is_single() ) ) {
		$footer_width       = '';
		$_post_footer_width = get_post_meta( get_the_ID(), '_post_footer_width', true );

		// Try to obtain from post meta.
		switch ( $_post_footer_width ) {
			case 'full':
				$footer_width = '100%';
				break;
			case 'limit':
				$footer_width = get_post_meta( get_the_ID(), '_post_footer_width_value', true );
				break;
			default:
				break;
		}

		// Try to obtain from theme settings for the current post type.
		if ( ! $footer_width ) {
			$post_type = get_post_type();
			$type = nice_get_option( $post_type . '_footer_width' );

			switch ( $type ) {
				case 'full':
					$footer_width = '100%';
					break;
				case 'limit':
					$footer_width = nice_get_option( $post_type . '_footer_width_value' );
					break;
				default:
					break;
			}
		}
	}

	// We may have obtained a value/unit pair, so in that case we need to parse it as a single string.
	if ( is_array( $footer_width ) ) {
		$footer_width = join( '', $footer_width );
	}

	/**
	 * @hook nice_footer_width_value
	 *
	 * Hook in here to modify the width of the footer.
	 *
	 * @since 1.1
	 */
	return apply_filters( 'nice_footer_width_value', $footer_width );
}
endif;

if ( ! function_exists( 'nice_footer_full_width' ) ) :
/**
 * Check if the footer sections should be displayed in full width
 *
 * @see    nice_footer_display()
 *
 * @since  1.0.0
 */
function nice_footer_full_width() {
	$is_full_width = nice_bool( nice_get_option( 'nice_footer_full_width' ) );

	if ( is_page() || is_single() ) {
		$post_footer_width = get_post_meta( get_the_ID(), '_post_footer_width', true );

		if ( 'full' === $post_footer_width ) {
			$is_full_width = true;
		} elseif ( 'limit' === $post_footer_width ) {
			$is_full_width = false;
		}

		$post_type         = get_post_type();
		$post_footer_width = nice_get_option( "_{$post_type}_footer_width" );

		if ( $post_footer_width ) {
			if ( 'full' === $post_footer_width ) {
				$is_full_width = true;
			} elseif ( 'limit' === $post_footer_width ) {
				$is_full_width = false;
			}
		}

	}

	if ( ! nice_header_vertical() && ! nice_boxed_layout() && $is_full_width ) {
		return true;
	}

	return false;
}
endif;

if ( ! function_exists( 'nice_footer_class' ) ) :
/**
 * Add classes to #footer element.
 *
 * @see    nice_footer_properties()
 *
 * @since  1.0.0
 *
 * @param  mixed|array|string $class List of classes for #footer element.
 * @param  bool               $echo  Whether to print the output or just return it.
 *
 * @return string
 */
function nice_footer_class( $class = null, $echo = true ) {
	// Return early if given class is not string or array.
	if ( ! is_null( $class ) && ! ( is_array( $class ) || is_string( $class ) ) ) {
		return null;
	}

	// Default classes.
	$classes = array(
		'site-footer',
	);

	// Skin class.
	if ( $skin = nice_footer_skin() ) {
		$classes[] = $skin;
	}

	// Transparent footer class.
	if ( nice_bool_option( 'nice_footer_transparent', false ) ) {
		$classes[] = 'transparent';
	}

	if ( ! is_array( $class ) && is_string( $class ) ) {
		$class = explode( ' ', $class );
	}

	if ( ! empty( $class ) ) {
		foreach ( $class as $c ) {
			$classes[] = $c;
		}
	}

	/**
	 * @hook nice_footer_class
	 *
	 * Hook here to modify the array of footer classes.
	 *
	 * @since 1.0.0
	 */
	$footer_class = apply_filters( 'nice_footer_class', $classes );

	$output = nice_css_classes( $footer_class, false );

	if ( $echo ) {
		echo $output;
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_back_to_top' ) ) :
add_action( 'wp_footer', 'nice_back_to_top' );
/**
 * Add the code for the back to top button (if enabled through options).
 *
 * @since 1.0.0
 */
function nice_back_to_top() {
	if ( ! nice_bool_option( '_back_to_top' ) ) {
		return;
	}

	$classes   = array();
	$classes[] = 'back-to-top';

	$button_style = nice_get_option( '_back_to_top_style' );

	if ( isset( $button_style ) && ( '' !== trim( $button_style ) ) ) {
		$classes[] = 'btn';
		$classes[] = 'btn-default';
		$classes[] = nice_theme_style_button_class( $button_style );

		// if the button style is solid background then add the background color class
		if ( 'solid' === $button_style ) {
			$button_background_color = nice_get_option( '_back_to_top_background_color' );

			if ( isset( $button_background_color ) && ( '' !== trim( $button_background_color ) ) ) {
				$classes[] = nice_theme_color_button_class( $button_background_color );
			}
		}

		$button_shape = nice_get_option( '_back_to_top_shape' );
		if ( isset( $button_shape ) && ( '' !== trim( $button_shape ) ) ) {
			$classes[] = nice_theme_shape_button_class( $button_shape );
		}
	} elseif ( $icon_color = nice_get_option( '_back_to_top_icon_color' ) ) {
		$classes[] = nice_theme_color_text_class( $icon_color );
	}

	ob_start();
	?>
		<a href="#" data-target="#wrapper" id="back-to-top" <?php nice_css_classes( $classes ); ?>>
			<i class="fa fa-angle-up"></i>
		</a>
	<?php

	$output = ob_get_contents();
	ob_end_clean();

	/**
	 * @hook nice_back_to_top
	 *
	 * Hook in here to modify the output for the back-to-top button.
	 *
	 * @since 1.0.0
	 */
	$output = apply_filters( 'nice_back_to_top', $output );

	echo $output;
}
endif;
