<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the header layout and the different options.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_header' ) ) :
add_action( 'nice_header', 'nice_header', 10 );
/**
 * Print the header
 *
 * @since 1.0.0
 */
function nice_header() {
	/**
	 * @hook nice_before_header
	 *
	 * Hook here to add HTML elements right before the header is printed.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_before_header' );
?>
	<?php
		/**
		 * @hook nice_top_bar
		 *
		 * The top bar should be printed here in case it's active.
		 *
		 * @since 1.0.0
		 *
		 * Hooked here:
		 * @see nice_top_bar()
		 */
		do_action( 'nice_top_bar' );
	?>

	<!-- BEGIN #header -->
	<header id="header" <?php nice_header_properties(); ?>>
		<!-- BEGIN #header-inner -->
		<div id="header-inner" class="col-full">
			<?php
				/**
				 * @hook nice_logo
				 *
				 * The site's logo (image or text) is printed here. Hook to add,
				 * remove or modify HTML elements from the site's logo.
				 *
				 * @since 1.0.0
				 *
				 * Hooked here:
				 * @see nice_logo_display() - 10
				 */
				do_action( 'nice_logo' );
			?>

			<?php
				/**
				 * @hook nice_navigation_menu
				 *
				 * The main navigation menu is printed here. Hook to add,
				 * remove or modify HTML elements from the main navigation.
				 *
				 * @since 1.0.0
				 *
				 * Hooked here:
				 *
				 * @see nice_navigation_menu()                      - 10 (prints the main navigation menu)
				 * @see nice_navigation_menu_extras_wrapper_start() - 15 (prints opening wrapper for internal contents)
				 * @see nice_navigation_social_icons()              - 20 (prints social icons menu)
				 * @see nice_navigation_search_form()               - 25 (prints search link)
				 * @see nice_woocommerce_integration_header_cart()  - 30 (prints shopping cart)
				 * @see nice_navigation_menu_extras_wrapper_end()   - 40 (prints closing wrapper for internal contents)
				 */
				do_action( 'nice_navigation_menu' );
			?>

		</div><!-- END #nav-container -->
	</header><!-- END #header -->
<?php

	/**
	 * @hook nice_header_after
	 *
	 * Hook here to add HTML elements right after the header is printed.
	 *
	 * @since 1.0.0
	 */
	do_action( 'nice_after_header' );
}
endif;

if ( ! function_exists( 'nice_header_class' ) ) :
/**
 * Add classes to #header element.
 *
 * @see    nice_header_properties()
 *
 * @since  1.0.0
 *
 * @param  array $class List of classes for #header element.
 * @param  bool  $echo  Whether to print the output or not.
 *
 * @return string
 */
function nice_header_class( array $class = array(), $echo = true ) {
	$classes = array();

	if ( nice_header_horizontal() || nice_overlay_navigation() ) {
		if ( nice_header_fixed() ) {
			$classes[] = 'fixed';

			if ( nice_bool_option( 'nice_header_shrink' ) ) {
				$classes[] = 'shrinkable';
			}
		}

		if ( nice_bool_option( 'nice_header_hide_until_scroll' ) ) {
			$classes[] = 'autoshow';
			$classes[] = 'hide-until-scroll';
		}

		if ( ! nice_bool_option( 'nice_header_hide_until_scroll' ) && nice_bool( nice_get_option( 'nice_header_autohide' ) ) ) {
			$classes[] = 'autohide';
		}

		if ( nice_bool( nice_get_option( 'nice_header_full_width' ) ) ) {
			$classes[] = 'full-width';
		}
	}

	if ( nice_bool( nice_get_option( 'nice_header_border' ) ) ) {
		$classes[] = 'has-border';
	}

	if ( nice_header_fixed_mobile() ) {
		$classes[] = 'fixed-mobile';
	}

	if ( nice_bool( nice_get_option( 'nice_header_shadow' ) ) ) {
		$classes[] = 'has-shadow';
	}

	if ( nice_header_transparent() ) {
		$classes[] = 'transparent';
		$classes[] = 'transparent-' . nice_transparent_header_skin();
	}

	if ( nice_header_transparent_mobile() ) {
		$classes[] = 'transparent-mobile';
		$classes[] = 'transparent-mobile-' . nice_transparent_header_skin();
	}

	if ( $header_background_color = nice_header_background_color() ) {
		$classes[] = nice_theme_color_background_class( $header_background_color );
	}

	if ( nice_header_centered() && ! nice_overlay_navigation() ) {
		$classes[] = 'align-center';
	} else {
		$classes[] = 'align-default';
	}

	if ( nice_header_vertical() ) {
		$classes[] = 'vertical';
		$classes[] = nice_get_option( 'nice_header_vertical_navigation_position', 'left' );
		$classes[] = nice_get_option( 'nice_header_vertical_align', 'top' );
		$classes[] = 'align-' . nice_get_option( 'nice_header_vertical_justify', 'left' );

		if ( nice_bool_option( '_header_vertical_hidden', false ) ) {
			$classes[] = 'initially-hidden';
		}

		if ( 'top' !== nice_get_option( 'nice_header_vertical_align', 'top' )
			&& nice_bool( nice_get_option( 'nice_header_vertical_logo_top', false ) )
		) {
			$classes[] = 'logo-top';
		}
	} else {
		$classes[] = 'horizontal';
	}

	if ( has_nav_menu( 'navigation-menu' ) || ( has_nav_menu( 'top-bar-menu' ) && nice_bool_option( '_top_bar' ) ) ) {
		$classes[] = 'has-navigation';
	} else {
		$classes[] = 'no-navigation';
	}

	$classes[] = 'header-' . nice_header_skin();
	$classes[] = 'submenu-' . nice_header_navigation_submenu_skin();

	$post_header_width = nice_header_width();

	if ( $post_header_width ) {
		if ( 'full' === $post_header_width ) {
			$classes[] = 'full-width';
		} elseif ( 'limit' === $post_header_width && false !== ( $key = array_search( 'full-width', $classes ) ) ) {
			unset( $classes[ $key ] );
		}
	}

	if ( nice_get_option( '_logo_mobile' ) || nice_get_option( '_logo_mobile_dark' ) ) {
		$classes[] = 'has-logo-mobile';
	}

	if ( ! empty( $class ) ) {
		$classes = array_merge( $classes, $class );
	}

	$classes = array_map( 'esc_attr', $classes );

	/**
	 * @hook nice_header_class
	 *
	 * Modify header classes by hooking in here.
	 *
	 * @since 1.0.0
	 */
	$classes = apply_filters( 'nice_header_class', $classes, $class );

	$output = nice_css_classes( $classes, $echo );

	return $output;
}
endif;

if ( ! function_exists( 'nice_header_data' ) ) :
add_filter( 'nice_header_properties_args', 'nice_header_data' );
/**
 * Add data attributes to #header element.
 *
 * @see    nice_header_properties()
 *
 * @since  1.0.0
 *
 * @param  array $args List of properties and values for #header element.
 *
 * @param  bool  $echo Whether to print the output or not.
 *
 * @return string
 */
function nice_header_data( array $args = array(), $echo = true ) {
	$data = array();
	$atts = array();
	$output = '';

	if ( nice_bool_option( 'nice_header_hide_until_scroll' ) ) {
		$data['autoshow'] = true;
		$data['autoshow-breakpoint'] = (int) nice_get_option( '_header_hide_until_scroll_breakpoint', 1 );
	}

	if ( ! empty( $data ) ) {
		foreach ( $data as $key => $value ) {
			$atts[] = 'data-' . $key . '="' . esc_attr( $value ) . '"';
		}
	}

	if ( ! empty( $args ) ) {
		foreach ( $args as $key => $value ) {
			$atts[] = 'data-' . (string) $key . '="' . esc_attr( $value ) . '"';
		}
	}

	/**
	 * @hook nice_header_data
	 *
	 * Modify header data attributes by hooking in here.
	 *
	 * @since 1.0.0
	 */
	$atts = apply_filters( 'nice_header_data', $atts, $args );

	if ( ! empty( $atts ) ) {
		$output = join( ' ', $atts );
	}

	if ( $echo ) {
		echo $output; // WPCS: XSS ok.
	}

	return $output;
}
endif;

/**
 * Remove compatibility mode for nice_logo().
 *
 * @since 1.0.0
 *
 * @see nice_logo()
 */
add_filter( 'nice_logo_compatibility', '__return_false' );

if ( ! function_exists( 'nice_logo_display' ) ) :
add_action( 'nice_logo', 'nice_logo_display', 10 );
/**
 * Display logo using framework functionality.
 *
 * @uses  nice_logo()
 *
 * @since 1.0.0
 */
function nice_logo_display() {
	/**
	 * @hook nice_logo_images
	 *
	 * Hook in here to modify the list of images.
	 *
	 * @since 1.0.0
	 */
	$images = apply_filters( 'nice_logo_images', array() );

	nice_logo( array(
		'before'        => '<div id="logo" ' . nice_logo_class( false ) . '>',
		'after'         => '</div>',
		'images'        => $images,
		'default_image' => nice_logo_default_image(),
		'height'        => nice_get_option( '_logo_height' ),
	) );
}
endif;

if ( ! function_exists( 'nice_logo_delete_transients' ) ) :
add_action( 'update_option_nice_options', 'nice_logo_delete_transients' );
/**
 * Remove image size transients when options are updated.
 *
 * @since 1.0.0
 */
function nice_logo_delete_transients() {
	if ( ! class_exists( 'Nice_Logo_Image' ) ) {
		nice_loader( 'engine/admin/classes/class-nice-logo-image.php' );
	}

	Nice_Logo_Image::delete_transients();
}
endif;

if ( ! function_exists( 'nice_logo_class' ) ) :
/**
 * Print or obtain HTML classes for the site's logo.
 *
 * @since  1.0.0
 *
 * @param  bool  $echo
 *
 * @return string
 */
function nice_logo_class( $echo = true ) {
	$classes = array(
		nice_header_navigation_style() . '-style',
		nice_get_option( '_header_top_navigation_alignment' ),
	);

	$font_site_title = nice_get_option( 'nice_font_site_title' );
	if ( nice_bool( nice_get_option( 'nice_text_title' ) ) && ! empty( $font_site_title ) ) {
		$classes[] = 'text';

		if ( nice_bool( nice_get_option( 'nice_text_tagline' ) ) && get_bloginfo( 'description' ) ) {
			$classes[] = 'has-tagline';
		}
	}

	if ( ! in_array( 'text', $classes, true ) ) {
		$classes[] = 'has-image';
	}

	if ( ! nice_header_vertical() ) {
		if ( nice_bool_option( '_hide_logo' ) ) {
			$classes[] = 'hide';
		}

		if ( nice_bool_option( '_header_fixed' ) && nice_bool_option( 'header_fixed_hide_logo' ) ) {
			$classes[] = 'hide-fixed';
		}
	}

	if ( nice_bool_option( '_hide_logo_mobile' ) ) {
		$classes[] = 'mobile-hidden';
	}

	// Return markup.
	return nice_css_classes( $classes, $echo );
}
endif;

if ( ! function_exists( 'nice_logo_text_title' ) ) :
add_filter( 'nice_logo_args', 'nice_logo_text_title' );
/**
 * Set text title values for logo.
 *
 * @since  1.0.0
 *
 * @param  array $args
 *
 * @return array
 */
function nice_logo_text_title( array $args = array() ) {
	if ( nice_bool( nice_get_option( 'nice_text_title' ) ) ) {
		$args['text_title'] = true;

		if ( nice_bool( nice_get_option( 'nice_text_tagline' ) ) ) {
			$args['text_tagline'] = true;
		}
	}

	return $args;
}
endif;

if ( ! function_exists( 'nice_logo_default_image' ) ) :
/**
 * Set default image values for logo.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_logo_default_image() {
	return array(
		'name'       => 'header-logo-default',
		'id'         => 'header-logo-default',
		'url'        => nice_get_file_uri( 'images/logo.png' ),
		'url_retina' => nice_get_file_uri( 'images/logo@2x.png' ),
		'img_class'  => array( 'img-logo-default' ),
	);
}
endif;

if ( ! function_exists( 'nice_logo_add_images' ) ) :
add_filter( 'nice_logo_images', 'nice_logo_add_images' );
/**
 * Add images to logo.
 *
 * @since 1.0.0
 *
 * @param array $images
 *
 * @return array
 */
function nice_logo_add_images( array $images = array() ) {
	$header_skin             = nice_header_skin();
	$header_transparent_skin = nice_transparent_header_skin();
	$logo                    = nice_get_option( '_logo' );
	$logo_dark               = nice_get_option( '_logo_dark' );
	$logo_mobile             = nice_get_option( '_logo_mobile' );
	$logo_mobile_dark        = nice_get_option( '_logo_mobile_dark' );
	$used_skins              = array();

	/**
	 * Obtain logo for transparent and non-transparent header.
	 *
	 * This block is not processed when accesing from mobile devices.
	 */
	if ( $logo || $logo_dark ) {
		// Try to obtain the header logo.
		if ( 'dark' === $header_skin ) {
			$images['header-logo'] = nice_dark_header_logo();
		} else {
			$images['header-logo'] = nice_light_header_logo();
		}

		$used_skins[] = $header_skin;

		// Try to obtain the transparent header's logo, if different from the main logo.
		if ( nice_header_transparent() && ! in_array( $header_transparent_skin, $used_skins, true ) ) {
			if ( $logo_dark && 'dark' === $header_transparent_skin ) {
				$images['transparent-header-logo'] = nice_dark_header_logo();
			} else {
				$images['transparent-header-logo'] = nice_light_header_logo();
			}
		}

		/**
		 * Set visualization priorities for different logo images.
		 *
		 * By adding the "primary" and "secondary" classes to the logo
		 * containers, we can control their visibility via CSS.
		 */
		if ( isset( $images['transparent-header-logo'] ) ) {
			$images['transparent-header-logo']['container_class'][] = 'primary';
			$images['header-logo']['container_class'][] = 'secondary';
		}
	} else { // Use default logo in case a custom one wasn't set.
		$images['header-logo'] = nice_logo_default_image();
	}

	/**
	 * Obtain logo for mobile devices.
	 */
	if ( $logo_mobile || $logo_mobile_dark ) {
		// Try to obtain the transparent header's logo, if different from the main logo.
		if ( nice_header_transparent_mobile() && ! in_array( $header_transparent_skin, $used_skins, true ) ) {
			if ( $logo_mobile_dark && 'dark' === $header_transparent_skin ) {
				$images['transparent-mobile-header-logo'] = nice_mobile_dark_header_logo();
			} else {
				$images['transparent-mobile-header-logo'] = nice_mobile_light_header_logo();
			}
		}

		if ( ( $logo_mobile_dark && 'dark' === $header_skin ) || ( $logo_mobile_dark && ! $logo_mobile ) ) {
			$images['mobile-header-logo'] = nice_mobile_dark_header_logo();
		} else {
			$images['mobile-header-logo'] = nice_mobile_light_header_logo();
		}

		/**
		 * Set visualization priorities for different logo images.
		 *
		 * By adding the "primary" and "secondary" classes to the logo
		 * containers, we can control their visibility via CSS.
		 */
		if ( isset( $images['transparent-mobile-header-logo'] ) ) {
			$images['transparent-mobile-header-logo']['container_class'][] = 'primary-mobile';
			$images['mobile-header-logo']['container_class'][] = 'secondary-mobile';
		}
	}

	return $images;
}
endif;

if ( ! function_exists( 'nice_light_header_logo' ) ) :
/**
 * Obtain values for the light header logo.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_light_header_logo() {
	return array(
		'name'       => 'header-logo-light',
		'id'         => 'header-logo-light',
		'url'        => nice_get_option( '_logo' ),
		'url_retina' => nice_get_option( '_logo_retina' ),
		'img_class'  => array( 'img-logo-light' ),
		'height'     => nice_get_option( '_logo_height' ),
	);
}
endif;

if ( ! function_exists( 'nice_dark_header_logo' ) ) :
/**
 * Obtain values for the dark header logo.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_dark_header_logo() {
	$logo_dark = nice_get_option( '_logo_dark' );

	return array(
		'name'       => 'header-logo-dark',
		'id'         => 'header-logo-dark',
		'url'        => $logo_dark ? $logo_dark : nice_get_option( '_logo' ),
		'url_retina' => nice_get_option( '_logo_retina_dark' ),
		'img_class'  => array( 'img-logo-dark' ),
		'height'     => nice_get_option( '_logo_height' ),
	);
}
endif;

if ( ! function_exists( 'nice_mobile_light_header_logo' ) ) :
/**
 * Obtain values for the mobile light header logo.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_mobile_light_header_logo() {
	return array(
		'name'            => 'header-logo-mobile-light',
		'id'              => 'header-logo-mobile-light',
		'url'             => nice_get_option( '_logo_mobile' ),
		'url_retina'      => nice_get_option( '_logo_mobile_retina' ),
		'img_class'       => array( 'img-logo-mobile' ),
		'container_class' => array( 'header-logo-mobile-wrapper' ),
		'height'          => nice_get_option( '_logo_height' ),
	);
}
endif;

if ( ! function_exists( 'nice_mobile_dark_header_logo' ) ) :
/**
 * Obtain values for the mobile dark header logo.
 *
 * @since 1.0.0
 *
 * @return array
 */
function nice_mobile_dark_header_logo() {
	return array(
		'name'            => 'header-logo-mobile-dark',
		'id'              => 'header-logo-mobile-dark',
		'url'             => nice_get_option( '_logo_mobile_dark' ),
		'url_retina'      => nice_get_option( '_logo_mobile_dark_retina' ),
		'img_class'       => array( 'img-logo-mobile' ),
		'container_class' => array( 'header-logo-mobile-wrapper' ),
		'height'          => nice_get_option( '_logo_height' ),
	);
}
endif;

if ( ! function_exists( 'nice_navigation_singular' ) ) :
add_filter( 'nice_navigation_menu_args', 'nice_navigation_singular', 5 );
/**
 * Return the menu id for post and pages.
 *
 * @see    nice_navigation_menu()
 *
 * @since  1.0.0
 *
 * @param  array $args Non-filtered arguments.
 * @return array       Filtered arguments.
 */
function nice_navigation_singular( $args ) {
	if ( is_page() || is_single() ) {

		$post_navigation_menu = get_post_meta( get_the_ID(), '_post_navigation_menu', true );

		if ( $post_navigation_menu ) {
			$args['menu'] = $post_navigation_menu;
		} else {

			$post_type = get_post_type();

			if ( $post_navigation_menu = nice_get_option( "_{$post_type}_navigation_menu" ) ) {
				$args['menu'] = $post_navigation_menu;
			}

		}
	}

	return $args;
}
endif;

if ( ! function_exists( 'nice_header_display' ) ) :
/**
 * check if the header should be displayed in singular templates.
 *
 * @see    nice_header_display()
 *
 * @since  1.0.0
 *
 */
function nice_header_display() {

	if ( is_page() || is_single() ) {
		$_post_header = get_post_meta( get_the_ID(), '_post_header', true );

		if ( $_post_header !== '' ) {
			if ( ! nice_bool( $_post_header ) ) {
				return false;
			}
		} else {

			$post_type    = get_post_type();
			$_post_header = nice_get_option( "_{$post_type}_header" );

			if ( $_post_header && ! nice_bool( $_post_header  ) ) {
				return false;
			}
		}

	}

	return true;

}
endif;

if ( ! function_exists( 'nice_header_display_html' ) ) :
add_filter( 'wp', 'nice_header_display_html' );
/**
 * check if the header should be displayed in singular templates.
 *
 * @see    nice_header_display_html()
 *
 * @since  1.1
 *
 */
function nice_header_display_html() {

	if ( ! nice_header_display() ) {
		remove_action( 'nice_header', 'nice_header' );
	}

}
endif;

if ( ! function_exists( 'nice_header_display_social' ) ) :
/**
 * Return whether to display or not the social icons in the header.
 *
 * @since 1.0.0
 *
 * @return string
 */
function nice_header_display_social() {
	$social_links        = nice_social_links( array( 'echo' => false ) );
	$nice_display_social = ! empty( $social_links ) && nice_bool_option( '_header_display_social' );

	if ( is_page() || is_single() ) {
		$_post_display_social = get_post_meta( get_the_ID(), '_post_header_display_social', true );

		if ( '' !== $_post_display_social ) {
			$nice_display_social = $_post_display_social;
		} else {
			$post_type            = get_post_type();
			$_post_display_social = nice_get_option( "_{$post_type}_header_display_social" );

			if ( '' !== $_post_display_social ) {
				$nice_display_social = $_post_display_social;
			}
		}
	}

	return nice_bool( apply_filters( 'nice_header_display_social', $nice_display_social ) );
}
endif;

if ( ! function_exists( 'nice_navigation_search_form' ) ) :
add_action( 'nice_navigation_menu', 'nice_navigation_search_form', 25 );
/**
 * Print search form in navigation area.
 *
 * @since  1.0.0
 */
function nice_navigation_search_form() {
	if ( ! nice_header_display_search() ) {
		return;
	}
	?>
	<div id="header-search">
		<a href="javascript:void(0);" class="search"><?php esc_html_e( 'Search', 'smart' ); ?></a>

		<div id="header-search-container" class="overlay">
			<a href="javascript:void(0);" class="close"><?php esc_html_e( 'Close', 'smart' ); ?></a>
			<?php get_search_form(); ?>
		</div>
	</div>
	<?php
}
endif;

if ( ! function_exists( 'nice_navigation_social_icons' ) ) :
add_action( 'nice_navigation_menu', 'nice_navigation_social_icons', 20 );
/**
 * Print social icons in navigation area.
 *
 * @since  1.0.0
 */
function nice_navigation_social_icons() {
	if ( ! nice_header_display_social() ) {
		return;
	}

	$social_links = nice_social_links( array( 'echo' => false ) );

	// Return early if we don't have links to show.
	if ( empty( $social_links ) ) {
		return;
	}
	?>

	<div id="header-social">
		<?php echo $social_links; // WPCS: XSS ok. ?>
	</div>
	<?php
}
endif;

if ( ! function_exists( 'nice_header_width' ) ) :
/**
 * Return the current width type for the header element.
 *
 * @since 1.1
 *
 * @return string
 */
function nice_header_width() {
	static $header_width = null;

	if ( ! nice_header_vertical() && is_null( $header_width ) ) {
		$header_width = '';

		// Try to obtain header width for single post object.
		if ( is_page() || is_single() ) {
			$post_type    = get_post_type();
			$header_width = get_post_meta( get_the_ID(), '_post_header_width', true );

			// Try to obtain from theme settings for the current post type.
			if ( ! $header_width ) {
				$header_width = nice_get_option( $post_type . '_header_width' );
			}
		}
	}

	/**
	 * @hook nice_header_width
	 *
	 * Hook in here to modify the width type for the header element.
	 *
	 * @since 1.1
	 */
	return apply_filters( 'nice_header_width', $header_width );
}
endif;

if ( ! function_exists( 'nice_header_width_value' ) ) :
/**
 * Return the current width of the header.
 *
 * @since 1.1
 *
 * @return string
 */
function nice_header_width_value() {
	static $header_width = null;

	// Try to obtain header width for single post object.
	if ( ! nice_header_vertical() && is_null( $header_width ) && ( is_page() || is_single() ) ) {
		$header_width       = '';
		$_post_header_width = get_post_meta( get_the_ID(), '_post_header_width', true );

		// Try to obtain from post meta.
		switch ( $_post_header_width ) {
			case 'full':
				$header_width = '100%';
				break;
			case 'limit':
				$header_width = get_post_meta( get_the_ID(), '_post_header_width_value', true );
				break;
			default:
				break;
		}

		// Try to obtain from theme settings for the current post type.
		if ( ! $header_width ) {
			$post_type = get_post_type();

			switch ( nice_get_option( $post_type . '_header_width' ) ) {
				case 'full':
					$header_width = '100%';
					break;
				case 'limit':
					$header_width = nice_get_option( $post_type . '_header_width_value' );
					break;
				default:
					break;
			}
		}
	}

	// We may have obtained a value/unit pair, so in that case we need to parse it as a single string.
	if ( is_array( $header_width ) ) {
		$header_width = join( '', $header_width );
	}

	/**
	 * @hook nice_header_width_value
	 *
	 * Hook in here to modify the width of the header.
	 *
	 * @since 1.1
	 */
	return apply_filters( 'nice_header_width_value', $header_width );
}
endif;
