<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the page title section.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_page_title_set_args' ) ) :
add_filter( 'nice_page_title_args', 'nice_page_title_set_args' );
/**
 * Modify page title for heading.
 *
 * @since  1.0.0
 *
 * @param  array $args
 *
 * @return array
 */
function nice_page_title_set_args( array $args = array() ) {
	if ( is_home() ) {
		$args['title'] = apply_filters( 'nice_blog_title', esc_html__( 'Blog', 'smart' ) );
	} elseif ( is_search() ) {
		$args['title'] = get_search_query();
	} elseif ( is_tag() || is_category() ) {
		$args['title'] = single_tag_title( '', false );
	} elseif ( is_archive() ) {
		$args['title'] = nice_get_archive_title();
	} elseif ( is_404() ) {
		$args['title'] = esc_html__( 'Not Found', 'smart' );
	}

	return $args;
}
endif;

if ( ! function_exists( 'nice_page_title_start' ) ) :
add_action( 'nice_heading_before_title', 'nice_page_title_start' );
/**
 * Set the opening div tag for the heading section
 *
 * @since 1.0.0

 */
function nice_page_title_start() {
	?>
	<div class="overlay"></div>
	<div class="heading-content">
		<div class="heading-content-inner col-full clearfix">
	<?php
}
endif;

if ( ! function_exists( 'nice_page_title_end' ) ) :
add_action( 'nice_heading_after_title', 'nice_page_title_end' );
/**
 * Set the closing div tag for the heading section
 *
 * @since 1.0.0

 */
function nice_page_title_end() {
	?>
		</div>
	</div>
	<?php
}
endif;

if ( ! function_exists( 'nice_page_title_scroll_down_arrow' ) ) :
add_action( 'nice_heading_after_title', 'nice_page_title_scroll_down_arrow', 15 );
/**
 * Set the closing div tag for the heading section
 *
 * @since 1.0.0

 */
function nice_page_title_scroll_down_arrow() {
	$is_shop         = class_exists( 'WooCommerce' ) && is_shop();
	$post            = $is_shop ? get_post( wc_get_page_id( 'shop' ) ) : get_post();
	$use_scroll_down = ( $post instanceof WP_Post ) ? $is_shop || is_page( $post ) || is_single( $post ) : false;

	if ( $use_scroll_down ) {
		$scroll_down  = get_post_meta( $post->ID, '_post_scroll_down_arrow', true );

		if ( ! empty( $scroll_down ) && nice_bool( $scroll_down ) ) { ?>
			<div id="heading-scrolldown"><a href="#container" data-target="#container"><i class="fa fa-angle-down"></i></a></div>
		<?php
		} else {

			$post_type   = get_post_type();
			$scroll_down = nice_get_option( "_{$post_type}_scroll_down_arrow" );

			if ( ! empty( $scroll_down ) && nice_bool( $scroll_down ) ) { ?>
				<div id="heading-scrolldown"><a href="#container" data-target="#container"><i class="fa fa-angle-down"></i></a></div>
			<?php
			}

		}
	}
}
endif;

if ( ! function_exists( 'nice_page_title_meta' ) ) :
add_filter( 'nice_page_title', 'nice_page_title_meta', 10, 2 );
/**
 * Set meta data for the page heading.
 *
 * @since 1.0.0
 *
 * @param  string $meta Current page title.
 *
 * @return string
 */
function nice_page_title_meta( $meta ) {
	$is_shop      = class_exists( 'WooCommerce' ) && is_shop();
	$post         = $is_shop ? get_post( wc_get_page_id( 'shop' ) ) : get_post();
	$use_subtitle = ( $post instanceof WP_Post ) ? $is_shop || is_singular( apply_filters( 'nice_page_subtitle_post_types', array( 'page' ) ) ) : false;
	$use_meta     = ( $post instanceof WP_Post ) ? is_single( $post ) : false;

	if ( apply_filters( 'nice_page_title_use_subtitle', $use_subtitle ) ) {
		$subtitle = get_post_meta( $post->ID, '_post_subtitle', true );

		if ( ! empty( $subtitle ) ) {
			$meta .= '<div class="page-subtitle clearfix">' . wpautop( $subtitle ) . '</div>';
		} else {

			$post_type = get_post_type();
			$subtitle  = nice_get_option( "_{$post_type}_subtitle" );

			if ( ! empty( $subtitle ) ) {
				$meta .= '<div class="page-subtitle clearfix">' . wpautop( $subtitle ) . '</div>';
			}

		}
	}

	if ( apply_filters( 'nice_page_title_use_meta', $use_meta ) ) {
		$meta .= nice_post_meta( array( 'echo' => false, 'context' => 'page-title' ) );
	}

	return $meta;
}
endif;

if ( ! function_exists( 'nice_single_post_meta_category' ) ) :
add_filter( 'nice_post_meta_categories', 'nice_single_post_meta_category', 10, 2 );
/**
 * Remove the post meta category on the single post page title section.
 *
 * @since 1.0.0
 *
 * @param $output
 * @param $context
 *
 * @return string
 */
function nice_single_post_meta_category( $output, $context ) {
	$post    = get_post();
	$is_post = ( $post instanceof WP_Post ) ? is_singular( array( 'post' ) ) : false;

	if ( $is_post ) {
		if ( 'page-title' === $context ) {
			$output = '';
		}
	}

	return $output;
}
endif;

function nice_single_post_meta_categories( $post ) { // @TODO: Organize this function, re-check name
	$is_post = ( $post instanceof WP_Post ) ? is_singular( array( 'post' ) ) : false;

	if ( $is_post ) {
		$categories_html = nice_post_categories( $post, false );

		if ( ! $categories_html ) {
			return;
		}

		$category_classes = array(
			'categories',
			'category-pills',
			'pills',
		);

		if ( $color = get_post_meta( $post->ID, '_post_categories_heading_color', true ) ) {
			$category_classes[] = nice_theme_color_pills_class( $color );
		} elseif ( $color = nice_get_option( "_post_categories_heading_color" ) ) {
			$category_classes[] = nice_theme_color_pills_class( $color );
		} else {
			$category_classes[] = 'pills-default-color';
		}

		if ( $shape = get_post_meta( $post->ID, '_post_categories_heading_shape', true ) ) {
			$category_classes[] = 'pills-' . $shape;
		} elseif ( $shape = nice_get_option( "_post_categories_heading_shape" ) ) {
			$category_classes[] = 'pills-' . $shape;
		}

		if ( $style = get_post_meta( $post->ID, '_post_categories_heading_style', true ) ) {
			$category_classes[] = 'pills-' . $style;
		} elseif ( $style = nice_get_option( "_post_categories_heading_style" ) ) {
			$category_classes[] = 'pills-' . $style;
		} else {
			$category_classes[] = 'pills-outline';
		}

		?>
			<section <?php nice_css_classes( $category_classes ); ?>>
				<?php echo $categories_html; // WPCS: XSS Ok. ?>
			</section>
		<?php

	}
}

if ( ! function_exists( 'nice_single_post_meta_category_page_title' ) ) :
add_action( 'nice_heading_before_title', 'nice_single_post_meta_category_page_title' );
/**
 * Relocate the categories before heading, remove the categories from the meta data.
 *
 * @since 1.0.0
 */
function nice_single_post_meta_category_page_title() {
	$post    = get_post();
	$is_post = ( $post instanceof WP_Post ) ? is_singular( array( 'post' ) ) : false;

	if ( $is_post ) {
		$_post_categories_heading = get_post_meta( $post->ID, '_post_categories_heading', true );
		$post_categories_display = ( '' !== $_post_categories_heading ) ? $_post_categories_heading : false;

		if ( nice_bool( $post_categories_display ) ) {
			nice_single_post_meta_categories( $post );
		} elseif ( '' === $_post_categories_heading ) { // Inherit from theme settings.
			$post_type                 = get_post_type();
			$_post_categories_heading  = nice_get_option( "_{$post_type}_title_heading" );

			$post_categories_display = ( '' !== $_post_categories_heading ) ? $_post_categories_heading : false;

			if ( nice_bool( $post_categories_display ) ) {
				nice_single_post_meta_categories( $post );
			}

		}
	}
}
endif;

if ( ! function_exists( 'nice_single_post_meta_author' ) ) :
add_filter( 'nice_post_meta_author', 'nice_single_post_meta_author', 10, 2 );
/**
 * Modify the post meta author output.
 *
 * @since 1.0.0
 *
 * @param string $output
 *
 * @return string
 */
function nice_single_post_meta_author( $output ) {
	$post = get_post();
	$is_post = ( $post instanceof WP_Post ) ? is_singular( array( 'post' ) ) : false;

	if ( $is_post ) {
		$author_id   = (int) $post->post_author;
		$author_name = get_the_author_meta( 'display_name', $author_id );
		$author_link = get_author_posts_url( $author_id );

		$output = '<section class="author entry-author entry-meta">';
		$output .= '<a href="' . $author_link . '">' . get_avatar( $author_id, 26 ) . '<span>' . esc_html__( 'by ', 'smart' ) . $author_name . '</span></a>';
		$output .= '</section>';
	}

	return $output;
}
endif;

if ( ! function_exists( 'nice_page_title_heading_display' ) ) :
add_filter( 'nice_page_title', 'nice_page_title_heading_display', 15, 2 );
/**
 * Check if the page title should display within the heading section.
 *
 * @since 1.0.0
 *
 * @param  string $title Current page title.
 *
 * @return string
 */
function nice_page_title_heading_display( $title ) {
	$is_shop      = class_exists( 'WooCommerce' ) && is_shop();
	$post         = $is_shop ? get_post( wc_get_page_id( 'shop' ) ) : get_post();
	$post_applies = ( $post instanceof WP_Post ) ? $is_shop || is_page( $post ) || is_single( $post ) : false;

	if ( $post_applies ) {

		$post_title_display = get_post_meta( $post->ID, '_post_title_heading', true );

		if ( ! empty( $post_title_display ) && ! nice_bool( $post_title_display ) ) {
			$title = null;
		} else {

			$post_type           = get_post_type();
			$post_title_display  = nice_get_option( "_{$post_type}_title_heading" );

			if ( ! empty( $post_title_display ) && ! nice_bool( $post_title_display ) ) {
				$title = null;
			}

		}
	}

	return $title;
}
endif;

if ( ! function_exists( 'nice_page_heading_class' ) ) :
add_filter( 'nice_heading_class', 'nice_page_heading_class' );
/**
 * Set heading class
 *
 * @since  1.0.0
 *
 * @param  array  $classes
 *
 * @return array
 */
function nice_page_heading_class( array $classes = array() ) {
	if ( nice_page_heading_has_parallax() ) {
		$classes[] = 'parallax';
	}

	if ( is_page() || is_single() ) {
		$heading_skin = get_post_meta( get_the_ID(), '_post_heading_skin', true );
	}

	if ( empty( $heading_skin ) ) {
		$post_type     = get_post_type();
		$heading_skin  = nice_get_option( "_{$post_type}_heading_skin" );
	}

	if ( empty( $heading_skin ) ) {
		$heading_skin = nice_get_option( 'nice_heading_skin', 'dark' );
	}

	$classes[] = $heading_skin;

	if ( $post_heading_background_color = nice_heading_background_color() ) {
		$classes[] = nice_theme_color_background_class( $post_heading_background_color );
	}

	return $classes;
}
endif;

if ( ! function_exists( 'nice_page_heading_background_image' ) ) :
/**
 * Obtain background image for current page.
 *
 * @since  1.0.0
 *
 * @param  int $post_id
 *
 * @return mixed|string|null
 */
function nice_page_heading_background_image( $post_id = null ) {
	$image = '';

	if ( is_page() || is_single() ) {
		$id    = $post_id ? $post_id : get_the_ID();
		$image = esc_url( get_post_meta( $id, '_post_background_image', true ) );

		if ( empty( $image ) && get_post_meta( $id, '_post_background_color', true ) ) {
			$image = null;
		}

		if ( empty( $image ) ) {
			$post_type = get_post_type();
			$image     = nice_get_option( "_{$post_type}_background_image" );

			if ( empty( $image ) && get_post_meta( $id, '_post_background_color', true ) ) {
				$image = null;
			}
		}
	}

	if ( empty( $image ) && null !== $image ) {
		$image = esc_url( nice_get_option( '_heading_background_image' ) );
	}

	return $image;
}
endif;

if ( ! function_exists( 'nice_page_heading_background_repeat' ) ) :
/**
 * Obtain background-repeat property value for current page.
 *
 * @since 1.0.0
 *
 * @param  int $post_id
 *
 * @return mixed|string|null
 */
function nice_page_heading_background_repeat( $post_id = null ) {
	$id = $post_id ? $post_id : get_the_ID();

	if ( is_page() || is_single() ) {

		$post_type = get_post_type();

		if ( esc_url( get_post_meta( $id, '_post_background_image', true ) ) ) {
			if ( $repeat = esc_attr( get_post_meta( $id, '_post_background_repeat', true ) ) ) {
				return $repeat;
			}
		} elseif ( esc_url ( nice_get_option( "_{$post_type}_background_image" ) ) ) {
			if ( $repeat = esc_attr( nice_get_option( "_{$post_type}_background_repeat" ) ) ) {
				return $repeat;
			}
		}
	}

	if ( esc_url( nice_get_option( '_heading_background_image' ) ) ) {
		return nice_get_option( '_heading_background_repeat' );
	}

	return null;
}
endif;

if ( ! function_exists( 'nice_page_heading_background_position' ) ) :
/**
 * Obtain background-position property value for current page.
 *
 * @since  1.0.0
 *
 * @param  int $post_id
 *
 * @return string
 */
function nice_page_heading_background_position( $post_id = null ) {
	$position  = '';
	$use_image = true;

	if ( is_page() || is_single() ) {
		$id        = $post_id ? $post_id : get_the_ID();
		$post_type = get_post_type();

		if ( esc_url( get_post_meta( $id, '_post_background_image', true ) ) ) {
			$position = esc_attr( get_post_meta( $id, '_post_background_position', true ) );
		} elseif ( esc_url ( nice_get_option( "_{$post_type}_background_image" ) ) ) {
			$position = esc_attr( nice_get_option( "_{$post_type}_background_position" ) );
		} else {
			$use_image = false;
		}
	}

	if ( empty( $position ) && $use_image && esc_url( nice_get_option( '_heading_background_image' ) ) ) {
		$position = nice_get_option( '_heading_background_position' );
	}

	return $position;
}
endif;

if ( ! function_exists( 'nice_page_heading_background_attachment' ) ) :
/**
 * Obtain background-attachment property value for current page.
 *
 * @since  1.0.0
 *
 * @param  int $post_id
 *
 * @return string
 */
function nice_page_heading_background_attachment( $post_id = null ) {
	$attachment = '';
	$use_image  = true;

	if ( is_page() || is_single() ) {
		$id       = $post_id ? $post_id : get_the_ID();
		$post_type = get_post_type();

		if ( esc_url( get_post_meta( $id, '_post_background_image', true ) ) ) {
			$attachment = esc_attr( get_post_meta( $id, '_post_background_attachment', true ) );
		} elseif ( esc_url ( nice_get_option( "_{$post_type}_background_image" ) ) ) {
			$attachment = esc_attr( nice_get_option( "_{$post_type}_background_attachment" ) );
		} else {
			$use_image = false;
		}
	}

	if ( empty( $attachment ) && $use_image && esc_url( nice_get_option( '_heading_background_image' ) ) ) {
		$attachment = nice_get_option( '_heading_background_attachment' );
	}

	return $attachment;
}
endif;

if ( ! function_exists( 'nice_page_heading_background_size' ) ) :
/**
 * Obtain background-size property value for current page.
 *
 * @since  1.0.0
 *
 * @param  int    $post_id
 *
 * @return string
 */
function nice_page_heading_background_size( $post_id = null ) {
	$size      = '';
	$use_image = true;

	if ( is_page() || is_single() ) {
		$id        = $post_id ? $post_id : get_the_ID();
		$post_type = get_post_type();

		if ( esc_url( get_post_meta( $id, '_post_background_image', true ) ) ) {
			$size = esc_attr( get_post_meta( $id, '_post_background_size', true ) );
		} elseif ( esc_url ( nice_get_option( "_{$post_type}_background_image" ) ) ) {
			$size = esc_attr( nice_get_option( "_{$post_type}_background_size" ) );
		} else {
			$use_image = false;
		}
	}

	if ( empty( $size ) && $use_image && esc_url( nice_get_option( '_heading_background_image' ) ) ) {
		$size = nice_get_option( '_heading_background_size' );
	}

	return $size;
}
endif;

if ( ! function_exists( 'nice_page_heading_alignment' ) ) :
/**
 * Obtain title horizontal alignment for current page.
 *
 * @since  1.0.0
 *
 * @param  int    $post_id
 *
 * @return string
 */
function nice_page_heading_alignment( $post_id = null ) {
	if ( is_page() || is_single() ) {
		$id        = $post_id ? $post_id : get_the_ID();
		$alignment = esc_attr( get_post_meta( $id, '_post_title_alignment', true ) );

		if ( empty( $alignment ) ) {
			$post_type = get_post_type();
			$alignment = nice_get_option( "_{$post_type}_title_alignment" );
		}
	}

	if ( empty( $alignment ) ) {
		$alignment = nice_get_option( '_heading_alignment', null );
	}

	return $alignment;
}
endif;

if ( ! function_exists( 'nice_page_heading_alignment_v' ) ) :
/**
 * Obtain title vertical alignment for current page.
 *
 * @since  1.0.0
 *
 * @param  int    $post_id
 *
 * @return string
 */
function nice_page_heading_alignment_v( $post_id = null ) {
	if ( is_page() || is_single() ) {
		$id        = $post_id ? $post_id : get_the_ID();
		$alignment = esc_attr( get_post_meta( $id, '_post_title_alignment_v', true ) );

		if ( empty( $alignment ) ) {
			$post_type = get_post_type();
			$alignment = nice_get_option( "_{$post_type}_title_alignment_v" );
		}

	}

	if ( empty( $alignment ) ) {
		$alignment = nice_get_option( '_heading_alignment_v', null );
	}

	return $alignment;
}
endif;

if ( ! function_exists( 'nice_page_heading_text_transform' ) ) :
/**
 * Obtain title text transformation for current page.
 *
 * @since  1.0.0
 *
 * @param  int    $post_id
 *
 * @return string
 */
function nice_page_heading_text_transform( $post_id = null ) {
	if ( is_page() || is_single() ) {
		$id        = $post_id ? $post_id : get_the_ID();
		$transform = esc_attr( get_post_meta( $id, '_post_title_text_transform', true ) );

		if ( empty( $transform ) ) {
			$post_type = get_post_type();
			$transform = nice_get_option( "_{$post_type}_title_text_transform" );
		}

	}

	if ( empty( $transform ) ) {
		$transform = nice_get_option( '_heading_text_transform', null );
	}

	return $transform;
}
endif;

if ( ! function_exists( 'nice_page_heading_font_weight' ) ) :
/**
 * Obtain title font weight for the current page.
 *
 * @since  1.0.0
 *
 * @param  int    $post_id
 *
 * @return string
 */
function nice_page_heading_font_weight( $post_id = null ) {
	if ( is_page() || is_single() ) {
		$id      = $post_id ? $post_id : get_the_ID();
		$weight = esc_attr( get_post_meta( $id, '_post_title_font_weight', true ) );

		if ( empty( $weight ) ) {
			$post_type = get_post_type();
			$weight    = nice_get_option( "_{$post_type}_title_font_weight" );
		}
	}

	if ( empty( $weight ) ) {
		$weight = nice_get_option( '_heading_font_weight', null );
	}

	return $weight;
}
endif;

if ( ! function_exists( 'nice_page_heading_height' ) ) :
/**
 * Obtain heading height for current page.
 *
 * @since  1.0.0
 *
 * @param  int   $post_id
 * @return array
 */
function nice_page_heading_height( $post_id = null ) {
	if ( is_page() || is_single() ) {
		$id     = $post_id ? $post_id : get_the_ID();
		$height = (array) get_post_meta( $id, '_post_title_height', true );

		if ( empty( $height[0] ) ) {
			$post_type = get_post_type();
			$height    = nice_get_option( "_{$post_type}_title_height" );
		}

	}

	if ( empty( $height[0] ) ) {
		$height = (array) nice_get_option( '_heading_height', null );
	}

	return $height;
}
endif;

if ( ! function_exists( 'nice_page_heading_height_min' ) ) :
/**
 * Obtain heading height_min for current page.
 *
 * @since  1.0.0
 *
 * @param  int   $post_id
 * @return array
 */
function nice_page_heading_height_min( $post_id = null ) {
	if ( is_page() || is_single() ) {
		$id         = $post_id ? $post_id : get_the_ID();
		$height_min = (array) get_post_meta( $id, '_post_title_height_min', true );

		if ( empty( $height_min[0] ) ) {
			$post_type  = get_post_type();
			$height_min = (array) nice_get_option( "_{$post_type}_title_height_min" );
		}
	}

	if ( empty( $height_min[0] ) ) {
		$height_min = (array) nice_get_option( '_heading_height_min', null );
	}

	return $height_min;
}
endif;

if ( ! function_exists( 'nice_page_heading_has_parallax' ) ) :
/**
 * Check if the page heading is supposed to have a parallax effect.
 *
 * @since  1.0.0
 *
 * @param  int $post_id
 *
 * @return bool
 */
function nice_page_heading_has_parallax( $post_id = null ) {
	if ( is_page() || is_single() ) {
		$id         = $post_id ? $post_id : get_the_ID();
		$post_type  = get_post_type();

		if ( esc_url( get_post_meta( $id, '_post_background_image', true ) ) ) {
			return nice_bool( get_post_meta( $id, '_post_background_image_parallax', true ) );
		}

		if ( esc_url ( nice_get_option( "_{$post_type}_background_image" ) ) ) {
			return nice_bool( nice_get_option( "_{$post_type}_background_image_parallax" ) );
		}

		if ( get_post_meta( $id, '_post_background_color', true ) ) {
			return false;
		}
	}

	return (bool) esc_url( nice_get_option( '_heading_background_image' ) ) && nice_bool_option( '_heading_background_image_parallax' );
}
endif;

if ( ! function_exists( 'nice_page_heading_title_args' ) ) :
add_filter( 'nice_page_title_args', 'nice_page_heading_title_args' );
/**
 * Set heading header class according to size.
 *
 * @since  1.0.0
 *
 * @param  array $args
 *
 * @return array
 */
function nice_page_heading_title_args( $args ) {
	$classes[] = 'page-title';

	if ( is_page() || is_single() ) {
		$heading_font_size = get_post_meta( get_the_ID(), '_post_title_font_size', true );

		if ( empty( $heading_font_size ) ) {
			$post_type         = get_post_type();
			$heading_font_size = nice_get_option( "_{$post_type}_title_font_size" );
		}

	}

	if ( empty( $heading_font_size ) ) {
		$heading_font_size = nice_get_option( 'nice_heading_font_size' );
	}

	if ( empty( $heading_font_size ) ) {
		$classes[] = 'h1';
	} else {
		$classes[] = $heading_font_size;
	}

	$args['before'] = '<h1 ' . nice_css_classes( $classes, false ) . '>';
	$args['after']  = '</h1>';

	return $args;
}
endif;

if ( ! function_exists( 'nice_page_heading_styling' ) ) :
add_filter( 'nice_inline_styles', 'nice_page_heading_styling', 20 );
/**
 * Add Custom Styling.
 *
 * @since  1.0.0
 *
 * @param  string $inline_styles
 *
 * @return string
 */
function nice_page_heading_styling( $inline_styles ) {
	$id = get_the_ID();

	// Initialize HTML output.
	$output = '';

	// Apply background color for header.
	if ( $heading_bg_image = nice_page_heading_background_image( $id ) ) {
		$output .= '#heading { background-image: url(' . $heading_bg_image . '); }' . "\n";
	}

	if ( $heading_bg_parallax = nice_page_heading_has_parallax( $id ) ) {
		$output .= '#heading { background-repeat: no-repeat; }' . "\n";
		$output .= '#heading { background-attachment: fixed; }' . "\n";
		$output .= '#heading { background-position: 50% 50%; }' . "\n";
		$output .= '#heading { background-size: cover; }' . "\n";
	} else {
		if ( $heading_bg_repeat = nice_page_heading_background_repeat( $id ) ) {
			$output .= '#heading { background-repeat: ' . $heading_bg_repeat . '; }' . "\n";
		}

		if ( $heading_bg_attachment = nice_page_heading_background_attachment( $id ) ) {
			$output .= '#heading { background-attachment: ' . $heading_bg_attachment . '; }' . "\n";
		}

		if ( $heading_bg_position = nice_page_heading_background_position( $id ) ) {
			$output .= '#heading { background-position: ' . $heading_bg_position . '; }' . "\n";
		}

		if ( $heading_bg_size = nice_page_heading_background_size( $id ) ) {
			$output .= '#heading { background-size: ' . $heading_bg_size . '; }' . "\n";
		}
	}

	if ( $heading_title_align_h = nice_page_heading_alignment( $id ) ) {
		$output .= '#heading { text-align: ' . $heading_title_align_h . ' }' . "\n";
	}

	if ( 'middle' !== ( $heading_title_align_v = nice_page_heading_alignment_v( $id ) ) ) {
		$output .= '#heading .heading-content { vertical-align: ' . $heading_title_align_v . ' }' . "\n";
	}

	if ( $heading_text_transform = nice_page_heading_text_transform( $id ) ) {
		$output .= '#heading .page-title { text-transform: ' . $heading_text_transform . ' }' . "\n";
	}

	if ( $heading_font_weight = nice_page_heading_font_weight( $id ) ) {
		$output .= '#heading .page-title { font-weight: ' . $heading_font_weight . ' }' . "\n";
	}

	$heading_height     = nice_page_heading_height( $id );
	$heading_height_min = nice_page_heading_height_min( $id );

	if ( ! empty( $heading_height[0] ) && ! empty( $heading_height[1] ) ) {
		$height = $heading_height[0];
		$unit   = ( '%' === $heading_height[1] ) ? 'vh' : $heading_height[1];

		$output .= '#heading { height: ' . $height . $unit . '; }' . "\n";

		if ( 'px' !== $unit ) {
			if ( ! empty( $heading_height_min ) ) {
				$output .= '#heading { min-height: ' . $heading_height_min[0] . 'px; }' . "\n";
			}

			if ( 'vh' === $unit ) {
				$output .= '#heading { box-sizing: border-box; }' . "\n";
			}
		}
	}

	// Set styles for heading in smaller screens.
	if ( is_admin() ) {
		// Tablet.
		$output .= '@media all and (max-width: 1023px) { body.admin #heading { max-height: calc(100vh - ' . ( nice_header_max_height() + 92 ) . 'px); } }' . "\n";
		// Responsive admin bar.
		$output .= '@media all and (max-width: 782px) { body.admin #heading { max-height: calc(100vh - ' . ( nice_header_max_height() + 106 ) . 'px); } }' . "\n";
	} else {
		$output .= '@media all and (max-width: 1023px) { #heading { max-height: calc(100vh - ' . ( nice_header_max_height() + 60 ) . 'px); } }' . "\n";
	}

	if ( ! empty( $output ) ) {
		$inline_styles .= "\n" . $output;
	}

	return $inline_styles;
}
endif;
