<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to customize the post content section.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_post_content_title' ) ) :
add_action( 'nice_before_single_post', 'nice_post_content_title', 10 );
/**
 * Set the title for the entry content on single templates.
 *
 * @since 1.0.0
 */
function nice_post_content_title() {
	$display            = false;
	$post_content_title = get_post_meta( get_the_ID(), '_post_title_content', true );

	if ( nice_bool( $post_content_title) ) {
		$display = true;
	} else {

		$post_type          = get_post_type();
		$post_content_title = nice_get_option( "_{$post_type}_title_content" );

		if ( nice_bool( $post_content_title) ) {
			$display = true;
		}

	}

	if ( nice_bool( $display ) ) : ?>

		<header class="entry-header">
			<?php the_title( '<h1 class="entry-title">', '</h1>' ); ?>
			<?php nice_post_meta(); ?>
		</header>

	<?php endif;
}
endif;

if ( ! function_exists( 'nice_post_thumbnail_display' ) ) :
add_filter( 'nice_post_thumbnail_display', 'nice_post_thumbnail_display' );
/**
 * Set if the post thumbnail should be displayed or hidden for the current post.
 *
 * @since  1.0.0
 *
 * @param  bool $display
 *
 * @return bool
 */
function nice_post_thumbnail_display( $display = false ) {
	$post    = get_post();
	$is_post = ( $post instanceof WP_Post ) ? is_singular( array( 'post' ) ) : false;

	// @TODO: Check this function when the CF is set to FALSE
	if ( $is_post ) {
		$post_thumbnail_display = get_post_meta( get_the_ID(), '_post_thumbnail_content', true );

		if ( nice_bool( $post_thumbnail_display ) ) {
			$post_thumbnail_display = true;
		} else {

			$post_type              = get_post_type();
			$post_thumbnail_display = nice_get_option( "_{$post_type}_thumbnail_content" );

			if ( '' === $post_thumbnail_display || nice_bool( $post_thumbnail_display ) ) {
				$post_thumbnail_display = true;
			}
		}

		$display = nice_bool( $post_thumbnail_display );
	}

	return $display;
}
endif;

if ( ! function_exists( 'nice_post_author_display' ) ) :
add_filter( 'nice_post_author_display', 'nice_post_author_display' );
/**
 * Set if the post author should be displayed or hidden for the current post.
 *
 * @since  1.0.0
 *
 * @param  bool $display
 *
 * @return bool
 */
function nice_post_author_display( $display = false ) {
	$hide = get_post_meta( get_the_ID(), '_post_author_hide', true );
	$hide = ( $hide !== '' );

	$show = get_post_meta( get_the_ID(), '_post_author_display', true );
	$show = ( $show !== '' ) ? nice_bool( $show ) : $display;

	if ( $display && $hide && ! $show ) {
		$display = false;
	} elseif ( $display && ! $hide && $show ) {
		$display = true;
	} elseif ( ! $display && $show ) {
		$display = true;
	} elseif ( ! $display && ! $show ) {
		$display = false;
	}

	return $display;
}
endif;

if ( ! function_exists( 'nice_post_footer_meta_display' ) ) :
add_action( 'nice_after_single_post', 'nice_post_footer_meta_display' );
/**
 * Display the footer meta for a post.
 *
 * @since 1.0.0
 */
function nice_post_footer_meta_display() {
	nice_post_footer_meta();
}
endif;

if ( ! function_exists( 'nice_post_footer_meta_template_custom' ) ) :
add_filter( 'nice_post_footer_meta_template', 'nice_post_footer_meta_template_custom', 10 );
/**
 * Set a custom template for the post footer meta data
 *
 * @since  1.0.0
 *
 * @param  string $template Unfiltered footer meta template.
 *
 * @return string
 */
function nice_post_footer_meta_template_custom( $template ) {
	if ( is_single() ) {
		$template = '[post_format] [post_comments] [post_tags]';
	}

	return $template;
}
endif;

if ( ! function_exists( 'nice_post_password_form' ) ) :
add_filter( 'the_password_form', 'nice_post_password_form' );
/**
 * Use custom markup for the password form in protected posts.
 *
 * @return string
 */
function nice_post_password_form() {
	$label = 'pwbox-' . get_the_ID();

	$output  = '<form class="post-password-form" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">';
	$output .= '<p>' . esc_html__( 'To view this protected post, enter the password below:', 'smart' ) . '</p>';
	$output .= '<p><label for="' . esc_attr( $label ) . '">' . esc_html__( 'Password:', 'smart' ) . '</label>';
	$output .= '<input name="post_password" id="' . esc_attr( $label ) . '" type="password" size="20" maxlength="20" />';
	$output .= '<input type="submit" name="Submit" value="' . esc_attr__( 'Submit', 'smart' ) . '"/>';
	$output .= '</p></form>';

	return $output;
}
endif;

if ( ! function_exists( 'nice_post_navigation' ) ) :
add_action( 'nice_footer', 'nice_post_navigation', 0 );
/**
 * Add navigation at the bottom of a post.
 *
 * @since 1.0.0
 */
function nice_post_navigation() {
	if ( ! is_single() ) {
		return;
	}

	$next     = get_next_post_link( '%link' );
	$previous = get_previous_post_link( '%link' );

	if ( $next or $previous ) : ?>
		<div <?php nice_post_navigation_class(); ?>>
			<div class="col-full clearfix">
				<nav id="nice-post-navigation" class="nav-entries">
					<ul>
						<li class="nav-prev columns-3"><?php echo $previous; ?></li>
						<li class="nav-next columns-3"><?php echo $next; ?></li>
					</ul>
				</nav>
			</div>
		</div>
	<?php endif;
}
endif;
