<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the sidebar configuration.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_has_sidebar' ) ) :
/**
 * Check if the theme should be currently displaying a sidebar.
 *
 * This function returns the result of a static variable to make sure secondary
 * loops don't overwrite the value for the main page being displayed. Set the
 * $reload parameter to true if you need to refresh the result.
 *
 * @since  1.0.0
 *
 * @param  bool $reload
 *
 * @return bool
 */
function nice_has_sidebar( $reload = false ) {
	static $has_sidebar = null;

	if ( is_null( $has_sidebar ) || $reload ) {
		$has_sidebar = true;
	}

	if ( is_404() ) {
		$has_sidebar = false;
	}

	if ( is_page() || is_single() ) {
		$has_sidebar = nice_bool( get_post_meta( get_the_ID(), '_post_sidebar', true ) );

		if ( ! $has_sidebar ) {
			$post_type   = get_post_type();
			$has_sidebar = nice_bool( nice_get_option( "_{$post_type}_sidebar" ) );
		}
	}

	/**
	 * @hook nice_has_sidebar
	 *
	 * Hook in here to redefine if the sidebar should be displayed.
	 *
	 * @since 1.1
	 */
	$has_sidebar = apply_filters( 'nice_has_sidebar', $has_sidebar );

	return $has_sidebar;
}
endif;

if ( ! function_exists( 'nice_sidebar_theming_body_class' ) ) :
add_filter( 'body_class', 'nice_sidebar_theming_body_class' );
/**
 * Assign a body class if the sidebar is active for that page/post.
 *
 * @since 1.0.0
 *
 * @param  array $classes
 * @return array
 */
function nice_sidebar_theming_body_class( $classes ) {
	if ( nice_has_sidebar() ) {
		$classes[] = 'has-sidebar';
	}

	return $classes;
}
endif;

if ( ! function_exists( 'nice_sidebar_theming' ) ) :
add_action( 'wp', 'nice_sidebar_theming' );
/**
 * Assign the sidebar ID and position.
 *
 * @since 1.0.0
 */
function nice_sidebar_theming() {
	if ( ! is_page() && ! is_single() ) {
		return;
	}

	// Don't display sidebar if not set.
	if ( ! nice_has_sidebar() ) {
		remove_action( 'nice_sidebar', 'nice_sidebar_do' );
		return; // Return early if the sidebar doesn't need to be displayed.
	}

	// Assign sidebar ID.
	add_filter( 'nice_sidebar_id', 'nice_sidebar_theming_id' );

	// Assign sidebar position.
	add_filter( 'nice_sidebar_position', 'nice_sidebar_theming_position' );
}
endif;

if ( ! function_exists( 'nice_sidebar_theming_id' ) ) :
/**
 * Helper function to return the current post sidebar ID.
 *
 * @since 1.0.0
 *
 * @return string
 */
function nice_sidebar_theming_id() {

	$sidebar_id = get_post_meta( get_the_ID(), '_post_sidebar_id', true );

	if ( $sidebar_id === '' ) {
		$post_type  = get_post_type();
		$sidebar_id = nice_get_option( "_{$post_type}_sidebar_id" );
	}

	return $sidebar_id;
}
endif;

if ( ! function_exists( 'nice_sidebar_theming_position' ) ) :
/**
 * Helper function to return the current post sidebar position.
 *
 * @since 1.0.0
 *
 * @return string
 */
function nice_sidebar_theming_position() {

	$sidebar_position = get_post_meta( get_the_ID(), '_post_sidebar_position', true );

	if ( $sidebar_position === '' ) {
		$post_type        = get_post_type();
		$sidebar_position = nice_get_option( "_{$post_type}_sidebar_position" );

		if ( $sidebar_position === '' ) {
			$sidebar_position = nice_get_option( '_sidebar_position' );
		}
	}
	return $sidebar_position;
}
endif;
