<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the front-end setup of the theme.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_theme_admin_bar_menu' ) ) :
add_filter( 'show_nice_admin_bar_menu', 'nice_theme_admin_bar_menu' );
/**
 * Setup the theme admin bar menu
 *
 * @since 1.0.2
 *
 * @return string
 */
function nice_theme_admin_bar_menu() {
	if ( ! nice_bool_option( '_admin_bar_menu' ) ) {
		return false;
	}

	return true;
}
endif;

if ( ! function_exists( 'nice_setup_responsive_image_size' ) ) :
add_filter( 'wp_calculate_image_sizes', 'nice_setup_responsive_image_size', 10, 2 );
/**
 * Make sure to correctly display responsive images on mobile window breakpoint.
 *
 * @since 1.0.0
 *
 * @param string $sizes
 * @param array  $size
 *
 * @return string
 */
function nice_setup_responsive_image_size( $sizes = '', $size = array() ) {
	if ( isset( $size[0] ) && ( 768 > (int) $size[0] ) ) {
		$sizes = '(max-width: 768px) 768px, 768px';
	}

	return $sizes;
}
endif;

if ( ! function_exists( 'nice_theme_button_class' ) ) :
/**
 * Return a button class from a given class name.
 *
 * @since  1.0.0
 *
 * @param  string  $class
 * @param  bool    $echo
 *
 * @return string
 */
function nice_theme_button_class( $class, $echo = false ) {
	return nice_prefix_class( 'btn', $class, $echo );
}
endif;

if ( ! function_exists( 'nice_theme_text_class' ) ) :
/**
 * Return a text class from a given class name.
 *
 * @since  1.0.0
 *
 * @param  string  $class
 * @param  bool    $echo
 *
 * @return string
 */
function nice_theme_text_class( $class, $echo = false ) {
	return nice_prefix_class( 'text', $class, $echo );
}
endif;

if ( ! function_exists( 'nice_theme_background_class' ) ) :
/**
 * Return a background class from a given class name.
 *
 * @since  1.0.0
 *
 * @param  string  $class
 * @param  bool    $echo
 *
 * @return string
 */
function nice_theme_background_class( $class, $echo = false ) {
	return nice_prefix_class( 'background', $class, $echo );
}
endif;

if ( ! function_exists( 'nice_theme_border_class' ) ) :
/**
 * Return a border class from a given class name.
 *
 * @since  1.0.0
 *
 * @param  string  $class
 * @param  bool    $echo
 *
 * @return string
 */
function nice_theme_border_class( $class, $echo = false ) {
	return nice_prefix_class( 'border', $class, $echo );
}
endif;

if ( ! function_exists( 'nice_theme_pills_class' ) ) :
/**
 * Return pills' class from a given class name.
 *
 * @since  1.0.0
 *
 * @param  string  $class
 * @param  bool    $echo
 *
 * @return string
 */
function nice_theme_pills_class( $class, $echo = false ) {
	return nice_prefix_class( 'pills', $class, $echo );
}
endif;
