<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains hooks to manage typography settings in the public-facing
 * side of the theme.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.6
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_custom_fonts' ) ) :
add_filter( 'nice_inline_styles', 'nice_custom_fonts' );
/**
 * Add custom fonts.
 *
 * @since 1.0.0
 *
 * @param string $inline_styles
 *
 * @return string
 */
function nice_custom_fonts( $inline_styles ) {
	// Obtain all breakpoints.
	$breakpoints = nice_responsive_breakpoints();

	// Initialize HTML output.
	$output = '';

	if ( nice_bool( nice_get_option( 'nice_header_menu_uppercase') ) ) {
		if ( ! nice_overlay_navigation() || nice_development_mode() ) {
			$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #navigation { text-transform: uppercase; } }' . "\n";
			$output .= '#navigation-extras { text-transform: uppercase; }' . "\n";
		}

		if ( nice_overlay_navigation() || nice_development_mode() ) {
			$output .= '#main-nav.overlay > .menu-item > a { text-transform: uppercase; }' . "\n";
		}

		$output .= '#header-search a.search { text-transform: uppercase; }' . "\n";
	}

	if ( nice_bool( nice_get_option( 'nice_header_submenu_uppercase') ) ) {
		if ( ! nice_overlay_navigation() || nice_development_mode() ) {
			$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #header #navigation #main-nav li > ul.sub-menu li a { text-transform: uppercase; } }' . "\n";
		}

		if ( nice_overlay_navigation() || nice_development_mode() ) {
			$output .= '#main-nav.overlay li > ul.sub-menu li a { text-transform: uppercase; }' . "\n";
		}
	}

	if ( nice_bool( nice_get_option( 'nice_custom_typography' ) ) ) {
		if ( $font_body = nice_get_option( 'nice_font_body' ) ) {
			$output .= 'body { ' . nice_custom_font_css( $font_body ) . ' }' . "\n";
			$output .= 'input, select, textarea {' . nice_custom_font_css( $font_body, array( 'include' => array( 'font-family', 'font-size' ) ) )  . '}' . "\n";
		}

		if ( $font_menu = nice_get_option( 'nice_font_menu' ) ) {
			$output .= '#navigation, #navigation-extras { ' . nice_custom_font_css( $font_menu ) . ' }' . "\n";
			$output .= '#top-bar { ' . nice_custom_font_css( $font_menu, array( 'exclude' => array( 'font-size' ) ) ) . ' }' . "\n";
		}

		if ( $font_submenu = nice_get_option( 'nice_font_submenu' ) ) {
			$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #navigation #main-nav li > ul.sub-menu li a { ' . nice_custom_font_css( $font_submenu, array( 'exclude' => array( 'letter-spacing' ) ) ) . ' } }' . "\n";
			$output .= '@media all and (min-width: ' . $breakpoints['desktop'] . 'px) { #top-nav li > ul.sub-menu li a { ' . nice_custom_font_css( $font_submenu, array( 'exclude' => array( 'letter-spacing', 'font-size' ) ) ) . ' } }' . "\n";
		}

		if ( $font_top_bar = nice_get_option( 'nice_font_top_bar' ) ) {
			$output .= '#top-bar { ' . nice_custom_font_css( $font_top_bar, array( 'exclude' => array( 'letter-spacing' ) ) ) . ' }' . "\n";
			$output .= '#top-nav li > ul.sub-menu li a { ' . nice_custom_font_css( $font_top_bar, array( 'exclude' => array( 'letter-spacing', 'font-size' ) ) ) . ' }' . "\n";
		}

		if ( ( nice_overlay_navigation() || nice_development_mode() ) && $font_overlay_menu = nice_get_option( 'nice_font_overlay_menu' ) ) {
			$output .= '#main-nav.overlay .menu-item a { ' . nice_custom_font_css( $font_overlay_menu ) . ' }' . "\n";
		}

		if ( $font_headings = nice_get_option( 'nice_font_headings' ) ) {
			$output .= 'h1, .h1, h2, .h2, h3, .h3, h4, .h4, h5, .h5, h6, .h6 { ' . nice_custom_font_css( $font_headings ) . ' }' . "\n";
			$output .= '.entry-title { ' . nice_custom_font_css( $font_headings, array( 'exclude' => array( 'letter-spacing' ) ) ) . ' }' . "\n";
			$output .= 'article.format-quote .quote { ' . nice_custom_font_css( $font_headings, array( 'exclude' => array( 'letter-spacing' ) ) ) . ' }' . "\n";
		}

		if ( $font_buttons = nice_get_option( 'nice_font_buttons' ) ) {
			$output .= 'button, input[type="button"], input[type="reset"], input[type="submit"], .btn, .button, .btn-link { ' . nice_custom_font_css( $font_buttons ) . ' }' . "\n";
		}

		if ( $font_secondary = nice_get_option( 'nice_font_secondary' ) ) {
			$output .= '#posts-ajax-loader-button, .comment-author .fn, .filter, #post-author .profile-link { ' . nice_custom_font_css( $font_buttons ) . ' }' . "\n";
			$output .= 'html .wp-pagenavi span, html .wp-pagenavi a, .nav-entries { ' . nice_custom_font_css( $font_buttons ) . ' }' . "\n";
		}
	}

	$heading_h1 = (array) nice_get_option( '_heading_h1', null );

	if ( ! empty( $heading_h1[0] ) ) {
		$heading_h1_value  = $heading_h1[0];
		$heading_h1_unit   = ( '' === $heading_h1[1] ) ? 'px' : $heading_h1[1];
		$output .= 'h1, .h1, body.single h1, body.single .h1, body.page h1, body.page .h1 { font-size: ' . $heading_h1_value . $heading_h1_unit . '; }' . "\n";
	}

	$heading_h2 = (array) nice_get_option( '_heading_h2', null );

	if ( ! empty( $heading_h2[0] ) ) {
		$heading_h2_value  = $heading_h2[0];
		$heading_h2_unit   = ( '' === $heading_h2[1] ) ? 'px' : $heading_h2[1];
		$output .= 'h2, .h2, body.single h2, body.single .h2, body.page h2, body.page .h2 { font-size: ' . $heading_h2_value . $heading_h2_unit . '; }' . "\n";
	}

	$heading_h3 = (array) nice_get_option( '_heading_h3', null );

	if ( ! empty( $heading_h3[0] ) ) {
		$heading_h3_value  = $heading_h3[0];
		$heading_h3_unit   = ( '' === $heading_h3[1] ) ? 'px' : $heading_h3[1];
		$output .= 'h3, .h3, body.single h3, body.single .h3, body.page h3, body.page .h3 { font-size: ' . $heading_h3_value . $heading_h3_unit . '; }' . "\n";
	}

	$heading_h4 = (array) nice_get_option( '_heading_h4', null );

	if ( ! empty( $heading_h4[0] ) ) {
		$heading_h4_value  = $heading_h4[0];
		$heading_h4_unit   = ( '' === $heading_h4[1] ) ? 'px' : $heading_h4[1];
		$output .= 'h4, .h4, body.single h4, body.single .h4, body.page h4, body.page .h4 { font-size: ' . $heading_h4_value . $heading_h4_unit . '; }' . "\n";
	}

	$heading_h5 = (array) nice_get_option( '_heading_h5', null );

	if ( ! empty( $heading_h5[0] ) ) {
		$heading_h5_value  = $heading_h5[0];
		$heading_h5_unit   = ( '' === $heading_h5[1] ) ? 'px' : $heading_h5[1];
		$output .= 'h5, .h5, body.single h5, body.single .h5, body.page h5, body.page .h5  { font-size: ' . $heading_h5_value . $heading_h5_unit . '; }' . "\n";
	}

	$heading_h6 = (array) nice_get_option( '_heading_h6', null );

	if ( ! empty( $heading_h6[0] ) ) {
		$heading_h6_value  = $heading_h6[0];
		$heading_h6_unit   = ( '' === $heading_h6[1] ) ? 'px' : $heading_h6[1];
		$output .= 'h6, .h6, body.single h6, body.single .h6, body.page h6, body.page .h6 { font-size: ' . $heading_h6_value . $heading_h6_unit . '; }' . "\n";
	}


	// Add Text title and tagline if text title option is enabled.
	if ( nice_bool( nice_get_option( 'nice_text_title' ) ) ) {
		$st = nice_get_option( 'nice_font_site_title' );
		$output .= '#header #logo.text a .text-logo { ' . nice_custom_font_css( $st ) . ' }' . "\n";
		$output .= '#header #logo.text .tagline { ' . nice_custom_font_css( nice_get_option( 'nice_font_tagline' ) ) . ' }' . "\n";
	}

	if ( ! empty( $output ) ) {
		$output = strip_tags( '/* Nice Custom Fonts */' . "\n\n" . $output );
		$inline_styles .= "\n" . $output;

	}
	return $inline_styles;
}
endif;

if ( ! function_exists( 'nice_theme_web_fonts' ) ) :
add_action( 'wp_enqueue_scripts', 'nice_theme_web_fonts' );
/**
 * Register the font stylesheet with the default web fonts.
 *
 * @since 1.0.0
 */
function nice_theme_web_fonts() {
	$web_fonts_uri = nice_get_web_fonts_uri();

	if ( ! $web_fonts_uri  ) {
		return;
	}

	wp_register_style( 'nice-theme-fonts', $web_fonts_uri );
	wp_enqueue_style ( 'nice-theme-fonts' );
}
endif;

if ( ! function_exists( 'nice_web_fonts_async_styles' ) ) :
add_filter( 'nice_theme_async_styles', 'nice_web_fonts_async_styles', 10, 2 );
/**
 * List of styles that can be loaded asynchronously.
 *
 * @since 1.0.0
 *
 * @param array $scripts
 * @param array $context
 *
 * @return array
 */
function nice_web_fonts_async_styles( $scripts = array(), $context = array() ) {
	static $added_scripts = array();

	if ( nice_load_async_styles() && nice_bool_option( '_async_google_fonts' ) ) {
		if ( ! in_array( 'nice-theme-fonts', $added_scripts, true ) ) {
			$added_scripts[] = 'nice-theme-fonts';
		}

		$href = isset( $context['href'] ) ? $context['href'] : null;
		$handle = isset( $context['handle'] ) ? $context['handle'] : null;

		if ( ! in_array( $handle, $added_scripts, true ) && stripos( $href, 'fonts.googleapis.com' ) ) {
			$added_scripts[] = $handle;
		}
	}

	$scripts = array_merge( $scripts, $added_scripts );

	return $scripts;
}
endif;
