<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the theme's setup.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.3
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_setup_development_mode' ) ) :
add_filter( 'nice_development_mode', 'nice_setup_development_mode' );
/**
 * Setup development mode.
 *
 * @since 1.0.0
 */
function nice_setup_development_mode() {
	return nice_bool_option( '_development_mode' );
}
endif;

if ( ! function_exists( 'nice_theme_textdomain' ) ) :
add_filter( 'nice_theme_textdomain', 'nice_theme_textdomain' );
/**
 * Setup the theme textdomain.
 *
 * @since 1.0.0
 *
 * @return string
 */
function nice_theme_textdomain() {
	return 'smart';
}
endif;

if ( ! function_exists( 'nice_theme_name' ) ) :
add_filter( '_nice_theme_name', 'nice_theme_name' );
/**
 * Setup the theme name.
 *
 * @since 1.0.3
 *
 * @return string
 */
function nice_theme_name() {
	return 'Smart';
}
endif;

if ( ! function_exists( 'nice_theme_slug' ) ) :
add_filter( '_nice_theme_slug', 'nice_theme_slug' );
/**
 * Setup the theme slug.
 *
 * @since 1.0.2
 *
 * @return string
 */
function nice_theme_slug() {
	return 'smart';
}
endif;

if ( ! function_exists( 'nice_theme_admin_menu_label' ) ) :
add_filter( 'nice_admin_menu_label', 'nice_theme_admin_menu_label' );
add_filter( 'nice_admin_bar_menu_label', 'nice_theme_admin_menu_label' );
/**
 * Set the Admin Menu label
 *
 * @since 1.0.0
 *
 * @return string
 */
function nice_theme_admin_menu_label() {
	return esc_html__( 'Smart', 'smart' );
}
endif;

if ( ! function_exists( 'nice_theme_setup' ) ) :
add_action( 'after_setup_theme', 'nice_theme_setup' );
/**
 * Basic setup for this theme.
 *
 * @since 1.0.0
 */
function nice_theme_setup() {
	add_theme_support( 'post-thumbnails' );

	$nice_image_sizes = array(
		'nice-slide' => array(
			'width'  => 1280,
			'height' => 580,
			'crop'   => false,
		),
		'nice-extra-large' => array(
			'width'  => 1600,
			'height' => 0,
			'crop'   => false,
		),
	);

	/**
	 * @hook nice_image_sizes
	 *
	 * Hook here to add image sizes.
	 *
	 * @since 1.0.0
	 */
	$nice_image_sizes = apply_filters( 'nice_image_sizes', $nice_image_sizes );

	// Image sizes.
	foreach ( $nice_image_sizes as $size => $image_data ) {
		add_image_size( $size, $image_data['width'], $image_data['height'], $image_data['crop'] );
	}

	// Supported post formats.
	add_theme_support( 'post-formats', array(
			'video',
			'image',
			'quote',
			'link',
			'gallery',
			'audio',
		)
	);

	// HTML5 supported elements.
	add_theme_support( 'html5', array(
			'search-form',
		)
	);

	// Add support for Customizer.
	add_theme_support( 'nice-customizer' );

	// Add support for title tag.
	add_theme_support( 'title-tag' );

	// Add support for Automatic feed links
	add_theme_support( 'automatic-feed-links' );

	if ( is_singular() ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
endif;

if ( ! function_exists( 'nice_wp_resize_crop_disable' ) ) :
add_filter( 'nice_option_nice_wp_resize_crop', 'nice_wp_resize_crop_disable' );
/**
 * Force crop functionality to always be disabled.
 *
 * @since 1.0.0
 */
function nice_wp_resize_crop_disable() {
	return false;
}
endif;
