<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage sidebars.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_sidebars_default' ) ) :
add_action( 'nice_register_sidebars', 'nice_sidebars_default', 10 );
/**
 * Register default sidebars.
 *
 * @since 1.0.0
 */
function nice_sidebars_default() {
	// Register the default sidebar for blog and index.php.
	register_sidebar(
		array(
			'name'          => esc_html__( 'Primary', 'smart' ),
			'id'            => 'primary',
			'description'   => esc_html__( 'Appears in the blog section of the site.', 'smart' ),
			'before_widget' => '<div class="box widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);

	// Register the default sidebar for Pages.
	register_sidebar(
		array(
			'name'          => esc_html__( 'Page', 'smart' ),
			'id'            => 'page',
			'description'   => esc_html__( 'Appears in the sidebar of the default page template.', 'smart' ),
			'before_widget' => '<div class="box widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);

	// Register the default sidebar for Pages.
	register_sidebar(
		array(
			'name'          => esc_html__( 'Contact', 'smart' ),
			'id'            => 'contact',
			'description'   => esc_html__( 'Appears in the sidebar of the contact page template.', 'smart' ),
			'before_widget' => '<div class="box widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);
}
endif;

if ( ! function_exists( 'nice_sidebars_footer' ) ) :
add_action( 'nice_register_sidebars', 'nice_sidebars_footer' );
/**
 * Register footer sidebars.
 *
 * @since 1.0.0
 */
function nice_sidebars_footer() {
	// Obtain number of footer columns. Default is 4.
	$nice_footer_columns = intval( nice_get_option( 'nice_footer_columns' ) );

	if ( 1 <= $nice_footer_columns ) {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer 1', 'smart' ),
				'id'            => 'footer-1',
				'description'   => esc_html__( 'Appears in the footer section of the site, the first column.', 'smart' ),
				'before_widget' => '<div class="box widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			)
		);
	}

	if ( 2 <= $nice_footer_columns ) {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer 2', 'smart' ),
				'id'            => 'footer-2',
				'description'   => esc_html__( 'Appears in the footer section of the site, the second column.', 'smart' ),
				'before_widget' => '<div class="box widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			)
		);
	}

	if ( 3 <= $nice_footer_columns ) {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer 3', 'smart' ),
				'id'            => 'footer-3',
				'description'   => esc_html__( 'Appears in the footer section of the site, the third column.', 'smart' ),
				'before_widget' => '<div class="box widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			)
		);
	}

	if ( 4 === $nice_footer_columns ) {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer 4', 'smart' ),
				'id'            => 'footer-4',
				'description'   => esc_html__( 'Appears in the footer section of the site, the fourth column.', 'smart' ),
				'before_widget' => '<div class="box widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			)
		);
	}
}
endif;
