<?php
/**
 * Smart by NiceThemes.
 *
 * This file contains functions to manage the different typography options.
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! function_exists( 'nice_set_default_web_fonts' ) ) :
add_filter( 'nice_web_fonts', 'nice_set_default_web_fonts' );
/**
 * Set default web fonts when none are defined.
 *
 * @since 1.0.0
 *
 * @param array $web_fonts
 *
 * @return array
 */
function nice_set_default_web_fonts( array $web_fonts = array() ) {
	if ( ! nice_bool_option( '_custom_typography' ) ) {
		$web_fonts = array_merge( $web_fonts, array(
				'Open Sans',
				'Poppins',
			)
		);
	}

	return $web_fonts;
}
endif;

if ( ! function_exists( 'nice_setup_web_fonts' ) ) :
add_filter( 'nice_use_web_font', 'nice_setup_web_fonts', 10, 3 );
/**
 * Check which web fonts should be loaded.
 *
 * @since  1.0.0
 *
 * @param  bool   $load
 * @param  string $key
 *
 * @return bool
 */
function nice_setup_web_fonts( $load, $key ) {
	switch ( $key ) {
		case 'nice_font_site_title':
			$load = nice_bool_option( '_text_title' );
			break;
		case 'nice_font_tagline':
			$load = nice_bool_option( '_text_title' ) && nice_bool_option( '_text_tagline' );
			break;
		case 'nice_font_overlay_menu':
			$load = 'overlay' === nice_get_option( '_header_navigation' ) && nice_bool_option( '_custom_typography' );
			break;
		default:
			$load = nice_bool_option( '_custom_typography' );
	}

	return $load;
}
endif;

if ( ! function_exists( 'nice_font_weight' ) ) :
/**
 * Return an array of the different font weight options
 *
 * @since  1.0.0
 *
 * @return array
 */
function nice_font_weight() {
	$font_weight = array(
		''  => esc_html__( 'Default CSS', 'smart' ),
		100 => esc_html__( '100', 'smart' ),
		200 => esc_html__( '200', 'smart' ),
		300 => esc_html__( '300', 'smart' ),
		400 => esc_html__( '400', 'smart' ),
		500 => esc_html__( '500', 'smart' ),
		600 => esc_html__( '600', 'smart' ),
		700 => esc_html__( '700', 'smart' ),
		800 => esc_html__( '800', 'smart' ),
		900 => esc_html__( '900', 'smart' ),
	);

	return $font_weight;
}
endif;
