<?php
/**
 * Smart by NiceThemes.
 *
 * Template Name: Blog - Masonry
 *
 * @package   Smart
 * @author    NiceThemes <hello@nicethemes.com>
 * @license   GPL-2.0+
 * @link      http://nicethemes.com/product/smart
 * @copyright 2017 NiceThemes
 * @since     1.0.0
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
?>

	<?php get_header(); ?>

	<?php
		/**
		 * @hook nice_blog_masonry_before
		 *
		 * Hook here to print HTML before the contents of the Masonry blog are
		 * printed.
		 *
		 * @since 1.0.0
		 */
		do_action( 'nice_blog_masonry_before' );
	?>

	<!-- BEGIN #content -->
	<section id="content" <?php nice_content_class( 'full-width blog-masonry ' . $post->post_name ); ?>>

		<?php if ( have_posts() ) : ?>

			<div id="masonry-grid" class="grid isotope-grid js-resize single-gutter-h single-gutter-v module-isotope style-default" data-layout-mode="masonry" data-columns="<?php echo esc_attr( nice_masonry_columns() ); ?>">

				<?php while ( have_posts() ) : the_post(); ?>

					<?php
						/**
						 * Load template for Masonry blog posts.
						 *
						 * @since 1.0.0
						 */
						get_template_part( 'template-parts/archive/content-masonry', get_post_format() );
					?>

				<?php endwhile; ?>

			</div>


		<?php else : ?>
				<?php esc_html_e( 'Sorry, no posts matched your criteria.', 'smart' ); ?>
		<?php endif; ?>

		<?php if ( nice_blog_masonry_show_load_more_button() ) : ?>
			<a href="#" id="posts-ajax-loader-button" title="<?php esc_attr_e( 'Load More', 'smart' ); ?>"><?php esc_html_e( 'Load More', 'smart' ); ?></a>
		<?php endif; ?>

		<div id="posts-ajax-loader">
			<?php if ( 'spin' === nice_get_option( '_masonry_posts_loader_icon', 'beat' ) ) : ?>
				<i class="fa fa-refresh fa-spin"></i>
			<?php else : ?>
				<div class="loader"></div>
			<?php endif; ?>
		</div>

	</section><!-- END #content -->

	<?php
		/**
		 * @hook nice_blog_masonry_after
		 *
		 * Hook here to print HTML after the contents of the Masonry blog are
		 * printed.
		 *
		 * @since 1.0.0
		 */
		do_action( 'nice_blog_masonry_after' );
	?>

	<?php get_footer(); ?>
